@@ -10,7 +10,6 @@ import org.basex.build.xml.*;
 import org.basex.core.*;
 import org.basex.core.cmd.*;
 import org.basex.data.*;
-import org.basex.data.atomic.*;
 import org.basex.io.*;
 import org.basex.util.*;
 import org.basex.util.list.*;
@@ -21,7 +20,7 @@ import org.xmldb.api.modules.*;
 /**
  * Implementation of the Collection Interface for the XMLDB:API.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class BXCollection implements Collection, BXXMLDBText {
@@ -34,17 +33,18 @@ public final class BXCollection implements Collection, BXXMLDBText {
    * Constructor to create/open a collection.
    * @param name name of the database
    * @param open open existing database
-   * @param d database context
+   * @param database database context
    * @throws XMLDBException exception
    */
-  public BXCollection(final String name, final boolean open, final Database d)
+  public BXCollection(final String name, final boolean open, final Database database)
       throws XMLDBException {
 
-    db = (BXDatabase) d;
+    db = (BXDatabase) database;
     ctx = db.ctx;
     try {
-      ctx.openDB(open ? Open.open(name, ctx) :
-        CreateDB.create(name, Parser.emptyParser(ctx.options), ctx));
+      final MainOptions opts = ctx.options;
+      ctx.openDB(open ? Open.open(name, ctx, opts) :
+        CreateDB.create(name, Parser.emptyParser(opts), ctx, opts));
     } catch(final IOException ex) {
       throw new XMLDBException(ErrorCodes.VENDOR_ERROR, ex.getMessage());
     }
@@ -65,12 +65,12 @@ public final class BXCollection implements Collection, BXXMLDBText {
   }
 
   @Override
-  public Service getService(final String nm, final String ver) throws XMLDBException {
+  public Service getService(final String name, final String version) throws XMLDBException {
     check();
-    if("1.0".equals(ver)) {
-      if(Token.eq(nm, BXQueryService.XPATH, BXQueryService.XQUERY))
-        return new BXQueryService(this, nm, ver);
-      if(nm.equals(BXCollectionManagementService.MANAGEMENT))
+    if("1.0".equals(version)) {
+      if(Strings.eq(name, BXQueryService.XPATH, BXQueryService.XQUERY))
+        return new BXQueryService(this, name, version);
+      if(name.equals(BXCollectionManagementService.MANAGEMENT))
         return new BXCollectionManagementService(this);
     }
     return null;
@@ -97,24 +97,24 @@ public final class BXCollection implements Collection, BXXMLDBText {
   @Override
   public String[] listChildCollections() throws XMLDBException {
     check();
-    return new String[] {};
+    return new String[0];
   }
 
   @Override
   public int getResourceCount() throws XMLDBException {
     check();
-    return ctx.data().resources.docs().size();
+    return ctx.data().meta.ndocs;
   }
 
   @Override
   public String[] listResources() throws XMLDBException {
     check();
-    final StringList sl = new StringList();
     final Data data = ctx.data();
-    final IntList il = data.resources.docs();
-    final int is = il.size();
-    for(int i = 0; i < is; i++) sl.add(Token.string(data.text(il.get(i), true)));
-    return sl.toArray();
+    final IntList docs = data.resources.docs();
+    final int ds = docs.size();
+    final StringList sl = new StringList(ds);
+    for(int d = 0; d < ds; d++) sl.add(Token.string(data.text(docs.get(d), true)));
+    return sl.finish();
   }
 
   @Override
@@ -122,7 +122,7 @@ public final class BXCollection implements Collection, BXXMLDBText {
     check();
 
     if(type.equals(XMLResource.RESOURCE_TYPE)) {
-      // create new id, if necessary
+      // create new id if necessary
       final String uid = id == null || id.isEmpty() ? createId() : id;
       return new BXXMLResource(null, 0, uid, this);
     }
@@ -144,10 +144,15 @@ public final class BXCollection implements Collection, BXXMLDBText {
     if(del.data != data && del.data != null) throw new XMLDBException(
         ErrorCodes.NO_SUCH_RESOURCE, ERR_UNKNOWN + data.meta.name);
 
-    if(!data.startUpdate()) throw new XMLDBException(ErrorCodes.VENDOR_ERROR, ERR_LOCK);
-    data.delete(getResource(del.getId()).pos);
-    ctx.update();
-    data.finishUpdate();
+    try {
+      data.startUpdate(ctx.options);
+      data.delete(getResource(del.getId()).pre);
+      ctx.invalidate();
+      data.finishUpdate(ctx.options);
+    } catch(final IOException ex) {
+      Util.debug(ex);
+      throw new XMLDBException(ErrorCodes.VENDOR_ERROR, ERR_LOCK);
+    }
   }
 
   @Override
@@ -165,7 +170,7 @@ public final class BXCollection implements Collection, BXXMLDBText {
 
     // document exists - delete old one first
     final Resource old = getResource(id);
-    if(old != null) removeResource(getResource(id));
+    if(old != null) removeResource(old);
 
     // create parser, dependent on input type
     final Object cont = xml.content;
@@ -182,10 +187,15 @@ public final class BXCollection implements Collection, BXXMLDBText {
     }
 
     final Data data = ctx.data();
-    if(!data.startUpdate()) throw new XMLDBException(ErrorCodes.VENDOR_ERROR, ERR_LOCK);
-    data.insert(data.meta.size, -1, new DataClip(md));
-    ctx.update();
-    data.finishUpdate();
+    try {
+      data.startUpdate(ctx.options);
+      data.insert(data.meta.size, -1, new DataClip(md));
+      ctx.invalidate();
+      data.finishUpdate(ctx.options);
+    } catch(final IOException ex) {
+      Util.debug(ex);
+      throw new XMLDBException(ErrorCodes.VENDOR_ERROR, ERR_LOCK);
+    }
   }
 
   @Override
@@ -219,21 +229,21 @@ public final class BXCollection implements Collection, BXXMLDBText {
   }
 
   @Override
-  public String getProperty(final String key) throws XMLDBException {
+  public String getProperty(final String name) throws XMLDBException {
     check();
     try {
-      return MetaData.class.getField(key).get(ctx.data().meta).toString();
+      return MetaData.class.getField(name).get(ctx.data().meta).toString();
     } catch(final Exception ex) {
       return null;
     }
   }
 
   @Override
-  public void setProperty(final String key, final String val) throws XMLDBException {
+  public void setProperty(final String name, final String val) throws XMLDBException {
     check();
     try {
       final MetaData md = ctx.data().meta;
-      final Field f = MetaData.class.getField(key);
+      final Field f = MetaData.class.getField(name);
       final Object k = f.get(md);
 
       if(k instanceof Boolean) {
@@ -246,7 +256,7 @@ public final class BXCollection implements Collection, BXXMLDBText {
         f.set(md, val);
       }
     } catch(final Exception ex) {
-      throw new XMLDBException(ErrorCodes.VENDOR_ERROR, ERR_PROP + key);
+      throw new XMLDBException(ErrorCodes.VENDOR_ERROR, ERR_PROP + name);
     }
   }
 
