@@ -2,7 +2,7 @@ package org.basex.api.xmldb;
 
 import java.util.*;
 
-import org.basex.data.*;
+import org.basex.query.value.*;
 import org.basex.util.*;
 import org.xmldb.api.base.*;
 import org.xmldb.api.base.Collection;
@@ -10,46 +10,47 @@ import org.xmldb.api.base.Collection;
 /**
  * Implementation of the ResourceSet Interface for the XMLDB:API.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 final class BXResourceSet implements ResourceSet, BXXMLDBText {
   /** Resources. */
-  private final ArrayList<Resource> res;
+  private final ArrayList<Resource> list;
   /** Collection reference. */
   private final Collection coll;
 
   /**
    * Default constructor with result.
-   * @param r result
-   * @param c collection
+   * @param result result
+   * @param coll collection
    */
-  BXResourceSet(final Result r, final Collection c) {
+  BXResourceSet(final Value result, final Collection coll) {
     // convert result into resource instances
-    res = new ArrayList<Resource>((int) r.size());
-    for(int s = 0; s < r.size(); ++s) res.add(new BXXMLResource(r, s, c));
-    coll = c;
+    final int rs = (int) result.size();
+    list = new ArrayList<>(rs);
+    for(int s = 0; s < rs; ++s) list.add(new BXXMLResource(result.itemAt(s), coll));
+    this.coll = coll;
   }
 
   @Override
-  public Resource getResource(final long i) throws XMLDBException {
-    if(i >= 0 && i < res.size()) return res.get((int) i);
+  public Resource getResource(final long index) throws XMLDBException {
+    if(index >= 0 && index < list.size()) return list.get((int) index);
     throw new XMLDBException(ErrorCodes.NO_SUCH_RESOURCE);
   }
 
   @Override
-  public void addResource(final Resource r) {
-    res.add(r);
+  public void addResource(final Resource resource) {
+    list.add(resource);
   }
 
   @Override
   public void removeResource(final long index) {
-    res.remove((int) index);
+    list.remove((int) index);
   }
 
   @Override
   public BXResourceIterator getIterator() {
-    return new BXResourceIterator(res);
+    return new BXResourceIterator(list);
   }
 
   @Override
@@ -63,11 +64,11 @@ final class BXResourceSet implements ResourceSet, BXXMLDBText {
 
   @Override
   public long getSize() {
-    return res.size();
+    return list.size();
   }
 
   @Override
   public void clear() {
-    res.clear();
+    list.clear();
   }
 }
