@@ -5,9 +5,9 @@ import java.util.*;
 import javax.servlet.http.*;
 
 /**
- * This class bundles context-based information on a single HTTP operation.
+ * This class creates and destroys HTTP sessions.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class SessionListener implements HttpSessionListener {
@@ -30,7 +30,7 @@ public final class SessionListener implements HttpSessionListener {
    * @return context;
    */
   public static synchronized HashMap<String, HttpSession> sessions() {
-    if(sessions == null) sessions = new HashMap<String, HttpSession>();
+    if(sessions == null) sessions = new HashMap<>();
     return sessions;
   }
 }
