@@ -1,5 +1,7 @@
 package org.basex.http.restxq;
 
+import static org.basex.http.restxq.RestXqText.*;
+
 import org.basex.http.*;
 import org.basex.query.*;
 
@@ -12,26 +14,36 @@ import org.basex.query.*;
  * <p>The implementation is based on Adam Retter's paper presented at XMLPrague 2012,
  * titled "RESTful XQuery - Standardised XQuery 3.0 Annotations for REST".</p>
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class RestXqServlet extends BaseXServlet {
   @Override
   protected void run(final HTTPContext http) throws Exception {
-    // authenticate user
-    http.authenticate();
+    // no trailing slash: send redirect
+    if(http.req.getPathInfo() == null) {
+      http.redirect("/");
+      return;
+    }
 
     // analyze input path
     final RestXqModules rxm = RestXqModules.get();
-    // select XQuery function
+
+    // initialize RESTXQ
+    if(http.path().equals("/" + INIT)) {
+      rxm.init();
+      return;
+    }
+
+    // select function that closest matches the request
     RestXqFunction func = rxm.find(http, null);
     if(func == null) throw HTTPCode.NO_XQUERY.get();
 
     try {
-      // process function that matches the current request
+      // process function
       func.process(http, null);
     } catch(final QueryException ex) {
-      // process optional error function
+      // run optional error function
       func = rxm.find(http, ex.qname());
       if(func == null) throw ex;
       func.process(http, ex);
