@@ -1,13 +1,9 @@
 package org.basex.http.webdav;
 
-import static org.basex.http.webdav.BXServletRequest.*;
-
 import javax.servlet.http.*;
 
 import org.basex.http.*;
-import org.basex.http.webdav.impl.ResourceMetaData;
-import org.basex.http.webdav.impl.ResourceMetaDataFactory;
-import org.basex.http.webdav.impl.WebDAVService;
+import org.basex.http.webdav.impl.*;
 import org.basex.server.*;
 import org.basex.util.*;
 
@@ -17,25 +13,26 @@ import com.bradmcevoy.http.*;
 /**
  * WebDAV resource factory. Main class for generating WebDAV resources.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Rositsa Shadura
  * @author Dimitar Popov
  */
-public final class BXResourceFactory implements ResourceFactory,
+final class BXResourceFactory implements ResourceFactory,
     ResourceMetaDataFactory<BXAbstractResource> {
 
-  /** HTTP Context. */
-  private final HTTPContext http;
+  /** Thread local variable to hold the current context. */
+  private static final ThreadLocal<HTTPContext> CONTEXTS = new ThreadLocal<>();
+
   /** WebDAV service. */
-  private final WebDAVService<BXAbstractResource> service;
+  private WebDAVService<BXAbstractResource> service;
 
   /**
-   * Constructor.
-   * @param ht http context
+   * Creates a new service.
+   * @param http http context
    */
-  BXResourceFactory(final HTTPContext ht) {
-    http = ht;
-    service = new WebDAVService<BXAbstractResource>(this, http);
+  void init(final HTTPContext http) {
+    service = new WebDAVService<>(this, http);
+    CONTEXTS.set(http);
   }
 
   /**
@@ -43,15 +40,13 @@ public final class BXResourceFactory implements ResourceFactory,
    */
   void close() {
     service.close();
+    CONTEXTS.remove();
   }
 
   @Override
   public Resource getResource(final String host, final String dbpath) {
-    final Auth a = HttpManager.request().getAuthorization();
-    if(a != null) http.credentials(a.getUser(), a.getPassword());
-
     try {
-      final HttpServletRequest r = getRequest();
+      final HttpServletRequest r = CONTEXTS.get().req;
       Path p = Path.path(dbpath);
       if(!r.getContextPath().isEmpty()) p = p.getStripFirst();
       if(!r.getServletPath().isEmpty()) p = p.getStripFirst();
