@@ -17,7 +17,7 @@ import org.basex.util.list.*;
 /**
  * This module contains functions for processing global sessions.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class Sessions extends QueryModule {
@@ -25,7 +25,7 @@ public final class Sessions extends QueryModule {
    * Returns the ids of all registered sessions.
    * @return session ids
    */
-  public Value ids() {
+  public static Value ids() {
     final HashMap<String, HttpSession> http = SessionListener.sessions();
     final TokenList tl = new TokenList(http.size());
     for(final String s : http.keySet()) tl.add(s);
@@ -86,7 +86,7 @@ public final class Sessions extends QueryModule {
    * @return session attribute
    * @throws QueryException query exception
    */
-  private Item get(final Str id, final Str key, final Item def) throws QueryException {
+  public Item get(final Str id, final Str key, final Item def) throws QueryException {
     final Object o = session(id).getAttribute(key.toJava());
     if(o == null) return def;
     if(o instanceof Item) return (Item) o;
