@@ -1,5 +1,6 @@
 package org.expath.ns;
 
+import static org.basex.query.QueryError.*;
 import static org.basex.util.Token.*;
 
 import java.io.*;
@@ -8,7 +9,6 @@ import org.basex.build.*;
 import org.basex.build.xml.*;
 import org.basex.io.*;
 import org.basex.query.*;
-import org.basex.query.util.*;
 import org.basex.query.value.item.*;
 import org.basex.query.value.node.*;
 import org.basex.query.value.type.*;
@@ -20,14 +20,14 @@ import com.vividsolutions.jts.io.gml2.*;
 /**
  * This module contains geo spatial functions for the Geo module.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Masoumeh Seydi
  */
 public final class Geo extends QueryModule {
   /** GML URI. */
   private static final byte[] URI = token("http://www.opengis.net/gml");
   /** Prefix: "gml". */
-  private static final String GML = "gml";
+  private static final byte[] GML = token("gml");
 
   /** QName gml:Point. */
   private static final QNm Q_GML_POINT = QNm.get(GML, "Point", URI);
@@ -69,7 +69,7 @@ public final class Geo extends QueryModule {
    */
   @Deterministic
   public QNm geometryType(final ANode node) throws QueryException {
-    return new QNm(GML + ':' + checkGeo(node).getGeometryType(), URI);
+    return QNm.get(GML, checkGeo(node).getGeometryType(), URI);
   }
 
   /**
@@ -125,7 +125,9 @@ public final class Geo extends QueryModule {
    */
   @Deterministic
   public Bln isEmpty(final ANode node) throws QueryException {
-    return Bln.get(node != null && checkGeo(node) != null);
+    if(node == null) return Bln.FALSE;
+    checkGeo(node);
+    return Bln.TRUE;
   }
 
   /**
@@ -418,10 +420,7 @@ public final class Geo extends QueryModule {
    */
   @Deterministic
   public Dbl x(final ANode node) throws QueryException {
-    final Geometry geo = geo(node, Q_GML_POINT);
-    if(geo == null && checkGeo(node) != null)
-      throw GeoErrors.geoType(node.qname().local(), "Point");
-
+    final Geometry geo = geo(node, "Point", Q_GML_POINT);
     return Dbl.get(geo.getCoordinate().x);
   }
 
@@ -433,10 +432,7 @@ public final class Geo extends QueryModule {
    */
   @Deterministic
   public Dbl y(final ANode node) throws QueryException {
-    final Geometry geo = geo(node, Q_GML_POINT);
-    if(geo == null && checkGeo(node) != null)
-      throw GeoErrors.geoType(node.qname().local(), "Point");
-
+    final Geometry geo = geo(node, "Point", Q_GML_POINT);
     return Dbl.get(geo.getCoordinate().y);
   }
 
@@ -448,10 +444,7 @@ public final class Geo extends QueryModule {
    */
   @Deterministic
   public Dbl z(final ANode node) throws QueryException {
-    final Geometry geo = geo(node, Q_GML_POINT);
-    if(geo == null && checkGeo(node) != null)
-      throw GeoErrors.geoType(node.qname().local(), "Line");
-
+    final Geometry geo = geo(node, "Point", Q_GML_POINT);
     return Dbl.get(geo.getCoordinate().z);
   }
 
@@ -475,10 +468,7 @@ public final class Geo extends QueryModule {
    */
   @Deterministic
   public ANode startPoint(final ANode node) throws QueryException {
-    final Geometry geo = geo(node, Q_GML_LINEARRING, Q_GML_LINESTRING);
-    if(geo == null && checkGeo(node) != null)
-      throw GeoErrors.geoType(node.qname().local(), "Line");
-
+    final Geometry geo = geo(node, "Line", Q_GML_LINEARRING, Q_GML_LINESTRING);
     return gmlWriter(((LineString) geo).getStartPoint());
   }
 
@@ -490,10 +480,7 @@ public final class Geo extends QueryModule {
    */
   @Deterministic
   public ANode endPoint(final ANode node) throws QueryException {
-    final Geometry geo = geo(node, Q_GML_LINEARRING, Q_GML_LINESTRING);
-    if(geo == null && checkGeo(node) != null)
-      throw GeoErrors.geoType(node.qname().local(), "Line");
-
+    final Geometry geo = geo(node, "Line", Q_GML_LINEARRING, Q_GML_LINESTRING);
     return gmlWriter(((LineString) geo).getEndPoint());
   }
 
@@ -506,10 +493,8 @@ public final class Geo extends QueryModule {
    */
   @Deterministic
   public Bln isClosed(final ANode node) throws QueryException {
-    final Geometry geo = geo(node, Q_GML_LINEARRING, Q_GML_LINESTRING, Q_GML_MULTILINESTRING);
-    if(geo == null && checkGeo(node) != null)
-      throw GeoErrors.geoType(node.qname().local(), "Line");
-
+    final Geometry geo = geo(node, "Line",
+        Q_GML_LINEARRING, Q_GML_LINESTRING, Q_GML_MULTILINESTRING);
     return Bln.get(geo instanceof LineString ? ((LineString) geo).isClosed() :
       ((MultiLineString) geo).isClosed());
   }
@@ -523,10 +508,7 @@ public final class Geo extends QueryModule {
    */
   @Deterministic
   public Bln isRing(final ANode node) throws QueryException {
-    final Geometry geo = geo(node, Q_GML_LINEARRING, Q_GML_LINESTRING);
-    if(geo == null && checkGeo(node) != null)
-      throw GeoErrors.geoType(node.qname().local(), "Line");
-
+    final Geometry geo = geo(node, "Line", Q_GML_LINEARRING, Q_GML_LINESTRING);
     return Bln.get(((LineString) geo).isRing());
   }
 
@@ -550,10 +532,7 @@ public final class Geo extends QueryModule {
    */
   @Deterministic
   public ANode pointN(final ANode node, final Int number) throws QueryException {
-    final Geometry geo = geo(node, Q_GML_LINEARRING, Q_GML_LINESTRING);
-    if(geo == null && checkGeo(node) != null)
-      throw GeoErrors.geoType(node.qname().local(), "Line");
-
+    final Geometry geo = geo(node, "Line", Q_GML_LINEARRING, Q_GML_LINESTRING);
     final int max = geo.getNumPoints();
     final long n = number.itr();
     if(n < 1 || n > max) throw GeoErrors.outOfRangeIdx(number);
@@ -605,10 +584,7 @@ public final class Geo extends QueryModule {
    */
   @Deterministic
   public ANode exteriorRing(final ANode node) throws QueryException {
-    final Geometry geo = geo(node, Q_GML_POLYGON);
-    if(geo == null && checkGeo(node) != null)
-      throw GeoErrors.geoType(node.qname().local(), "Polygon");
-
+    final Geometry geo = geo(node, "Polygon", Q_GML_POLYGON);
     return gmlWriter(((Polygon) geo).getExteriorRing());
   }
 
@@ -620,10 +596,7 @@ public final class Geo extends QueryModule {
    */
   @Deterministic
   public Int numInteriorRing(final ANode node) throws QueryException {
-    final Geometry geo = geo(node, Q_GML_POLYGON);
-    if(geo == null && checkGeo(node) != null)
-      throw GeoErrors.geoType(node.qname().local(), "Polygon");
-
+    final Geometry geo = geo(node, "Polygon", Q_GML_POLYGON);
     return Int.get(((Polygon) geo).getNumInteriorRing());
   }
 
@@ -636,10 +609,7 @@ public final class Geo extends QueryModule {
    */
   @Deterministic
   public ANode interiorRingN(final ANode node, final Int number) throws QueryException {
-    final Geometry geo = geo(node, Q_GML_POLYGON);
-    if(geo == null && checkGeo(node) != null)
-      throw GeoErrors.geoType(node.qname().local(), "Polygon");
-
+    final Geometry geo = geo(node, "Polygon", Q_GML_POLYGON);
     final long n = number.itr();
     final int max = ((Polygon) geo).getNumInteriorRing();
     if(n < 1 || n > max) throw GeoErrors.outOfRangeIdx(number);
@@ -655,22 +625,43 @@ public final class Geo extends QueryModule {
    * @return geometry
    * @throws QueryException query exception
    */
-  private Geometry checkGeo(final ANode node) throws QueryException {
+  private static Geometry checkGeo(final ANode node) throws QueryException {
     final Geometry geo = geo(node, QNAMES);
     if(geo == null) throw GeoErrors.unrecognizedGeo(node.qname().local());
     return geo;
   }
 
   /**
-   * Reads an element as a gml node. Returns a geometry element
-   * or {@code null} if the element does not match one of the specified types.
+   * Reads an element as a gml node. Returns a geometry element or raises an error if the element
+   * does not match one of the specified types.
+   * @param node xml node containing gml object(s)
+   * @param type expected type (can be {@code null})
+   * @param names allowed geometry types
+   * @return geometry, or {@code null}
+   * @throws QueryException query exception
+   */
+  private static Geometry geo(final ANode node, final String type, final QNm... names)
+      throws QueryException {
+
+    final Geometry geo = geo(node, names);
+    if(geo == null) {
+      checkGeo(node);
+      throw GeoErrors.geoType(node.qname().local(), type);
+    }
+    return geo;
+  }
+
+  /**
+   * Reads an element as a gml node. Returns a geometry element or {@code null}.
    * @param node xml node containing gml object(s)
    * @param names allowed geometry types
    * @return geometry, or {@code null}
    * @throws QueryException query exception
    */
-  private Geometry geo(final ANode node, final QNm... names) throws QueryException {
-    if(node.type != NodeType.ELM) throw Err.FUNCMP.get(null, this, NodeType.ELM, node.type);
+  private static Geometry geo(final ANode node, final QNm... names)
+      throws QueryException {
+
+    if(node.type != NodeType.ELM) throw EXPTYPE_X_X_X.get(null, NodeType.ELM, node.type, node);
 
     final QNm qname = node.qname();
     for(final QNm geo : names) {
@@ -708,7 +699,7 @@ public final class Geo extends QueryModule {
       final IO io = new IOContent(geo);
       return new DBNode(MemBuilder.build(new XMLParser(io, queryContext.context.options)));
     } catch(final IOException ex) {
-      throw Err.IOERR.get(null, ex);
+      throw IOERR_X.get(null, ex);
     }
   }
 }
\ No newline at end of file
