@@ -9,7 +9,7 @@ import org.basex.query.*;
 /**
  * This class contains some methods for performing advanced query tests.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public abstract class AdvancedQueryTest extends SandboxTest {
@@ -19,19 +19,17 @@ public abstract class AdvancedQueryTest extends SandboxTest {
    * @return result
    */
   private static String query(final String query) {
-    final QueryProcessor qp = new QueryProcessor(query, context);
-    try {
+    try(final QueryProcessor qp = new QueryProcessor(query, context)) {
       final ArrayOutput ao = new ArrayOutput();
-      final Serializer ser = qp.getSerializer(ao);
-      qp.execute().serialize(ser);
-      ser.close();
+      try(final Serializer ser = qp.getSerializer(ao)) {
+        qp.value().serialize(ser);
+      }
       return ao.toString().replaceAll("(\\r|\\n)\\s*", "");
     } catch(final Exception ex) {
+      ex.printStackTrace();
       final AssertionError err = new AssertionError("Query failed:\n" + query);
       err.initCause(ex);
       throw err;
-    } finally {
-      qp.close();
     }
   }
 
