@@ -6,10 +6,10 @@ import org.junit.*;
 /**
  * This class tests the embedded HTTP Client.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Rositsa Shadura
  */
-public class ServerFnHttpTest extends FnHttpTest {
+public final class ServerFnHttpTest extends FnHttpTest {
   /**
    * Start server.
    * @throws Exception exception
