@@ -5,16 +5,16 @@ import org.junit.*;
 /**
  * This class tests the server-based REST API.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
-public class ServerRESTTest extends RESTTest {
+public final class ServerRESTTest extends RESTTest {
   /**
    * Start server.
    * @throws Exception exception
    */
   @BeforeClass
   public static void start() throws Exception {
-    init(ROOT, false);
+    init(REST_ROOT, false);
   }
 }
