@@ -1,6 +1,6 @@
 package org.expath.ns;
 
-import static org.basex.query.util.Err.*;
+import static org.basex.query.QueryError.*;
 import static org.junit.Assert.*;
 
 import org.basex.AdvancedQueryTest;
@@ -11,7 +11,7 @@ import org.junit.*;
 /**
  * This class tests the XQuery Geo functions prefixed with "geo".
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Masoumeh Seydi
  */
 public final class GeoTest extends AdvancedQueryTest {
@@ -21,7 +21,7 @@ public final class GeoTest extends AdvancedQueryTest {
     run("geo:dimension(" +
             "<gml:Point><gml:coordinates>1,2</gml:coordinates></gml:Point>)", "0");
 
-    error("geo:dimension(text {'a'})", FUNCMP.qname());
+    error("geo:dimension(text {'a'})", EXPTYPE_X_X_X.qname());
     error("geo:dimension(<gml:unknown/>)", GeoErrors.qname(1));
     error("geo:dimension(<gml:Point>" +
             "<gml:coordinates>1 2</gml:coordinates></gml:Point>)",
@@ -36,7 +36,7 @@ public final class GeoTest extends AdvancedQueryTest {
             "<gml:Point><gml:coordinates>1,2</gml:coordinates></gml:Point>" +
             "</gml:MultiPoint>)", "gml:MultiPoint");
 
-    error("geo:geometryType(text {'srsName'})", FUNCMP.qname());
+    error("geo:geometryType(text {'srsName'})", EXPTYPE_X_X_X.qname());
     error("geo:geometryType(<gml:unknown/>)", GeoErrors.qname(1));
     error("geo:geometryType(<gml:Point><gml:coordinates>1 2</gml:coordinates>" +
             "</gml:Point>)", GeoErrors.qname(2));
@@ -51,7 +51,7 @@ public final class GeoTest extends AdvancedQueryTest {
             "-150,50 -150,60 -125,60 -125,50 -150,50" +
             "</coordinates></gml:LinearRing></outerboundaryIs></gml:Polygon>)", "0");
 
-    error("geo:srid(text {'a'})", FUNCMP.qname());
+    error("geo:srid(text {'a'})", EXPTYPE_X_X_X.qname());
     error("geo:srid(<gml:unknown/>)", GeoErrors.qname(1));
     error("geo:srid(<gml:LinearRing><gml:pos>1,1 20,1 50,30 1,1</gml:pos>" +
             "</gml:LinearRing>)", GeoErrors.qname(2));
@@ -67,7 +67,7 @@ public final class GeoTest extends AdvancedQueryTest {
             "<gml:coordinates>1.0,1.0 1.0,30.0 50.0,30.0 50.0,1.0 1.0,1.0" +
             "</gml:coordinates></gml:LinearRing></gml:outerBoundaryIs></gml:Polygon>");
 
-    error("geo:envelope(text {'a'})", FUNCMP.qname());
+    error("geo:envelope(text {'a'})", EXPTYPE_X_X_X.qname());
     error("geo:envelope(<gml:unknown/>)", GeoErrors.qname(1));
     error("geo:envelope(<gml:LinearRing><gml:pos>1,1 20,1 50,30 1,1</gml:pos>" +
             "</gml:LinearRing>)", GeoErrors.qname(2));
@@ -79,7 +79,7 @@ public final class GeoTest extends AdvancedQueryTest {
     run("geo:asText(<gml:LineString><gml:coordinates>1,1 55,99 2,1" +
             "</gml:coordinates></gml:LineString>)", "LINESTRING (1 1, 55 99, 2 1)");
 
-    error("geo:asText(text {'a'})", FUNCMP.qname());
+    error("geo:asText(text {'a'})", EXPTYPE_X_X_X.qname());
     error("geo:asText(<gml:unknown/>)", GeoErrors.qname(1));
     error("geo:asText(<gml:LineString><gml:coordinates>1,1</gml:coordinates>" +
             "</gml:LineString>)", GeoErrors.qname(2));
@@ -92,7 +92,7 @@ public final class GeoTest extends AdvancedQueryTest {
             "</gml:coordinates></gml:LineString>)",
           "AAAAAAIAAAADP/AAAAAAAAA/8AAAAAAAAEBLgAAAAAAAQFjAAAAAAABAAAAAAAAAAD/wAAAAAAAA");
 
-    error("geo:asBinary(text {'a'})", FUNCMP.qname());
+    error("geo:asBinary(text {'a'})", EXPTYPE_X_X_X.qname());
     error("geo:asBinary(<gml:unknown/>)", GeoErrors.qname(1));
     error("geo:asBinary(<gml:LinearRing><gml:coordinates>1,1 55,99 2,1" +
             "</gml:coordinates></gml:LinearRing>)", GeoErrors.qname(2));
@@ -104,7 +104,7 @@ public final class GeoTest extends AdvancedQueryTest {
     run("geo:isSimple(<gml:LineString><gml:coordinates>1,1 20,1 10,4 20,-10" +
             "</gml:coordinates></gml:LineString>)", "false");
 
-    error("geo:isSimple(text {'a'})", FUNCMP.qname());
+    error("geo:isSimple(text {'a'})", EXPTYPE_X_X_X.qname());
     error("geo:isSimple(<gml:unknown/>)", GeoErrors.qname(1));
     error("geo:isSimple(<gml:LinearRing><gml:coordinates>1,1 55,99 2,1" +
             "</gml:coordinates></gml:LinearRing>)", GeoErrors.qname(2));
@@ -123,8 +123,8 @@ public final class GeoTest extends AdvancedQueryTest {
     run("geo:boundary(" +
         "<gml:Point><gml:coordinates>2,3</gml:coordinates></gml:Point>)",
         "<gml:MultiGeometry xmlns:gml=\"http://www.opengis.net/gml\"/>");
-    error("geo:boundary(text {'a'})", FUNCMP.qname());
-    error("geo:boundary(a)", NOCTX.qname());
+    error("geo:boundary(text {'a'})", EXPTYPE_X_X_X.qname());
+    error("geo:boundary(a)", NOCTX_X.qname());
     error("geo:boundary(<gml:geo/>)", GeoErrors.qname(1));
     error("geo:boundary(<gml:Point><gml:pos>1 2</gml:pos></gml:Point>)",
         GeoErrors.qname(2));
@@ -139,7 +139,7 @@ public final class GeoTest extends AdvancedQueryTest {
             "<gml:coordinates>1,1 2,1 5,3 1,1</gml:coordinates></gml:LinearRing>" +
             "</gml:outerBoundaryIs></gml:Polygon>)", "false");
 
-    error("geo:equals(text {'a'}, a)", NOCTX.qname());
+    error("geo:equals(text {'a'}, a)", NOCTX_X.qname());
     error("geo:equals(<gml:unknown/>, <gml:LinearRing><gml:coordinates>" +
             "1,1 2,1 5,3 1,1</gml:coordinates></gml:LinearRing>)", GeoErrors.qname(1));
     error("geo:equals(<gml:LinearRing><gml:coordinates>1,1 55,99 2,1" +
@@ -158,12 +158,12 @@ public final class GeoTest extends AdvancedQueryTest {
             "<gml:LineString><gml:coordinates>0,0 2,1 3,3</gml:coordinates>" +
             "</gml:LineString>)", "false");
 
-    error("geo:disjoint(a, text {'a'})", NOCTX.qname());
+    error("geo:disjoint(a, text {'a'})", NOCTX_X.qname());
     error("geo:disjoint(<gml:Ring/>, " +
             "<gml:LinearRing><gml:coordinates>1,1 2,1 5,3 1,1</gml:coordinates>" +
             "</gml:LinearRing>)", GeoErrors.qname(1));
     error("geo:disjoint(<gml:LineString><gml:coordinates></gml:coordinates>" +
-                  "</gml:LineString>)", FUNCARGSG.qname());
+                  "</gml:LineString>)", FUNCARGNUM_X_X_X.qname());
   }
 
   /** Test method. */
@@ -175,7 +175,7 @@ public final class GeoTest extends AdvancedQueryTest {
             "</gml:MultiLineString>, <gml:LineString><gml:coordinates>0,0 2,1 3,3" +
             "</gml:coordinates></gml:LineString>)", "true");
 
-    error("geo:intersects(a, text {'a'})", NOCTX.qname());
+    error("geo:intersects(a, text {'a'})", NOCTX_X.qname());
     error("geo:intersects(<gml:Point><gml:coordinates>10,10 12,11</gml:coordinates>" +
             "</gml:Point>, <gml:LinearRing><gml:coordinates>1,1 2,1 5,3 1,1" +
             "</gml:coordinates></gml:LinearRing>)", GeoErrors.qname(2));
@@ -193,7 +193,7 @@ public final class GeoTest extends AdvancedQueryTest {
         "</gml:MultiLineString>, <gml:LineString><gml:coordinates>0,0 2,1 3,3" +
         "</gml:coordinates></gml:LineString>)", "false");
 
-    error("geo:touches(a, text {'a'})", NOCTX.qname());
+    error("geo:touches(a, text {'a'})", NOCTX_X.qname());
     error("geo:touches(<gml:Point><gml:coordinates>10,10 12,11</gml:coordinates>" +
             "</gml:Point>, <gml:LinearRing><gml:coordinates>1,1 2,1 5,3 1,1" +
             "</gml:coordinates></gml:LinearRing>)", GeoErrors.qname(2));
@@ -210,13 +210,13 @@ public final class GeoTest extends AdvancedQueryTest {
         "<gml:LineString><gml:coordinates>0,0 2,2</gml:coordinates></gml:LineString>)",
         "false");
 
-    error("geo:crosses(a, text {'a'})", NOCTX.qname());
+    error("geo:crosses(a, text {'a'})", NOCTX_X.qname());
     error("geo:crosses(<gml:Point><gml:coordinates>10,10 12,11" +
             "</gml:coordinates></gml:Point>, " +
             "<gml:LinearRing><gml:coordinates>1,1 2,1 5,3 1,1</gml:coordinates>" +
             "</gml:LinearRing>)", GeoErrors.qname(2));
     error("geo:crosses(<gml:Point><gml:coordinates>1,1</gml:coordinates></gml:Point>)",
-            FUNCARGSG.qname());
+            FUNCARGNUM_X_X_X.qname());
   }
 
   /** Test method. */
@@ -227,13 +227,13 @@ public final class GeoTest extends AdvancedQueryTest {
             "<gml:LinearRing><gml:coordinates>1,1 20,1 50,30 1,1</gml:coordinates>" +
             "</gml:LinearRing>)", "false");
 
-    error("geo:within()", FUNCARGSG.qname());
+    error("geo:within()", FUNCARGNUM_X_X_X.qname());
     error("geo:within(" +
             "<gml:unknown><gml:coordinates>1,1</gml:coordinates></gml:unknown>, " +
             "<gml:LinearRing><gml:coordinates>1,1 2,1 5,3 1,1" +
             "</gml:coordinates></gml:LinearRing>)", GeoErrors.qname(1));
     error("geo:within(<gml:Point><gml:coordinates>1,1</gml:coordinates></gml:Point>)",
-            FUNCARGSG.qname());
+            FUNCARGNUM_X_X_X.qname());
   }
 
   /** Test method. */
@@ -244,14 +244,14 @@ public final class GeoTest extends AdvancedQueryTest {
             "<gml:Point><gml:coordinates>1.00,1.00</gml:coordinates></gml:Point>)",
             "true");
 
-    error("geo:contains()", FUNCARGSG.qname());
+    error("geo:contains()", FUNCARGNUM_X_X_X.qname());
     error("geo:contains(" +
             "<gml:Point><gml:coordinates>1,1</gml:coordinates></gml:Point>, " +
             "<gml:Line><gml:coordinates>1,1 2,1 5,3 1,1</gml:coordinates></gml:Line>)",
             GeoErrors.qname(1));
     error("geo:contains(" +
             "<gml:Point><gml:coordinates>1,1</gml:coordinates></gml:Point>)",
-            FUNCARGSG.qname());
+            FUNCARGNUM_X_X_X.qname());
   }
 
   /** Test method. */
@@ -262,13 +262,13 @@ public final class GeoTest extends AdvancedQueryTest {
             "</gml:LineString>, <gml:LineString><gml:coordinates>1,1 55,0" +
             "</gml:coordinates></gml:LineString>)", "false");
 
-    error("geo:overlaps()", FUNCARGSG.qname());
+    error("geo:overlaps()", FUNCARGNUM_X_X_X.qname());
     error("geo:overlaps(<gml:LineString><gml:coordinates>1,1 55,99 2,1" +
             "</gml:coordinates></gml:LineString>," +
             "<gml:LineString></gml:LineString>)", GeoErrors.qname(2));
     error("geo:overlaps(" +
             "<gml:unknown><gml:coordinates>1,1</gml:coordinates></gml:unknown>)",
-            FUNCARGSG.qname());
+            FUNCARGNUM_X_X_X.qname());
   }
 
   /** Test method. */
@@ -282,20 +282,20 @@ public final class GeoTest extends AdvancedQueryTest {
 
     error("geo:relate(<gml:Point><gml:coordinates>18,11</gml:coordinates></gml:Point>,"
           + "<gml:LineString><gml:coordinates>11,10 20,1 20,20</gml:coordinates>" +
-            "</gml:LineString>, \"0******\")", FUNCMP.qname());
+            "</gml:LineString>, \"0******\")", EXPTYPE_X_X_X.qname());
 
     error("geo:relate(" +
             "<gml:Point><gml:coordinates>18,11</gml:coordinates></gml:Point>," +
             "<gml:LineString><gml:coordinates>11,10 20,1 20,20</gml:coordinates>" +
-            "</gml:LineString>, \"0*******12*F\")", FUNCMP.qname());
+            "</gml:LineString>, \"0*******12*F\")", EXPTYPE_X_X_X.qname());
 
-    error("geo:relate()", FUNCARGSG.qname());
+    error("geo:relate()", FUNCARGNUM_X_X_X.qname());
     error("geo:relate(" +
             "<gml:Line><gml:coordinates>1,1 55,99 2,1</gml:coordinates></gml:Line>," +
             "<gml:LineString></gml:LineString>, \"0********\")", GeoErrors.qname(1));
     error("geo:relate(" +
             "<gml:Point><gml:coordinates>1,1</gml:coordinates></gml:Point>," +
-            " \"0********\")", FUNCARGSG.qname());
+            " \"0********\")", FUNCARGNUM_X_X_X.qname());
   }
 
   /** Test method. */
@@ -307,13 +307,13 @@ public final class GeoTest extends AdvancedQueryTest {
             "10,10 20,10 30,40 20,40 10,10</gml:coordinates></gml:LinearRing>" +
             "</gml:outerBoundaryIs></gml:Polygon>)", "60");
 
-    error("geo:distance()", FUNCARGSG.qname());
+    error("geo:distance()", FUNCARGNUM_X_X_X.qname());
     error("geo:distance(" +
             "<gml:LinearRing><gml:coordinates>1,1 55,99 2,1</gml:coordinates>" +
             "</gml:LinearRing>, <gml:LineString></gml:LineString>)", GeoErrors.qname(2));
     error("geo:distance(" +
             "<gml:Point><gml:coordinates>1,1</gml:coordinates></gml:Point>)",
-            FUNCARGSG.qname());
+            FUNCARGNUM_X_X_X.qname());
   }
 
   /** Test method. */
@@ -336,8 +336,8 @@ public final class GeoTest extends AdvancedQueryTest {
             "<gml:LinearRing><gml:coordinates>1,1 55,99 2,1</gml:coordinates>" +
             "</gml:LinearRing>, xs:double(1))", GeoErrors.qname(2));
     error("geo:buffer(<gml:LinearRing><gml:coordinates>1,1 55,99 1,1" +
-            "</gml:coordinates></gml:LinearRing>, 1)", FUNCMP.qname());
-    error("geo:buffer(xs:double(1))", FUNCARGSG.qname());
+            "</gml:coordinates></gml:LinearRing>, 1)", EXPTYPE_X_X_X.qname());
+    error("geo:buffer(xs:double(1))", FUNCARGNUM_X_X_X.qname());
   }
 
   /** Test method. */
@@ -352,7 +352,7 @@ public final class GeoTest extends AdvancedQueryTest {
 
     error("geo:convexHull(<gml:LinearRing><gml:coordinates>1,1 55,99 1,1" +
             "</gml:coordinates></gml:LinearRing>)", GeoErrors.qname(2));
-    error("geo:convexHull()", FUNCARGSG.qname());
+    error("geo:convexHull()", FUNCARGNUM_X_X_X.qname());
     error("geo:convexHull(<gml:LinearRing/>)", GeoErrors.qname(2));
   }
 
@@ -374,7 +374,7 @@ public final class GeoTest extends AdvancedQueryTest {
             "<gml:coordinates>2.0,3.0</gml:coordinates></gml:Point>");
 
     error("geo:intersection(<gml:LinearRing><gml:coordinates></gml:coordinates>" +
-            "</gml:LinearRing>)", FUNCARGSG.qname());
+            "</gml:LinearRing>)", FUNCARGNUM_X_X_X.qname());
     error("geo:intersection(<gml:Geo><gml:coordinates>2,3</gml:coordinates>" +
             "</gml:Geo>,<gml:Point><gml:coordinates>2,3</gml:coordinates></gml:Point>)",
             GeoErrors.qname(1));
@@ -404,7 +404,7 @@ public final class GeoTest extends AdvancedQueryTest {
             "<gml:Point><gml:coordinates>2,3</gml:coordinates></gml:Point>)",
             GeoErrors.qname(2));
     error("geo:union(text {'a'}, <gml:Point><gml:coordinates>2,3" +
-            "</gml:coordinates></gml:Point>)", FUNCMP.qname());
+            "</gml:coordinates></gml:Point>)", EXPTYPE_X_X_X.qname());
   }
 
   /** Test method. */
@@ -422,7 +422,7 @@ public final class GeoTest extends AdvancedQueryTest {
         "<gml:Point><gml:coordinates>2,3</gml:coordinates></gml:Point>)",
         GeoErrors.qname(2));
     error("geo:difference(text {'a'}, <gml:Point><gml:coordinates>2,3" +
-        "</gml:coordinates></gml:Point>)", FUNCMP.qname());
+        "</gml:coordinates></gml:Point>)", EXPTYPE_X_X_X.qname());
   }
 
   /** Test method. */
@@ -445,7 +445,7 @@ public final class GeoTest extends AdvancedQueryTest {
             GeoErrors.qname(1));
 
     error("geo:symDifference(text {'a'}, <gml:Point><gml:coordinates>2,3" +
-            "</gml:coordinates></gml:Point>)", FUNCMP.qname());
+            "</gml:coordinates></gml:Point>)", EXPTYPE_X_X_X.qname());
   }
 
   /** Test method. */
@@ -466,7 +466,7 @@ public final class GeoTest extends AdvancedQueryTest {
             "<gml:Point><gml:coordinates>2,1</gml:coordinates></gml:Point>, 2)",
             GeoErrors.qname(4));
     error("geo:geometryN(text {'a'}, <gml:Point><gml:coordinates>2,3" +
-            "</gml:coordinates></gml:Point>)", FUNCMP.qname());
+            "</gml:coordinates></gml:Point>)", EXPTYPE_X_X_X.qname());
   }
 
   /** Test method. */
@@ -486,7 +486,7 @@ public final class GeoTest extends AdvancedQueryTest {
         GeoErrors.qname(2));
     error("geo:x(<gml:geo><gml:coordinates>2,1</gml:coordinates></gml:geo>)",
         GeoErrors.qname(1));
-    error("geo:x(text {'a'})", FUNCMP.qname());
+    error("geo:x(text {'a'})", EXPTYPE_X_X_X.qname());
   }
 
   /** Test method. */
@@ -507,7 +507,7 @@ public final class GeoTest extends AdvancedQueryTest {
         GeoErrors.qname(2));
     error("geo:y(<gml:geo><gml:coordinates>2,1</gml:coordinates></gml:geo>)",
         GeoErrors.qname(1));
-    error("geo:y(a)", NOCTX.qname());
+    error("geo:y(a)", NOCTX_X.qname());
   }
 
   /** Test method. */
@@ -528,7 +528,7 @@ public final class GeoTest extends AdvancedQueryTest {
             GeoErrors.qname(2));
     error("geo:z(<gml:geo><gml:coordinates>2,1</gml:coordinates></gml:geo>)",
         GeoErrors.qname(1));
-    error("geo:z(a)", NOCTX.qname());
+    error("geo:z(a)", NOCTX_X.qname());
   }
 
   /** Test method. */
@@ -573,8 +573,8 @@ public final class GeoTest extends AdvancedQueryTest {
     error("geo:startPoint(" +
             "<gml:LineString><gml:coordinates>1,1</gml:coordinates></gml:LineString>)",
             GeoErrors.qname(2));
-    error("geo:startPoint()", FUNCARGSG.qname());
-    error("geo:startPoint(text {'gml:Point'})", FUNCMP.qname());
+    error("geo:startPoint()", FUNCARGNUM_X_X_X.qname());
+    error("geo:startPoint(text {'gml:Point'})", EXPTYPE_X_X_X.qname());
     error("geo:startPoint(<gml:geo><gml:coordinates>2,1</gml:coordinates></gml:geo>)",
             GeoErrors.qname(1));
   }
@@ -599,8 +599,8 @@ public final class GeoTest extends AdvancedQueryTest {
     error("geo:endPoint(" +
             "<gml:LineString><gml:coordinates>1,1</gml:coordinates></gml:LineString>)",
             GeoErrors.qname(2));
-    error("geo:endPoint()", FUNCARGSG.qname());
-    error("geo:endPoint(text {'gml:Point'})", FUNCMP.qname());
+    error("geo:endPoint()", FUNCARGNUM_X_X_X.qname());
+    error("geo:endPoint(text {'gml:Point'})", EXPTYPE_X_X_X.qname());
     error("geo:endPoint(<gml:geo><gml:coordinates>2,1</gml:coordinates></gml:geo>)",
             GeoErrors.qname(1));
   }
@@ -624,8 +624,8 @@ public final class GeoTest extends AdvancedQueryTest {
     error("geo:isClosed(" +
             "<gml:LineString><gml:coordinates>1,1</gml:coordinates></gml:LineString>)",
             GeoErrors.qname(2));
-    error("geo:isClosed()", FUNCARGSG.qname());
-    error("geo:isClosed(text {'gml:Point'})", FUNCMP.qname());
+    error("geo:isClosed()", FUNCARGNUM_X_X_X.qname());
+    error("geo:isClosed(text {'gml:Point'})", EXPTYPE_X_X_X.qname());
     error("geo:isClosed(" +
             "<gml:Point><gml:coordinates>2,1</gml:coordinates></gml:Point>)",
             GeoErrors.qname(3));
@@ -650,8 +650,8 @@ public final class GeoTest extends AdvancedQueryTest {
     error("geo:isRing(" +
             "<gml:LineString><gml:coordinates>1,1</gml:coordinates></gml:LineString>)",
             GeoErrors.qname(2));
-    error("geo:isRing()", FUNCARGSG.qname());
-    error("geo:isRing(text {'gml:Point'})", FUNCMP.qname());
+    error("geo:isRing()", FUNCARGNUM_X_X_X.qname());
+    error("geo:isRing(text {'gml:Point'})", EXPTYPE_X_X_X.qname());
     error("geo:isRing(<Point><gml:coordinates>2,1</gml:coordinates></Point>)",
             GeoErrors.qname(1));
   }
@@ -672,8 +672,8 @@ public final class GeoTest extends AdvancedQueryTest {
 
     error("geo:numPoints(<gml:LineString><gml:coordinates>1,1</gml:coordinates>" +
             "</gml:LineString>)", GeoErrors.qname(2));
-    error("geo:numPoints()", FUNCARGSG.qname());
-    error("geo:numPoints(text {'gml:Point'})", FUNCMP.qname());
+    error("geo:numPoints()", FUNCARGNUM_X_X_X.qname());
+    error("geo:numPoints(text {'gml:Point'})", EXPTYPE_X_X_X.qname());
     error("geo:numPoints(<Point><gml:coordinates>2,1</gml:coordinates></Point>)",
             GeoErrors.qname(1));
   }
@@ -703,7 +703,7 @@ public final class GeoTest extends AdvancedQueryTest {
             "</gml:coordinates></gml:LineString>, 5)", GeoErrors.qname(4));
     error("geo:pointN(<gml:LineString><gml:coordinates>11,10 20,1 20,20 12,13" +
             "</gml:coordinates></gml:LineString>, 0)", GeoErrors.qname(4));
-    error("geo:pointN(text {'a'},3)", FUNCMP.qname());
+    error("geo:pointN(text {'a'},3)", EXPTYPE_X_X_X.qname());
   }
 
   /** Test method. */
@@ -722,7 +722,7 @@ public final class GeoTest extends AdvancedQueryTest {
 
     error("geo:area(<gml:LinearRing><gml:coordinates>0,0 0,20 0,0" +
             "</gml:coordinates></gml:LinearRing>)", GeoErrors.qname(2));
-    error("geo:area()", FUNCARGSG.qname());
+    error("geo:area()", FUNCARGNUM_X_X_X.qname());
     error("geo:area(<gml:geo><gml:coordinates>2,1</gml:coordinates></gml:geo>)",
             GeoErrors.qname(1));
   }
@@ -752,8 +752,8 @@ public final class GeoTest extends AdvancedQueryTest {
     error("geo:centroid(" +
             "<gml:unknown><gml:coordinates>1,1</gml:coordinates></gml:unknown>)",
             GeoErrors.qname(1));
-    error("geo:centroid()", FUNCARGSG.qname());
-    error("geo:centroid(text {'a'})", FUNCMP.qname());
+    error("geo:centroid()", FUNCARGNUM_X_X_X.qname());
+    error("geo:centroid(text {'a'})", EXPTYPE_X_X_X.qname());
   }
 
   /** Test method. */
@@ -781,8 +781,8 @@ public final class GeoTest extends AdvancedQueryTest {
             "<gml:unknown><gml:coordinates>1,1</gml:coordinates></gml:unknown>)",
             GeoErrors.qname(1));
 
-    error("geo:pointOnSurface()", FUNCARGSG.qname());
-    error("geo:pointOnSurface(text {'a'})", FUNCMP.qname());
+    error("geo:pointOnSurface()", FUNCARGNUM_X_X_X.qname());
+    error("geo:pointOnSurface(text {'a'})", EXPTYPE_X_X_X.qname());
   }
 
   /** Test method. */
@@ -801,8 +801,8 @@ public final class GeoTest extends AdvancedQueryTest {
     error("geo:exteriorRing(" +
             "<gml:unknown><gml:coordinates>1,1</gml:coordinates></gml:unknown>)",
             GeoErrors.qname(1));
-    error("geo:exteriorRing()", FUNCARGSG.qname());
-    error("geo:exteriorRing(text {'a'})", FUNCMP.qname());
+    error("geo:exteriorRing()", FUNCARGNUM_X_X_X.qname());
+    error("geo:exteriorRing(text {'a'})", EXPTYPE_X_X_X.qname());
   }
 
   /** Test method. */
@@ -821,8 +821,8 @@ public final class GeoTest extends AdvancedQueryTest {
             "<gml:unknown><gml:coordinates>1,1</gml:coordinates></gml:unknown>)",
             GeoErrors.qname(1));
 
-    error("geo:numInteriorRing()", FUNCARGSG.qname());
-    error("geo:numInteriorRing(text {'a'})", FUNCMP.qname());
+    error("geo:numInteriorRing()", FUNCARGNUM_X_X_X.qname());
+    error("geo:numInteriorRing(text {'a'})", EXPTYPE_X_X_X.qname());
   }
 
   /** Test method. */
@@ -854,8 +854,8 @@ public final class GeoTest extends AdvancedQueryTest {
             "<gml:Point><gml:coordinates>2.0,3.0</gml:coordinates></gml:Point>, 1)",
             GeoErrors.qname(3));
 
-    error("geo:interiorRingN(text {'<gml:Polygon/'}, 1)", FUNCMP.qname());
-    error("geo:interiorRingN()", FUNCARGSG.qname());
+    error("geo:interiorRingN(text {'<gml:Polygon/'}, 1)", EXPTYPE_X_X_X.qname());
+    error("geo:interiorRingN()", FUNCARGNUM_X_X_X.qname());
   }
 
   /**
@@ -877,16 +877,18 @@ public final class GeoTest extends AdvancedQueryTest {
     final String q = "import module namespace geo='http://expath.org/ns/geo'; " +
         "declare namespace gml='http://www.opengis.net/gml';" + query;
 
-    final QueryProcessor qp = new QueryProcessor(q, context);
-    try {
-      final String res = qp.execute().toString().replaceAll("(\\r|\\n) *", "");
+    System.setErr(NULL);
+    try(final QueryProcessor qp = new QueryProcessor(q, context)) {
+      final String res = qp.value().serialize().toString().replaceAll("(\\r|\\n) *", "");
       fail("Query did not fail:\n" + query + "\n[E] " +
           error + "...\n[F] " + res);
     } catch(final QueryException ex) {
       if(!ex.qname().eq(error))
         fail("Wrong error code:\n[E] " + error + "\n[F] " + ex.qname());
+    } catch(final Exception ex) {
+      fail(ex.toString());
     } finally {
-      qp.close();
+      System.setErr(ERR);
     }
   }
 }
