@@ -3,9 +3,9 @@ package org.basex;
 import static org.basex.core.Text.*;
 
 import java.awt.*;
+import java.util.*;
 
 import javax.swing.*;
-import javax.swing.UIManager.LookAndFeelInfo;
 
 import org.basex.core.*;
 import org.basex.core.cmd.*;
@@ -19,14 +19,14 @@ import org.basex.util.list.*;
 /**
  * This is the starter class for the graphical frontend.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class BaseXGUI extends Main {
   /** Database context. */
   private final Context context = new Context();
   /** Files, specified as arguments. */
-  private final StringList files = new StringList();
+  private final StringList files = new StringList(0);
   /** Mac OS X GUI optimizations. */
   GUIMacOSX osxGUI;
 
@@ -63,37 +63,35 @@ public final class BaseXGUI extends Main {
 
     // read options
     final GUIOptions gopts = new GUIOptions();
-    // cache results to pass them on to all visualizations
-    context.options.set(MainOptions.CACHEQUERY, true);
-    // reduce number of results to save memory
-    context.options.set(MainOptions.MAXHITS, gopts.get(GUIOptions.MAXHITS));
 
+    // initialize look and feel
+    init(gopts);
     // initialize fonts and colors
     GUIConstants.init(gopts);
 
     SwingUtilities.invokeLater(new Runnable() {
       @Override
       public void run() {
-        // initialize look and feel
-        init(gopts);
         // open main window
         final GUI gui = new GUI(context, gopts);
         if(osxGUI != null) osxGUI.init(gui);
 
-        // open specified document or database
-        for(final String file : files) {
+        // open specified file
+        final ArrayList<IOFile> xqfiles = new ArrayList<>();
+        for(final String file : files.finish()) {
           if(file.matches("^.*\\" + IO.BASEXSUFFIX + "[^.]*$")) continue;
 
           final IOFile io = new IOFile(file);
           final boolean xml = file.endsWith(IO.XMLSUFFIX);
-          if(xml && BaseXDialog.confirm(gui, Util.info(Text.CREATE_DB_FILE, io))) {
+          if(xml && BaseXDialog.confirm(gui, Util.info(CREATE_DB_FILE, io))) {
             gopts.set(GUIOptions.INPUTPATH, io.path());
             gopts.set(GUIOptions.DBNAME, io.dbname());
             DialogProgress.execute(gui, new Check(file));
           } else {
-            gui.editor.open(io);
+            xqfiles.add(io);
           }
         }
+        gui.editor.init(xqfiles);
       }
     });
 
@@ -111,31 +109,12 @@ public final class BaseXGUI extends Main {
    * @param opts gui options
    */
   private static void init(final GUIOptions opts) {
-    // added to handle possible JDK 1.6 bug (thanks to Makoto Yui)
-    final LookAndFeelInfo[] lafis = UIManager.getInstalledLookAndFeels();
-
-    final String laf = opts.get(GUIOptions.LOOKANDFEEL);
     try {
       // refresh views when windows are resized
       Toolkit.getDefaultToolkit().setDynamicLayout(true);
-      // set specified look & feel
-      if(laf.equals("Metal")) {
-        // use non-bold fonts in Java's look & feel
-        final UIDefaults def = UIManager.getDefaults();
-        for(final Object k : def.keySet()) {
-          final Object v = def.get(k);
-          if(v instanceof Font) def.put(k, ((Font) v).deriveFont(Font.PLAIN));
-        }
-      } else if(laf.isEmpty()) {
-        UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
-      } else {
-        for(final LookAndFeelInfo lafi : lafis) {
-          if(lafi.getName().equals(laf)) {
-            UIManager.setLookAndFeel(lafi.getClassName());
-            break;
-          }
-        }
-      }
+      // set look and feel
+      final String laf = opts.get(GUIOptions.LOOKANDFEEL);
+      UIManager.setLookAndFeel(laf.isEmpty() ? UIManager.getSystemLookAndFeelClassName() : laf);
     } catch(final Exception ex) {
       Util.stack(ex);
     }
