@@ -6,16 +6,16 @@ import org.w3c.dom.*;
 /**
  * DOM - CData implementation.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
-public final class BXCData extends BXText implements CDATASection {
+final class BXCData extends BXText implements CDATASection {
   /**
    * Constructor.
-   * @param n node reference
+   * @param node node reference
    */
-  public BXCData(final ANode n) {
-    super(n);
+  BXCData(final ANode node) {
+    super(node);
   }
 
   @Override
