@@ -6,15 +6,15 @@ import org.w3c.dom.*;
 /**
  * DOM - Comment implementation.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class BXComm extends BXChar implements Comment {
   /**
    * Constructor.
-   * @param n node reference
+   * @param node node reference
    */
-  public BXComm(final ANode n) {
-    super(n);
+  BXComm(final ANode node) {
+    super(node);
   }
 }
