@@ -10,16 +10,16 @@ import org.w3c.dom.*;
 /**
  * DOM - Document implementation.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class BXDoc extends BXNode implements Document {
   /**
    * Constructor.
-   * @param n node reference
+   * @param node node reference
    */
-  public BXDoc(final ANode n) {
-    super(n);
+  public BXDoc(final ANode node) {
+    super(node);
   }
 
   @Override
@@ -28,43 +28,43 @@ public final class BXDoc extends BXNode implements Document {
   }
 
   @Override
-  public BXNode adoptNode(final Node source) {
+  public BXNode adoptNode(final Node node) {
     throw readOnly();
   }
 
   @Override
-  public BXAttr createAttribute(final String nm) {
-    return new BXAttr(new FAttr(new QNm(nm), EMPTY));
+  public BXAttr createAttribute(final String name) {
+    return new BXAttr(new FAttr(new QNm(name), EMPTY));
   }
 
   @Override
-  public BXAttr createAttributeNS(final String uri, final String qn) {
-    return new BXAttr(new FAttr(new QNm(qn, uri), EMPTY));
+  public BXAttr createAttributeNS(final String uri, final String name) {
+    return new BXAttr(new FAttr(new QNm(name, uri), EMPTY));
   }
 
   @Override
-  public BXCData createCDATASection(final String dat) {
-    return new BXCData(new FTxt(dat));
+  public BXCData createCDATASection(final String value) {
+    return new BXCData(new FTxt(value));
   }
 
   @Override
-  public BXComm createComment(final String dat) {
-    return new BXComm(new FComm(dat));
+  public BXComm createComment(final String value) {
+    return new BXComm(new FComm(value));
   }
 
   @Override
   public BXDocFrag createDocumentFragment() {
-    return new BXDocFrag(new FDoc(node.baseURI()));
+    return new BXDocFrag(new FDoc(nd.baseURI()));
   }
 
   @Override
-  public BXElem createElement(final String nm) {
-    return new BXElem(new FElem(new QNm(nm)));
+  public BXElem createElement(final String name) {
+    return new BXElem(new FElem(new QNm(name)));
   }
 
   @Override
-  public BXElem createElementNS(final String uri, final String qn) {
-    return new BXElem(new FElem(new QNm(qn, uri)));
+  public BXElem createElementNS(final String uri, final String name) {
+    return new BXElem(new FElem(new QNm(name, uri)));
   }
 
   @Override
@@ -73,13 +73,13 @@ public final class BXDoc extends BXNode implements Document {
   }
 
   @Override
-  public BXPI createProcessingInstruction(final String t, final String dat) {
-    return new BXPI(new FPI(t, dat));
+  public BXPI createProcessingInstruction(final String name, final String value) {
+    return new BXPI(new FPI(name, value));
   }
 
   @Override
-  public BXText createTextNode(final String dat) {
-    return new BXText(new FTxt(dat));
+  public BXText createTextNode(final String value) {
+    return new BXText(new FTxt(value));
   }
 
   @Override
@@ -104,12 +104,12 @@ public final class BXDoc extends BXNode implements Document {
 
   @Override
   public DOMConfiguration getDomConfig() {
-    throw Util.notImplemented();
+    throw notImplemented();
   }
 
   @Override
-  public BXElem getElementById(final String elementId) {
-    throw Util.notImplemented();
+  public BXElem getElementById(final String id) {
+    throw notImplemented();
   }
 
   @Override
@@ -118,8 +118,8 @@ public final class BXDoc extends BXNode implements Document {
   }
 
   @Override
-  public BXNList getElementsByTagNameNS(final String namespaceURI, final String localName) {
-    throw Util.notImplemented();
+  public BXNList getElementsByTagNameNS(final String uri, final String name) {
+    throw notImplemented();
   }
 
   @Override
@@ -129,17 +129,17 @@ public final class BXDoc extends BXNode implements Document {
 
   @Override
   public String getInputEncoding() {
-    return UTF8;
+    return Strings.UTF8;
   }
 
   @Override
   public boolean getStrictErrorChecking() {
-    throw Util.notImplemented();
+    throw notImplemented();
   }
 
   @Override
   public String getXmlEncoding() {
-    return UTF8;
+    return Strings.UTF8;
   }
 
   @Override
@@ -153,8 +153,8 @@ public final class BXDoc extends BXNode implements Document {
   }
 
   @Override
-  public BXNode importNode(final Node importedNode, final boolean deep) {
-    throw Util.notImplemented();
+  public BXNode importNode(final Node node, final boolean deep) {
+    throw notImplemented();
   }
 
   @Override
@@ -163,28 +163,27 @@ public final class BXDoc extends BXNode implements Document {
   }
 
   @Override
-  public BXNode renameNode(final Node n, final String namespaceURI,
-      final String qualifiedName) {
+  public BXNode renameNode(final Node node, final String uri, final String name) {
     throw readOnly();
   }
 
   @Override
-  public void setDocumentURI(final String documentURI) {
+  public void setDocumentURI(final String uri) {
     throw readOnly();
   }
 
   @Override
-  public void setStrictErrorChecking(final boolean strictErrorChecking) {
-    throw Util.notImplemented();
+  public void setStrictErrorChecking(final boolean value) {
+    throw notImplemented();
   }
 
   @Override
-  public void setXmlStandalone(final boolean xmlStandalone) {
-    throw Util.notImplemented();
+  public void setXmlStandalone(final boolean value) {
+    throw notImplemented();
   }
 
   @Override
-  public void setXmlVersion(final String xmlVersion) {
-    throw Util.notImplemented();
+  public void setXmlVersion(final String value) {
+    throw notImplemented();
   }
 }
