@@ -6,16 +6,16 @@ import org.w3c.dom.*;
 /**
  * DOM - Document fragment implementation.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
-public final class BXDocFrag extends BXNode implements DocumentFragment {
+final class BXDocFrag extends BXNode implements DocumentFragment {
   /**
    * Constructor.
-   * @param n node reference
+   * @param node node reference
    */
-  public BXDocFrag(final ANode n) {
-    super(n);
+  BXDocFrag(final ANode node) {
+    super(node);
   }
 
   @Override
