@@ -8,31 +8,31 @@ import org.w3c.dom.*;
 /**
  * DOM - Element implementation.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class BXElem extends BXNode implements Element {
   /**
    * Constructor.
-   * @param n node reference
+   * @param node node reference
    */
-  public BXElem(final ANode n) {
-    super(n);
+  BXElem(final ANode node) {
+    super(node);
   }
 
   @Override
   public String getNodeName() {
-    return Token.string(node.name());
+    return Token.string(nd.name());
   }
 
   @Override
   public String getLocalName() {
-    return Token.string(Token.local(node.name()));
+    return Token.string(Token.local(nd.name()));
   }
 
   @Override
   public BXNNode getAttributes() {
-    return new BXNNode(finish(node.attributes()));
+    return new BXNNode(finish(nd.attributes()));
   }
 
   @Override
@@ -43,13 +43,13 @@ public final class BXElem extends BXNode implements Element {
 
   @Override
   public String getNamespaceURI() {
-    final byte[] uri = node.qname().uri();
+    final byte[] uri = nd.qname().uri();
     return uri.length == 0 ? null : Token.string(uri);
   }
 
   @Override
-  public String getAttributeNS(final String uri, final String ln) {
-    throw Util.notImplemented();
+  public String getAttributeNS(final String uri, final String name) {
+    throw notImplemented();
   }
 
   @Override
@@ -58,8 +58,8 @@ public final class BXElem extends BXNode implements Element {
   }
 
   @Override
-  public BXAttr getAttributeNodeNS(final String uri, final String ln) {
-    throw Util.notImplemented();
+  public BXAttr getAttributeNodeNS(final String uri, final String name) {
+    throw notImplemented();
   }
 
   @Override
@@ -68,13 +68,13 @@ public final class BXElem extends BXNode implements Element {
   }
 
   @Override
-  public BXNList getElementsByTagNameNS(final String uri, final String ln) {
-    throw Util.notImplemented();
+  public BXNList getElementsByTagNameNS(final String uri, final String name) {
+    throw notImplemented();
   }
 
   @Override
   public TypeInfo getSchemaTypeInfo() {
-    throw Util.notImplemented();
+    throw notImplemented();
   }
 
   @Override
@@ -88,8 +88,8 @@ public final class BXElem extends BXNode implements Element {
   }
 
   @Override
-  public boolean hasAttributeNS(final String uri, final String ln) {
-    throw Util.notImplemented();
+  public boolean hasAttributeNS(final String uri, final String name) {
+    throw notImplemented();
   }
 
   @Override
@@ -98,7 +98,7 @@ public final class BXElem extends BXNode implements Element {
   }
 
   @Override
-  public void removeAttributeNS(final String uri, final String ln) {
+  public void removeAttributeNS(final String uri, final String name) {
     throw readOnly();
   }
 
@@ -113,44 +113,44 @@ public final class BXElem extends BXNode implements Element {
   }
 
   @Override
-  public void setAttributeNS(final String uri, final String qn, final String value) {
+  public void setAttributeNS(final String uri, final String name, final String value) {
     throw readOnly();
   }
 
   @Override
-  public BXAttr setAttributeNode(final Attr at) {
+  public BXAttr setAttributeNode(final Attr node) {
     throw readOnly();
   }
 
   @Override
-  public BXAttr setAttributeNodeNS(final Attr at) {
+  public BXAttr setAttributeNodeNS(final Attr node) {
     throw readOnly();
   }
 
   @Override
-  public void setIdAttribute(final String name, final boolean isId) {
+  public void setIdAttribute(final String name, final boolean id) {
     throw readOnly();
   }
 
   @Override
-  public void setIdAttributeNS(final String uri, final String ln, final boolean isId) {
+  public void setIdAttributeNS(final String uri, final String name, final boolean id) {
     throw readOnly();
   }
 
   @Override
-  public void setIdAttributeNode(final Attr at, final boolean isId) {
+  public void setIdAttributeNode(final Attr node, final boolean id) {
     throw readOnly();
   }
 
   /**
    * Returns the specified attribute.
    * @param name attribute name
-   * @return node, or {@code null}
+   * @return node or {@code null}
    */
   private ANode attribute(final String name) {
-    final AxisIter ai = node.attributes();
+    final BasicNodeIter iter = nd.attributes();
     final byte[] nm = Token.token(name);
-    for(ANode n; (n = ai.next()) != null;) if(Token.eq(nm, n.name())) return n.finish();
+    for(ANode n; (n = iter.next()) != null;) if(Token.eq(nm, n.name())) return n.finish();
     return null;
   }
 }
