@@ -1,22 +1,22 @@
 package org.basex.api.dom;
 
-import org.basex.query.util.*;
+import org.basex.query.util.list.*;
 import org.basex.util.*;
 import org.w3c.dom.*;
 
 /**
  * DOM - Named node map implementation.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
-public final class BXNNode extends BXNList implements NamedNodeMap {
+final class BXNNode extends BXNList implements NamedNodeMap {
   /**
    * Constructor.
-   * @param nb nodes
+   * @param nodes nodes
    */
-  public BXNNode(final ANodeList nb) {
-    super(nb);
+  BXNNode(final ANodeList nodes) {
+    super(nodes);
   }
 
   @Override
@@ -24,33 +24,33 @@ public final class BXNNode extends BXNList implements NamedNodeMap {
     final byte[] nm = Token.token(name);
     final int s = getLength();
     for(int i = 0; i < s; ++i) {
-      if(Token.eq(nl.get(i).name(), nm)) return item(i);
+      if(Token.eq(nodes.get(i).name(), nm)) return item(i);
     }
     return null;
   }
 
   @Override
-  public BXNode getNamedItemNS(final String uri, final String ln) {
-    throw Util.notImplemented();
+  public BXNode getNamedItemNS(final String uri, final String name) {
+    throw BXNode.notImplemented();
   }
 
   @Override
   public BXNode setNamedItem(final Node node) {
-    throw Util.notImplemented();
+    throw BXNode.notImplemented();
   }
 
   @Override
   public BXNode removeNamedItem(final String name) {
-    throw Util.notImplemented();
+    throw BXNode.notImplemented();
   }
 
   @Override
   public BXNode setNamedItemNS(final Node node) {
-    throw Util.notImplemented();
+    throw BXNode.notImplemented();
   }
 
   @Override
-  public BXNode removeNamedItemNS(final String uri, final String ln) {
-    throw Util.notImplemented();
+  public BXNode removeNamedItemNS(final String uri, final String name) {
+    throw BXNode.notImplemented();
   }
 }
