@@ -7,8 +7,10 @@ import java.util.*;
 
 import org.basex.core.cmd.*;
 import org.basex.core.parse.*;
+import org.basex.core.users.*;
 import org.basex.data.*;
 import org.basex.io.out.*;
+import org.basex.query.value.*;
 import org.basex.util.*;
 import org.basex.util.list.*;
 import org.xml.sax.*;
@@ -18,7 +20,7 @@ import org.xml.sax.*;
  * implementations. It evaluates queries that are sent by the GUI, the client or
  * the standalone version.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public abstract class Command extends Proc {
@@ -28,44 +30,48 @@ public abstract class Command extends Proc {
   public final Perm perm;
   /** Indicates if the command requires an opened database. */
   public final boolean openDB;
-  /** Exception, resulting from command execution. */
-  public Exception cause;
 
-  /** Performance measurements. */
-  protected Performance perf;
   /** Database context. */
   protected Context context;
+  /** Convenience access to database options. */
+  protected MainOptions options;
+  /** Convenience access to static options. */
+  protected StaticOptions soptions;
+
   /** Output stream. */
   protected PrintOutput out;
   /** Optional input source. */
   protected InputSource in;
-  /** Database options. */
-  protected MainOptions options;
-  /** Global options. */
-  protected GlobalOptions goptions;
+
+  /** Exception, resulting from command execution. */
+  protected Exception exception;
+  /** Performance measurements. */
+  protected Performance perf;
+  /** Maximum number of results (ignored if negative). */
+  protected int maxResults = -1;
 
   /** Container for query information. */
   private final TokenBuilder info = new TokenBuilder();
 
   /**
    * Constructor for commands requiring no opened database.
-   * @param p required permission
-   * @param arg arguments
+   * @param perm required permission
+   * @param args arguments
    */
-  protected Command(final Perm p, final String... arg) {
-    this(p, false, arg);
+  protected Command(final Perm perm, final String... args) {
+    this(perm, false, args);
   }
 
   /**
    * Constructor.
-   * @param p required permission
-   * @param d requires opened database
-   * @param arg arguments
+   * @param perm required permission
+   * @param openDB requires an opened database
+   * @param args arguments
    */
-  protected Command(final Perm p, final boolean d, final String... arg) {
-    perm = p;
-    openDB = d;
-    args = arg;
+  protected Command(final Perm perm, final boolean openDB, final String... args) {
+    this.perm = perm;
+    this.openDB = openDB;
+    this.args = args;
   }
 
   /**
@@ -77,11 +83,11 @@ public abstract class Command extends Proc {
    */
   public final void execute(final Context ctx, final OutputStream os) throws BaseXException {
     // check if data reference is available
-    final Data dt = ctx.data();
-    if(dt == null && openDB) throw new BaseXException(NO_DB_OPENED);
+    final Data data = ctx.data();
+    if(data == null && openDB) throw new BaseXException(NO_DB_OPENED);
 
     // check permissions
-    if(!ctx.perm(perm, dt != null ? dt.meta : null))
+    if(!ctx.perm(perm, data != null && !data.inMemory() ? data.meta.name : null))
       throw new BaseXException(PERM_REQUIRED_X, perm);
 
     // set updating flag
@@ -93,7 +99,7 @@ public abstract class Command extends Proc {
       // run command and return success flag
       if(!run(ctx, os)) {
         final BaseXException ex = new BaseXException(info());
-        ex.initCause(cause);
+        ex.initCause(exception);
         throw ex;
       }
     } catch(final RuntimeException th) {
@@ -120,23 +126,23 @@ public abstract class Command extends Proc {
 
   /**
    * Attaches an input stream.
-   * @param is input stream
+   * @param input input stream
    */
-  public void setInput(final InputStream is) {
-    in = new InputSource(is);
+  public final void setInput(final InputStream input) {
+    in = new InputSource(input);
   }
 
   /**
    * Attaches an input source.
-   * @param is input source
+   * @param input input source
    */
-  public void setInput(final InputSource is) {
-    in = is;
+  public final void setInput(final InputSource input) {
+    in = input;
   }
 
   /**
-   * Runs the command without permission, data and concurrency checks.
-   * Should be called with care, and only by other database commands.
+   * Runs the command without permission, data and concurrency checks. Should be called with care,
+   * and only by other database commands.
    * @param ctx database context
    * @return result of check
    */
@@ -153,11 +159,18 @@ public abstract class Command extends Proc {
   }
 
   /**
-   * Returns the result set, generated by a query command. Will only yield results if
-   * {@link MainOptions#CACHEQUERY} is set, and can only be called once.
+   * Returns the cause of an error.
+   * @return error
+   */
+  public final Exception exception() {
+    return exception;
+  }
+
+  /**
+   * Returns a cached result set generated by {@link AQuery#query}. Can only be called once.
    * @return result set
    */
-  public Result result() {
+  public Value finish() {
     return null;
   }
 
@@ -181,9 +194,8 @@ public abstract class Command extends Proc {
   }
 
   /**
-   * Closes an open data reference and returns {@code true} if this command will change
-   * the {@link Context#data()} reference. This method is required by the progress dialog
-   * in the frontend.
+   * Closes an open data reference and returns {@code true} if this command will change the
+   * {@link Context#data()} reference. This method is required by the GUI progress dialog.
    * @param ctx database context
    * @return result of check
    */
@@ -192,9 +204,17 @@ public abstract class Command extends Proc {
     return false;
   }
 
+  /**
+   * Enforces a maximum number of query results. This method is required by the GUI.
+   * @param max maximum number of results (ignored if negative)
+   */
+  public final void maxResults(final int max) {
+    maxResults = max;
+  }
+
   /**
    * Returns true if this command returns a progress value.
-   * This method is required by the progress dialog in the frontend.
+   * This method is required by the GUI progress dialog.
    * @return result of check
    */
   public boolean supportsProg() {
@@ -203,20 +223,30 @@ public abstract class Command extends Proc {
 
   /**
    * Returns true if this command can be stopped.
-   * This method is required by the progress dialog in the frontend.
+   * This method is required by the GUI progress dialog.
    * @return result of check
    */
   public boolean stoppable() {
     return false;
   }
 
-  @Override
-  public final String toString() {
-    final CmdBuilder cb = new CmdBuilder(this);
+  /**
+   * Returns a string representation of the command.
+   * @param conf hide confidential information
+   * @return result of check
+   */
+  public final String toString(final boolean conf) {
+    final CmdBuilder cb = new CmdBuilder(this, conf);
     build(cb);
     return cb.toString();
   }
 
+
+  @Override
+  public final String toString() {
+    return toString(false);
+  }
+
   // PROTECTED METHODS ========================================================
 
   /**
@@ -271,30 +301,61 @@ public abstract class Command extends Proc {
   }
 
   /**
-   * Adds the names of the database that has been addressed by the argument index.
-   * No databases will be added if the argument uses glob syntax.
+   * Adds the names of the database that has been addressed by the argument index. No databases will
+   * be added if the argument uses glob syntax.
    * @param db databases
-   * @param a argument index
+   * @param index argument index
    * @return {@code false} if database cannot be determined due to glob syntax
    */
-  protected final boolean databases(final StringList db, final int a) {
+  protected final boolean databases(final StringList db, final int index) {
     // return true if the addressed database argument does not exists
-    if(args.length <= a || args[a] == null) return true;
-    final boolean noglob = !args[a].matches(".*[\\?\\*,].*");
-    if(noglob) db.add(args[a]);
+    if(args.length <= index || args[index] == null) return true;
+    final boolean noglob = !args[index].matches(".*[\\?\\*,].*");
+    if(noglob) db.add(args[index]);
     return noglob;
   }
 
+  /**
+   * Starts an update operation.
+   * @param data data reference
+   * @return success flag
+   */
+  protected final boolean startUpdate(final Data data) {
+    try {
+      data.startUpdate(options);
+      return true;
+    } catch(final IOException ex) {
+      info(Util.message(ex));
+      return false;
+    }
+  }
+
+  /**
+   * Finalizes an update operation.
+   * @param data data reference
+   * @return success flag
+   */
+  protected final boolean finishUpdate(final Data data) {
+    try {
+      if(data.meta.autoopt) Optimize.optimize(data, options, null);
+      data.finishUpdate(options);
+      return true;
+    } catch(final IOException ex) {
+      info(Util.message(ex));
+      return false;
+    }
+  }
+
   /**
    * Returns the specified command option.
-   * @param s string to be found
-   * @param typ options enumeration
+   * @param string string to be found
+   * @param type options enumeration
    * @param <E> token type
    * @return option
    */
-  protected static <E extends Enum<E>> E getOption(final String s, final Class<E> typ) {
+  protected static <E extends Enum<E>> E getOption(final String string, final Class<E> type) {
     try {
-      return Enum.valueOf(typ, s.toUpperCase(Locale.ENGLISH));
+      return Enum.valueOf(type, string.toUpperCase(Locale.ENGLISH));
     } catch(final Exception ex) {
       return null;
     }
@@ -307,11 +368,24 @@ public abstract class Command extends Proc {
    * @return closed flag
    */
   protected static boolean close(final Context ctx, final String db) {
-    final boolean close = ctx.data() != null &&
-        db.equals(ctx.data().meta.name) && ctx.dbs.pins(db) == 1;
+    final boolean close = ctx.data() != null && db.equals(ctx.data().meta.name)
+        && ctx.datas.pins(db) == 1;
     return close && new Close().run(ctx);
   }
 
+  /**
+   * Initializes the command execution.
+   * @param ctx database context
+   * @param os output stream
+   */
+  public void init(final Context ctx, final OutputStream os) {
+    perf = new Performance();
+    context = ctx;
+    options = ctx.options;
+    soptions = ctx.soptions;
+    out = PrintOutput.get(os);
+  }
+
   /**
    * Runs the command without permission, data and concurrency checks.
    * @param ctx database context
@@ -319,30 +393,28 @@ public abstract class Command extends Proc {
    * @return result of check
    */
   public boolean run(final Context ctx, final OutputStream os) {
-    perf = new Performance();
-    context = ctx;
-    options = ctx.options;
-    goptions = ctx.globalopts;
-    out = PrintOutput.get(os);
-
+    init(ctx, os);
     try {
       return run();
     } catch(final ProcException ex) {
       // process was interrupted by the user or server
       abort();
       return error(INTERRUPTED);
-    } catch(final Throwable ex) {
-      // unexpected error
+    } catch(final OutOfMemoryError ex) {
+      // out of memory
       Performance.gc(2);
       abort();
-      if(ex instanceof OutOfMemoryError) {
-        Util.debug(ex);
-        return error(OUT_OF_MEM + (perm == Perm.CREATE ? H_OUT_OF_MEM : ""));
-      }
+      Util.debug(ex);
+      return error(OUT_OF_MEM + (perm == Perm.CREATE ? H_OUT_OF_MEM : ""));
+    } catch(final Throwable ex) {
+      // any other unexpected error
+      abort();
       return error(Util.bug(ex) + Prop.NL + info);
     } finally {
       // flushes the output
-      try { if(out != null) out.flush(); } catch(final IOException ignored) { }
+      try {
+        if(out != null) out.flush();
+      } catch(final IOException ignored) { }
     }
   }
 }
