@@ -1,10 +1,11 @@
 package org.basex.core;
 
-import static org.basex.core.Text.*;
-
+import org.basex.core.locks.*;
+import org.basex.core.users.*;
 import org.basex.data.*;
 import org.basex.io.random.*;
 import org.basex.query.util.pkg.*;
+import org.basex.query.value.seq.*;
 import org.basex.server.*;
 import org.basex.util.*;
 import org.basex.util.list.*;
@@ -16,51 +17,50 @@ import org.basex.util.list.*;
  * all operations, as it organizes concurrent data access, ensuring that no
  * process will concurrently write to the same data instances.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class Context {
-  /** Client listener. Set to {@code null} in standalone/server mode. */
-  public final ClientListener listener;
   /** Blocked clients. */
   public final ClientBlocker blocker;
   /** Options. */
   public final MainOptions options = new MainOptions();
-  /** Global options. */
-  public final GlobalOptions globalopts;
-  /** Client connections. */
+  /** Static options. */
+  public final StaticOptions soptions;
+  /** Client sessions. */
   public final Sessions sessions;
-  /** Event pool. */
-  public final Events events;
   /** Opened databases. */
-  public final Datas dbs;
+  public final Datas datas;
   /** Users. */
   public final Users users;
   /** Package repository. */
   public final Repo repo;
   /** Databases list. */
   public final Databases databases;
-
-  /** User reference. */
-  public User user;
   /** Log. */
   public final Log log;
 
-  // GUI references
-  /** Marked nodes. */
-  public Nodes marked;
-  /** Copied nodes. */
-  public Nodes copied;
-  /** Focused node. */
-  public int focused = -1;
+  /** Client listener. Set to {@code null} in standalone/server mode. */
+  public ClientListener listener;
 
-  /** Node context. Set if it does not contain all documents of the current database. */
-  private Nodes current;
+  /** Current node context. Set if it does not contain all documents of the current database. */
+  private DBNodes current;
   /** Process locking. */
   private final Locking locks;
+  /** User reference. */
+  private User user;
   /** Data reference. */
   private Data data;
 
+  // GUI references
+
+  /** Marked nodes. */
+  public DBNodes marked;
+  /** Copied nodes. */
+  public DBNodes copied;
+  /** Focused node. */
+  public int focused = -1;
+
   /**
    * Default constructor, which is usually called once in the lifetime of a project.
    */
@@ -73,20 +73,17 @@ public final class Context {
    * @param file retrieve options from disk
    */
   public Context(final boolean file) {
-    this(new GlobalOptions(file));
+    this(new StaticOptions(file));
   }
 
   /**
    * Constructor, called by clients, and adopting the variables of the main process.
    * The {@link #user} reference must be set after calling this method.
    * @param ctx context of the main process
-   * @param cl client listener
    */
-  public Context(final Context ctx, final ClientListener cl) {
-    listener = cl;
-    globalopts = ctx.globalopts;
-    dbs = ctx.dbs;
-    events = ctx.events;
+  public Context(final Context ctx) {
+    soptions = ctx.soptions;
+    datas = ctx.datas;
     sessions = ctx.sessions;
     databases = ctx.databases;
     blocker = ctx.blocker;
@@ -97,31 +94,58 @@ public final class Context {
   }
 
   /**
-   * Private constructor.
-   * @param gopts main options
+   * Constructor, called by clients, and adopting the variables of the main process.
+   * The {@link #user} reference must be set after calling this method.
+   * @param ctx context of the main process
+   * @param listener client listener
    */
-  private Context(final GlobalOptions gopts) {
-    globalopts = gopts;
-    dbs = new Datas();
-    events = new Events();
-    sessions = new Sessions();
-    blocker = new ClientBlocker();
-    databases = new Databases(this);
-    locks = gopts.get(GlobalOptions.GLOBALLOCK) ? new ProcLocking(this) : new DBLocking(gopts);
-    users = new Users(this);
-    repo = new Repo(this);
-    log = new Log(this);
-    user = users.get(S_ADMIN);
-    listener = null;
+  public Context(final Context ctx, final ClientListener listener) {
+    this(ctx);
+    this.listener = listener;
   }
 
   /**
-   * Closes the database context. Should only be called on the global database context,
+   * Private constructor.
+   * @param soptions static options
+   */
+  private Context(final StaticOptions soptions) {
+    this.soptions = soptions;
+    datas = new Datas();
+    sessions = new Sessions();
+    blocker = new ClientBlocker();
+    databases = new Databases(soptions);
+    locks = soptions.get(StaticOptions.GLOBALLOCK) ? new ProcLocking(soptions) :
+      new DBLocking(soptions);
+    users = new Users(soptions);
+    repo = new Repo(soptions);
+    log = new Log(soptions);
+    user = users.get(UserText.ADMIN);
+  }
+
+  /**
+   * Returns the user of this context.
+   * @return user
+   */
+  public User user() {
+    return user;
+  }
+
+  /**
+   * Sets the user of this context. This method can only be called once.
+   * @param us user
+   */
+  public void user(final User us) {
+    if(user != null) throw Util.notExpected("User has already been assigned.");
+    user = us;
+  }
+
+  /**
+   * Closes the database context. Must only be called on the global database context,
    * and not on client instances.
    */
   public synchronized void close() {
     while(!sessions.isEmpty()) sessions.get(0).quit();
-    dbs.close();
+    datas.close();
     log.close();
   }
 
@@ -146,11 +170,10 @@ public final class Context {
    * Returns the current node context.
    * @return node set
    */
-  public Nodes current() {
-    if(current != null || data == null) return current;
-    final Nodes n = new Nodes(data.resources.docs().toArray(), data);
-    n.root = true;
-    return n;
+  public DBNodes current() {
+    if(data == null) return null;
+    if(current != null) return current;
+    return new DBNodes(data, true, data.resources.docs().toArray());
   }
 
   /**
@@ -158,18 +181,18 @@ public final class Context {
    * nodes of the currently opened database.
    * @param curr node set
    */
-  public void current(final Nodes curr) {
-    current = curr.checkRoot();
+  public void current(final DBNodes curr) {
+    current = curr.discardDocs();
   }
 
   /**
    * Sets the specified data instance as current database.
-   * @param d data reference
+   * @param dt data reference
    */
-  public void openDB(final Data d) {
-    data = d;
+  public void openDB(final Data dt) {
+    data = dt;
     copied = null;
-    set(null, new Nodes(d));
+    set(null, new DBNodes(dt));
   }
 
   /**
@@ -186,7 +209,7 @@ public final class Context {
    * @param curr context set
    * @param mark marked nodes
    */
-  public void set(final Nodes curr, final Nodes mark) {
+  public void set(final DBNodes curr, final DBNodes mark) {
     current = curr;
     marked = mark;
     focused = -1;
@@ -195,7 +218,7 @@ public final class Context {
   /**
    * Invalidates the current node set.
    */
-  public void update() {
+  public void invalidate() {
     current = null;
   }
 
@@ -205,19 +228,29 @@ public final class Context {
    * @return result of check
    */
   public boolean pinned(final String db) {
-    return dbs.pinned(db) || TableDiskAccess.locked(db, this);
+    return datas.pinned(db) || TableDiskAccess.locked(db, this);
   }
 
   /**
    * Checks if the current user has the specified permission.
-   * @param p requested permission
-   * @param md optional meta data reference
+   * @param perm requested permission
+   * @param db database (can be {@code null})
    * @return result of check
    */
-  public boolean perm(final Perm p, final MetaData md) {
-    final User us = md == null || p == Perm.CREATE || p == Perm.ADMIN ? null :
-      md.users.get(user.name);
-    return (us == null ? user : us).has(p);
+  public boolean perm(final Perm perm, final String db) {
+    return user.has(perm, db);
+  }
+
+  /**
+   * Filters databases to the ones that have the specified permission.
+   * @param perm requested permission
+   * @param dbs list of databases
+   * @return resulting list
+   */
+  public StringList filter(final Perm perm, final StringList dbs) {
+    final StringList sl = new StringList(dbs.size());
+    for(final String db : dbs) if(perm(perm, db)) sl.add(db);
+    return sl;
   }
 
   /**
@@ -229,13 +262,13 @@ public final class Context {
     pr.registered(true);
 
     // administrators will not be affected by the timeout
-    if(!user.has(Perm.ADMIN)) pr.startTimeout(globalopts.get(GlobalOptions.TIMEOUT) * 1000L);
+    if(!user.has(Perm.ADMIN)) pr.startTimeout(soptions.get(StaticOptions.TIMEOUT) * 1000L);
 
     // get touched databases
     final LockResult lr = new LockResult();
     pr.databases(lr);
-    final StringList read = prepareLock(lr.read, lr.readAll);
     final StringList write = prepareLock(lr.write, lr.writeAll);
+    final StringList read = write == null ? null : prepareLock(lr.read, lr.readAll);
     locks.acquire(pr, read, write);
   }
 
@@ -254,18 +287,18 @@ public final class Context {
    * Prepares the string list for locking.
    * @param sl string list
    * @param all lock all databases
-   * @return string list, or {@code null}
+   * @return string list, or {@code null} if all databases need to be locked
    */
   private StringList prepareLock(final StringList sl, final boolean all) {
     if(all) return null;
 
-    // replace empty string with currently opened database and return array
     for(int d = 0; d < sl.size(); d++) {
-      if(Token.eq(sl.get(d), DBLocking.CTX, DBLocking.COLL)) {
-        if(data == null) sl.deleteAt(d);
+      // replace context reference with real database name, or remove it if no database is open
+      if(sl.get(d).equals(DBLocking.CONTEXT)) {
+        if(data == null) sl.remove(d--);
         else sl.set(d, data.meta.name);
       }
     }
-    return sl.sort(true).unique();
+    return sl.sort().unique();
   }
 }
