@@ -2,14 +2,16 @@ package org.basex.core;
 
 import static org.basex.core.Text.*;
 
-import org.basex.util.*;
+import java.util.*;
+
+import org.basex.core.locks.*;
 
 /**
  * This class is implemented by all kinds of processes.
  * It gives feedback on the current process. Moreover, it allows to
  * interrupt the process by calling the {@link #stop()} method.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public abstract class Proc {
@@ -22,8 +24,8 @@ public abstract class Proc {
   boolean registered;
   /** Stopped flag. */
   private boolean stopped;
-  /** Timeout thread. */
-  private Thread timeout;
+  /** Timer. */
+  private Timer timer;
   /** Sub process. */
   private Proc sub;
 
@@ -108,24 +110,20 @@ public abstract class Proc {
   public final void startTimeout(final long ms) {
     if(ms == 0) return;
 
-    timeout = new Thread() {
+    timer = new Timer(true);
+    timer.schedule(new TimerTask() {
       @Override
-      public void run() {
-        Performance.sleep(ms);
-        Proc.this.stop();
-      }
-    };
-    timeout.setDaemon(true);
-    timeout.start();
+      public void run() { stop(); }
+    }, ms);
   }
 
   /**
    * Stops the timeout thread.
    */
   public final void stopTimeout() {
-    if(timeout != null) {
-      timeout.interrupt();
-      timeout = null;
+    if(timer != null) {
+      timer.cancel();
+      timer = null;
     }
   }
 
@@ -134,6 +132,7 @@ public abstract class Proc {
    * @param lr container for lock result to pass around
    */
   public void databases(final LockResult lr) {
+    // default (worst case): lock all databases
     lr.writeAll = true;
   }
 
