@@ -2,14 +2,21 @@ package org.basex.core;
 
 import static org.basex.core.Lang.*;
 
-import org.basex.core.parse.Commands.*;
+import org.basex.core.parse.Commands.CmdAlter;
+import org.basex.core.parse.Commands.CmdCreate;
+import org.basex.core.parse.Commands.CmdDrop;
+import org.basex.core.parse.Commands.CmdIndex;
+import org.basex.core.parse.Commands.CmdInfo;
+import org.basex.core.parse.Commands.CmdPerm;
+import org.basex.core.parse.Commands.CmdRepo;
+import org.basex.core.parse.Commands.CmdShow;
 import org.basex.util.*;
 
 /**
  * This class contains internationalized text strings, which are used throughout the project.
  * If this class is called first, the Strings are initialized by the {@link Lang} class.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public interface Text {
@@ -48,13 +55,13 @@ public interface Text {
   String S_STANDALONE = "Standalone";
   /** Start information. */
   String  S_LOCALINFO =
-    " [-bcdiLoqrRsuvVwxXz] [input]" + NL +
-    "  [input]     Execute input file or expression" + NL +
+    " [-bcdiIoqrRstuvVwxXz] [input]" + NL +
+    "  [input]     XQuery or command file, or query string" + NL +
     "  -b<pars>    Bind external query variables" + NL +
     "  -c<input>   Execute commands from file or string" + NL +
     "  -d          Activate debugging mode" + NL +
-    "  -i<input>   Open initial file or database" + NL +
-    "  -L          Append newlines to query results" + NL +
+    "  -i<input>   Assign file or database to context" + NL +
+    "  -I<input>   Assign input string to context" + NL +
     "  -o<output>  Write output to file" + NL +
     "  -q<expr>    Execute XQuery expression" + NL +
     "  -r<num>     Set number of query executions" + NL +
@@ -72,13 +79,13 @@ public interface Text {
   String S_CLIENT = "Client";
   /** Client start information. */
   String S_CLIENTINFO =
-    " [-bcdiLnopPqrRsUvVwxz] [input]" + NL +
-    "  [input]     Execute input file or expression" + NL +
+    " [-bcdiInopPqrRsUvVwxXz] [input]" + NL +
+    "  [input]     XQuery or command file, or query string" + NL +
     "  -b<pars>    Bind external query variables" + NL +
     "  -c<input>   Execute commands from file or string" + NL +
     "  -d          Activate debugging mode" + NL +
-    "  -i<input>   Open initial file or database" + NL +
-    "  -L          Append newlines to query results" + NL +
+    "  -i<input>   Assign file or database to context" + NL +
+    "  -I<input>   Assign input string to context" + NL +
     "  -n<name>    Set server (host) name" + NL +
     "  -o<output>  Write output to file" + NL +
     "  -p<port>    Set server port" + NL +
@@ -98,11 +105,10 @@ public interface Text {
   String S_SERVER = "Server";
   /** Server start information. */
   String S_SERVERINFO =
-    " [-cdeinpSz] [stop]" + NL +
+    " [-cdinpSz] [stop]" + NL +
     "  stop      Stop running server" + NL +
     "  -c<cmds>  Execute initial database commands" + NL +
     "  -d        Activate debugging mode" + NL +
-    "  -e<port>  Set event port" + NL +
     "  -n<name>  Set host the server is bound to" + NL +
     "  -p<port>  Set server port" + NL +
     "  -S        Start as service" + NL +
@@ -117,10 +123,9 @@ public interface Text {
 
   /** HTTP information. */
   String S_HTTPINFO =
-    " [-dehlnpPsSUz] [stop]" + NL +
+    " [-dhlnpPsSUz] [stop]" + NL +
     "  stop      Stop running server" + NL +
     "  -d        Activate debugging mode" + NL +
-    "  -e<port>  Set event port" + NL +
     "  -h<port>  Set port of HTTP server" + NL +
     "  -l        Start in local mode" + NL +
     "  -n<name>  Set host name of database server" + NL +
@@ -138,10 +143,6 @@ public interface Text {
 
   /** Localhost. */
   String S_LOCALHOST = "localhost";
-  /** User name. */
-  String[] S_USERINFO = { "Username", "Read", "Write", "Create", "Admin" };
-  /** Default admin user and password. */
-  String S_ADMIN = "admin";
 
   /** Command keyword. */
   String S_ALL = "ALL";
@@ -174,8 +175,6 @@ public interface Text {
   /** Index info. */
   String HASH = "Hash";
   /** Index info. */
-  String FUZZY = "Fuzzy";
-  /** Index info. */
   String SORTED_LIST = "Sorted List";
 
   /** Query hits. */
@@ -192,11 +191,19 @@ public interface Text {
   /** Options error. */
   String OPT_OFFSET = "List counter for '%' is invalid.";
   /** Options error. */
-  String OPT_BOOLEAN = "Value of '%' must be a boolean.";
+  String OPT_BOOLEAN = "Value of '%' must be 'yes', 'no', or a boolean.";
   /** Options error. */
   String OPT_NUMBER = "Value of '%' must be a number.";
   /** Options error. */
+  String OPT_STRING = "Value of '%' must be a string.";
+  /** Options error. */
+  String OPT_MAP = "Value of '%' must be a map.";
+  /** Options error. */
+  String OPT_FUNC = "Value of '%' must be a function.";
+  /** Options error. */
   String OPT_ONEOF = "Value of '%' must be one of (%).";
+  /** Options error. */
+  String OPT_EXPECT = "% expected, % found: %.";
 
   /** "log". */
   String PLOTLOG = "log";
@@ -227,24 +234,28 @@ public interface Text {
   /** "Stack Trace". */
   String STACK_TRACE = "Stack Trace";
   /** Copyright info. */
-  String COPYRIGHT = "\u00A9 2005-14 " + Prop.ENTITY;
+  String COPYRIGHT = "\u00A9 2005-15 " + Prop.ENTITY;
 
   // SERVER ===================================================================
 
   /** Server was started. */
-  String SRV_STARTED_PORT_X = lang("srv_started_port_%");
+  String PORT_X = " (" + lang("port") + ": %).";
+  /** Server was started. */
+  String SRV_STARTED_PORT_X = lang("srv_started") + PORT_X;
   /** Server was stopped. */
-  String SRV_STOPPED_PORT_X = lang("srv_stopped_port_%");
+  String SRV_STOPPED_PORT_X = lang("srv_stopped") + PORT_X;
   /** Server is running or permission was denied. */
-  String SRV_RUNNING = lang("srv_running");
-  /** Ports was specified twice. */
-  String PORT_TWICE_X = lang("port_twice_%");
+  String SRV_RUNNING = lang("srv_running") + '.';
+  /** Server is running or permission was denied. */
+  String SRV_RUNNING_X = lang("srv_running") + PORT_X;
+  /** Connection error. */
+  String CONNECTION_ERROR = lang("connection_error") + '.';
+  /** Connection error. */
+  String CONNECTION_ERROR_X = lang("connection_error") + PORT_X;
   /** Unknown host. */
   String UNKNOWN_HOST_X = lang("unknown_host_x");
   /** Timeout exceeded. */
   String TIMEOUT_EXCEEDED = lang("timeout_exceeded");
-  /** Connection error. */
-  String CONNECTION_ERROR = lang("connection_error");
   /** Access denied. */
   String ACCESS_DENIED = lang("access_denied");
   /** User name. */
@@ -252,11 +263,6 @@ public interface Text {
   /** Password. */
   String PASSWORD = lang("password");
 
-  /** Option flag. */
-  String INFOON = lang("ON");
-  /** Option flag. */
-  String INFOOFF = lang("OFF");
-
   // COMMANDS =================================================================
 
   /** Console text. */
@@ -273,20 +279,18 @@ public interface Text {
   /** Command help. */
   String[] HELPCREATE = {
     "[" + CmdCreate.BACKUP + '|' + CmdCreate.DATABASE + '|' +
-    CmdCreate.EVENT + '|' + CmdCreate.INDEX + '|' + CmdCreate.USER + "] [...]",
+    CmdCreate.INDEX + '|' + CmdCreate.USER + "] [...]",
     lang("c_create1"),
     lang("c_create2") + NL +
     LI + CmdDrop.BACKUP + " [" + S_NAME + "]:" + NL +
-    "  " + lang("c_create4", S_NAME) + NL +
+    "  " + lang("c_create22", S_NAME) + NL +
     LI + CmdCreate.DATABASE + " [" + S_NAME + "] ([" + S_INPUT + "]):"  + NL +
-    "  " + lang("c_create3", S_NAME, S_INPUT) + NL +
-    LI + CmdCreate.EVENT + " [" + S_NAME + "]: " + NL +
-    "  " + lang("c_create9") + NL +
+    "  " + lang("c_create21", S_NAME, S_INPUT) + NL +
     LI + CmdCreate.INDEX + " [" + CmdIndex.TEXT + '|' + CmdIndex.ATTRIBUTE +
     '|' + CmdIndex.FULLTEXT + "]:" + NL +
-    "  " + lang("c_create5") + NL +
+    "  " + lang("c_create23") + NL +
     LI + CmdCreate.USER + " [" + S_NAME + "] ([" + S_PW + "]):" + NL +
-    "  " + lang("c_create8")
+    "  " + lang("c_create24")
   };
 
   /** Command help. */
@@ -341,20 +345,18 @@ public interface Text {
   };
   /** Command help. */
   String[] HELPDROP = {
-    "[" + CmdDrop.BACKUP + '|' + CmdDrop.DATABASE + '|' + CmdDrop.EVENT + '|' +
+    "[" + CmdDrop.BACKUP + '|' + CmdDrop.DATABASE + '|' +
       CmdDrop.INDEX + '|' + CmdDrop.USER + "] [...]",
     lang("c_drop1"),
     lang("c_drop2") + NL +
     LI + CmdDrop.BACKUP + " [" + S_NAME + "]:" + NL +
-      "  " + lang("c_drop24", S_NAME) + NL +
+      "  " + lang("c_drop24") + NL +
     LI + CmdDrop.DATABASE + " [" + S_NAME + "]:" + NL +
       "  " + lang("c_drop21") + NL +
-    LI + CmdDrop.EVENT + " [" + S_NAME + "]:" + NL +
-      "  " + lang("c_drop25", S_NAME) + NL +
     LI + CmdDrop.INDEX + " [" + CmdIndex.TEXT + '|' +
       CmdIndex.ATTRIBUTE + '|' + CmdIndex.FULLTEXT + "]:" + NL +
       "  " + lang("c_drop22") + NL +
-    LI + CmdDrop.USER + " [" + S_NAME + "] (" + ON + " [database]): " + NL +
+    LI + CmdDrop.USER + " [" + S_NAME + "] (" + ON + " [pattern]): " + NL +
       "  " + lang("c_drop23")
   };
   /** Command help. */
@@ -391,10 +393,6 @@ public interface Text {
     '[' + S_INPUT + ']', lang("c_execute1"), lang("c_execute2", S_INPUT)
   };
   /** Command help. */
-  String[] HELPCS = {
-    '[' + S_QUERY + ']', lang("c_cs1"), lang("c_cs2")
-  };
-  /** Command help. */
   String[] HELPKILL = {
     '[' + S_NAME + ']', lang("c_kill1"), lang("c_kill2")
   };
@@ -413,11 +411,9 @@ public interface Text {
   };
   /** Command help. */
   String[] HELPSHOW = {
-    "[" + CmdShow.BACKUPS + '|' + CmdShow.EVENTS +
-    '|' + CmdShow.SESSIONS + '|' + CmdShow.USERS + ']',
+    "[" + CmdShow.BACKUPS + '|' + CmdShow.SESSIONS + '|' + CmdShow.USERS + ']',
     lang("c_show1"),
     lang("c_show21") + NL +
-    LI + CmdShow.EVENTS + ": " + lang("c_show26") + NL +
     LI + CmdShow.SESSIONS + ": " + lang("c_show23") + NL +
     LI + CmdShow.USERS + " (" + ON + " [database]): " + lang("c_show24") + NL +
     LI + CmdShow.BACKUPS + ": " + lang("c_show25")
@@ -425,20 +421,22 @@ public interface Text {
   /** Command help. */
   String[] HELPGRANT = {
     "[" + CmdPerm.NONE + '|' + CmdPerm.READ + '|' + CmdPerm.WRITE + '|' +
-    CmdPerm.CREATE + '|' + CmdPerm.ADMIN + "] (" + ON + " [database]) " + S_TO +
+    CmdPerm.CREATE + '|' + CmdPerm.ADMIN + "] (" + ON + " [pattern]) " + S_TO +
     " [user]",
     lang("c_grant1"),
     lang("c_grant2")
   };
   /** Command help. */
   String[] HELPALTER = {
-    "[" + CmdCreate.DATABASE + '|' + CmdCreate.USER + "] [...]",
+    "[" + CmdAlter.DATABASE + '|' + CmdAlter.PASSWORD + '|' + CmdAlter.USER + "] [...]",
     lang("c_alter1"),
     lang("c_alter2") + NL  +
-    LI + CmdCreate.DATABASE + " [" + S_NAME + "] [newname]" + NL +
+    LI + CmdAlter.DATABASE + " [" + S_NAME + "] [newname]" + NL +
     "  " + lang("c_alterdb") + NL +
-    LI + CmdCreate.USER  + " [" + S_NAME + "] ([" + S_PW + "]):" + NL +
-    "  " + lang("c_alterpw")
+    LI + CmdAlter.PASSWORD + " [" + S_NAME + "] [" + S_PW + "]" + NL +
+    "  " + lang("c_alterpw") + NL +
+    LI + CmdAlter.USER  + " [" + S_NAME + "] ([newname]):" + NL +
+    "  " + lang("c_alteruser")
   };
   /** Command help. */
   String[] HELPINSPECT = {
@@ -446,13 +444,11 @@ public interface Text {
   };
   /** Command help. */
   String[] HELPSET = {
-    "[option] ([value])",
-    lang("c_set1", "info"),
-    lang("c_set2", "option", "value")
+    "[option] ([value])", lang("c_set1"), lang("c_set2")
   };
   /** Command help. */
   String[] HELPGET = {
-    "[option]", lang("c_get1", "info"), lang("c_get2", "option")
+    "[option]", lang("c_get1"), lang("c_get2")
   };
   /** Command help. */
   String[] HELPPASSWORD = {
@@ -476,7 +472,7 @@ public interface Text {
   };
   /** Command help. */
   String[] HELPEXIT = {
-    "", lang("c_exit1", Prop.NAME), lang("c_exit2", Prop.NAME)
+    "", lang("c_exit1"), lang("c_exit2")
   };
 
   // COMMAND INFOS ============================================================
@@ -538,8 +534,6 @@ public interface Text {
 
   /** Database created. */
   String DB_CREATED_X_X = lang("db_created_%_%");
-  /** Path added. */
-  String PATH_ADDED_X_X = lang("path_added_%_%");
   /** Parse error. */
   String NOT_PARSED_X = lang("not_parsed_%");
 
@@ -553,6 +547,8 @@ public interface Text {
   String RES_RENAMED_X_X = lang("res_renamed_%_%");
   /** Resource replaced. */
   String RES_REPLACED_X_X = lang("res_replaced_%_%");
+  /** Resource added. */
+  String RES_ADDED_X = lang("res_added_%");
   /** "Resource Properties". */
   String RES_PROPS = lang("res_props");
 
@@ -566,8 +562,6 @@ public interface Text {
   String NO_TOKENIZER_X = lang("no_tokenizer_%");
   /** No stemmer found. */
   String NO_STEMMER_X = lang("no_stemmer_%");
-  /** Points to a directory. */
-  String NO_DIR_ALLOWED_X = lang("no_dir_allowed_%");
 
   // DATABASE COMMANDS ========================================================
 
@@ -575,6 +569,8 @@ public interface Text {
   String DB_NOT_FOUND_X = lang("db_not_found_%");
   /** Name invalid. */
   String NAME_INVALID_X = lang("name_invalid_%");
+  /** Path invalid. */
+  String PATH_INVALID_X = lang("path_invalid_%");
   /** Database pinned. */
   String DB_PINNED_X = lang("db_pinned_%");
   /** Database updated. */
@@ -692,8 +688,6 @@ public interface Text {
 
   /** Show sessions. */
   String SESSIONS_X = lang("sessions_%");
-  /** Show events. */
-  String EVENTS_X = lang("events_%");
   /** Show packages. */
   String PACKAGES_X = lang("packages_%");
   /** Permission required. */
@@ -716,32 +710,16 @@ public interface Text {
   String USER_CREATED_X = lang("user_created_%");
   /** Password changed. */
   String PW_CHANGED_X = lang("pw_changed_%");
+  /** User altered. */
+  String USER_RENAMED_X_X = lang("user_renamed_%_%");
   /** User unknown. */
   String USER_EXISTS_X = lang("user_exists_%");
-  /** Password is no valid MD5 hash. */
-  String PW_NOT_VALID = lang("pw_not_valid");
   /** Admin user. */
-  String ADMIN_STATIC_X = lang("admin_static_%");
+  String ADMIN_STATIC = lang("admin_static");
   /** Killed sessions. */
   String SESSIONS_KILLED_X = lang("sessions_killed_%");
   /** User kills itself. */
   String KILL_SELF_X = lang("kill_self_%");
-  /** Event dropped. */
-  String EVENT_DROPPED_X = lang("event_dropped_%");
-  /** Event added. */
-  String EVENT_CREATED_X = lang("event_created_%");
-  /** Event not found. */
-  String EVENT_UNKNOWN_X = lang("event_unknown_%");
-  /** Already watching the event. */
-  String EVENT_WATCHED_X = lang("event_watched_%");
-  /** Nothing to unwatch. */
-  String EVENT_NOT_WATCHED_X = lang("event_not_watched_%");
-  /** Event already exists. */
-  String EVENT_EXISTS_X = lang("event_exists_%");
-  /** Watch Event. */
-  String WATCHING_EVENT_X = lang("watching_event_%");
-  /** Unwatch Event. */
-  String UNWATCHING_EVENT_X = lang("unwatching_event_%");
   /** Package deleted. */
   String PKG_DELETED_X = lang("pkg_deleted_%");
   /** Package installed. */
@@ -795,6 +773,10 @@ public interface Text {
   String PARAMETERS = lang("parameters");
   /** "Path". */
   String PATH = lang("path");
+  /** Input. */
+  String INPUT = lang("input");
+  /** External Variables. */
+  String EXTERNAL_VARIABLES = lang("external_variables");
 
   /** Command info. */
   String RECENTLY_OPENED = lang("recently_opened");
@@ -835,7 +817,7 @@ public interface Text {
   /** Info on up-to-date. */
   String UP_TO_DATE = lang("up_to_date");
 
-  /** Info on tags. */
+  /** Info on elements. */
   String ELEMENTS = lang("elements");
   /** Info on attributes. */
   String ATTRIBUTES = lang("attributes");
@@ -894,6 +876,8 @@ public interface Text {
   /** Command info. */
   String COPY_PATH = lang("copy_path");
   /** Command info. */
+  String ADD_AS_IMPORT = lang("add_as_import");
+  /** Command info. */
   String NEW = lang("new");
   /** Command info. */
   String DELETE = lang("delete");
@@ -973,6 +957,8 @@ public interface Text {
   String SAVE_AS = lang("save_as");
   /** Command info. */
   String PACKAGES = lang("packages");
+  /** Command info. */
+  String SHOW_HIDDEN_FILES = lang("show_hidden_files");
 
   /** Command info. */
   String FONTS_D = lang("fonts") + DOTS;
@@ -990,7 +976,7 @@ public interface Text {
   /** Button for refreshing. */
   String REFRESH = lang("refresh");
 
-  /** "Search". */
+  /** "Find". */
   String FIND = lang("find");
   /** "Find files". */
   String FIND_FILES = lang("find_files");
@@ -1007,15 +993,17 @@ public interface Text {
 
   /** "Command". */
   String COMMAND = lang("command");
-  /** "XQuery". */
-  String XQUERY = lang("xquery");
   /** "Backup". */
   String BACKUP = lang("backup");
+  /** "XQuery". */
+  String XQUERY = "XQuery";
 
   /** Button text for deleting files. */
   String DROP = lang("drop");
   /** Button text for optimization. */
   String OPTIMIZE = lang("optimize");
+  /** Button text for optimization. */
+  String OPTIMIZE_ALL = lang("optimize_all");
   /** Button text for renaming databases. */
   String RENAME = lang("rename");
   /** Button text for restoring databases. */
@@ -1027,13 +1015,7 @@ public interface Text {
   /** Button text for creating things. */
   String CREATE = lang("create");
   /** Button for starting the server. */
-  String START = lang("start");
-  /** Button for starting the server. */
   String STOP = lang("stop");
-  /** Button for connecting. */
-  String CONNECT = lang("connect");
-  /** Button for disconnecting. */
-  String DISCONNECT = lang("disconnect");
   /** Button for deleting all. */
   String DELETE_ALL = lang("delete_all");
   /** Button for adding. */
@@ -1067,6 +1049,8 @@ public interface Text {
   String FILE_OR_DIR = lang("file_or_dir");
   /** Use Catalog file Checkbox. */
   String USE_CATALOG_FILE = lang("use_catalog_file");
+  /** Use XInclude. */
+  String USE_XINCLUDE = lang("use_xinclude");
   /** Use Catalog file not found on CP. */
   String HELP1_USE_CATALOG = lang("help1_use_catalog");
   /** Use Catalog file not found on CP. */
@@ -1136,10 +1120,12 @@ public interface Text {
   String MERGE_TYPES = lang("merge_types");
   /** Merge type information. */
   String INCLUDE_STRINGS = lang("include_strings");
-  /** Specification. */
-  String SPECIFICATION = lang("specification");
   /** Unescape characters. */
   String UNESCAPE_CHARS = lang("unescape_chars");
+  /** Liberal parsing. */
+  String LIBERAL_PARSING = lang("liberal_parsing");
+  /** Backslash. */
+  String BACKSLASHES = lang("backslashes");
 
   /** General info. */
   String GENERAL = lang("general");
@@ -1158,8 +1144,6 @@ public interface Text {
   /** Dialog asking if a new database should be be created. */
   String NEW_DB_QUESTION = lang("no_db_found") + NL + lang("new_db_question");
 
-  /** Users. */
-  String USERS = lang("users");
   /** Users. */
   String USERS_X = lang("users_%");
   /** Confirmation . */
@@ -1211,6 +1195,8 @@ public interface Text {
   String DELETE_FILE_X = lang("delete_file_%");
   /** Dialog title for reopening a file. */
   String REOPEN_FILE_X = lang("reopen_file_%");
+  /** Close all. */
+  String CLOSE_ALL = lang("close_all");
 
   /** Dialog title for exporting nodes. */
   String OUTPUT_DIR = lang("output_dir");
@@ -1219,6 +1205,8 @@ public interface Text {
 
   /** Database path. */
   String DATABASE_PATH = lang("database_path");
+  /** Repository path. */
+  String REPOSITORY_PATH = lang("repository_path");
   /** Interactions. */
   String GUI_INTERACTIONS = lang("gui_interactions");
   /** Look and feel. */
@@ -1376,47 +1364,6 @@ public interface Text {
   /** No HTML Parser. */
   String H_NO_HTML_PARSER = lang("h_no_html_parser");
 
-  // SERVER TEXTS =============================================================
-
-  /** Server. */
-  String S_LOCALSERVER = lang("s_localserver");
-  /** Users. */
-  String S_CONNECT = lang("s_connect");
-  /** Host. */
-  String S_HOST = lang("s_host");
-  /** PORT. */
-  String S_PORT = lang("s_port");
-  /** Local. */
-  String S_LOCALPORT = lang("s_localport");
-  /** Create user. */
-  String S_CREATEU = lang("s_createu");
-  /** Global permissions. */
-  String S_GLOBPERM = lang("s_globperm") + COLS;
-  /** Local permissions. */
-  String S_LOCPERM = lang("s_locperm") + COLS;
-  /** Question for dropping user. */
-  String S_DRQUESTION = lang("s_drquestion") + NL + ARE_YOU_SURE;
-  /** Question for revoking right from logged in user. */
-  String S_DBREVOKE = lang("s_dbrevoke") + NL + ARE_YOU_SURE;
-  /** Login. */
-  String S_ADLOGIN = lang("s_adlogin");
-  /** Connected. */
-  String S_CONNECTED = lang("s_connected");
-  /** Disconnected. */
-  String S_DISCONNECTED = lang("s_disconnected");
-  /** Server information. */
-  String S_INFO1 = lang("s_info1");
-  /** Server information. */
-  String S_INFO2 = lang("s_info2");
-  /** Sessions. */
-  String S_SESSIONS = lang("s_sessions");
-  /** Logs. */
-  String S_LOCALLOGS = lang("s_locallogs");
-  /** Button text for altering password. */
-  String S_ALTER = lang("s_alter") + DOTS;
-  /** Command info. */
-  String S_SERVER_ADMIN = lang("s_server_admin");
-
   /** Dummy string to check if all language strings have been assigned. */
   String DUMMY = lang(null);
 }
