@@ -1,20 +1,22 @@
 package org.basex.core.cmd;
 
 import org.basex.core.*;
+import org.basex.core.locks.*;
+import org.basex.core.users.*;
 
 /**
  * Abstract class for database backup.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 abstract class ABackup extends Command {
   /**
    * Protected constructor.
-   * @param a arguments
+   * @param args arguments
    */
-  ABackup(final String... a) {
-    super(Perm.CREATE, false, a);
+  ABackup(final String... args) {
+    super(Perm.CREATE, false, args);
   }
 
   @Override
