@@ -1,22 +1,21 @@
 package org.basex.core.cmd;
 
 import static org.basex.core.Text.*;
-import static org.basex.data.DataText.*;
 
 import java.io.*;
 
 import org.basex.core.*;
+import org.basex.core.locks.*;
+import org.basex.core.users.*;
 import org.basex.data.*;
 import org.basex.index.*;
-import org.basex.index.ft.*;
-import org.basex.index.value.*;
 import org.basex.io.*;
 import org.basex.util.*;
 
 /**
  * Abstract class for database creation commands.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public abstract class ACreate extends Command {
@@ -25,51 +24,49 @@ public abstract class ACreate extends Command {
 
   /**
    * Protected constructor, specifying command arguments.
-   * @param arg arguments
+   * @param args arguments
    */
-  ACreate(final String... arg) {
-    this(Perm.CREATE, false, arg);
+  ACreate(final String... args) {
+    this(Perm.CREATE, false, args);
     newData = true;
   }
 
   /**
    * Protected constructor, specifying command flags and arguments.
-   * @param p required permission
-   * @param d requires opened database
-   * @param arg arguments
+   * @param perm required permission
+   * @param openDB requires opened database
+   * @param args arguments
    */
-  ACreate(final Perm p, final boolean d, final String... arg) {
-    super(p, d, arg);
+  ACreate(final Perm perm, final boolean openDB, final String... args) {
+    super(perm, openDB, args);
   }
 
   /**
    * Converts the input (second argument of {@link #args}, or {@link #in} reference)
    * to an {@link IO} reference.
    * @param name name of source
-   * @return IO reference
+   * @return IO reference (can be {@code null})
    * @throws IOException I/O exception
    */
-  IO sourceToIO(final String name) throws IOException {
+  final IO sourceToIO(final String name) throws IOException {
     IO io = null;
     if(args[1] != null && !args[1].isEmpty()) {
       io = IO.get(args[1]);
     } else if(in != null) {
       if(in.getCharacterStream() != null) {
-        final Reader r = in.getCharacterStream();
-        final TokenBuilder tb = new TokenBuilder();
-        try {
-          for(int c; (c = r.read()) != -1;) tb.add(c);
-        } finally {
-          r.close();
+        final StringBuilder sb = new StringBuilder();
+        try(final Reader r = in.getCharacterStream()) {
+          for(int c; (c = r.read()) != -1;) sb.append((char) c);
         }
-        io = new IOContent(tb.finish());
+        io = new IOContent(sb.toString());
       } else if(in.getByteStream() != null) {
         io = new IOStream(in.getByteStream());
       } else if(in.getSystemId() != null) {
         io = IO.get(in.getSystemId());
       }
     }
-    // update name if not given by the IO reference anyway
+
+    // assign (intermediate) name to input reference
     if(io instanceof IOContent || io instanceof IOStream) {
       if(name.endsWith("/")) throw new BaseXException(NAME_INVALID_X, name);
       io.name(name.isEmpty() ? "" : name + '.' + options.get(MainOptions.PARSER));
@@ -77,53 +74,70 @@ public abstract class ACreate extends Command {
     return io;
   }
 
+  /**
+   * Starts an update operation.
+   * @return success flag
+   */
+  final boolean startUpdate() {
+    return startUpdate(context.data());
+  }
+
+  /**
+   * Finalizes an update operation.
+   * @return success flag
+   */
+  final boolean finishUpdate() {
+    return finishUpdate(context.data());
+  }
+
   /**
    * Builds the specified index.
-   * @param index index to be built
+   * @param type index to be built
    * @param data data reference
+   * @param options main options
    * @param cmd calling command
    * @throws IOException I/O exception
    */
-  static void create(final IndexType index, final Data data, final ACreate cmd) throws IOException {
-    if(data.inMemory()) return;
+  static void create(final IndexType type, final Data data, final MainOptions options,
+      final ACreate cmd) throws IOException {
 
-    final IndexBuilder ib;
-    switch(index) {
-      case TEXT:      ib = new ValueIndexBuilder(data, true); break;
-      case ATTRIBUTE: ib = new ValueIndexBuilder(data, false); break;
-      case FULLTEXT:  ib = new FTBuilder(data); break;
-      default:        throw Util.notExpected();
+    data.meta.dirty = true;
+    final boolean ok = data.dropIndex(type);
+    if(ok) {
+      if(type == IndexType.TEXT) {
+        data.meta.textindex = true;
+      } else if(type == IndexType.ATTRIBUTE) {
+        data.meta.attrindex = true;
+      } else if(type == IndexType.FULLTEXT) {
+        data.meta.ftxtindex = true;
+      } else {
+        throw Util.notExpected();
+      }
     }
-    data.closeIndex(index);
-    data.setIndex(index, (cmd == null ? ib : cmd.proc(ib)).build());
+    data.createIndex(type, options, cmd);
   }
 
   /**
    * Drops the specified index.
-   * @param index index type
+   * @param type index type
    * @param data data reference
-   * @return success of operation
+   * @return success flag
    */
-  static boolean drop(final IndexType index, final Data data) {
-    String pat = null;
-    switch(index) {
-      case TEXT:
-        data.meta.textindex = false;
-        pat = DATATXT;
-        break;
-      case ATTRIBUTE:
-        data.meta.attrindex = false;
-        pat = DATAATV;
-        break;
-      case FULLTEXT:
-        data.meta.ftxtindex = false;
-        pat = DATAFTX;
-        break;
-      default:
-    }
-    data.closeIndex(index);
+  static boolean drop(final IndexType type, final Data data) {
     data.meta.dirty = true;
-    return pat == null || data.meta.drop(pat + '.');
+    final boolean ok = data.dropIndex(type);
+    if(ok) {
+      if(type == IndexType.TEXT) {
+        data.meta.textindex = false;
+      } else if(type == IndexType.ATTRIBUTE) {
+        data.meta.attrindex = false;
+      } else if(type == IndexType.FULLTEXT) {
+        data.meta.ftxtindex = false;
+      } else {
+        throw Util.notExpected();
+      }
+    }
+    return ok;
   }
 
   @Override
@@ -135,7 +149,7 @@ public abstract class ACreate extends Command {
   @Override
   public void databases(final LockResult lr) {
     // default implementation for commands accessing (exclusively) the opened database
-    lr.write.add(DBLocking.CTX);
+    lr.write.add(DBLocking.CONTEXT);
   }
 
   @Override
