@@ -1,20 +1,22 @@
 package org.basex.core.cmd;
 
 import org.basex.core.*;
+import org.basex.core.locks.*;
+import org.basex.core.users.*;
 
 /**
  * Abstract class for option commands.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 abstract class AGet extends Command {
   /**
    * Default constructor.
-   * @param a arguments
+   * @param args arguments
    */
-  AGet(final String... a) {
-    super(Perm.NONE, a);
+  AGet(final String... args) {
+    super(Perm.NONE, args);
   }
 
   @Override
