@@ -2,16 +2,16 @@ package org.basex.core.cmd;
 
 import static org.basex.core.Text.*;
 
-import org.basex.core.*;
+import org.basex.core.users.*;
 import org.basex.data.*;
-import org.basex.data.atomic.*;
 import org.basex.io.*;
+import org.basex.query.up.atomic.*;
 import org.basex.util.list.*;
 
 /**
  * Evaluates the 'delete' command and deletes resources from a database.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class Delete extends ACreate {
@@ -28,23 +28,22 @@ public final class Delete extends ACreate {
     final Data data = context.data();
     final String target = args[0];
 
-    // start update
-    if(!data.startUpdate()) return error(DB_PINNED_X, data.meta.name);
+    if(!startUpdate()) return false;
 
     // delete all documents
     final IntList docs = data.resources.docs(target);
-    final AtomicUpdateCache atomics = new AtomicUpdateCache(data);
+    final AtomicUpdateCache auc = new AtomicUpdateCache(data);
     final int ds = docs.size();
-    for(int d = 0; d < ds; d++) atomics.addDelete(docs.get(d));
-    atomics.execute(false);
-    context.update();
+    for(int d = 0; d < ds; d++) auc.addDelete(docs.get(d));
+    auc.execute(false);
+    context.invalidate();
 
     // delete binaries
     final TokenList bins = data.resources.binaries(target);
     delete(data, target);
 
     // finish update
-    data.finishUpdate();
+    if(!finishUpdate()) return false;
 
     // return info message
     return info(RES_DELETED_X_X, docs.size() + bins.size(), perf);
