@@ -3,12 +3,14 @@ package org.basex.core.cmd;
 import static org.basex.core.Text.*;
 
 import org.basex.core.*;
+import org.basex.core.locks.*;
+import org.basex.core.users.*;
 import org.basex.data.*;
 
 /**
  * Evaluates the 'flush' command and flushes the database buffers.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class Flush extends Command {
@@ -22,16 +24,12 @@ public final class Flush extends Command {
   @Override
   protected boolean run() {
     final Data data = context.data();
-    if(!options.get(MainOptions.AUTOFLUSH)) {
-      options.set(MainOptions.AUTOFLUSH, true);
-      data.finishUpdate();
-      options.set(MainOptions.AUTOFLUSH, false);
-    }
+    if(!options.get(MainOptions.AUTOFLUSH)) data.flush(true);
     return info(DB_FLUSHED_X, data.meta.name, perf);
   }
 
   @Override
   public void databases(final LockResult lr) {
-    lr.write.add(DBLocking.CTX);
+    lr.write.add(DBLocking.CONTEXT);
   }
 }
