@@ -1,12 +1,16 @@
 package org.basex.core.cmd;
 
 import static org.basex.core.Text.*;
+
 import java.io.*;
 import java.util.*;
 
 import org.basex.core.*;
+import org.basex.core.locks.*;
 import org.basex.core.parse.*;
-import org.basex.core.parse.Commands.*;
+import org.basex.core.parse.Commands.Cmd;
+import org.basex.core.parse.Commands.CmdInfo;
+import org.basex.core.users.*;
 import org.basex.data.*;
 import org.basex.util.*;
 
@@ -14,7 +18,7 @@ import org.basex.util.*;
  * Evaluates the 'info database' command and returns information on the
  * currently opened database.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class InfoDB extends AInfo {
@@ -27,14 +31,14 @@ public final class InfoDB extends AInfo {
 
   @Override
   protected boolean run() throws IOException {
-    final boolean create = context.user.has(Perm.CREATE);
+    final boolean create = context.user().has(Perm.CREATE);
     out.print(db(context.data().meta, false, true, create));
     return true;
   }
 
   @Override
   public void databases(final LockResult lr) {
-    lr.read.add(DBLocking.CTX);
+    lr.read.add(DBLocking.CONTEXT);
   }
 
   /**
@@ -59,13 +63,13 @@ public final class InfoDB extends AInfo {
     // count number of raw files
     info(tb, DOCUMENTS, meta.ndocs);
     info(tb, BINARIES, meta.path != null ? meta.binaries().descendants().size() : 0);
-    info(tb, TIMESTAMP, DateTime.format(new Date(meta.dbtime()), DateTime.DATETIME));
+    info(tb, TIMESTAMP, DateTime.format(new Date(meta.dbtime())));
     if(meta.corrupt) tb.add(' ' + DB_CORRUPT + NL);
 
     tb.add(NL).addExt(header, RES_PROPS);
     if(create && !meta.original.isEmpty()) info(tb, INPUT_PATH, meta.original);
     if(meta.filesize != 0) info(tb, INPUT_SIZE, Performance.format(meta.filesize));
-    info(tb, TIMESTAMP, DateTime.format(new Date(meta.time), DateTime.DATETIME));
+    info(tb, TIMESTAMP, DateTime.format(new Date(meta.time)));
     info(tb, ENCODING, meta.encoding);
     info(tb, MainOptions.CHOP.name(), meta.chop);
 
@@ -84,6 +88,7 @@ public final class InfoDB extends AInfo {
         info(tb, MainOptions.DIACRITICS.name(), meta.diacritics);
         info(tb, MainOptions.STOPWORDS.name(), meta.stopwords);
         info(tb, MainOptions.UPDINDEX.name(), meta.updindex);
+        info(tb, MainOptions.AUTOOPTIMIZE.name(), meta.autoopt);
         info(tb, MainOptions.MAXCATS.name(), meta.maxcats);
         info(tb, MainOptions.MAXLEN.name(), meta.maxlen);
       }
