@@ -6,17 +6,20 @@ import static org.basex.util.Token.*;
 import java.io.*;
 
 import org.basex.core.*;
+import org.basex.core.locks.*;
+import org.basex.core.users.*;
 import org.basex.data.*;
 import org.basex.index.resource.*;
 import org.basex.io.*;
 import org.basex.io.serial.*;
 import org.basex.util.*;
+import org.basex.util.http.*;
 import org.basex.util.list.*;
 
 /**
  * Evaluates the 'list' command and shows all available databases.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class List extends Command {
@@ -29,7 +32,7 @@ public final class List extends Command {
 
   /**
    * Default constructor.
-   * @param name database name
+   * @param name database name (can be {@code null})
    */
   public List(final String name) {
     this(name, null);
@@ -37,21 +40,21 @@ public final class List extends Command {
 
   /**
    * Default constructor.
-   * @param name database name
-   * @param path database path
+   * @param name database name (can be {@code null})
+   * @param path database path (can be {@code null})
    */
   public List(final String name, final String path) {
-    super(Perm.NONE, name, path);
+    super(Perm.NONE, name == null ? "" : name, path == null ? "" : path);
   }
 
   @Override
   protected boolean run() throws IOException {
-    return args[0] == null || args[0].isEmpty() ? list() : listDB();
+    return args[0].isEmpty() ? list() : listDB();
   }
 
   @Override
   public void databases(final LockResult lr) {
-    if(args[0] == null || args[0].isEmpty()) lr.readAll = true;
+    if(args[0].isEmpty()) lr.readAll = true;
     else lr.read.add(args[0]);
   }
 
@@ -64,39 +67,35 @@ public final class List extends Command {
     final Table table = new Table();
     table.description = DATABASES_X;
 
-    final boolean create = context.user.has(Perm.CREATE);
+    final boolean create = context.user().has(Perm.CREATE);
     table.header.add(NAME);
     table.header.add(RESOURCES);
     table.header.add(SIZE);
     if(create) table.header.add(INPUT_PATH);
 
-    for(final String name : context.databases.listDBs()) {
+    for(final String name : context.filter(Perm.READ, context.databases.listDBs())) {
       String file = null;
-      long size = 0;
-      int docs = 0;
-      final MetaData meta = new MetaData(name, context);
+      long dbsize = 0;
+      int count = 0;
+
       try {
+        final MetaData meta = new MetaData(name, options, soptions);
         meta.read();
-        size = meta.dbsize();
-        docs = meta.ndocs;
-        if(context.perm(Perm.READ, meta)) file = meta.original;
+        dbsize = meta.dbsize();
+        file = meta.original;
+        // add number of raw files
+        count = meta.ndocs + new IOFile(soptions.dbpath(name), IO.RAW).descendants().size();
       } catch(final IOException ex) {
         file = ERROR;
       }
 
-      // count number of raw files
-      final IOFile dir = new IOFile(goptions.dbpath(name), IO.RAW);
-      final int bin = dir.descendants().size();
-
       // create entry
-      if(file != null) {
-        final TokenList tl = new TokenList(4);
-        tl.add(name);
-        tl.add(docs + bin);
-        tl.add(size);
-        if(create) tl.add(file);
-        table.contents.add(tl);
-      }
+      final TokenList tl = new TokenList(create ? 4 : 3);
+      tl.add(name);
+      tl.add(count);
+      tl.add(dbsize);
+      if(create) tl.add(file);
+      table.contents.add(tl);
     }
     out.println(table.sort().finish());
     return true;
@@ -108,20 +107,19 @@ public final class List extends Command {
    * @throws IOException I/O exception
    */
   private boolean listDB() throws IOException {
-    final String db = args[0];
-    final String path = args[1] != null ? args[1] : "";
+    final String db = args[0], path = args[1];
     if(!Databases.validName(db)) return error(NAME_INVALID_X, db);
 
     final Table table = new Table();
     table.description = RESOURCES;
     table.header.add(INPUT_PATH);
     table.header.add(TYPE);
-    table.header.add(MimeTypes.CONTENT_TYPE);
+    table.header.add(DataText.CONTENT_TYPE);
     table.header.add(SIZE);
 
     try {
       // add xml documents
-      final Data data = Open.open(db, context);
+      final Data data = Open.open(db, context, options);
       final Resources res = data.resources;
       final IntList il = res.docs(path);
       final int ds = il.size();
@@ -131,7 +129,7 @@ public final class List extends Command {
         final byte[] file = data.text(pre, true);
         tl.add(file);
         tl.add(SerialMethod.XML.toString());
-        tl.add(MimeTypes.APP_XML);
+        tl.add(MediaType.APPLICATION_XML.toString());
         tl.add(data.size(pre, Data.DOC));
         table.contents.add(tl);
       }
@@ -141,7 +139,7 @@ public final class List extends Command {
         final TokenList tl = new TokenList(3);
         tl.add(file);
         tl.add(SerialMethod.RAW.toString());
-        tl.add(MimeTypes.get(f));
+        tl.add(MediaType.get(f).toString());
         tl.add(data.meta.binary(f).length());
         table.contents.add(tl);
       }
@@ -155,12 +153,12 @@ public final class List extends Command {
 
   /**
    * Returns a list of all databases.
-   * @param ctx database context
+   * @param sopts static options
    * @return list of databases
    */
-  public static StringList list(final Context ctx) {
+  public static StringList list(final StaticOptions sopts) {
     final StringList db = new StringList();
-    for(final IOFile f : ctx.globalopts.dbpath().children()) {
+    for(final IOFile f : sopts.dbpath().children()) {
       final String name = f.name();
       if(f.isDir() && !name.startsWith(".")) db.add(name);
     }
