@@ -2,10 +2,10 @@ package org.basex.core.cmd;
 
 import static org.basex.core.Text.*;
 
-import org.basex.core.*;
 import org.basex.core.parse.*;
 import org.basex.core.parse.Commands.Cmd;
 import org.basex.core.parse.Commands.CmdRepo;
+import org.basex.core.users.*;
 import org.basex.query.*;
 import org.basex.query.util.pkg.*;
 import org.basex.util.*;
@@ -13,7 +13,7 @@ import org.basex.util.*;
 /**
  * Evaluates the 'repo delete' command.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Rositsa Shadura
  */
 public final class RepoDelete extends ARepo {
@@ -22,12 +22,12 @@ public final class RepoDelete extends ARepo {
 
   /**
    * Constructor.
-   * @param p package
-   * @param i input info
+   * @param perm package
+   * @param info input info
    */
-  public RepoDelete(final String p, final InputInfo i) {
-    super(Perm.CREATE, p);
-    info = i;
+  public RepoDelete(final String perm, final InputInfo info) {
+    super(Perm.CREATE, perm);
+    this.info = info;
   }
 
   @Override
