@@ -3,13 +3,16 @@ package org.basex.core.cmd;
 import java.io.*;
 
 import org.basex.core.*;
+import org.basex.core.locks.*;
 import org.basex.core.parse.*;
-import org.basex.core.parse.Commands.*;
+import org.basex.core.parse.Commands.Cmd;
+import org.basex.core.parse.Commands.CmdShow;
+import org.basex.core.users.*;
 
 /**
  * Evaluates the 'show sessions' command and shows server sessions.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class ShowSessions extends Command {
