@@ -4,8 +4,8 @@ import static org.basex.core.Text.*;
 
 import java.io.*;
 
-import org.basex.core.*;
 import org.basex.core.parse.*;
+import org.basex.core.users.*;
 import org.basex.data.*;
 import org.basex.io.*;
 import org.basex.io.in.*;
@@ -16,10 +16,13 @@ import org.xml.sax.*;
 /**
  * Evaluates the 'store' command and stores binary content into the database.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class Store extends ACreate {
+  /** Indicates if database should be locked. */
+  boolean lock = true;
+
   /**
    * Constructor, specifying a target path.
    * The input needs to be set via {@link #setInput(InputStream)}.
@@ -40,43 +43,39 @@ public final class Store extends ACreate {
 
   @Override
   protected boolean run() {
-    final boolean create = context.user.has(Perm.CREATE);
+    final boolean create = context.user().has(Perm.CREATE);
     String path = MetaData.normPath(args[0]);
-    if(path == null || path.endsWith(".")) return error(NAME_INVALID_X, args[0]);
+    if(path == null || path.endsWith(".")) return error(PATH_INVALID_X, args[0]);
 
     if(in == null) {
       final IO io = IO.get(args[1]);
-      if(!io.exists() || io.isDir())
-        return error(RES_NOT_FOUND_X, create ? io : args[1]);
+      if(!io.exists() || io.isDir()) return error(RES_NOT_FOUND_X, create ? io : args[1]);
       in = io.inputSource();
       // set/add name of document
-      if((path.isEmpty() || path.endsWith("/")) && !(io instanceof IOContent))
-        path += io.name();
+      if((path.isEmpty() || path.endsWith("/")) && !(io instanceof IOContent)) path += io.name();
     }
 
-    // ensure that the final name is not empty
-    if(path.isEmpty()) return error(NAME_INVALID_X, path);
-
     // ensure that the name is not empty and contains no trailing dots
     final Data data = context.data();
     if(data.inMemory()) return error(NO_MAINMEM);
 
     final IOFile file = data.meta.binary(path);
-    if(path.isEmpty() || path.endsWith(".") || file == null || file.isDir())
-      return error(NAME_INVALID_X, create ? path : args[0]);
+    if(path.isEmpty() || path.endsWith(".") || file == null)
+      return error(PATH_INVALID_X, create ? path : args[0]);
 
     // start update
-    if(!data.startUpdate()) return error(DB_PINNED_X, data.meta.name);
-
+    if(lock && !startUpdate()) return false;
+    boolean ok = true;
     try {
       store(in, file);
-      return info(QUERY_EXECUTED_X_X, "", perf);
+      ok = info(QUERY_EXECUTED_X_X, "", perf);
     } catch(final IOException ex) {
       Util.debug(ex);
-      return error(FILE_NOT_SAVED_X, file);
+      ok = error(FILE_NOT_SAVED_X, file);
     } finally {
-      data.finishUpdate();
+      if(lock) ok &= finishUpdate();
     }
+    return ok;
   }
 
   /**
@@ -87,27 +86,22 @@ public final class Store extends ACreate {
    */
   public static void store(final InputSource in, final IOFile file) throws IOException {
     // add directory if it does not exist anyway
-    file.dir().md();
+    if(file.isDir()) file.delete();
+    file.parent().md();
 
-    final PrintOutput po = new PrintOutput(file.path());
-    try {
+    try(final PrintOutput po = new PrintOutput(file.path())) {
       final Reader r = in.getCharacterStream();
       final InputStream is = in.getByteStream();
       final String id = in.getSystemId();
       if(r != null) {
-        for(int c; (c = r.read()) != -1;) po.utf8(c);
+        for(int c; (c = r.read()) != -1;) po.print(c);
       } else if(is != null) {
         for(int b; (b = is.read()) != -1;) po.write(b);
       } else if(id != null) {
-        final BufferInput bi = new BufferInput(IO.get(id));
-        try {
+        try(final BufferInput bi = new BufferInput(IO.get(id))) {
           for(int b; (b = bi.read()) != -1;) po.write(b);
-        } finally {
-          bi.close();
         }
       }
-    } finally {
-      po.close();
     }
   }
 
