@@ -2,7 +2,7 @@ package org.basex.data;
 
 import static org.basex.core.Text.*;
 import static org.basex.data.DataText.*;
-import static org.basex.util.Token.*;
+import static org.basex.util.Strings.*;
 
 import java.io.*;
 
@@ -18,19 +18,15 @@ import org.basex.util.ft.*;
 /**
  * This class provides meta information on a database.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class MetaData {
   /** Database path. Set to {@code null} if database is in main memory. */
   public final IOFile path;
-  /** Database options. */
-  public final MainOptions options;
 
   /** Database name. */
   public volatile String name;
-  /** Database users. */
-  public volatile Users users;
 
   /** Encoding of original document. */
   public volatile String encoding = UTF8;
@@ -38,18 +34,20 @@ public final class MetaData {
   public volatile String original = "";
   /** Size of original document. */
   public volatile long filesize;
-  /** Number of stored documents. */
-  public volatile int ndocs;
   /** Timestamp of original document. */
   public volatile long time;
+  /** Number of stored documents. */
+  public volatile int ndocs;
 
   /** Flag for whitespace chopping. */
   public volatile boolean chop;
   /** Flag for activated automatic index update. */
   public volatile boolean updindex;
+  /** Flag for automatic index updating. */
+  public volatile boolean autoopt;
   /** Indicates if a text index exists. */
   public volatile boolean textindex;
-  /** Indicates if a attribute index exists. */
+  /** Indicates if an attribute index exists. */
   public volatile boolean attrindex;
   /** Indicates if a full-text index exists. */
   public volatile boolean ftxtindex;
@@ -77,15 +75,14 @@ public final class MetaData {
   /** Language of full-text search index. */
   public volatile Language language;
 
-  /** Flag for out-of-date index structures.
-   *  Will be removed as soon as all indexes support updates. */
+  /** Indicates if index structures are out-dated. */
   public volatile boolean uptodate = true;
-  /** Flag to indicate possible corruption. */
+  /** Indicate if the database may be corrupt. */
   public volatile boolean corrupt;
   /** Dirty flag. */
   public volatile boolean dirty;
 
-  /** Table size. */
+  /** Number of nodes. */
   public volatile int size;
   /** Last (highest) id assigned to a node. */
   public volatile int lastid = -1;
@@ -98,32 +95,22 @@ public final class MetaData {
   private volatile int scoring;
 
   /**
-   * Constructor, specifying the database options.
-   * @param opts database options
+   * Constructor for a main-memory database instance.
+   * @param options database options
    */
-  public MetaData(final MainOptions opts) {
-    this("", opts, null);
+  MetaData(final MainOptions options) {
+    this("", options, null);
   }
 
   /**
-   * Constructor, specifying the database name and context.
-   * @param db name of the database
-   * @param ctx database context
+   * Constructor.
+   * @param name name of the database
+   * @param options database options
+   * @param sopts static options
    */
-  public MetaData(final String db, final Context ctx) {
-    this(db, ctx.options, ctx.globalopts);
-  }
-
-  /**
-   * Constructor, specifying the database name.
-   * @param db name of the database
-   * @param opts database options
-   * @param gopts global options
-   */
-  private MetaData(final String db, final MainOptions opts, final GlobalOptions gopts) {
-    path = gopts != null ? gopts.dbpath(db) : null;
-    options = opts;
-    name = db;
+  public MetaData(final String name, final MainOptions options, final StaticOptions sopts) {
+    this.name = name;
+    path = sopts != null ? sopts.dbpath(name) : null;
     chop = options.get(MainOptions.CHOP);
     createtext = options.get(MainOptions.TEXTINDEX);
     createattr = options.get(MainOptions.ATTRINDEX);
@@ -132,11 +119,11 @@ public final class MetaData {
     stemming = options.get(MainOptions.STEMMING);
     casesens = options.get(MainOptions.CASESENS);
     updindex = options.get(MainOptions.UPDINDEX);
+    autoopt = options.get(MainOptions.AUTOOPTIMIZE);
     maxlen = options.get(MainOptions.MAXLEN);
     maxcats = options.get(MainOptions.MAXCATS);
     stopwords = options.get(MainOptions.STOPWORDS);
     language = Language.get(options);
-    users = new Users(null);
   }
 
   // STATIC METHODS ==========================================================
@@ -146,12 +133,13 @@ public final class MetaData {
    * removes duplicate and leading slashes.
    * Returns {@code null} if the path contains invalid characters.
    * @param path input path
-   * @return normalized path, or {@code null}
+   * @return normalized path or {@code null}
    */
   public static String normPath(final String path) {
     final StringBuilder sb = new StringBuilder();
     boolean slash = false;
-    for(int p = 0; p < path.length(); p++) {
+    final int pl = path.length();
+    for(int p = 0; p < pl; p++) {
       final char c = path.charAt(p);
       if(c == '\\' || c == '/') {
         if(!slash && p != 0) sb.append('/');
@@ -167,15 +155,15 @@ public final class MetaData {
 
   /**
    * Calculates the database size.
-   * @param io current file
+   * @param file current file
    * @return file length
    */
-  private static long dbsize(final IOFile io) {
+  private static long dbsize(final IOFile file) {
     long s = 0;
-    if(io.isDir()) {
-      for(final IOFile f : io.children()) s += dbsize(f);
+    if(file.isDir()) {
+      for(final IOFile f : file.children()) s += dbsize(f);
     } else {
-      s += io.length();
+      s += file.length();
     }
     return s;
   }
@@ -183,11 +171,11 @@ public final class MetaData {
   /**
    * Creates a database file.
    * @param path database path
-   * @param fn filename
+   * @param name filename
    * @return database filename
    */
-  public static IOFile file(final IOFile path, final String fn) {
-    return new IOFile(path, fn + IO.BASEXSUFFIX);
+  public static IOFile file(final IOFile path, final String name) {
+    return new IOFile(path, name + IO.BASEXSUFFIX);
   }
 
   // PUBLIC METHODS ===========================================================
@@ -219,11 +207,11 @@ public final class MetaData {
   /**
    * Returns a file instance for the specified database file.
    * Should only be called if database is disk-based.
-   * @param fn filename
+   * @param filename filename
    * @return database filename
    */
-  public IOFile dbfile(final String fn) {
-    return file(path, fn);
+  public IOFile dbfile(final String filename) {
+    return file(path, filename);
   }
 
   /**
@@ -235,7 +223,15 @@ public final class MetaData {
   }
 
   /**
-   * Returns the specified binary file, or {@code null} if the resource
+   * Returns a file that indicates ongoing updates.
+   * @return updating file
+   */
+  public IOFile updateFile() {
+    return dbfile(DATAUPD);
+  }
+
+  /**
+   * Returns the specified binary file or {@code null} if the resource
    * path cannot be resolved (e.g. if it points to a parent directory).
    * @param pth internal file path
    * @return binary directory
@@ -250,11 +246,11 @@ public final class MetaData {
   /**
    * Drops the specified database files.
    * Should only be called if database is disk-based.
-   * @param pat file pattern, or {@code null} if all files are to be deleted
+   * @param pattern file pattern or {@code null} if all files are to be deleted
    * @return result of check
    */
-  public synchronized boolean drop(final String pat) {
-    return path != null && DropDB.drop(path, pat + IO.BASEXSUFFIX);
+  public synchronized boolean drop(final String pattern) {
+    return path != null && DropDB.drop(path, pattern + IO.BASEXSUFFIX);
   }
 
   /**
@@ -262,12 +258,8 @@ public final class MetaData {
    * @throws IOException exception
    */
   public void read() throws IOException {
-    DataInput di = null;
-    try {
-      di = new DataInput(dbfile(DATAINF));
+    try(final DataInput di = new DataInput(dbfile(DATAINF))) {
       read(di);
-    } finally {
-      if(di != null) try { di.close(); } catch(final IOException ignored) { }
     }
   }
 
@@ -276,15 +268,16 @@ public final class MetaData {
    * @param in input stream
    * @throws IOException I/O exception
    */
-  public void read(final DataInput in) throws IOException {
+  void read(final DataInput in) throws IOException {
     String storage = "", istorage = "";
     while(true) {
-      final String k = string(in.readToken());
+      final String k = Token.string(in.readToken());
       if(k.isEmpty()) break;
       if(k.equals(DBPERM)) {
-        users.read(in);
+        // legacy (Version < 8)
+        for(int u = in.readNum(); u > 0; --u) { in.readToken(); in.readToken(); in.readNum(); }
       } else {
-        final String v = string(in.readToken());
+        final String v = Token.string(in.readToken());
         if(k.equals(DBSTR))           storage    = v;
         else if(k.equals(IDBSTR))     istorage   = v;
         else if(k.equals(DBFNAME))    original   = v;
@@ -302,6 +295,7 @@ public final class MetaData {
         else if(k.equals(DBFTDC))     diacritics = toBool(v);
         else if(k.equals(DBCHOP))     chop       = toBool(v);
         else if(k.equals(DBUPDIDX))   updindex   = toBool(v);
+        else if(k.equals(DBAUTOOPT))  autoopt    = toBool(v);
         else if(k.equals(DBTXTIDX))   textindex  = toBool(v);
         else if(k.equals(DBATVIDX))   attrindex  = toBool(v);
         else if(k.equals(DBFTXIDX))   ftxtindex  = toBool(v);
@@ -344,6 +338,7 @@ public final class MetaData {
     writeInfo(out, DBSIZE,     size);
     writeInfo(out, DBCHOP,     chop);
     writeInfo(out, DBUPDIDX,   updindex);
+    writeInfo(out, DBAUTOOPT,  autoopt);
     writeInfo(out, DBTXTIDX,   textindex);
     writeInfo(out, DBATVIDX,   attrindex);
     writeInfo(out, DBFTXIDX,   ftxtindex);
@@ -359,8 +354,6 @@ public final class MetaData {
     writeInfo(out, DBUPTODATE, uptodate);
     writeInfo(out, DBLASTID,   lastid);
     if(language != null) writeInfo(out, DBFTLN, language.toString());
-    out.writeToken(token(DBPERM));
-    users.write(out);
     out.write(0);
   }
 
@@ -379,52 +372,63 @@ public final class MetaData {
     ftxtindex = false;
   }
 
+  /**
+   * Assigns parser information.
+   * @param parser parser
+   */
+  public void assign(final Parser parser) {
+    final IO file = parser.source;
+    original = file != null ? file.path() : "";
+    filesize = file != null ? file.length() : 0;
+    time = file != null ? file.timeStamp() : System.currentTimeMillis();
+  }
+
   // PRIVATE METHODS ==========================================================
 
   /**
    * Converts the specified string to a boolean value.
-   * @param v value
+   * @param value value
    * @return result
    */
-  private static boolean toBool(final String v) {
-    return "1".equals(v);
+  private static boolean toBool(final String value) {
+    return "1".equals(value);
   }
 
   /**
    * Writes a boolean option to the specified output.
    * @param out output stream
-   * @param k key
-   * @param v value
+   * @param name key
+   * @param value value
    * @throws IOException I/O exception
    */
-  private static void writeInfo(final DataOutput out, final String k, final boolean v)
+  private static void writeInfo(final DataOutput out, final String name, final boolean value)
       throws IOException {
-    writeInfo(out, k, v ? "1" : "0");
+    writeInfo(out, name, value ? "1" : "0");
   }
 
   /**
    * Writes a numeric option to the specified output.
    * @param out output stream
-   * @param k key
-   * @param v value
+   * @param name key
+   * @param value value
    * @throws IOException I/O exception
    */
-  private static void writeInfo(final DataOutput out, final String k, final long v)
+  private static void writeInfo(final DataOutput out, final String name, final long value)
       throws IOException {
-    writeInfo(out, k, Long.toString(v));
+    writeInfo(out, name, Long.toString(value));
   }
 
   /**
    * Writes a string option to the specified output.
    * @param out output stream
-   * @param k key
-   * @param v value
+   * @param name key
+   * @param value value
    * @throws IOException I/O exception
    */
-  private static void writeInfo(final DataOutput out, final String k, final String v)
+  private static void writeInfo(final DataOutput out, final String name, final String value)
       throws IOException {
-    out.writeToken(token(k));
-    out.writeToken(token(v));
+    out.writeToken(Token.token(name));
+    out.writeToken(Token.token(value));
   }
 
 }
