@@ -3,7 +3,7 @@ package org.basex.gui;
 /**
  * This interface defines GUI command methods.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public interface GUICommand {
@@ -48,7 +48,7 @@ public interface GUICommand {
    * Returns a shortcut.
    * @return shortcut
    */
-  String shortcut();
+  String shortCut();
 
   /**
    * Returns the command shortcuts.
