@@ -10,7 +10,7 @@ import org.basex.util.options.*;
 /**
  * Project specific CheckBox implementation.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class BaseXCheckBox extends JCheckBox {
@@ -72,7 +72,7 @@ public final class BaseXCheckBox extends JCheckBox {
    */
   public BaseXCheckBox large() {
     final Font f = getFont();
-    setFont(new Font(f.getName(), Font.PLAIN, (int) f.getSize2D() + 4));
+    setFont(new Font(f.getName(), Font.PLAIN, (int) (f.getSize2D() * 1.3)));
     return this;
   }
 
