@@ -4,6 +4,7 @@ import static org.basex.gui.GUIConstants.*;
 
 import java.awt.*;
 import java.awt.event.*;
+import java.util.*;
 
 import org.basex.gui.dialog.*;
 import org.basex.util.*;
@@ -11,14 +12,12 @@ import org.basex.util.*;
 /**
  * This component visualizes the current memory consumption.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class BaseXMem extends BaseXPanel {
   /** Default width of the memory status box. */
   private static final int DWIDTH = 70;
-  /** Dialog window with memory consumption. */
-  private static DialogMem mem;
 
   /**
    * Constructor.
@@ -28,24 +27,18 @@ public final class BaseXMem extends BaseXPanel {
   public BaseXMem(final Window win, final boolean mouse) {
     super(win);
     BaseXLayout.setWidth(this, DWIDTH);
-    BaseXLayout.setHeight(this, getFont().getSize() + 6);
+    setPreferredSize(new Dimension(getPreferredSize().width, getFont().getSize() + 6));
     if(mouse) {
       setCursor(CURSORHAND);
       addMouseListener(this);
       addMouseMotionListener(this);
     }
 
-    final Thread t = new Thread() {
+    // regularly refresh panel
+    new Timer(true).scheduleAtFixedRate(new TimerTask() {
       @Override
-      public void run() {
-        while(true) {
-          repaint();
-          Performance.sleep(5000);
-        }
-      }
-    };
-    t.setDaemon(true);
-    t.start();
+      public void run() { repaint(); }
+    }, 0, 5000);
   }
 
   @Override
@@ -60,9 +53,9 @@ public final class BaseXMem extends BaseXPanel {
     final int hh = getHeight();
 
     // draw memory box
-    g.setColor(Color.white);
+    g.setColor(BACK);
     g.fillRect(0, 0, ww - 3, hh - 3);
-    g.setColor(GRAY);
+    g.setColor(gray);
     g.drawLine(0, 0, ww - 4, 0);
     g.drawLine(0, 0, 0, hh - 4);
     g.drawLine(ww - 3, 0, ww - 3, hh - 3);
@@ -82,14 +75,13 @@ public final class BaseXMem extends BaseXPanel {
     final String sz = Performance.format(used, true);
     final int fw = (ww - fm.stringWidth(sz)) / 2;
     final int h = fm.getHeight() - 3;
-    g.setColor(full ? colormark3 : DGRAY);
+    g.setColor(full ? colormark3 : dgray);
     g.drawString(sz, fw, h);
   }
 
   @Override
   public void mousePressed(final MouseEvent e) {
-    if(mem == null) mem = new DialogMem(gui);
-    else mem.setVisible(true);
+    DialogMem.show(gui);
     repaint();
   }
 }
