@@ -13,7 +13,7 @@ import org.basex.gui.*;
  * Displays a text hint on empty text fields.
  * Inspired by {@code http://tips4java.wordpress.com/2009/11/29/text-prompt/}.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 final class BaseXTextHint extends JLabel implements DocumentListener {
@@ -29,7 +29,7 @@ final class BaseXTextHint extends JLabel implements DocumentListener {
     super(text);
     component = comp;
 
-    setForeground(GUIConstants.GRAY);
+    setForeground(GUIConstants.gray);
     setBorder(new EmptyBorder(comp.getInsets()));
     setFont(comp.getFont());
 
