@@ -10,14 +10,14 @@ import org.basex.data.*;
 /**
  * JTree node for representing database content (raw files / documents).
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Lukas Kircher
  */
 public abstract class TreeNode extends DefaultMutableTreeNode implements TreeWillExpandListener {
   /** Node name. */
   public final byte[] name;
   /** Relative path to this node. Starts with one slash, no trailing slashes.
-   *  File / folder name is not part of the path. */
+   *  File/folder name is not part of the path. */
   final byte[] path;
   /** Tree reference for lazy loading. */
   final BaseXTree tree;
@@ -28,16 +28,16 @@ public abstract class TreeNode extends DefaultMutableTreeNode implements TreeWil
 
   /**
    * Constructor.
-   * @param nm displayed node name
-   * @param pth folder path
-   * @param bxt tree reference
-   * @param d data reference
+   * @param name displayed node name
+   * @param path folder path
+   * @param text tree reference
+   * @param data data reference
    */
-  TreeNode(final byte[] nm, final byte[] pth, final BaseXTree bxt, final Data d) {
-    name = nm;
-    path = pth;
-    tree = bxt;
-    data = d;
+  TreeNode(final byte[] name, final byte[] path, final BaseXTree text, final Data data) {
+    this.name = name;
+    this.path = path;
+    this.tree = text;
+    this.data = data;
     tree.addTreeWillExpandListener(this);
   }
 
