@@ -5,10 +5,10 @@ import java.awt.*;
 /**
  * This class defines syntax highlighting for JSON files.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
-public final class SyntaxJSON extends Syntax {
+final class SyntaxJSON extends Syntax {
   /** Quoted flag. */
   private boolean quoted;
 
