@@ -2,20 +2,17 @@ package org.basex.gui.text;
 
 import static org.basex.util.Token.*;
 
-import java.io.*;
 import java.util.*;
 
 import org.basex.gui.*;
-import org.basex.gui.text.TextPanel.SearchDir;
-import org.basex.io.*;
-import org.basex.io.in.*;
+import org.basex.gui.text.SearchBar.SearchDir;
 import org.basex.util.*;
 import org.basex.util.list.*;
 
 /**
  * Provides methods for editing a text that is visualized by the {@link TextPanel}.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class TextEditor {
@@ -59,10 +56,12 @@ public final class TextEditor {
    */
   boolean text(final byte[] txt) {
     if(eq(txt, text)) return false;
+    final int tl = txt.length;
     text = txt;
     lines = -1;
     noSelect();
     if(search != null) searchPos = search.search(txt);
+    if(pos > tl) pos = tl;
     return true;
   }
 
@@ -158,15 +157,14 @@ public final class TextEditor {
     int ch = curr();
     forward(select);
     if(ch != '\n') {
-      if(Character.isLetterOrDigit(ch)) {
-        while(Character.isLetterOrDigit(ch)) ch = next();
-        while(ch != '\n' && Character.isWhitespace(ch)) ch = next();
-      } else if(Character.isWhitespace(ch)) {
-        while(ch != '\n' && Character.isWhitespace(ch)) ch = next();
+      if(FTToken.lod(ch)) {
+        while(FTToken.lod(ch)) ch = next();
+        while(ch != '\n' && FTToken.ws(ch)) ch = next();
+      } else if(FTToken.ws(ch)) {
+        while(ch != '\n' && FTToken.ws(ch)) ch = next();
       } else {
-        while(ch != '\n' && !Character.isLetterOrDigit(ch) &&
-            !Character.isWhitespace(ch)) ch = next();
-        while(ch != '\n' && Character.isWhitespace(ch)) ch = next();
+        while(ch != '\n' && !FTToken.lod(ch) && !FTToken.ws(ch)) ch = next();
+        while(ch != '\n' && FTToken.ws(ch)) ch = next();
       }
       if(pos != size()) prev();
     }
@@ -182,20 +180,29 @@ public final class TextEditor {
 
     int ch = back(select);
     if(ch != '\n') {
-      if(Character.isLetterOrDigit(ch)) {
-        while(Character.isLetterOrDigit(ch)) ch = prev();
-      } else if(Character.isWhitespace(ch)) {
-        while(ch != '\n' && Character.isWhitespace(ch)) ch = prev();
-        while(Character.isLetterOrDigit(ch)) ch = prev();
+      if(FTToken.lod(ch)) {
+        while(FTToken.lod(ch)) ch = prev();
+      } else if(FTToken.ws(ch)) {
+        while(ch != '\n' && FTToken.ws(ch)) ch = prev();
+        while(FTToken.lod(ch)) ch = prev();
       } else {
-        while(ch != '\n' && !Character.isLetterOrDigit(ch) &&
-            !Character.isWhitespace(ch)) ch = prev();
+        while(ch != '\n' && !FTToken.lod(ch) && !FTToken.ws(ch)) ch = prev();
       }
       if(pos != 0) next();
     }
     if(select) endSelection();
   }
 
+  /**
+   * Returns the position of first character of the current auto-completion input.
+   * @return position
+   */
+  int completionStart() {
+    int p = pos;
+    while(p > 0 && !ws(text[p - 1])) --p;
+    return p;
+  }
+
   /**
    * Jumps to the beginning of the text.
    * @param select selection flag
@@ -276,11 +283,11 @@ public final class TextEditor {
     final int p = pos;
     boolean s = true;
     // find beginning of line
-    while(back(select) != '\n') s &= Character.isWhitespace(curr());
+    while(back(select) != '\n') s &= FTToken.ws(curr());
     if(pos != 0 || curr() == '\n') forward(select);
     // move to first non-whitespace character
     if(p == pos || !s) {
-      while(Character.isWhitespace(curr()) && curr() != '\n') forward(select);
+      while(FTToken.ws(curr()) && curr() != '\n') forward(select);
     }
 
     if(select) endSelection();
@@ -411,16 +418,25 @@ public final class TextEditor {
     final byte[] ste = concat(st, SPACE), ene = concat(SPACE, en);
     final int sl = st.length, el = en.length, sle = ste.length, ele = ene.length;
 
-    // no selection: select line
     if(!selected()) {
+      // no selection: select line
       start = pos;
       end = pos;
       while(start > 0 && text[start - 1] != '\n') --start;
       while(end < size() && text[end] != '\n') ++end;
+    } else if(start > end) {
+      // selection -> start < end
+      final int s = start;
+      start = end;
+      end = s;
     }
 
-    final int min = Math.min(start, end);
-    int max = Math.max(start, end);
+    // ignore whitespaces
+    while(start < end && ws(text[start])) ++start;
+    while(end > start && ws(text[end - 1])) --end;
+
+    final int min = start;
+    int max = end;
     if(selected() && text[max - 1] == '\n') max--;
 
     // create new text with or without comment
@@ -494,48 +510,26 @@ public final class TextEditor {
   }
 
   /**
-   * Code completion.
+   * Inserts the specified value and updates the cursor position.
+   * @param value value
+   * @param p position to start completion from
    */
-  void complete() {
-    if(selected()) return;
-
-    // ignore space before cursor
-    final boolean space = pos > 0 && ws(text[pos - 1]);
-    if(space) pos--;
-
-    // replace pre-defined completion strings
-    for(int s = 0; s < REPLACE.size(); s += 2) {
-      final String key = REPLACE.get(s);
-      if(!find(key)) continue;
-      // key found
-      String value = REPLACE.get(s + 1);
-      final int p = pos - key.length(), car = value.indexOf('_');
-      if(car != -1) value = value.replace("_", "");
-      // adopt current indentation
-      final int ind = open();
-      if(ind != 0) {
-        final StringBuilder spaces = new StringBuilder();
-        for(int i = 0; i < ind; i++) spaces.append(' ');
-        value = new TokenBuilder().addSep(value.split("\n"), "\n" + spaces).toString();
-      }
-      // delete old string, add new one
-      replace(p, pos + (space ? 1 : 0), value);
-      // adjust cursor
-      if(car != -1) pos = p + car;
+  void complete(final String value, final int p) {
+    // key found
+    String v = value;
+    final int car = v.indexOf('_');
+    if(car != -1) v = v.replace("_", "");
+    // adopt current indentation
+    final int ind = open();
+    if(ind != 0) {
+      final StringBuilder spaces = new StringBuilder();
+      for(int i = 0; i < ind; i++) spaces.append(' ');
+      v = new TokenBuilder().addSep(v.split("\n"), "\n" + spaces).toString();
     }
-
-    // replace entities
-    int p = pos;
-    while(--p >= 0 && XMLToken.isChar(text[p]));
-    ++p;
-    final String key = Token.string(text, p, pos - p);
-    final byte[] value = XMLToken.getEntity(token(key));
-    if(value != null) {
-      replace(p, pos + (space ? 1 : 0), string(value));
-      return;
-    }
-
-    if(space) pos++;
+    // delete old string, add new one
+    replace(p, pos, v);
+    // adjust cursor
+    if(car != -1) pos = p + car;
   }
 
   /**
@@ -568,15 +562,14 @@ public final class TextEditor {
     for(int i = s; i < e; i++) {
       final byte ch = tmp[i];
       if(ch == '\n') {
-        tl.add(bl.toArray());
-        bl.reset();
+        tl.add(bl.next());
       } else {
         bl.add(ch);
       }
     }
 
     // sort data and merge duplicate lines
-    if(!bl.isEmpty()) tl.add(bl.toArray());
+    if(!bl.isEmpty()) tl.add(bl.finish());
     tl.sort(gopts.get(GUIOptions.CASESORT), gopts.get(GUIOptions.ASCSORT));
     if(gopts.get(GUIOptions.MERGEDUPL)) tl.unique();
 
@@ -705,14 +698,14 @@ public final class TextEditor {
       } else if(ch == '~') {
         // closes XQuery comments
         if(prev == ':' && pprv == '(') {
-          sb.append("\n : \n ");
+          sb.append("  ");
           if(curr != ':') {
             sb.append(':');
             if(curr != ')') sb.append(')');
           } else if(next != ')') {
             sb.append(')');
           }
-          move = 5;
+          move = 2;
         }
       } else if(ch == '-') {
         // closes XML comments
@@ -753,20 +746,19 @@ public final class TextEditor {
    * @param sb string builder
    */
   private void closeElem(final StringBuilder sb) {
-    int p = pos - 1;
-    for(; p >= 0; p--) {
-      final byte b = text[p];
-      if(!XMLToken.isNCChar(b) && b != ':') {
-        if(b == '<' && p < pos - 1) {
+    final int p = pos;
+    while(pos > 0) {
+      final int cp = prev();
+      if(!XMLToken.isNCChar(cp) && cp != ':') {
+        if(cp == '<' && pos < p - 1) {
           // add closing element
-          sb.append("</");
-          while(++p < pos) sb.append((char) text[p]);
-          sb.append('>');
-          break;
+          next();
+          sb.append("</").append(new TokenBuilder().add(text, pos, p).toString()).append('>');
         }
-        return;
+        break;
       }
     }
+    pos = p;
   }
 
   /**
@@ -870,17 +862,6 @@ public final class TextEditor {
     add(value);
   }
 
-  /**
-   * Checks if the specified key is found before the current cursor position.
-   * @param key string to be found
-   * @return result of check
-   */
-  private boolean find(final String key) {
-    final byte[] k = token(key);
-    final int s = pos - k.length;
-    return s >= 0 && indexOf(text, k, s) == s && (s == 0 || !XMLToken.isChar(text[s - 1]));
-  }
-
   /**
    * Extends the current selection to the beginning of the first and the end of the last line.
    * @return if text is selected
@@ -1072,10 +1053,10 @@ public final class TextEditor {
    * Selects the word at the cursor position.
    */
   void selectWord() {
-    final boolean ch = ftChar(curr());
+    final boolean ch = FTToken.lod(curr());
     while(pos() > 0) {
       final int cp = back(true);
-      if(cp == '\n' || ch != ftChar(cp)) {
+      if(cp == '\n' || ch != FTToken.lod(cp)) {
         forward(true);
         break;
       }
@@ -1083,7 +1064,7 @@ public final class TextEditor {
     startSelect();
     while(pos() < size()) {
       final int cp = curr();
-      if(cp == '\n' || ch != ftChar(cp)) break;
+      if(cp == '\n' || ch != FTToken.lod(cp)) break;
       forward(true);
     }
     endSelection();
@@ -1174,32 +1155,4 @@ public final class TextEditor {
   public String toString() {
     return copy();
   }
-
-  /** Index for all replacements. */
-  private static final StringList REPLACE = new StringList();
-
-  /** Reads in the property file. */
-  static {
-    try {
-      final String file = "/completions.properties";
-      final InputStream is = MimeTypes.class.getResourceAsStream(file);
-      if(is == null) {
-        Util.errln(file + " not found.");
-      } else {
-        final NewlineInput nli = new NewlineInput(is);
-        try {
-          for(String line; (line = nli.readLine()) != null;) {
-            final int i = line.indexOf('=');
-            if(i == -1 || line.startsWith("#")) continue;
-            REPLACE.add(line.substring(0, i));
-            REPLACE.add(line.substring(i + 1).replace("\\n", "\n"));
-          }
-        } finally {
-          nli.close();
-        }
-      }
-    } catch(final IOException ex) {
-      Util.errln(ex);
-    }
-  }
 }
