@@ -14,7 +14,7 @@ import org.basex.util.list.*;
  * access is needed, it is advisable to directly work on the {@link Data}
  * class.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class ViewData {
@@ -22,8 +22,7 @@ public final class ViewData {
   private ViewData() { }
 
   /**
-   * Checks if the specified node is a leaf node
-   * (text node or file element or file tag).
+   * Checks if the specified node is a text node.
    * @param opts gui options
    * @param d data reference
    * @param pre pre value
@@ -61,8 +60,7 @@ public final class ViewData {
     final TokenBuilder tb = new TokenBuilder();
     tb.add(Function._DB_OPEN.args(data.meta.name, Token.string(doc)));
     for(int i = il.size() - 1; i >= 0; i--) {
-      tb.add('/');
-      tb.add(content(data, il.get(i), true));
+      tb.add('/').add(content(data, il.get(i), true));
     }
     return tb.finish();
   }
@@ -97,7 +95,7 @@ public final class ViewData {
   }
 
   /**
-   * Returns the tag name of the specified node.
+   * Returns the name of the specified element.
    * Note that the pre value must reference an element node.
    * @param opts gui options
    * @param data data reference
@@ -121,7 +119,7 @@ public final class ViewData {
    * @return name id
    */
   public static int nameID(final Data data) {
-    return data.atnindex.id(T_NAME);
+    return data.attrNames.id(T_NAME);
   }
 
   /**
@@ -130,7 +128,7 @@ public final class ViewData {
    * @return name id
    */
   public static int sizeID(final Data data) {
-    return data.atnindex.id(T_SIZE);
+    return data.attrNames.id(T_SIZE);
   }
 
   /**
