@@ -8,13 +8,14 @@ import org.basex.core.*;
 import org.basex.data.*;
 import org.basex.gui.*;
 import org.basex.gui.layout.*;
+import org.basex.query.value.seq.*;
 import org.basex.util.*;
 
 /**
  * This class serves as a container for all existing views. The observer pattern
  * is used to inform all views on user interactions.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class ViewNotifier {
@@ -28,9 +29,9 @@ public final class ViewNotifier {
   final GUI gui;
 
   /** Zoomed rectangle history. */
-  private final Nodes[] marked = new Nodes[MAXHIST];
+  private final DBNodes[] marked = new DBNodes[MAXHIST];
   /** Zoomed rectangle history. */
-  private final Nodes[] cont = new Nodes[MAXHIST];
+  private final DBNodes[] cont = new DBNodes[MAXHIST];
   /** Command history. */
   private final String[] queries = new String[MAXHIST];
   /** Attached views. */
@@ -40,18 +41,18 @@ public final class ViewNotifier {
 
   /**
    * Constructor.
-   * @param main reference to the main window
+   * @param gui reference to the main window
    */
-  public ViewNotifier(final GUI main) {
-    gui = main;
+  public ViewNotifier(final GUI gui) {
+    this.gui = gui;
   }
 
   /**
    * Adds a new view.
-   * @param v view to be added
+   * @param vw view to be added
    */
-  void add(final View v) {
-    view = Array.add(view, v);
+  void add(final View vw) {
+    view = Array.add(view, vw);
   }
 
   /**
@@ -79,7 +80,7 @@ public final class ViewNotifier {
     gui.context.focused = -1;
     for(final View v : view) v.refreshInit();
     gui.layoutViews();
-    gui.setTitle(data != null ? data.meta.name : null);
+    gui.setTitle();
   }
 
   /**
@@ -101,7 +102,7 @@ public final class ViewNotifier {
    * @param mark marked nodes
    * @param vw the calling view
    */
-  public void mark(final Nodes mark, final View vw) {
+  public void mark(final DBNodes mark, final View vw) {
     final Context ctx = gui.context;
     ctx.marked = mark;
     for(final View v : view) if(v != vw && v.visible()) v.refreshMark();
@@ -125,9 +126,9 @@ public final class ViewNotifier {
     if(f == -1) return;
 
     final Context ctx = gui.context;
-    Nodes nodes = ctx.marked;
+    DBNodes nodes = ctx.marked;
     if(mode == 0) {
-      nodes = new Nodes(f, ctx.data());
+      nodes = new DBNodes(ctx.data(), f);
     } else if(mode == 1) {
       nodes.union(new int[] { f });
     } else {
@@ -164,20 +165,20 @@ public final class ViewNotifier {
    * @param quick quick switch
    * @param vw the calling view
    */
-  public void context(final Nodes nodes, final boolean quick, final View vw) {
+  public void context(final DBNodes nodes, final boolean quick, final View vw) {
     final Context ctx = gui.context;
 
     // add new entry if current node set has not been cached yet
-    final Nodes newn = nodes.checkRoot();
-    final Nodes empty = new Nodes(new int[0], ctx.data(), ctx.marked.ftpos);
-    final Nodes curr = quick ? ctx.current() : null;
-    final Nodes cmp = quick ? curr : ctx.marked;
+    final DBNodes newn = nodes.discardDocs();
+    final DBNodes empty = new DBNodes(ctx.data()).ftpos(ctx.marked.ftpos());
+    final DBNodes curr = quick ? ctx.current() : null;
+    final DBNodes cmp = quick ? curr : ctx.marked;
     if(cont[hist] == null ? cmp != null : cmp == null || !cont[hist].sameAs(cmp)) {
       checkHist();
       if(quick) {
         // store history entry
         queries[hist] = "";
-        marked[hist] = new Nodes(ctx.data());
+        marked[hist] = new DBNodes(ctx.data());
         // add current entry
         cont[++hist] = curr;
       } else {
@@ -204,7 +205,7 @@ public final class ViewNotifier {
   public void update() {
     final Data data = initHistory(gui.context);
     if(data == null) return;
-    gui.context.marked = new Nodes(data);
+    gui.context.marked = new DBNodes(data);
     for(final View v : view) if(v.visible()) v.refreshUpdate();
     gui.refreshControls();
   }
@@ -249,7 +250,7 @@ public final class ViewNotifier {
   /**
    * Removes existing history entries and sets an initial entry.
    * @param ctx database context
-   * @return {@link Data} reference, or {@code null}
+   * @return {@link Data} reference or {@code null}
    */
   private Data initHistory(final Context ctx) {
     for(int h = 0; h < histsize; h++) {
@@ -263,7 +264,7 @@ public final class ViewNotifier {
     final Data data = ctx.data();
     if(data != null) {
       // new database opened
-      marked[0] = new Nodes(data);
+      marked[0] = new DBNodes(data);
       queries[0] = "";
     }
     return data;
