@@ -8,19 +8,18 @@ import java.awt.*;
 import java.awt.event.*;
 import java.io.*;
 import java.util.*;
+import java.util.Timer;
 import java.util.regex.*;
 
 import javax.swing.*;
-import javax.swing.border.*;
 import javax.swing.event.*;
 
-import org.basex.build.*;
+import org.basex.build.json.*;
 import org.basex.core.*;
 import org.basex.core.cmd.*;
 import org.basex.core.parse.*;
 import org.basex.gui.*;
-import org.basex.gui.GUIConstants.Fill;
-import org.basex.gui.GUIConstants.Msg;
+import org.basex.gui.dialog.*;
 import org.basex.gui.layout.*;
 import org.basex.gui.layout.BaseXFileChooser.Mode;
 import org.basex.gui.layout.BaseXLayout.DropHandler;
@@ -40,7 +39,7 @@ import org.xml.sax.*;
 /**
  * This view allows the input and evaluation of queries and documents.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class EditorView extends View {
@@ -68,7 +67,7 @@ public final class EditorView extends View {
   /** Splitter. */
   private final BaseXSplit split;
   /** Header string. */
-  private final BaseXLabel label;
+  private final BaseXHeader header;
   /** Query area. */
   private final BaseXTabs tabs;
   /** Query file that has last been evaluated. */
@@ -88,9 +87,9 @@ public final class EditorView extends View {
   public EditorView(final ViewNotifier man) {
     super(EDITORVIEW, man);
     layout(new BorderLayout());
+    setBackground(PANEL);
 
-    label = new BaseXLabel(EDITOR, true, false);
-    label.setForeground(GRAY);
+    header = new BaseXHeader(EDITOR);
 
     tabs = new BaseXTabs(gui);
     tabs.setFocusable(Prop.MAC);
@@ -103,21 +102,18 @@ public final class EditorView extends View {
     final AbstractButton openB = BaseXButton.command(GUIMenuCmd.C_EDITOPEN, gui);
     final AbstractButton saveB = BaseXButton.get("c_save", SAVE, false, gui);
     final AbstractButton find = search.button(FIND_REPLACE);
+    final AbstractButton vars = BaseXButton.get("c_vars", EXTERNAL_VARIABLES, false, gui);
+
     hist = BaseXButton.get("c_hist", RECENTLY_OPENED, false, gui);
-
     stop = BaseXButton.get("c_stop", STOP, false, gui);
-    stop.addKeyListener(this);
     stop.setEnabled(false);
-
     go = BaseXButton.get("c_go", BaseXLayout.addShortcut(RUN_QUERY,
         BaseXKeys.EXEC1.toString()), false, gui);
-    go.addKeyListener(this);
     test = BaseXButton.get("c_test", BaseXLayout.addShortcut(RUN_TESTS,
         BaseXKeys.UNIT.toString()), false, gui);
-    test.addKeyListener(this);
 
-    final BaseXBack buttons = new BaseXBack(Fill.NONE);
-    buttons.layout(new TableLayout(1, 8, 1, 0)).border(0, 0, 8, 0);
+    final BaseXBack buttons = new BaseXBack(false);
+    buttons.layout(new TableLayout(1, 9, 1, 0)).border(0, 0, 8, 0);
     buttons.add(openB);
     buttons.add(saveB);
     buttons.add(hist);
@@ -125,11 +121,12 @@ public final class EditorView extends View {
     buttons.add(Box.createHorizontalStrut(6));
     buttons.add(stop);
     buttons.add(go);
+    buttons.add(vars);
     buttons.add(test);
 
-    final BaseXBack north = new BaseXBack(Fill.NONE).layout(new BorderLayout());
+    final BaseXBack north = new BaseXBack(false).layout(new BorderLayout());
     north.add(buttons, BorderLayout.WEST);
-    north.add(label, BorderLayout.EAST);
+    north.add(header, BorderLayout.EAST);
 
     // status and query pane
     search.editor(addTab(), false);
@@ -138,12 +135,13 @@ public final class EditorView extends View {
     pos = new BaseXLabel(" ");
     posCode.invokeLater();
 
-    final BaseXBack south = new BaseXBack(Fill.NONE).border(10, 0, 2, 0);
+    final BaseXBack south = new BaseXBack(false).border(4, 0, 0, 0);
     south.layout(new BorderLayout(4, 0));
     south.add(info, BorderLayout.CENTER);
     south.add(pos, BorderLayout.EAST);
 
-    final BaseXBack main = new BaseXBack().border(5).mode(Fill.NONE);
+    final BaseXBack main = new BaseXBack().border(5);
+    main.setOpaque(false);
     main.layout(new BorderLayout());
     main.add(north, BorderLayout.NORTH);
     main.add(center, BorderLayout.CENTER);
@@ -151,7 +149,7 @@ public final class EditorView extends View {
 
     project = new ProjectView(this);
     split = new BaseXSplit(true);
-    split.mode(Fill.NONE);
+    split.setOpaque(false);
     split.add(project);
     split.add(main);
     split.init(new double[] { 0.3, 0.7 }, new double[] { 0, 1 });
@@ -189,7 +187,7 @@ public final class EditorView extends View {
 
         // create popup menu with of recently opened files
         final StringList opened = new StringList();
-        for(final EditorArea ea : editors()) opened.add(ea.file.path());
+        for(final EditorArea ea : editors()) opened.add(ea.file().path());
 
         final StringList hst = new StringList(HISTORY);
         final StringList all = new StringList(gui.gopts.get(GUIOptions.EDITOR));
@@ -242,6 +240,12 @@ public final class EditorView extends View {
         run(getEditor(), Action.EXECUTE);
       }
     });
+    vars.addActionListener(new ActionListener() {
+      @Override
+      public void actionPerformed(final ActionEvent e) {
+        DialogBindings.show(gui);
+      }
+    });
     test.addActionListener(new ActionListener() {
       @Override
       public void actionPerformed(final ActionEvent e) {
@@ -258,6 +262,7 @@ public final class EditorView extends View {
         posCode.invokeLater();
         refreshMark();
         run(ea, Action.PARSE);
+        gui.setTitle();
       }
     });
 
@@ -267,16 +272,6 @@ public final class EditorView extends View {
         if(file instanceof File) open(new IOFile((File) file));
       }
     });
-
-    SwingUtilities.invokeLater(new Runnable() {
-      @Override
-      public void run() {
-        // remember opened files; don't complain about missing files
-        for(final String file : gui.gopts.get(GUIOptions.OPEN)) {
-          open(new IOFile(file), false, false);
-        }
-      }
-    });
   }
 
   @Override
@@ -297,12 +292,12 @@ public final class EditorView extends View {
 
   @Override
   public void refreshLayout() {
-    label.border(-6, 0, 0, 2).setFont(lfont);
-    for(final EditorArea edit : editors()) edit.setFont(mfont);
+    header.refreshLayout();
+    for(final EditorArea edit : editors()) edit.refreshLayout(mfont);
     search.refreshLayout();
-    final Font ef = GUIConstants.font.deriveFont(7f + (fontSize >> 1));
-    info.setFont(ef);
-    pos.setFont(ef);
+    final Font f = font.deriveFont((float) ((FONTSIZE * SCALE + fontSize) / 2));
+    info.setFont(f);
+    pos.setFont(f);
     project.refreshLayout();
   }
 
@@ -359,12 +354,12 @@ public final class EditorView extends View {
    */
   public void jumpToFile() {
     final EditorArea editor = getEditor();
-    if(editor.opened()) project.jump(editor.file);
+    if(editor.opened()) project.jump(editor.file());
   }
 
   /**
    * Switches the current editor tab.
-   * @param next next next/previous tag
+   * @param next next next/previous tab
    */
   public void tab(final boolean next) {
     final int s = tabs.getTabCount() - 1;
@@ -372,6 +367,25 @@ public final class EditorView extends View {
     tabs.setSelectedIndex(i);
   }
 
+  /**
+   * Opens the previously opened and new files.
+   * @param files files to be opened
+   */
+  public void init(final ArrayList<IOFile> files) {
+    // open previous files; do not complain about missing files
+    final String[] fs = gui.gopts.get(GUIOptions.OPEN);
+    for(final String file : fs) open(new IOFile(file), false, false);
+
+    // open specified files
+    for(final IOFile file : files) open(file);
+
+    // initialize project root with path of first file
+    final IOFile f = fs.length == 0 ? files.isEmpty() ? null : files.get(0) : new IOFile(fs[0]);
+    if(f != null) project.changeRoot(f.parent(), false);
+
+    gui.setTitle();
+  }
+
   /**
    * Opens a new file.
    */
@@ -384,13 +398,6 @@ public final class EditorView extends View {
     for(final IOFile f : fc.multi().selectAll(Mode.FOPEN)) open(f);
   }
 
-  /**
-   * Reverts the contents of the currently opened editor.
-   */
-  public void reopen() {
-    getEditor().reopen(true);
-  }
-
   /**
    * Saves the contents of the currently opened editor.
    * @return {@code false} if operation was canceled
@@ -407,7 +414,7 @@ public final class EditorView extends View {
   public boolean saveAs() {
     // open file chooser for XML creation
     final EditorArea edit = getEditor();
-    final String path = edit.opened() ? edit.file.path() : gui.gopts.get(GUIOptions.WORKPATH);
+    final String path = edit.opened() ? edit.file().path() : gui.gopts.get(GUIOptions.WORKPATH);
     final BaseXFileChooser fc = new BaseXFileChooser(SAVE_AS, path, gui);
     fc.filter(XQUERY_FILES, IO.XQSUFFIXES);
     fc.filter(BXS_FILES, IO.BXSSUFFIX);
@@ -419,8 +426,7 @@ public final class EditorView extends View {
     if(file == null) return false;
 
     // success: display new file in project view
-    edit.save(file);
-    return true;
+    return edit.save(file);
   }
 
   /**
@@ -445,7 +451,7 @@ public final class EditorView extends View {
   /**
    * Opens and parses the specified query file.
    * @param file query file
-   * @return opened editor, or {@code null} if file could not be opened
+   * @return opened editor or {@code null} if file could not be opened
    */
   public EditorArea open(final IOFile file) {
     return open(file, true, true);
@@ -456,7 +462,7 @@ public final class EditorView extends View {
    * @param file query file
    * @param parse parse contents
    * @param error display error if file does not exist
-   * @return opened editor, or {@code null} if file could not be opened
+   * @return opened editor or {@code null} if file could not be opened
    */
   private EditorArea open(final IOFile file, final boolean parse, final boolean error) {
     if(!visible()) GUIMenuCmd.C_SHOWEDITOR.execute(gui);
@@ -465,7 +471,6 @@ public final class EditorView extends View {
     if(edit != null) {
       // display open file
       tabs.setSelectedComponent(edit);
-      edit.reopen(true);
     } else {
       try {
         // check and retrieve content
@@ -474,8 +479,8 @@ public final class EditorView extends View {
 
         // get current editor
         edit = getEditor();
-        // create new tab if current text is stored on disk or has been modified
-        if(edit.opened() || edit.modified) edit = addTab();
+        // create new tab if text in current tab is stored on disk or has been modified
+        if(edit.opened() || edit.modified()) edit = addTab();
         edit.initText(text);
         edit.file(file);
         if(parse) run(edit, Action.PARSE);
@@ -508,7 +513,7 @@ public final class EditorView extends View {
       }
     }
 
-    IOFile file = editor.file;
+    IOFile file = editor.file();
     editor.last = in;
 
     final boolean xquery = file.hasSuffix(IO.XQSUFFIXES) || !file.path().contains(".");
@@ -523,7 +528,7 @@ public final class EditorView extends View {
       if(exec && lib) {
         final EditorArea ea = execEditor();
         if(ea != null) {
-          file = ea.file;
+          file = ea.file();
           input = string(ea.getText());
           lib = false;
         }
@@ -540,14 +545,11 @@ public final class EditorView extends View {
         execFile = file;
       } else {
         // parse query
-        final QueryContext qc = new QueryContext(gui.context);
-        try {
+        try(final QueryContext qc = new QueryContext(gui.context)) {
           qc.parse(input, lib, null, null);
           info(null);
         } catch(final QueryException ex) {
           info(ex);
-        } finally {
-          qc.close();
         }
       }
     } else if(file.hasSuffix(IO.JSONSUFFIX)) {
@@ -577,7 +579,7 @@ public final class EditorView extends View {
 
   /**
    * Evaluates the info message resulting from command or query parsing.
-   * @param ex exception, or {@code null}
+   * @param ex exception or {@code null}
    */
   private void info(final Exception ex) {
     info(ex, false, false);
@@ -590,7 +592,7 @@ public final class EditorView extends View {
   private EditorArea execEditor() {
     if(execFile != null) {
       for(final EditorArea edit : editors()) {
-        if(edit.file.path().equals(execFile.path())) return edit;
+        if(edit.file().path().equals(execFile.path())) return edit;
       }
     }
     execFile = null;
@@ -600,26 +602,25 @@ public final class EditorView extends View {
   /**
    * Retrieves the contents of the specified file, or opens it externally.
    * @param file query file
-   * @return contents, or {@code null} reference
+   * @return contents or {@code null} reference
    * @throws IOException I/O exception
    */
   private byte[] read(final IOFile file) throws IOException {
     // check content
     final TokenBuilder text = new TokenBuilder((int) Math.min(Integer.MAX_VALUE, file.length()));
-    final TextInput ti = new NewlineInput(file).validate(true);
-    boolean valid = true;
-    try {
+    try(final TextInput ti = new NewlineInput(file).validate(true)) {
+      boolean valid = true;
       while(true) {
         try {
           final int cp = ti.read();
-          if(cp == -1) return text.array();
+          if(cp == -1) return text.finish();
           text.add(cp);
         } catch(final InputException ex) {
           if(valid) {
             valid = false;
-            final Boolean binary = BaseXDialog.yesNoCancel(gui, H_FILE_BINARY);
-            if(binary == null) return null;
-            if(binary) {
+            final String action = BaseXDialog.yesNoCancel(gui, H_FILE_BINARY);
+            if(action == null) return null;
+            if(action == YES) {
               try {
                 file.open();
               } catch(final IOException ioex) {
@@ -630,8 +631,6 @@ public final class EditorView extends View {
           }
         }
       }
-    } finally {
-      ti.close();
     }
   }
 
@@ -639,21 +638,22 @@ public final class EditorView extends View {
    * Refreshes the list of recent query files and updates the query path.
    * @param file new file
    */
-  void refreshHistory(final IO file) {
+  void refreshHistory(final IOFile file) {
     final StringList paths = new StringList();
     if(file != null) {
       final String path = file.path();
-      gui.gopts.set(GUIOptions.WORKPATH, file.dirPath());
+      gui.gopts.set(GUIOptions.WORKPATH, file.dir());
       paths.add(path);
       tabs.setToolTipTextAt(tabs.getSelectedIndex(), path);
     }
     final String[] old = gui.gopts.get(GUIOptions.EDITOR);
-    for(int p = 0; paths.size() < HISTORY && p < old.length; p++) {
+    final int ps = paths.size(), ol = old.length;
+    for(int p = 0; ps < HISTORY && p < ol; p++) {
       final IO fl = IO.get(old[p]);
       if(fl.exists() && !fl.eq(file)) paths.add(fl.path());
     }
     // store sorted history
-    gui.gopts.set(GUIOptions.EDITOR, paths.toArray());
+    gui.gopts.set(GUIOptions.EDITOR, paths.finish());
     hist.setEnabled(!paths.isEmpty());
   }
 
@@ -667,7 +667,7 @@ public final class EditorView extends View {
     if(!confirm(ea)) return false;
 
     // remove reference to last executed file
-    if(execFile != null && ea.file.path().equals(execFile.path())) execFile = null;
+    if(execFile != null && ea.file().path().equals(execFile.path())) execFile = null;
     tabs.remove(ea);
     final int t = tabs.getTabCount();
     final int i = tabs.getSelectedIndex();
@@ -696,21 +696,20 @@ public final class EditorView extends View {
    */
   public void start() {
     final int thread = threadID;
-    new Thread() {
+    new Timer(true).schedule(new TimerTask() {
       @Override
       public void run() {
-        Performance.sleep(200);
         if(thread == threadID) {
           info.setText(PLEASE_WAIT_D, Msg.SUCCESS).setToolTipText(null);
           stop.setEnabled(true);
         }
       }
-    }.start();
+    }, 200);
   }
 
   /**
    * Processes the result from a command or query execution.
-   * @param th exception, or {@code null}
+   * @param th exception or {@code null}
    * @param stopped {@code true} if evaluation was interrupted
    * @param refresh refresh buttons
    */
@@ -744,10 +743,10 @@ public final class EditorView extends View {
         errorInfo = ((QueryException) th).info();
       } else if(th instanceof SAXParseException) {
         final SAXParseException ex = (SAXParseException) th;
-        final String path = getEditor().file.path();
+        final String path = getEditor().file().path();
         errorInfo = new InputInfo(path, ex.getLineNumber(), ex.getColumnNumber());
       } else {
-        errorInfo = new InputInfo(getEditor().file.path(), 1, 1);
+        errorInfo = new InputInfo(getEditor().file().path(), 1, 1);
       }
       error(false);
     }
@@ -767,7 +766,7 @@ public final class EditorView extends View {
   public void jump(final String link) {
     final Matcher m = LINK.matcher(link);
     if(m.matches()) {
-      errorInfo = new InputInfo(m.group(1), toInt(m.group(2)), toInt(m.group(3)));
+      errorInfo = new InputInfo(m.group(1), Strings.toInt(m.group(2)), Strings.toInt(m.group(3)));
       error(true);
     } else {
       Util.stack("No match found: " + link);
@@ -831,28 +830,16 @@ public final class EditorView extends View {
    */
   public boolean confirm() {
     // save modified files
-    for(final EditorArea edit : editors()) {
-      tabs.setSelectedComponent(edit);
-      if(!confirm(edit)) return false;
-    }
+    if(!confirm(null)) return false;
     // remember opened files
     final StringList files = new StringList();
     for(final EditorArea edit : editors()) {
-      if(edit.opened()) files.add(edit.file.path());
+      if(edit.opened()) files.add(edit.file().path());
     }
-    gui.gopts.set(GUIOptions.OPEN, files.toArray());
+    gui.gopts.set(GUIOptions.OPEN, files.finish());
     return true;
   }
 
-  /**
-   * Checks if the current text can be saved or reverted.
-   * @return result of check
-   */
-  public boolean modified() {
-    final EditorArea edit = getEditor();
-    return edit.modified || !edit.opened();
-  }
-
   /**
    * Returns the current editor.
    * @return editor
@@ -873,21 +860,21 @@ public final class EditorView extends View {
       final boolean dir = renamed.isDir();
       final String oldPath = old.file().getCanonicalPath() + (dir ? File.separator : "");
       // iterate through all tabs
-      final int s = tabs.getTabCount() - 1;
-      for(int i = 0; i < s; i++) {
-        final Component c = tabs.getComponentAt(i);
+      for(final Component c : tabs.getComponents()) {
         if(!(c instanceof EditorArea)) continue;
 
         final EditorArea ea = (EditorArea) c;
-        final String editPath = ea.file.file().getCanonicalPath();
+        if(!ea.opened()) continue;
+
+        final String editPath = ea.file().file().getCanonicalPath();
         if(dir) {
           // change path to files in a renamed directory
           if(editPath.startsWith(oldPath)) {
-            ea.file = new IOFile(renamed + File.separator + editPath.substring(oldPath.length()));
+            ea.file(new IOFile(renamed + File.separator + editPath.substring(oldPath.length())));
           }
         } else if(oldPath.equals(editPath)) {
           // update file reference and label of editor tab
-          ea.file = renamed;
+          ea.file(renamed);
           ea.label.setText(renamed.name());
           break;
         }
@@ -904,18 +891,20 @@ public final class EditorView extends View {
    */
   void refreshControls(final EditorArea edit, final boolean force) {
     // update modification flag
-    final boolean oe = edit.modified;
-    edit.modified = edit.hist != null && edit.hist.modified();
-    if(edit.modified == oe && !force) return;
+    final boolean mod = edit.hist != null && edit.hist.modified();
+    if(mod == edit.modified() && !force) return;
+
+    edit.modified(mod);
 
     // update tab title
-    String title = edit.file.name();
-    if(edit.modified) title += '*';
+    String title = edit.file().name();
+    if(mod) title += '*';
     edit.label.setText(title);
-    edit.script = edit.file.hasSuffix(IO.BXSSUFFIX);
+    edit.script = edit.file().hasSuffix(IO.BXSSUFFIX);
 
     // update components
     gui.refreshControls();
+    gui.setTitle();
     posCode.invokeLater();
     refreshMark();
   }
@@ -937,7 +926,7 @@ public final class EditorView extends View {
    */
   private EditorArea find(final IO file, final boolean opened) {
     for(final EditorArea edit : editors()) {
-      if(edit.file.eq(file) && (!opened || edit.opened())) return edit;
+      if(edit.file().eq(file) && (!opened || edit.opened())) return edit;
     }
     return null;
   }
@@ -951,14 +940,15 @@ public final class EditorView extends View {
     final BoolList bl = new BoolList();
     for(final EditorArea edit : editors()) {
       if(edit.opened()) continue;
-      final String n = edit.file.name().substring(FILE.length());
+      final String n = edit.file().name().substring(FILE.length());
       bl.set(n.isEmpty() ? 1 : Integer.parseInt(n), true);
     }
     // find first free file number
-    int c = 0;
-    while(++c < bl.size() && bl.get(c));
+    int b = 0;
+    final int bs = bl.size();
+    while(++b < bs && bl.get(b));
     // create io reference
-    return new IOFile(gui.gopts.get(GUIOptions.WORKPATH), FILE + (c == 1 ? "" : c));
+    return new IOFile(gui.gopts.get(GUIOptions.WORKPATH), FILE + (b == 1 ? "" : b));
   }
 
   /**
@@ -969,7 +959,8 @@ public final class EditorView extends View {
     final EditorArea edit = new EditorArea(this, newTabFile());
     edit.setFont(mfont);
 
-    final BaseXBack tab = new BaseXBack(new BorderLayout(10, 0)).mode(Fill.NONE);
+    final BaseXBack tab = new BaseXBack(new BorderLayout(10, 0));
+    tab.setOpaque(false);
     tab.add(edit.label, BorderLayout.CENTER);
 
     final AbstractButton close = tabButton("e_close", "e_close2");
@@ -1008,7 +999,7 @@ public final class EditorView extends View {
    */
   private AbstractButton tabButton(final String icon, final String rollover) {
     final AbstractButton b = BaseXButton.get(icon, null, false, gui);
-    b.setBorder(new EmptyBorder(2, 0, 2, 0));
+    b.setBorder(BaseXLayout.border(2, 0, 2, 0));
     b.setContentAreaFilled(false);
     b.setFocusable(false);
     b.setRolloverIcon(BaseXImages.icon(rollover));
@@ -1017,13 +1008,22 @@ public final class EditorView extends View {
 
   /**
    * Shows a quit dialog for the specified editor.
-   * @param edit editor to be saved
+   * @param edit editor to be saved, or {@code null} to save all editors
    * @return {@code false} if confirmation was canceled
    */
   private boolean confirm(final EditorArea edit) {
-    if(edit.modified && (edit.opened() || edit.getText().length != 0)) {
-      final Boolean ok = BaseXDialog.yesNoCancel(gui, Util.info(CLOSE_FILE_X, edit.file.name()));
-      if(ok == null || ok && !save()) return false;
+    final boolean all = edit == null;
+    final EditorArea[] eas = all ? editors() : new EditorArea[] { edit };
+    final String[] buttons = all && eas.length > 1 ? new String[] { CLOSE_ALL } : new String[0];
+
+    for(final EditorArea ea : eas) {
+      tabs.setSelectedComponent(ea);
+      if(ea.modified() && (ea.opened() || ea.getText().length != 0)) {
+        final String msg = Util.info(CLOSE_FILE_X, ea.file().name());
+        final String action = BaseXDialog.yesNoCancel(gui, msg, buttons);
+        if(action == null || action.equals(B_YES) && !save()) return false;
+        else if(action.equals(CLOSE_ALL)) break;
+      }
     }
     return true;
   }
@@ -1033,7 +1033,7 @@ public final class EditorView extends View {
    * @return editors
    */
   private EditorArea[] editors() {
-    final ArrayList<EditorArea> edits = new ArrayList<EditorArea>();
+    final ArrayList<EditorArea> edits = new ArrayList<>();
     for(final Component c : tabs.getComponents()) {
       if(c instanceof EditorArea) edits.add((EditorArea) c);
     }
