@@ -7,7 +7,7 @@ import org.basex.util.*;
 /**
  * This class organizes all map rectangles in a simple list.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 final class MapRects implements Iterable<MapRect> {
@@ -105,7 +105,7 @@ final class MapRects implements Iterable<MapRect> {
 
   @Override
   public Iterator<MapRect> iterator() {
-    return new ArrayIterator<MapRect>(list, size);
+    return new ArrayIterator<>(list, size);
   }
 
   /**
