@@ -10,7 +10,7 @@ import org.basex.util.hash.*;
 /**
  * Axis component of the scatter plot visualization.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Lukas Kircher
  */
 final class PlotAxis {
@@ -18,7 +18,7 @@ final class PlotAxis {
   private static final int TEXTLENGTH = 11;
   /** Plot data reference. */
   private final PlotData plotData;
-  /** Tag reference to selected attribute. */
+  /** Reference to selected attribute. */
   int attrID;
   /** Number of different categories for x attribute. */
   int nrCats;
@@ -45,8 +45,8 @@ final class PlotAxis {
   /** Axis uses logarithmic scale. */
   boolean log;
 
-  /** True if attribute is a tag, false if attribute. */
-  private boolean tag;
+  /** True if attribute is an element, false if attribute. */
+  private boolean elem;
   /** Ln of min. */
   private double logMin;
   /** Ln of max. */
@@ -54,17 +54,17 @@ final class PlotAxis {
 
   /**
    * Constructor.
-   * @param data plot data reference
+   * @param plotData plot data reference
    */
-  PlotAxis(final PlotData data) {
-    plotData = data;
+  PlotAxis(final PlotData plotData) {
+    this.plotData = plotData;
   }
 
   /**
    * (Re)Initializes axis.
    */
   private void initialize() {
-    tag = false;
+    elem = false;
     type = StatsType.INTEGER;
     co = new double[0];
     nrCats = -1;
@@ -88,10 +88,10 @@ final class PlotAxis {
     if(attribute == null) return false;
     initialize();
     byte[] b = token(attribute);
-    tag = !contains(b, '@');
+    elem = !contains(b, '@');
     b = delete(b, '@');
     final Data data = plotData.context.data();
-    attrID = (tag ? data.tagindex : data.atnindex).id(b);
+    attrID = (elem ? data.elemNames : data.attrNames).id(b);
     refreshAxis();
     return true;
   }
@@ -103,8 +103,8 @@ final class PlotAxis {
    */
   void refreshAxis() {
     final Data data = plotData.context.data();
-    final Stats key = tag ? data.tagindex.stat(attrID) :
-      data.atnindex.stat(attrID);
+    final Stats key = elem ? data.elemNames.stat(attrID) :
+      data.attrNames.stat(attrID);
     if(key == null) return;
     type = key.type;
     if(type == null) return;
@@ -112,10 +112,11 @@ final class PlotAxis {
       type = StatsType.TEXT;
 
     final int[] items = plotData.pres;
-    if(items.length < 1) return;
-    co = new double[items.length];
-    final byte[][] vals = new byte[items.length][];
-    for(int i = 0; i < items.length; ++i) {
+    final int il = items.length;
+    if(il < 1) return;
+    co = new double[il];
+    final byte[][] vals = new byte[il][];
+    for(int i = 0; i < il; ++i) {
       byte[] value = getValue(items[i]);
       if(type == StatsType.TEXT && value.length > TEXTLENGTH) {
         value = substring(value, 0, TEXTLENGTH);
@@ -131,8 +132,8 @@ final class PlotAxis {
       if(!log) prepareLinAxis();
 
       // coordinates for TEXT already calculated in textToNum()
-      for(int i = 0; i < vals.length; ++i)
-        co[i] = calcPosition(vals[i]);
+      final int vl = vals.length;
+      for(int v = 0; v < vl; ++v) co[v] = calcPosition(vals[v]);
     }
   }
 
@@ -249,8 +250,8 @@ final class PlotAxis {
     final int limit = pre + data.size(pre, Data.ELEM);
     for(int p = pre; p < limit; ++p) {
       final int kind = data.kind(p);
-      if((kind == Data.ELEM && tag || kind == Data.ATTR && !tag) &&
-          attrID == data.name(p)) return data.atom(p);
+      if((kind == Data.ELEM && elem || kind == Data.ATTR && !elem) &&
+          attrID == data.nameId(p)) return data.atom(p);
     }
     return EMPTY;
   }
@@ -262,12 +263,13 @@ final class PlotAxis {
   private void minMax(final byte[][] vals) {
     min = Integer.MAX_VALUE;
     max = Integer.MIN_VALUE;
-    int i = -1;
+    int v = -1;
     boolean b = false;
-    while(++i < vals.length) {
-      if(vals[i].length > 0) {
+    final int vl = vals.length;
+    while(++v < vl) {
+      if(vals[v].length > 0) {
         b = true;
-        final double d = toDouble(vals[i]);
+        final double d = toDouble(vals[v]);
         if(d < min) min = d;
         if(d > max) max = d;
       }
