@@ -11,15 +11,15 @@ import java.awt.event.*;
 import javax.swing.*;
 
 import org.basex.data.*;
-import org.basex.gui.GUIConstants.Fill;
 import org.basex.gui.*;
 import org.basex.gui.layout.*;
 import org.basex.gui.view.table.TableData.TableCol;
+import org.basex.query.value.seq.*;
 
 /**
  * This is the header of the table view.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 final class TableHeader extends BaseXPanel {
@@ -47,10 +47,11 @@ final class TableHeader extends BaseXPanel {
    */
   TableHeader(final TableView v) {
     super(v.gui);
-    mode(Fill.NONE).setFocusable(true);
+    setOpaque(false);
+    setFocusable(true);
     tdata = v.tdata;
     view = v;
-    BaseXLayout.setHeight(this, fontSize + 8 << 1);
+    refreshLayout();
     addMouseListener(this);
     addMouseMotionListener(this);
     addKeyListener(this);
@@ -73,12 +74,20 @@ final class TableHeader extends BaseXPanel {
     });
   }
 
+  /**
+   * Called when GUI design has changed.
+   */
+  public void refreshLayout() {
+    setPreferredSize(new Dimension(getPreferredSize().width, fontSize * 3));
+    setSize(getPreferredSize());
+  }
+
   @Override
   public void paintComponent(final Graphics g) {
     super.paintComponent(g);
 
     g.setFont(font);
-    g.setColor(Color.black);
+    g.setColor(TEXT);
     if(tdata.rows == null) {
       BaseXLayout.drawCenter(g, NO_DATA, getWidth(), getHeight() / 2);
       return;
@@ -87,11 +96,11 @@ final class TableHeader extends BaseXPanel {
     final int fsz = fontSize;
     int w = getWidth();
     final int h = getHeight();
-    final int hh = h >> 1;
+    final int hh = h / 2;
     g.setColor(color2);
     g.drawLine(0, h - 1, w, h - 1);
 
-    final int bs = BaseXScrollBar.SIZE;
+    final int bs = view.scroll.getWidth();
     w -= bs;
     double x = 0;
     final int nc = tdata.cols.length;
@@ -103,14 +112,14 @@ final class TableHeader extends BaseXPanel {
       final boolean clicked = n == clickCol && moveC == -1 && header;
       BaseXLayout.drawCell(g, (int) x, (int) ce + 1, 0, hh, clicked);
       // input field
-      g.setColor(Color.white);
+      g.setColor(BACK);
       g.fillRect((int) x + 1, hh, (int) ce - (int) x - 2, hh - 2);
       g.drawLine((int) ce - 1, hh - 1, (int) ce - 1, h - 2);
-      g.setColor(GRAY);
+      g.setColor(gray);
       g.drawLine((int) ce, hh - 1, (int) ce, h - 2);
 
       // draw headers
-      g.setColor(Color.black);
+      g.setColor(TEXT);
       g.setFont(bfont);
 
       final int off = clicked ? 1 : 0;
@@ -128,7 +137,7 @@ final class TableHeader extends BaseXPanel {
       if(box != null && inputCol == n) {
         box.paint(g, (int) x, hh, (int) ce - (int) x, hh);
       } else {
-        g.setColor(Color.black);
+        g.setColor(TEXT);
         g.setFont(font);
         g.drawString(tdata.cols[n].filter, (int) x + 5, h - 7);
       }
@@ -138,13 +147,15 @@ final class TableHeader extends BaseXPanel {
     final boolean clicked = nc == clickCol;
     BaseXLayout.drawCell(g, (int) x, w + bs, 0, hh, clicked && header);
     BaseXLayout.drawCell(g, (int) x, w + bs, hh - 1, h, clicked && !header);
-    g.setColor(Color.black);
-    g.setFont(bfont);
-    smooth(g);
+    BaseXLayout.antiAlias(g);
 
     int o = header && clicked ? 1 : 0;
-    g.fillPolygon(new int[] { (int) x + o + 4, (int) x + o + bs - 4, (int) x + o + bs / 2 },
-        new int[] { o + 6, o + 6, o + bs - 3 }, 3);
+    final int xo = (int) (4 * SCALE), yo = (int) (6 * SCALE);
+    g.setColor(TEXT);
+    g.fillPolygon(
+        new int[] { (int) x + o + xo, (int) x + o + bs - xo, (int) x + o + bs / 2 },
+        new int[] { o + yo, o + yo, o + bs - yo }, 3);
+    g.setFont(bfont);
 
     o = !header && clicked ? 1 : 0;
     final byte[] reset = { 'x' };
@@ -159,7 +170,7 @@ final class TableHeader extends BaseXPanel {
     Cursor cursor = CURSORARROW;
     mouseX = e.getX();
 
-    final int w = getWidth() - BaseXScrollBar.SIZE;
+    final int w = getWidth() - view.scroll.getWidth();
     if(header(e.getY())) {
       moveC = colSep(w, mouseX);
       if(moveC != -1) cursor = CURSORMOVEH;
@@ -182,9 +193,11 @@ final class TableHeader extends BaseXPanel {
    */
   private int colSep(final int w, final int mx) {
     double x = 0;
-    for(int i = 0; i < tdata.cols.length; ++i) {
+    final TableCol[] cols = tdata.cols;
+    final int tl = cols.length;
+    for(int i = 0; i < tl; ++i) {
       if(i > 0 && Math.abs(mx - x) < 3) return i;
-      x += w * tdata.cols[i].width;
+      x += w * cols[i].width;
     }
     return -1;
   }
@@ -195,23 +208,24 @@ final class TableHeader extends BaseXPanel {
 
     if(moveC != -1) {
       final int x = e.getX();
-      final double p = (double) (x - mouseX) / (getWidth() - BaseXScrollBar.SIZE);
+      final double p = (double) (x - mouseX) / (getWidth() - view.scroll.getWidth());
       final double[] ww = new double[tdata.cols.length];
-      for(int w = 0; w < ww.length; ++w) ww[w] = tdata.cols[w].width;
+      final int wl = ww.length;
+      for(int w = 0; w < wl; ++w) ww[w] = tdata.cols[w].width;
 
       if(e.isShiftDown()) {
         ww[moveC - 1] += p;
         ww[moveC] -= p;
       } else {
         for(int i = 0; i < moveC; ++i) ww[i] += p / moveC;
-        for(int i = moveC; i < ww.length; ++i) ww[i] -= p / (ww.length - moveC);
+        for(int i = moveC; i < wl; ++i) ww[i] -= p / (wl - moveC);
       }
       for(final double w : ww) if(w < 0.0001) return;
       mouseX = x;
 
-      for(int w = 0; w < ww.length; ++w) tdata.cols[w].width = ww[w];
+      for(int w = 0; w < wl; ++w) tdata.cols[w].width = ww[w];
     } else if(clickCol != -1) {
-      int c = tdata.column(getWidth() - BaseXScrollBar.SIZE, e.getX());
+      int c = tdata.column(getWidth() - view.scroll.getWidth(), e.getX());
       if(c == -1) c = tdata.cols.length;
       if(c != clickCol || header != header(e.getY())) clickCol = -1;
     }
@@ -230,7 +244,7 @@ final class TableHeader extends BaseXPanel {
   public void mousePressed(final MouseEvent e) {
     if(tdata.rows == null || !SwingUtilities.isLeftMouseButton(e)) return;
 
-    clickCol = tdata.column(getWidth() - BaseXScrollBar.SIZE, mouseX);
+    clickCol = tdata.column(getWidth() - view.scroll.getWidth(), mouseX);
     if(clickCol == -1) clickCol = tdata.cols.length;
     header = header(e.getY());
     repaint();
@@ -282,9 +296,9 @@ final class TableHeader extends BaseXPanel {
 
     final Data data = view.gui.context.data();
     final JPopupMenu popup = new JPopupMenu();
-    final byte[] root = data.tagindex.key(tdata.root);
+    final byte[] root = data.elemNames.key(tdata.root);
     for(final byte[] en : tdata.roots) {
-      final int id = data.tagindex.id(en);
+      final int id = data.elemNames.id(en);
       final JMenuItem mi = new JRadioButtonMenuItem(string(en), eq(root, en));
       mi.addActionListener(new ActionListener() {
         @Override
@@ -362,10 +376,10 @@ final class TableHeader extends BaseXPanel {
     if(ENTER.is(e)) {
       box.stop();
       inputCol = -1;
-      final Nodes marked = view.gui.context.marked;
+      final DBNodes marked = view.gui.context.marked;
       if(marked.size() != 0) view.gui.notify.context(marked, false, null);
     } else if(TAB.is(e)) {
-      tdata.cols[inputCol].filter = box.text;
+      tdata.cols[inputCol].filter = box.text();
       box.stop();
       final int in = inputCol + (e.isShiftDown() ? -1 : 1);
       if(in < 0) {
@@ -386,7 +400,7 @@ final class TableHeader extends BaseXPanel {
   public void keyTyped(final KeyEvent e) {
     if(tdata.roots.isEmpty() || box == null || inputCol == -1 ||
         control(e) || !box.add(e)) return;
-    tdata.cols[inputCol].filter = box.text;
+    tdata.cols[inputCol].filter = box.text();
     view.query();
   }
 }
