@@ -12,9 +12,7 @@ import javax.swing.*;
 
 import org.basex.core.*;
 import org.basex.core.parse.*;
-import org.basex.data.*;
 import org.basex.gui.*;
-import org.basex.gui.GUIConstants.Fill;
 import org.basex.gui.layout.*;
 import org.basex.gui.layout.BaseXFileChooser.Mode;
 import org.basex.gui.text.*;
@@ -23,12 +21,14 @@ import org.basex.io.*;
 import org.basex.io.out.*;
 import org.basex.io.serial.*;
 import org.basex.query.*;
+import org.basex.query.value.*;
+import org.basex.query.value.seq.*;
 import org.basex.util.*;
 
 /**
  * This class offers a fast text view, using the {@link TextPanel} class.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class TextView extends View {
@@ -36,7 +36,7 @@ public final class TextView extends View {
   private final SearchEditor search;
 
   /** Header string. */
-  private final BaseXLabel label;
+  private final BaseXHeader header;
   /** Home button. */
   private final AbstractButton home;
   /** Text Area. */
@@ -45,7 +45,7 @@ public final class TextView extends View {
   /** Result command. */
   private Command cmd;
   /** Result nodes. */
-  private Nodes ns;
+  private DBNodes ns;
 
   /**
    * Default constructor.
@@ -55,8 +55,7 @@ public final class TextView extends View {
     super(TEXTVIEW, man);
     border(5).layout(new BorderLayout(0, 5));
 
-    label = new BaseXLabel(RESULT, true, false);
-    label.setForeground(GRAY);
+    header = new BaseXHeader(RESULT);
 
     home = BaseXButton.command(GUIMenuCmd.C_HOME, gui);
     home.setEnabled(false);
@@ -68,15 +67,15 @@ public final class TextView extends View {
     final AbstractButton save = BaseXButton.get("c_save", SAVE, false, gui);
     final AbstractButton find = search.button(FIND);
 
-    final BaseXBack buttons = new BaseXBack(Fill.NONE);
+    final BaseXBack buttons = new BaseXBack(false);
     buttons.layout(new TableLayout(1, 3, 1, 0)).border(0, 0, 4, 0);
     buttons.add(save);
     buttons.add(home);
     buttons.add(find);
 
-    final BaseXBack b = new BaseXBack(Fill.NONE).layout(new BorderLayout());
+    final BaseXBack b = new BaseXBack(false).layout(new BorderLayout());
     b.add(buttons, BorderLayout.WEST);
-    b.add(label, BorderLayout.EAST);
+    b.add(header, BorderLayout.EAST);
     add(b, BorderLayout.NORTH);
 
     add(search, BorderLayout.CENTER);
@@ -111,7 +110,7 @@ public final class TextView extends View {
 
   @Override
   public void refreshLayout() {
-    label.border(-6, 0, 0, 2).setFont(lfont);
+    header.refreshLayout();
     text.setFont(mfont);
     search.bar().refreshLayout();
   }
@@ -138,17 +137,17 @@ public final class TextView extends View {
 
   /**
    * Serializes the specified nodes.
-   * @param n nodes to display
+   * @param nodes nodes to display
    */
-  private void setText(final Nodes n) {
+  private void setText(final DBNodes nodes) {
     if(visible()) {
       try {
         final ArrayOutput ao = new ArrayOutput();
         ao.setLimit(gui.gopts.get(GUIOptions.MAXTEXT));
-        if(n != null) n.serialize(Serializer.get(ao));
+        if(nodes != null) nodes.serialize(Serializer.get(ao));
         setText(ao);
         cmd = null;
-        ns = ao.finished() ? n : null;
+        ns = ao.finished() ? nodes : null;
       } catch(final IOException ex) {
         Util.debug(ex);
       }
@@ -160,27 +159,27 @@ public final class TextView extends View {
   /**
    * Caches the output.
    * @param out cached output
-   * @param c command
-   * @param r result
+   * @param command command
+   * @param result result
    * @throws QueryException query exception
    */
-  public void cacheText(final ArrayOutput out, final Command c, final Result r)
+  public void cache(final ArrayOutput out, final Command command, final Value result)
       throws QueryException {
 
     // cache command or node set
     cmd = null;
     ns = null;
 
-    final int mh = gui.context.options.get(MainOptions.MAXHITS);
+    final int mh = gui.gopts.get(GUIOptions.MAXRESULTS);
     boolean parse = false;
-    if(mh >= 0 && r != null && r.size() >= mh) {
+    if(mh >= 0 && result != null && result.size() >= mh) {
       parse = true;
     } else if(out.finished()) {
-      if(r instanceof Nodes) ns = (Nodes) r;
+      if(result instanceof DBNodes) ns = (DBNodes) result;
       else parse = true;
     }
     // create new command instance
-    if(parse) cmd = new CommandParser(c.toString(), gui.context).parseSingle();
+    if(parse) cmd = new CommandParser(command.toString(), gui.context).parseSingle();
   }
 
   /**
@@ -195,7 +194,7 @@ public final class TextView extends View {
       System.arraycopy(chop, 0, buf, size - chop.length, chop.length);
     }
     text.setText(buf, size);
-    label.setText((out.finished() ? CHOPPED : "") + RESULT);
+    header.setText((out.finished() ? CHOPPED : "") + RESULT);
     home.setEnabled(gui.context.data() != null);
   }
 
@@ -211,28 +210,17 @@ public final class TextView extends View {
     gui.gopts.set(GUIOptions.WORKPATH, file.path());
 
     gui.cursor(CURSORWAIT, true);
-    final MainOptions opts = gui.context.options;
-    final int mh = opts.get(MainOptions.MAXHITS);
-    opts.set(MainOptions.MAXHITS, -1);
-    opts.set(MainOptions.CACHEQUERY, false);
-
-    PrintOutput out = null;
-    try {
-      out = new PrintOutput(file.toString());
+    try(final PrintOutput out = new PrintOutput(file.toString())) {
       if(cmd != null) {
         cmd.execute(gui.context, out);
       } else if(ns != null) {
         ns.serialize(Serializer.get(out));
       } else {
-        final byte[] txt = text.getText();
-        for(final byte t : txt) if(t < 0 || t > ' ' || ws(t)) out.write(t);
+        for(final byte t : text.getText()) if(t < 0 || t > ' ' || ws(t)) out.write(t);
       }
     } catch(final IOException ex) {
       BaseXDialog.error(gui, Util.info(FILE_NOT_SAVED_X, file));
     } finally {
-      if(out != null) try { out.close(); } catch(final IOException ignored) { }
-      opts.set(MainOptions.MAXHITS, mh);
-      opts.set(MainOptions.CACHEQUERY, true);
       gui.cursor(CURSORARROW, true);
     }
   }
