@@ -1,25 +1,22 @@
 package org.basex.index;
 
+import org.basex.core.*;
 import org.basex.index.query.*;
 
 /**
  * This interface defines the methods which have to be implemented
  * by an index structure.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public interface Index {
-  /**
-   * Initializes the index.
-   */
-  void init();
-
   /**
    * Returns information on the index structure.
+   * @param options main options
    * @return info
    */
-  byte[] info();
+  byte[] info(final MainOptions options);
 
   /**
    * Returns all entries that match the specified token.
@@ -43,6 +40,12 @@ public interface Index {
    */
   int costs(final IndexToken token);
 
+  /**
+   * Drops the index.
+   * @return success flag
+   */
+  boolean drop();
+
   /**
    * Closes the index.
    */
