@@ -6,13 +6,14 @@ import java.io.*;
 
 import org.basex.core.*;
 import org.basex.data.*;
+import org.basex.index.value.*;
 import org.basex.util.*;
 
 /**
  * This interface defines the functions which are needed for building
  * new index structures.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public abstract class IndexBuilder extends Proc {
@@ -35,12 +36,24 @@ public abstract class IndexBuilder extends Proc {
   /** Threshold for freeing memory when estimating main memory consumption. */
   private int gcCount;
 
+  /**
+   * Constructor.
+   * @param data reference
+   * @param max maximum number of operations per partial index
+   */
+  protected IndexBuilder(final Data data, final int max) {
+    this.data = data;
+    size = data.meta.size;
+    splitSize = max;
+    if(Performance.memory() >= maxMem) Performance.gc(1);
+  }
+
   /**
    * Builds the index structure and returns an index instance.
    * @return index instance
    * @throws IOException I/O Exception
    */
-  public abstract Index build() throws IOException;
+  public abstract ValueIndex build() throws IOException;
 
   /**
    * Checks if the command was interrupted, and prints some debug output.
@@ -79,7 +92,7 @@ public abstract class IndexBuilder extends Proc {
   }
 
   /**
-   * Performs memory cleanup after writing partial memory, if necessary.
+   * Performs memory cleanup after writing partial memory if necessary.
    */
   protected final void finishSplit() {
     if(splitSize <= 0) Performance.gc(1);
@@ -99,18 +112,6 @@ public abstract class IndexBuilder extends Proc {
     Util.errln(sb);
   }
 
-  /**
-   * Constructor.
-   * @param d reference
-   * @param max maximum number of operations per partial index
-   */
-  protected IndexBuilder(final Data d, final int max) {
-    data = d;
-    size = data.meta.size;
-    splitSize = max;
-    if(Performance.memory() >= maxMem) Performance.gc(1);
-  }
-
   @Override
   public final String tit() {
     return CREATING_INDEXES;
@@ -118,6 +119,6 @@ public abstract class IndexBuilder extends Proc {
 
   @Override
   public final double prog() {
-    return (double) pre / (size + (splits > 0 ? size / 50 : 0));
+    return pre / (size + (splits > 0 ? size / 50d : 0d));
   }
 }
