@@ -1,11 +1,11 @@
 package org.basex.index.query;
 
-import org.basex.data.*;
+import org.basex.query.util.ft.*;
 
 /**
  * This interface provides methods for returning index results.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public abstract class FTIndexIterator extends IndexIterator {
