@@ -6,12 +6,12 @@ import org.basex.util.*;
 /**
  * This class stores a numeric range for index access.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class NumericRange implements IndexToken {
   /** Index type. */
-  public final IndexType type;
+  private final boolean text;
   /** Minimum value. */
   public final double min;
   /** Maximum value. */
@@ -19,19 +19,19 @@ public final class NumericRange implements IndexToken {
 
   /**
    * Constructor.
-   * @param it index type
-   * @param mn minimum value
-   * @param mx maximum value
+   * @param text text/attribute index
+   * @param min minimum value
+   * @param max maximum value
    */
-  public NumericRange(final IndexType it, final double mn, final double mx) {
-    type = it;
-    min = mn;
-    max = mx;
+  public NumericRange(final boolean text, final double min, final double max) {
+    this.text = text;
+    this.min = min;
+    this.max = max;
   }
 
   @Override
   public IndexType type() {
-    return type;
+    return text ? IndexType.TEXT : IndexType.ATTRIBUTE;
   }
 
   @Override
