@@ -2,8 +2,8 @@ package org.basex.index.resource;
 
 import java.io.*;
 
+import org.basex.core.*;
 import org.basex.data.*;
-import org.basex.data.atomic.*;
 import org.basex.index.*;
 import org.basex.index.query.*;
 import org.basex.io.in.DataInput;
@@ -15,7 +15,7 @@ import org.basex.util.list.*;
 /**
  * <p>This index organizes the resources of a database (XML documents and raw files).</p>
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class Resources implements Index {
@@ -53,17 +53,12 @@ public final class Resources implements Index {
 
   /**
    * Returns the {@code pre} values of all document nodes.
-   * @return document nodes
+   * @return document nodes (internal representation!)
    */
   public synchronized IntList docs() {
     return docs.docs();
   }
 
-  @Override
-  public synchronized void init() {
-    docs.init();
-  }
-
   /**
    * Adds entries to the index and updates subsequent nodes.
    * @param pre insertion position
@@ -102,36 +97,25 @@ public final class Resources implements Index {
   }
 
   /**
-   * Returns the pre values of all document nodes starting with the specified path.
+   * Returns the pre values of all document nodes that start with the specified path.
    * @param path input path
-   * @return root nodes
+   * @return pre values (internal representation!)
    */
   public synchronized IntList docs(final String path) {
     return docs.docs(path, false);
   }
 
   /**
-   * Returns the pre values of all document nodes matching the specified path.
+   * Returns the pre value of the document node that matches the specified path, or {@code -1}.
    * @param path input path
-   * @param exact exact (no prefix) matches
-   * @return root nodes
-   */
-  public synchronized IntList docs(final String path, final boolean exact) {
-    return docs.docs(path, exact);
-  }
-
-  /**
-   * Returns the pre value of the node that matches the specified path, or {@code -1}.
-   * @param path input path
-   * @return pre value
+   * @return pre value, or {@code -1}
    */
   public int doc(final String path) {
-    return docs.doc(path, true);
+    return docs.doc(path);
   }
 
   /**
-   * Returns the database paths to all binary files that match the
-   * specified path.
+   * Returns the database paths to all binary files that start with the specified path.
    * @param path input path
    * @return root nodes
    */
@@ -163,6 +147,11 @@ public final class Resources implements Index {
 
   // Inherited methods ========================================================
 
+  @Override
+  public boolean drop() {
+    throw Util.notExpected();
+  }
+
   @Override
   public void close() { }
 
@@ -177,7 +166,7 @@ public final class Resources implements Index {
   }
 
   @Override
-  public byte[] info() {
+  public byte[] info(final MainOptions options) {
     throw Util.notExpected();
   }
 
