@@ -3,10 +3,10 @@ package org.basex.io.out;
 /**
  * This output stream swallows all data it receives.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class NullOutput extends PrintOutput {
   @Override
-  public void write(final int b) { }
+  public void write(final int value) { }
 }
