@@ -5,11 +5,9 @@ import java.io.*;
 import org.basex.util.*;
 
 /**
- * This class is a stream-wrapper for textual data. Note that the internal
- * byte representation (usually UTF8) will be directly output without
- * further character conversion.
+ * This class is a stream-wrapper for textual data encoded in UTF8.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public class PrintOutput extends OutputStream {
@@ -36,10 +34,10 @@ public class PrintOutput extends OutputStream {
 
   /**
    * Constructor, given an output stream.
-   * @param out output stream reference
+   * @param os output stream reference
    */
-  private PrintOutput(final OutputStream out) {
-    os = out;
+  protected PrintOutput(final OutputStream os) {
+    this.os = os;
   }
 
   /**
@@ -56,12 +54,11 @@ public class PrintOutput extends OutputStream {
 
   /**
    * Sets the maximum number of bytes to be written.
-   * If the number is negative, all bytes will be written.
    * Note that the limit might break unicode characters.
-   * @param m maximum
+   * @param limit maximum
    */
-  public void setLimit(final int m) {
-    max = m < 0 ? Long.MAX_VALUE : m;
+  public final void setLimit(final int limit) {
+    max = limit;
   }
 
   @Override
@@ -70,68 +67,58 @@ public class PrintOutput extends OutputStream {
   }
 
   /**
-   * Writes a character as UTF8.
-   * @param ch character to be printed
+   * Prints a single codepoint.
+   * @param cp codepoint to be printed
    * @throws IOException I/O exception
    */
-  public void utf8(final int ch) throws IOException {
-    if(ch <= 0x7F) {
-      write(ch);
-    } else if(ch <= 0x7FF) {
-      write(ch >>  6 & 0x1F | 0xC0);
-      write(ch & 0x3F | 0x80);
-    } else if(ch <= 0xFFFF) {
-      write(ch >> 12 & 0x0F | 0xE0);
-      write(ch >>  6 & 0x3F | 0x80);
-      write(ch & 0x3F | 0x80);
+  public void print(final int cp) throws IOException {
+    if(cp <= 0x7F) {
+      write(cp);
+    } else if(cp <= 0x7FF) {
+      write(cp >>  6 & 0x1F | 0xC0);
+      write(cp & 0x3F | 0x80);
+    } else if(cp <= 0xFFFF) {
+      write(cp >> 12 & 0x0F | 0xE0);
+      write(cp >>  6 & 0x3F | 0x80);
+      write(cp & 0x3F | 0x80);
     } else {
-      write(ch >> 18 & 0x07 | 0xF0);
-      write(ch >> 12 & 0x3F | 0x80);
-      write(ch >>  6 & 0x3F | 0x80);
-      write(ch & 0x3F | 0x80);
+      write(cp >> 18 & 0x07 | 0xF0);
+      write(cp >> 12 & 0x3F | 0x80);
+      write(cp >>  6 & 0x3F | 0x80);
+      write(cp & 0x3F | 0x80);
     }
   }
 
-  /**
-   * Writes a string to the output stream, suffixed by a 0 byte.
-   * @param str string to be written
-   * @throws IOException I/O exception
-   */
-  public final void writeString(final String str) throws IOException {
-    print(Token.token(str));
-    write(0);
-  }
-
-  /**
-   * Prints a string to the output stream.
-   * @param str string to be written
-   * @throws IOException I/O exception
-   */
-  public final void print(final String str) throws IOException {
-    print(Token.token(str));
-  }
-
-  /**
-   * Prints a string and newline to the output stream.
-   * @param str string to be written
-   * @throws IOException I/O exception
-   */
-  public final void println(final String str) throws IOException {
-    print(str);
-    print(Prop.NL);
-  }
-
   /**
    * Prints a token to the output stream.
    * @param token token to be written
    * @throws IOException I/O exception
    */
-  public final void print(final byte[] token) throws IOException {
-    for(final byte t : token) write(t);
+  public void print(final byte[] token) throws IOException {
+    for(final byte cp : token) write(cp);
   }
 
   /**
-   * Prints a token to the output stream.
+   * Prints a string to the output stream.
+   * @param string string to be written
+   * @throws IOException I/O exception
+   */
+  public void print(final String string) throws IOException {
+    print(Token.token(string));
+  }
+
+  /**
+   * Prints a string and newline to the output stream.
+   * @param string string to be written
+   * @throws IOException I/O exception
+   */
+  public final void println(final String string) throws IOException {
+    print(string);
+    print(Prop.NL);
+  }
+
+  /**
+   * Prints a token to the output stream, followed by a system-specific newline.
    * @param token token to be written
    * @throws IOException I/O exception
    */
@@ -162,11 +149,18 @@ public class PrintOutput extends OutputStream {
   }
 
   /**
-   * Checks if stream can output more characters; can be overwritten to
-   * interrupt streaming at some point.
-   * @return result of check
+   * Checks if stream can output more characters.
+   * @return {@code true} if stream is exhausted
    */
-  public boolean finished() {
-    return false;
+  public final boolean finished() {
+    return size == max;
+  }
+
+  /**
+   * Returns the encoding.
+   * @return encoding
+   */
+  public String encoding() {
+    return Strings.UTF8;
   }
 }
