@@ -8,16 +8,16 @@ import org.basex.util.*;
 /**
  * This class allows positional read and write access to a database file.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
-public final class DataAccess {
+public final class DataAccess implements Closeable {
   /** Buffer manager. */
   private final Buffers bm = new Buffers();
   /** Reference to the data input stream. */
-  private final RandomAccessFile file;
+  private final RandomAccessFile raf;
   /** File length. */
-  private long len;
+  private long length;
   /** Changed flag. */
   private boolean changed;
   /** Offset. */
@@ -25,20 +25,20 @@ public final class DataAccess {
 
   /**
    * Constructor, initializing the file reader.
-   * @param fl the file to be read
+   * @param file the file to be read
    * @throws IOException I/O Exception
    */
-  public DataAccess(final IOFile fl) throws IOException {
+  public DataAccess(final IOFile file) throws IOException {
     RandomAccessFile f = null;
     try {
-      f = new RandomAccessFile(fl.file(), "rw");
-      len = f.length();
+      f = new RandomAccessFile(file.file(), "rw");
+      length = f.length();
+      raf = f;
+      cursor(0);
     } catch(final IOException ex) {
       if(f != null) f.close();
       throw ex;
     }
-    file = f;
-    cursor(0);
   }
 
   /**
@@ -48,7 +48,7 @@ public final class DataAccess {
     try {
       for(final Buffer b : bm.all()) if(b.dirty) writeBlock(b);
       if(changed) {
-        file.setLength(len);
+        raf.setLength(length);
         changed = false;
       }
     } catch(final IOException ex) {
@@ -56,13 +56,11 @@ public final class DataAccess {
     }
   }
 
-  /**
-   * Closes the data access.
-   */
+  @Override
   public synchronized void close() {
     flush();
     try {
-      file.close();
+      raf.close();
     } catch(final IOException ex) {
       Util.stack(ex);
     }
@@ -76,21 +74,12 @@ public final class DataAccess {
     return buffer(false).pos + off;
   }
 
-  /**
-   * Sets the file length.
-   * @param l file length
-   */
-  private synchronized void length(final long l) {
-    changed |= l != len;
-    len = l;
-  }
-
   /**
    * Returns the file length.
    * @return file length
    */
   public long length() {
-    return len;
+    return length;
   }
 
   /**
@@ -98,25 +87,16 @@ public final class DataAccess {
    * @return result of check
    */
   public boolean more() {
-    return cursor() < len;
-  }
-
-  /**
-   * Reads the next byte.
-   * @return next byte
-   */
-  private int read() {
-    final Buffer bf = buffer(off == IO.BLOCKSIZE);
-    return bf.data[off++] & 0xFF;
+    return cursor() < length;
   }
 
   /**
    * Reads a byte value from the specified position.
-   * @param p position
+   * @param pos position
    * @return integer value
    */
-  public synchronized byte read1(final long p) {
-    cursor(p);
+  public synchronized byte read1(final long pos) {
+    cursor(pos);
     return read1();
   }
 
@@ -130,11 +110,11 @@ public final class DataAccess {
 
   /**
    * Reads an integer value from the specified position.
-   * @param p position
+   * @param pos position
    * @return integer value
    */
-  public synchronized int read4(final long p) {
-    cursor(p);
+  public synchronized int read4(final long pos) {
+    cursor(pos);
     return read4();
   }
 
@@ -148,11 +128,11 @@ public final class DataAccess {
 
   /**
    * Reads a 5-byte value from the specified file offset.
-   * @param p position
+   * @param pos position
    * @return long value
    */
-  public synchronized long read5(final long p) {
-    cursor(p);
+  public synchronized long read5(final long pos) {
+    cursor(pos);
     return read5();
   }
 
@@ -161,8 +141,7 @@ public final class DataAccess {
    * @return long value
    */
   public synchronized long read5() {
-    return ((long) read() << 32) + ((long) read() << 24) +
-      (read() << 16) + (read() << 8) + read();
+    return ((long) read() << 32) + ((long) read() << 24) + (read() << 16) + (read() << 8) + read();
   }
 
   /**
@@ -196,22 +175,22 @@ public final class DataAccess {
 
   /**
    * Reads a number of bytes from the specified offset.
-   * @param p position
-   * @param l length
+   * @param pos position
+   * @param len length
    * @return byte array
    */
-  public synchronized byte[] readBytes(final long p, final int l) {
-    cursor(p);
-    return readBytes(l);
+  public synchronized byte[] readBytes(final long pos, final int len) {
+    cursor(pos);
+    return readBytes(len);
   }
 
   /**
    * Reads a number of bytes.
-   * @param n length
+   * @param len length
    * @return byte array
    */
-  public synchronized byte[] readBytes(final int n) {
-    int l = n;
+  public synchronized byte[] readBytes(final int len) {
+    int l = len;
     int ll = IO.BLOCKSIZE - off;
     final byte[] b = new byte[l];
 
@@ -231,20 +210,20 @@ public final class DataAccess {
 
   /**
    * Sets the disk cursor.
-   * @param p read position
+   * @param pos read position
    */
-  public void cursor(final long p) {
-    off = (int) (p & IO.BLOCKSIZE - 1);
-    final long b = p - off;
+  public void cursor(final long pos) {
+    off = (int) (pos & IO.BLOCKSIZE - 1);
+    final long b = pos - off;
     if(!bm.cursor(b)) return;
 
     final Buffer bf = bm.current();
     try {
       if(bf.dirty) writeBlock(bf);
       bf.pos = b;
-      file.seek(bf.pos);
-      if(bf.pos < file.length())
-        file.readFully(bf.data, 0, (int) Math.min(len - bf.pos, IO.BLOCKSIZE));
+      raf.seek(bf.pos);
+      if(bf.pos < raf.length())
+        raf.readFully(bf.data, 0, (int) Math.min(length - bf.pos, IO.BLOCKSIZE));
     } catch(final IOException ex) {
       Util.stack(ex);
     }
@@ -255,149 +234,106 @@ public final class DataAccess {
    * @return next integer
    */
   public synchronized int readNum() {
-    final int v = read();
-    switch(v & 0xC0) {
+    final int value = read();
+    switch(value & 0xC0) {
     case 0:
-      return v;
+      return value;
     case 0x40:
-      return (v - 0x40 << 8) + read();
+      return (value - 0x40 << 8) + read();
     case 0x80:
-      return (v - 0x80 << 24) + (read() << 16) + (read() << 8) + read();
+      return (value - 0x80 << 24) + (read() << 16) + (read() << 8) + read();
     default:
       return (read() << 24) + (read() << 16) + (read() << 8) + read();
     }
   }
 
-  /**
-   * Writes the next byte.
-   * @param b byte to be written
-   */
-  private void write(final int b) {
-    final Buffer bf = buffer(off == IO.BLOCKSIZE);
-    bf.dirty = true;
-    bf.data[off++] = (byte) b;
-    final long nl = bf.pos + off;
-    if(nl > len) length(nl);
-  }
-
   /**
    * Writes a 5-byte value to the specified position.
-   * @param p position in the file
-   * @param v value to be written
+   * @param pos position in the file
+   * @param value value to be written
    */
-  public void write5(final long p, final long v) {
-    cursor(p);
-    write((byte) (v >>> 32));
-    write((byte) (v >>> 24));
-    write((byte) (v >>> 16));
-    write((byte) (v >>> 8));
-    write((byte) v);
+  public void write5(final long pos, final long value) {
+    cursor(pos);
+    write((byte) (value >>> 32));
+    write((byte) (value >>> 24));
+    write((byte) (value >>> 16));
+    write((byte) (value >>> 8));
+    write((byte) value);
   }
 
   /**
    * Writes an integer value to the specified position.
-   * @param p write position
-   * @param v byte array to be appended
+   * @param pos write position
+   * @param value byte array to be appended
    */
-  public void write4(final long p, final int v) {
-    cursor(p);
-    write4(v);
+  public void write4(final long pos, final int value) {
+    cursor(pos);
+    write4(value);
   }
 
   /**
    * Writes an integer value to the current position.
-   * @param v value to be written
+   * @param value value to be written
    */
-  public void write4(final int v) {
-    write(v >>> 24);
-    write(v >>> 16);
-    write(v >>>  8);
-    write(v);
+  public void write4(final int value) {
+    write(value >>> 24);
+    write(value >>> 16);
+    write(value >>>  8);
+    write(value);
   }
 
   /**
    * Write a value to the file.
-   * @param p write position
-   * @param v value to be written
+   * @param pos write position
+   * @param value value to be written
    */
-  public void writeNum(final long p, final int v) {
-    cursor(p);
-    writeNum(v);
+  public void writeNum(final long pos, final int value) {
+    cursor(pos);
+    writeNum(value);
   }
 
   /**
    * Writes integers to the file in compressed form.
    * @param p write position
-   * @param v integer values
+   * @param values integer values
    */
-  public void writeNums(final long p, final int[] v) {
+  public void writeNums(final long p, final int[] values) {
     cursor(p);
-    writeNum(v.length);
-    for(final int n : v) writeNum(n);
+    writeNum(values.length);
+    for(final int n : values) writeNum(n);
   }
 
   /**
-   * Appends integers to the file in compressed form.
-   * @param v integer values
-   * @return the position in the file where the values have been written
-   */
-  public long appendNums(final int[] v) {
-    final long end = len;
-    writeNums(end, v);
-    return end;
-  }
-
-  /**
-   * Appends a value to the file and return it's offset.
-   * @param p write position
-   * @param v byte array to be appended
-   */
-  public void writeToken(final long p, final byte[] v) {
-    cursor(p);
-    writeToken(v, 0, v.length);
-  }
-
-  /**
-   * Write a token to the file.
-   * @param buf buffer containing the token
+   * Writes a byte array to the file.
+   * @param buffer buffer containing the token
    * @param offset offset in the buffer where the token starts
-   * @param length token length
+   * @param len token length
    */
-  private void writeToken(final byte[] buf, final int offset, final int length) {
-    writeNum(length);
-
-    final int last = offset + length;
+  public void writeBytes(final byte[] buffer, final int offset, final int len) {
+    final int last = offset + len;
     int o = offset;
 
     while(o < last) {
-      final Buffer bf = buffer(off == IO.BLOCKSIZE);
+      final Buffer bf = buffer();
       final int l = Math.min(last - o, IO.BLOCKSIZE - off);
-      System.arraycopy(buf, o, bf.data, off, l);
+      System.arraycopy(buffer, o, bf.data, off, l);
       bf.dirty = true;
       off += l;
       o += l;
+      // adjust file size
+      final long nl = bf.pos + off;
+      if(nl > length) length(nl);
     }
-
-    // adjust file size if needed
-    final long nl = bm.current().pos + off;
-    if(nl > len) length(nl);
   }
 
   /**
    * Appends a value to the file and return it's offset.
-   * @param v number to be appended
+   * @param pos write position
+   * @param values byte array to be appended
    */
-  private void writeNum(final int v) {
-    if(v < 0 || v > 0x3FFFFFFF) {
-      write(0xC0); write(v >>> 24); write(v >>> 16); write(v >>> 8); write(v);
-    } else if(v > 0x3FFF) {
-      write(v >>> 24 | 0x80); write(v >>> 16);
-      write(v >>> 8); write(v);
-    } else if(v > 0x3F) {
-      write(v >>> 8 | 0x40); write(v);
-    } else {
-      write(v);
-    }
+  public void writeToken(final long pos, final byte[] values) {
+    cursor(pos);
+    writeToken(values, 0, values.length);
   }
 
   /**
@@ -414,21 +350,21 @@ public final class DataAccess {
 
     // extend available space by subsequent zero-bytes
     cursor(pos + os);
-    for(; pos + os < len && os < size && read() == 0xFF; os++);
+    for(; pos + os < length && os < size && read() == 0xFF; os++);
 
     long o = pos;
-    if(pos + os == len) {
+    if(pos + os == length) {
       // entry is placed last: reset file length (discard last entry)
       length(pos);
     } else {
       int t = size;
       if(os < size) {
         // gap is too small for new entry...
-        // reset cursor to overwrite entry with zero-bytes
+        // reset cursor to overwrite entry
         cursor(pos);
         t = 0;
         // place new entry after last entry
-        o = len;
+        o = length;
       } else {
         // gap is large enough: set cursor to overwrite remaining bytes
         cursor(pos + size);
@@ -439,17 +375,86 @@ public final class DataAccess {
     return o;
   }
 
+  /**
+   * Sets the file length.
+   * @param len file length
+   */
+  private synchronized void length(final long len) {
+    if(len != length) {
+      changed = true;
+      length = len;
+    }
+  }
+
   // PRIVATE METHODS ==========================================================
 
+  /**
+   * Reads the next byte.
+   * @return next byte
+   */
+  private int read() {
+    final Buffer bf = buffer();
+    return bf.data[off++] & 0xFF;
+  }
+
+  /**
+   * Writes the next byte.
+   * @param value byte to be written
+   */
+  private void write(final int value) {
+    final Buffer bf = buffer();
+    bf.dirty = true;
+    bf.data[off++] = (byte) value;
+    final long nl = bf.pos + off;
+    if(nl > length) length(nl);
+  }
+
+  /**
+   * Write a token to the file.
+   * @param buffer buffer containing the token
+   * @param offset offset in the buffer where the token starts
+   * @param len token length
+   */
+  private void writeToken(final byte[] buffer, final int offset, final int len) {
+    writeNum(len);
+    writeBytes(buffer, offset, len);
+  }
+
+  /**
+   * Appends a value to the file and return it's offset.
+   * @param value number to be appended
+   */
+  private void writeNum(final int value) {
+    if(value < 0 || value > 0x3FFFFFFF) {
+      write(0xC0); write(value >>> 24); write(value >>> 16); write(value >>> 8); write(value);
+    } else if(value > 0x3FFF) {
+      write(value >>> 24 | 0x80); write(value >>> 16);
+      write(value >>> 8); write(value);
+    } else if(value > 0x3F) {
+      write(value >>> 8 | 0x40); write(value);
+    } else {
+      write(value);
+    }
+  }
+
   /**
    * Writes the specified block to disk.
-   * @param bf buffer to write
+   * @param buffer buffer to write
    * @throws IOException I/O exception
    */
-  private void writeBlock(final Buffer bf) throws IOException {
-    file.seek(bf.pos);
-    file.write(bf.data);
-    bf.dirty = false;
+  private void writeBlock(final Buffer buffer) throws IOException {
+    final long pos = buffer.pos, len = Math.min(IO.BLOCKSIZE, length - pos);
+    raf.seek(pos);
+    raf.write(buffer.data, 0, (int) len);
+    buffer.dirty = false;
+  }
+
+  /**
+   * Returns a buffer which can be used for writing new bytes.
+   * @return buffer
+   */
+  private Buffer buffer() {
+    return buffer(off == IO.BLOCKSIZE);
   }
 
   /**
