@@ -1,19 +1,24 @@
 package org.basex.io.serial;
 
 import static org.basex.data.DataText.*;
-import static org.basex.query.QueryText.*;
-import static org.basex.query.util.Err.*;
+import static org.basex.query.QueryError.*;
 import static org.basex.util.Token.*;
 
 import java.io.*;
+import java.nio.charset.*;
+import java.util.*;
 
-import org.basex.build.*;
-import org.basex.build.CsvOptions.CsvFormat;
-import org.basex.build.JsonOptions.JsonFormat;
+import org.basex.build.csv.*;
+import org.basex.build.csv.CsvOptions.CsvFormat;
+import org.basex.build.json.*;
+import org.basex.build.json.JsonOptions.JsonFormat;
 import org.basex.data.*;
+import org.basex.io.out.*;
 import org.basex.io.serial.csv.*;
 import org.basex.io.serial.json.*;
+import org.basex.query.*;
 import org.basex.query.iter.*;
+import org.basex.query.util.ft.*;
 import org.basex.query.value.item.*;
 import org.basex.query.value.node.*;
 import org.basex.query.value.type.*;
@@ -24,73 +29,88 @@ import org.basex.util.list.*;
 /**
  * This is an interface for serializing XQuery values.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
-public abstract class Serializer {
-  /** Default serialization parameters. */
-  public static final SerializerOptions OPTIONS = new SerializerOptions();
-
+public abstract class Serializer implements Closeable {
   /** Stack with names of opened elements. */
-  protected final TokenList tags = new TokenList();
+  protected final Stack<QNm> elems = new Stack<>();
   /** Current level. */
   protected int level;
   /** Current element name. */
-  protected byte[] tag;
-  /** Undeclare prefixes. */
-  boolean undecl;
+  protected QNm elem;
   /** Indentation flag. */
   protected boolean indent;
 
   /** Stack with currently available namespaces. */
-  private final Atts nspaces = new Atts(XML, XMLURI).add(EMPTY, EMPTY);
+  private final Atts nspaces = new Atts(XML, QueryText.XML_URI).add(EMPTY, EMPTY);
   /** Stack with namespace size pointers. */
   private final IntList nstack = new IntList();
 
+  /** Static context. */
+  protected StaticContext sc;
+  /** Indicates if more than one item was serialized. */
+  protected boolean more;
   /** Indicates if an element is currently being opened. */
   private boolean opening;
 
   /**
-   * Returns an XML serializer.
+   * Returns an adaptive serializer.
    * @param os output stream reference
    * @return serializer
    * @throws IOException I/O exception
    */
-  public static XMLSerializer get(final OutputStream os) throws IOException {
-    return new XMLSerializer(os, OPTIONS);
+  public static Serializer get(final OutputStream os) throws IOException {
+    return get(os, null);
   }
 
   /**
    * Returns a specific serializer.
    * @param os output stream reference
-   * @param sopts serialization parameters (can be {@code null})
+   * @param sopts serialization parameters (may be {@code null})
    * @return serializer
    * @throws IOException I/O exception
    */
   public static Serializer get(final OutputStream os, final SerializerOptions sopts)
       throws IOException {
 
-    // no parameters given: serialize as XML
-    if(sopts == null) return get(os);
+    // create print output
+    final SerializerOptions so = sopts == null ? SerializerOptions.get(true) : sopts;
+    final String enc = Strings.normEncoding(so.get(SerializerOptions.ENCODING), true);
+    final PrintOutput po;
+    if(enc == Strings.UTF8) {
+      po = PrintOutput.get(os);
+    } else {
+      try {
+        po = new EncoderOutput(os, Charset.forName(enc));
+      } catch(final Exception ex) {
+        throw SERENCODING_X.getIO(enc);
+      }
+    }
+    final int limit = so.get(SerializerOptions.LIMIT);
+    if(limit != -1) po.setLimit(so.get(SerializerOptions.LIMIT));
 
-    // standard types: XHTML, HTML, text
-    switch(sopts.get(SerializerOptions.METHOD)) {
-      case XHTML: return new XHTMLSerializer(os, sopts);
-      case HTML:  return new HTMLSerializer(os, sopts);
-      case TEXT:  return new TextSerializer(os, sopts);
-      case RAW:   return new RawSerializer(os, sopts);
+    // no parameters given: serialize adaptively
+    switch(so.get(SerializerOptions.METHOD)) {
+      case XHTML: return new XHTMLSerializer(po, so);
+      case HTML:  return new HTMLSerializer(po, so);
+      case TEXT:  return new TextSerializer(po, so);
+      case RAW:   return new RawSerializer(po, so);
       case CSV:
-        final CsvOptions copts = sopts.get(SerializerOptions.CSV);
-        final CsvFormat cform = copts.get(CsvOptions.FORMAT);
-        return cform == CsvFormat.MAP ? new CsvMapSerializer(os, sopts) :
-               new CsvDirectSerializer(os, sopts);
+        final CsvOptions copts = so.get(SerializerOptions.CSV);
+        return copts.get(CsvOptions.FORMAT) == CsvFormat.MAP
+               ? new CsvMapSerializer(po, so)
+               : new CsvDirectSerializer(po, so);
       case JSON:
-        final JsonSerialOptions jopts = sopts.get(SerializerOptions.JSON);
-        final JsonFormat jform = jopts.get(JsonOptions.FORMAT);
-        return jform == JsonFormat.JSONML ? new JsonMLSerializer(os, sopts) :
-               jform == JsonFormat.MAP ? new JsonMapSerializer(os, sopts) :
-               new JsonNodeSerializer(os, sopts);
-      default: return new XMLSerializer(os, sopts);
+        final JsonSerialOptions jopts = so.get(SerializerOptions.JSON);
+        final JsonFormat jformat = jopts.get(JsonOptions.FORMAT);
+        return jformat == JsonFormat.JSONML ? new JsonMLSerializer(po, so) :
+               jformat == JsonFormat.BASIC  ? new JsonBasicSerializer(po, so) :
+               new JsonNodeSerializer(po, so);
+      case XML:
+        return new XMLSerializer(po, so);
+      default:
+        return new AdaptiveSerializer(po, so);
     }
   }
 
@@ -102,51 +122,21 @@ public abstract class Serializer {
    * @throws IOException I/O exception
    */
   public void serialize(final Item item) throws IOException {
-    serialize(item, false);
-  }
-
-  /**
-   * Serializes the specified item, which may be a node or an atomic value.
-   * @param item item to be serialized
-   * @param atts also serialize attributes and namespaces
-   * @throws IOException I/O exception
-   */
-  public void serialize(final Item item, final boolean atts) throws IOException {
-    serialize(item, atts, false);
-  }
-
-  /**
-   * Serializes the specified item, which may be a node or an atomic value.
-   * @param item item to be serialized
-   * @param atts also serialize attributes and namespaces
-   * @param iter iterative evaluation
-   * @throws IOException I/O exception
-   */
-  public void serialize(final Item item, final boolean atts, final boolean iter)
-      throws IOException {
-
-    openResult();
     if(item instanceof ANode) {
-      final Type type = item.type;
-      if(!atts) {
-        if(type == NodeType.ATT) throw SERATTR.getIO(item);
-        if(type == NodeType.NSP) throw SERNS.getIO(item);
-      }
-      serialize((ANode) item);
+      node((ANode) item);
     } else if(item instanceof FItem) {
-      throw SERFUNC.getIO(item.type());
+      function((FItem) item);
     } else {
-      finishElement();
-      atomic(item, iter);
+      atomic(item);
     }
-    closeResult();
+    more = true;
   }
 
   /**
    * Closes the serializer.
    * @throws IOException I/O exception
    */
-  @SuppressWarnings("unused")
+  @Override
   public void close() throws IOException { }
 
   /**
@@ -162,37 +152,198 @@ public abstract class Serializer {
    */
   public void reset() { }
 
+  /**
+   * Assigns the static context.
+   * @param sctx static context
+   * @return serializer
+   */
+  public Serializer sc(final StaticContext sctx) {
+    sc = sctx;
+    return this;
+  }
+
   // PROTECTED METHODS ==================================================================
 
+  /**
+   * Serializes the specified node.
+   * @param node node to be serialized
+   * @throws IOException I/O exception
+   */
+  protected void node(final ANode node) throws IOException {
+    if(ignore(node)) return;
+
+    if(node instanceof DBNode) {
+      node((DBNode) node);
+    } else {
+      final Type type = node.type;
+      if(type == NodeType.COM) {
+        prepareComment(node.string());
+      } else if(type == NodeType.TXT) {
+        prepareText(node.string(), null);
+      } else if(type == NodeType.PI) {
+        preparePi(node.name(), node.string());
+      } else if(type == NodeType.ATT) {
+        attribute(node.name(), node.string(), true);
+      } else if(type == NodeType.NSP) {
+        namespace(node.name(), node.string(), true);
+      } else if(type == NodeType.DOC) {
+        openDoc(node.baseURI());
+        for(final ANode n : node.children()) node(n);
+        closeDoc();
+      } else {
+        // serialize elements (code will never be called for attributes)
+        final QNm name = node.qname();
+        openElement(name);
+
+        // serialize declared namespaces
+        final Atts nsp = node.namespaces();
+        for(int p = nsp.size() - 1; p >= 0; p--) namespace(nsp.name(p), nsp.value(p), false);
+        // add new or updated namespace
+        namespace(name.prefix(), name.uri(), false);
+
+        // serialize attributes
+        final boolean i = indent;
+        BasicNodeIter iter = node.attributes();
+        for(ANode nd; (nd = iter.next()) != null;) {
+          final byte[] n = nd.name();
+          final byte[] v = nd.string();
+          attribute(n, v, false);
+          if(eq(n, XML_SPACE) && indent) indent = !eq(v, PRESERVE);
+        }
+
+        // serialize children
+        iter = node.children();
+        for(ANode n; (n = iter.next()) != null;) node(n);
+        closeElement();
+        indent = i;
+      }
+    }
+  }
+
   /**
    * Opens an element.
    * @param name element name
    * @throws IOException I/O exception
    */
-  final void startElement(final byte[] name) throws IOException {
-    finishElement();
-    nstack.push(nspaces.size());
+  protected final void openElement(final QNm name) throws IOException {
+    prepare();
     opening = true;
-    tag = name;
+    elem = name;
     startOpen(name);
+    nstack.push(nspaces.size());
   }
 
   /**
    * Closes an element.
    * @throws IOException I/O exception
    */
-  final void closeElement() throws IOException {
+  protected final void closeElement() throws IOException {
     nspaces.size(nstack.pop());
     if(opening) {
       finishEmpty();
       opening = false;
     } else {
-      tag = tags.pop();
+      elem = elems.peek();
       level--;
       finishClose();
+      elems.pop();
     }
   }
 
+  /**
+   * Opens a document.
+   * @param name name
+   * @throws IOException I/O exception
+   */
+  @SuppressWarnings("unused")
+  protected void openDoc(final byte[] name) throws IOException { }
+
+  /**
+   * Closes a document.
+   * @throws IOException I/O exception
+   */
+  @SuppressWarnings("unused")
+  protected void closeDoc() throws IOException { }
+
+  /**
+   * Serializes a namespace.
+   * @param prefix prefix
+   * @param uri uri
+   * @param standalone standalone flag
+   * @throws IOException I/O exception
+   */
+  protected void namespace(final byte[] prefix, final byte[] uri, final boolean standalone)
+      throws IOException {
+
+    final byte[] u = nsUri(prefix);
+    if(u == null || !eq(u, uri)) {
+      attribute(prefix.length == 0 ? XMLNS : concat(XMLNSC, prefix), uri, standalone);
+      nspaces.add(prefix, uri);
+    }
+  }
+
+  /**
+   * Gets the namespace URI currently bound by the given prefix.
+   * @param prefix namespace prefix
+   * @return URI if found, {@code null} otherwise
+   */
+  protected final byte[] nsUri(final byte[] prefix) {
+    for(int n = nspaces.size() - 1; n >= 0; n--) {
+      if(eq(nspaces.name(n), prefix)) return nspaces.value(n);
+    }
+    return null;
+  }
+
+  /**
+   * Checks if an element should be ignored.
+   * @param node node to be serialized
+   * @return result of check
+   */
+  @SuppressWarnings("unused")
+  protected boolean ignore(final ANode node) {
+    return false;
+  }
+
+  /**
+   * Serializes an attribute.
+   * @param name name
+   * @param value value
+   * @param standalone standalone flag
+   * @throws IOException I/O exception
+   */
+  @SuppressWarnings("unused")
+  protected void attribute(final byte[] name, final byte[] value, final boolean standalone)
+      throws IOException { }
+
+  /**
+   * Starts an element.
+   * @param name element name
+   * @throws IOException I/O exception
+   */
+  @SuppressWarnings("unused")
+  protected void startOpen(final QNm name) throws IOException { }
+
+  /**
+   * Finishes an opening element node.
+   * @throws IOException I/O exception
+   */
+  @SuppressWarnings("unused")
+  protected void finishOpen() throws IOException { }
+
+  /**
+   * Closes an empty element.
+   * @throws IOException I/O exception
+   */
+  @SuppressWarnings("unused")
+  protected void finishEmpty() throws IOException { }
+
+  /**
+   * Closes an element.
+   * @throws IOException I/O exception
+   */
+  @SuppressWarnings("unused")
+  protected void finishClose() throws IOException { }
+
   /**
    * Serializes a text.
    * @param value value
@@ -200,112 +351,15 @@ public abstract class Serializer {
    * @throws IOException I/O exception
    */
   @SuppressWarnings("unused")
-  void finishText(final byte[] value, final FTPos ftp) throws IOException {
-    text(value);
-  }
-  /**
-   * Gets the namespace URI currently bound by the given prefix.
-   * @param pref namespace prefix
-   * @return URI if found, {@code null} otherwise
-   */
-  final byte[] nsUri(final byte[] pref) {
-    for(int n = nspaces.size() - 1; n >= 0; n--) {
-      if(eq(nspaces.name(n), pref)) return nspaces.value(n);
-    }
-    return null;
-  }
-
-
-  /**
-   * Serializes a namespace if it has not been serialized by an ancestor yet.
-   * @param pref prefix
-   * @param uri URI
-   * @throws IOException I/O exception
-   */
-  protected void namespace(final byte[] pref, final byte[] uri) throws IOException {
-    if(!undecl && pref.length != 0 && uri.length == 0) return;
-    final byte[] u = nsUri(pref);
-    if(u == null || !eq(u, uri)) {
-      attribute(pref.length == 0 ? XMLNS : concat(XMLNSC, pref), uri);
-      nspaces.add(pref, uri);
-    }
-  }
-
-  /**
-   * Starts a result.
-   * @throws IOException I/O exception
-   */
-  @SuppressWarnings("unused")
-  void openResult() throws IOException { }
-
-  /**
-   * Closes a result.
-   * @throws IOException I/O exception
-   */
-  @SuppressWarnings("unused")
-  void closeResult() throws IOException { }
-
-  /**
-   * Opens a document.
-   * @param name name
-   * @throws IOException I/O exception
-   */
-  @SuppressWarnings("unused")
-  void openDoc(final byte[] name) throws IOException { }
-
-  /**
-   * Closes a document.
-   * @throws IOException I/O exception
-   */
-  @SuppressWarnings("unused")
-  void closeDoc() throws IOException { }
-
-  /**
-   * Serializes an attribute.
-   * @param name name
-   * @param value value
-   * @throws IOException I/O exception
-   */
-  protected abstract void attribute(final byte[] name, final byte[] value) throws IOException;
-
-  /**
-   * Starts an element.
-   * @param name tag name
-   * @throws IOException I/O exception
-   */
-  protected abstract void startOpen(final byte[] name) throws IOException;
-
-  /**
-   * Finishes an opening element node.
-   * @throws IOException I/O exception
-   */
-  protected abstract void finishOpen() throws IOException;
-
-  /**
-   * Closes an empty element.
-   * @throws IOException I/O exception
-   */
-  protected abstract void finishEmpty() throws IOException;
-
-  /**
-   * Closes an element.
-   * @throws IOException I/O exception
-   */
-  protected abstract void finishClose() throws IOException;
-
-  /**
-   * Serializes a text.
-   * @param value value
-   * @throws IOException I/O exception
-   */
-  protected abstract void finishText(final byte[] value) throws IOException;
+  protected void text(final byte[] value, final FTPos ftp) throws IOException { }
 
   /**
    * Serializes a comment.
    * @param value value
    * @throws IOException I/O exception
    */
-  protected abstract void finishComment(final byte[] value) throws IOException;
+  @SuppressWarnings("unused")
+  protected void comment(final byte[] value) throws IOException { }
 
   /**
    * Serializes a processing instruction.
@@ -313,95 +367,49 @@ public abstract class Serializer {
    * @param value value
    * @throws IOException I/O exception
    */
-  protected abstract void finishPi(final byte[] name, final byte[] value) throws IOException;
+  @SuppressWarnings("unused")
+  protected void pi(final byte[] name, final byte[] value) throws IOException { }
 
   /**
    * Serializes an atomic value.
    * @param item item
-   * @param iter iterative evaluation
    * @throws IOException I/O exception
    */
-  protected abstract void atomic(final Item item, final boolean iter) throws IOException;
-
-  // PRIVATE METHODS ==========================================================
+  @SuppressWarnings("unused")
+  protected void atomic(final Item item) throws IOException { }
 
   /**
-   * Serializes the specified node.
-   * @param node node to be serialized
+   * Serializes a function item.
+   * @param item item
    * @throws IOException I/O exception
    */
-  private void serialize(final ANode node) throws IOException {
-    if(node instanceof DBNode) {
-      serialize((DBNode) node);
-    } else {
-      final Type type = node.type;
-      if(type == NodeType.COM) {
-        comment(node.string());
-      } else if(type == NodeType.TXT) {
-        text(node.string());
-      } else if(type == NodeType.PI) {
-        pi(node.name(), node.string());
-      } else if(type == NodeType.ATT) {
-        attribute(node.name(), node.string());
-      } else if(type == NodeType.NSP) {
-        namespace(node.name(), node.string());
-      } else if(type == NodeType.DOC) {
-        openDoc(node.baseURI());
-        for(final ANode n : node.children()) serialize(n);
-        closeDoc();
-      } else {
-        // serialize elements (code will never be called for attributes)
-        final QNm name = node.qname();
-        startElement(name.string());
+  @SuppressWarnings("unused")
+  protected void function(final FItem item) throws IOException { }
 
-        // serialize declared namespaces
-        final Atts nsp = node.namespaces();
-        for(int p = nsp.size() - 1; p >= 0; p--) {
-          namespace(nsp.name(p), nsp.value(p));
-        }
-        // add new or updated namespace
-        namespace(name.prefix(), name.uri());
-
-        // serialize attributes
-        final boolean i = indent;
-        AxisMoreIter ai = node.attributes();
-        for(ANode nd; (nd = ai.next()) != null;) {
-          final byte[] n = nd.name();
-          final byte[] v = nd.string();
-          attribute(n, v);
-          if(eq(n, XML_SPACE)) indent &= eq(v, DataText.DEFAULT);
-        }
-        // serialize children
-        ai = node.children();
-        for(ANode n; (n = ai.next()) != null;) serialize(n);
-        indent = i;
-        closeElement();
-      }
-    }
-  }
+  // PRIVATE METHODS ==========================================================
 
   /**
    * Serializes a node of the specified data reference.
    * @param node database node
    * @throws IOException I/O exception
    */
-  private void serialize(final DBNode node) throws IOException {
-    final FTPosData ft = node instanceof FTPosNode ? ((FTPosNode) node).ft : null;
-    final Data data = node.data;
-    int p = node.pre;
-    int k = data.kind(p);
-    if(k == Data.ATTR) throw SERATTR.getIO(node);
+  private void node(final DBNode node) throws IOException {
+    final FTPosData ft = node instanceof FTPosNode ? ((FTPosNode) node).ftpos : null;
+    final Data data = node.data();
+    int pre = node.pre();
+    int kind = data.kind(pre);
+    if(kind == Data.ATTR) throw SERATTR_X.getIO(node);
 
     boolean doc = false;
-    final TokenSet nsp = data.nspaces.size() == 0 ? null : new TokenSet();
+    final TokenSet nsp = data.nspaces.isEmpty() ? null : new TokenSet();
     final IntList pars = new IntList();
     final BoolList indt = new BoolList();
 
     // loop through all table entries
-    final int s = p + data.size(p, k);
-    while(p < s && !finished()) {
-      k = data.kind(p);
-      final int r = data.parent(p, k);
+    final int s = pre + data.size(pre, kind);
+    while(pre < s && !finished()) {
+      kind = data.kind(pre);
+      final int r = data.parent(pre, kind);
 
       // close opened elements...
       while(!pars.isEmpty() && pars.peek() >= r) {
@@ -410,39 +418,39 @@ public abstract class Serializer {
         pars.pop();
       }
 
-      if(k == Data.DOC) {
+      if(kind == Data.DOC) {
         if(doc) closeDoc();
-        openDoc(data.text(p++, true));
+        openDoc(data.text(pre++, true));
         doc = true;
-      } else if(k == Data.TEXT) {
-        final FTPos ftd = ft != null ? ft.get(data, p) : null;
-        if(ftd != null) text(data.text(p++, true), ftd);
-        else text(data.text(p++, true));
-      } else if(k == Data.COMM) {
-        comment(data.text(p++, true));
+      } else if(kind == Data.TEXT) {
+        prepareText(data.text(pre, true), ft != null ? ft.get(data, pre) : null);
+        pre++;
+      } else if(kind == Data.COMM) {
+        prepareComment(data.text(pre++, true));
       } else {
-        if(k == Data.PI) {
-          pi(data.name(p, Data.PI), data.atom(p++));
+        if(kind == Data.PI) {
+          preparePi(data.name(pre, Data.PI), data.atom(pre++));
         } else {
           // add element node
-          final byte[] name = data.name(p, k);
-          startElement(name);
+          final byte[] name = data.name(pre, kind);
+          final byte[] uri = data.nspaces.uri(data.uriId(pre, kind));
+          openElement(new QNm(name, uri));
 
           // add namespace definitions
           if(nsp != null) {
             // add namespaces from database
             nsp.clear();
-            int pp = p;
+            int pp = pre;
 
             // check namespace of current element
-            final byte[] u = data.nspaces.uri(data.uri(p, k));
-            namespace(prefix(name), u == null ? EMPTY : u);
+            namespace(prefix(name), uri == null ? EMPTY : uri, false);
 
             do {
-              final Atts ns = data.ns(pp);
-              for(int n = 0; n < ns.size(); ++n) {
+              final Atts ns = data.namespaces(pp);
+              final int nl = ns.size();
+              for(int n = 0; n < nl; n++) {
                 final byte[] pref = ns.name(n);
-                if(nsp.add(pref)) namespace(pref, ns.value(n));
+                if(nsp.add(pref)) namespace(pref, ns.value(n), false);
               }
               // check ancestors only on top level
               if(level != 0) break;
@@ -453,12 +461,12 @@ public abstract class Serializer {
 
           // serialize attributes
           indt.push(indent);
-          final int as = p + data.attSize(p, k);
-          while(++p != as) {
-            final byte[] n = data.name(p, Data.ATTR);
-            final byte[] v = data.text(p, false);
-            attribute(n, v);
-            if(eq(n, XML_SPACE)) indent &= eq(v, DataText.DEFAULT);
+          final int as = pre + data.attSize(pre, kind);
+          while(++pre != as) {
+            final byte[] n = data.name(pre, Data.ATTR);
+            final byte[] v = data.text(pre, false);
+            attribute(n, v, false);
+            if(eq(n, XML_SPACE) && indent) indent = !eq(v, PRESERVE);
           }
           pars.push(r);
         }
@@ -474,35 +482,25 @@ public abstract class Serializer {
     if(doc) closeDoc();
   }
 
-  /**
-   * Serializes a text.
-   * @param v text bytes
-   * @param ftp full-text positions, used for visualization highlighting
-   * @throws IOException I/O exception
-   */
-  private void text(final byte[] v, final FTPos ftp) throws IOException {
-    finishElement();
-    finishText(v, ftp);
-  }
-
   /**
    * Serializes a comment.
    * @param value value
    * @throws IOException I/O exception
    */
-  private void comment(final byte[] value) throws IOException {
-    finishElement();
-    finishComment(value);
+  private void prepareComment(final byte[] value) throws IOException {
+    prepare();
+    comment(value);
   }
 
   /**
    * Serializes a text.
    * @param value text bytes
+   * @param ftp full-text positions, used for visualization highlighting
    * @throws IOException I/O exception
    */
-  private void text(final byte[] value) throws IOException {
-    finishElement();
-    finishText(value);
+  private void prepareText(final byte[] value, final FTPos ftp) throws IOException {
+    prepare();
+    text(value, ftp);
   }
 
   /**
@@ -511,20 +509,20 @@ public abstract class Serializer {
    * @param value value
    * @throws IOException I/O exception
    */
-  private void pi(final byte[] name, final byte[] value) throws IOException {
-    finishElement();
-    finishPi(name, value);
+  private void preparePi(final byte[] name, final byte[] value) throws IOException {
+    prepare();
+    pi(name, value);
   }
 
   /**
    * Finishes an opening element node if necessary.
    * @throws IOException I/O exception
    */
-  private void finishElement() throws IOException {
+  private void prepare() throws IOException {
     if(!opening) return;
     opening = false;
     finishOpen();
-    tags.push(tag);
+    elems.push(elem);
     level++;
   }
 }
