@@ -1,18 +1,19 @@
 package org.basex.query;
 
 import static org.basex.core.Text.*;
-import static org.basex.query.util.Err.*;
+import static org.basex.query.QueryError.*;
 import static org.basex.util.Token.*;
 
+import java.io.*;
 import java.util.*;
 import java.util.Map.Entry;
-import java.util.regex.*;
 
-import org.basex.build.*;
-import org.basex.build.JsonOptions.JsonFormat;
-import org.basex.build.JsonOptions.JsonSpec;
+import org.basex.build.json.*;
+import org.basex.build.json.JsonOptions.*;
 import org.basex.core.*;
 import org.basex.core.MainOptions.MainParser;
+import org.basex.core.locks.*;
+import org.basex.core.users.*;
 import org.basex.core.Context;
 import org.basex.data.*;
 import org.basex.io.*;
@@ -21,13 +22,16 @@ import org.basex.io.serial.*;
 import org.basex.query.expr.*;
 import org.basex.query.expr.Expr.Flag;
 import org.basex.query.func.*;
+import org.basex.query.func.fn.*;
 import org.basex.query.iter.*;
 import org.basex.query.up.*;
-import org.basex.query.util.*;
-import org.basex.query.util.pkg.*;
+import org.basex.query.util.collation.*;
+import org.basex.query.util.ft.*;
+import org.basex.query.util.list.*;
 import org.basex.query.value.*;
 import org.basex.query.value.item.*;
 import org.basex.query.value.node.*;
+import org.basex.query.value.seq.*;
 import org.basex.query.value.type.*;
 import org.basex.query.var.*;
 import org.basex.util.*;
@@ -40,13 +44,10 @@ import org.basex.util.options.*;
  * This class organizes both static and dynamic properties that are specific to a
  * single query.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
-public final class QueryContext extends Proc {
-  /** URL pattern (matching Clark and EQName notation). */
-  private static final Pattern BIND = Pattern.compile("^((\"|')(.*?)\\2:|Q?(\\{(.*?)\\}))(.+)$");
-
+public final class QueryContext extends Proc implements Closeable {
   /** The evaluation stack. */
   public final QueryStack stack = new QueryStack();
   /** Static variables. */
@@ -54,13 +55,17 @@ public final class QueryContext extends Proc {
   /** Functions. */
   public final StaticFuncs funcs = new StaticFuncs();
   /** Externally bound variables. */
-  private final HashMap<QNm, Expr> bindings = new HashMap<QNm, Expr>();
+  private final HashMap<QNm, Value> bindings = new HashMap<>();
 
-  /** Query resources. */
-  public final QueryResources resource = new QueryResources(this);
+  /** Parent query context. */
+  private final QueryContext qcParent;
+  /** Query info. */
+  public final QueryInfo info;
   /** Database context. */
   public final Context context;
 
+  /** Query resources. */
+  public QueryResources resources;
   /** HTTP context. */
   public Object http;
 
@@ -69,9 +74,9 @@ public final class QueryContext extends Proc {
   /** Cached thesaurus files. */
   public HashMap<String, IO> thes;
   /** Global database options (will be reassigned after query execution). */
-  public final HashMap<Option<?>, Object> staticOpts = new HashMap<Option<?>, Object>();
+  final HashMap<Option<?>, Object> staticOpts = new HashMap<>();
   /** Temporary query options (key/value pairs), supplied by option declarations. */
-  public final StringList tempOpts = new StringList();
+  final StringList tempOpts = new StringList();
 
   /** Current context value. */
   public Value value;
@@ -79,42 +84,36 @@ public final class QueryContext extends Proc {
   public long pos = 1;
   /** Current context size. */
   public long size = 1;
-  /** Globally available nodes (may be {@code null}). */
-  Nodes nodes;
 
+  /** Full-text position data (needed for highlighting full-text results). */
+  public FTPosData ftPosData = Prop.gui ? new FTPosData() : null;
   /** Available collations. */
   public TokenObjMap<Collation> collations;
   /** Current full-text token. */
   public FTLexer ftToken;
   /** Current full-text options. */
   private FTOpt ftOpt;
-  /** Full-text position data (needed for highlighting full-text results). */
-  public FTPosData ftPosData;
   /** Full-text token positions (needed for highlighting full-text results). */
   public int ftPos;
+  /** Scoring flag. */
+  public boolean scoring;
 
   /** Current Date. */
   public Item date;
   /** Current DateTime. */
-  public Item dtm;
+  public Item datm;
   /** Current Time. */
   public Item time;
   /** Current timezone. */
   public Item zone;
+  /** Current nanoseconds. */
+  public long nano;
 
-  /** Strings to lock defined by lock:read option. */
+  /** Strings to lock defined by read-lock option. */
   public final StringList readLocks = new StringList(0);
-  /** Strings to lock defined by lock:write option. */
+  /** Strings to lock defined by write-lock option. */
   public final StringList writeLocks = new StringList(0);
 
-  /** Pending updates. */
-  public Updates updates;
-  /** Pending output. */
-  public final ValueBuilder output = new ValueBuilder();
-
-  /** Compilation flag: current node has leaves. */
-  public boolean leaf;
-
   /** Number of successive tail calls. */
   public int tailCalls;
   /** Maximum number of successive tail calls (will be set before compilation). */
@@ -124,110 +123,119 @@ public final class QueryContext extends Proc {
   private XQFunction tailFunc;
   /** Arguments for the next tail call. */
   private Value[] args;
-
   /** Counter for variable IDs. */
   public int varIDs;
 
-  /** Pre-declared modules, containing module uri and their file paths. */
+  /** Pre-declared modules, containing module uri and their file paths (required for test APIs). */
   final TokenMap modDeclared = new TokenMap();
   /** Parsed modules, containing the file path and module uri. */
   final TokenMap modParsed = new TokenMap();
   /** Stack of module files that are currently parsed. */
   final TokenList modStack = new TokenList();
 
-  /** Serializer options. */
-  SerializerOptions serialOpts;
   /** Initial context value. */
-  public MainModule ctxItem;
-  /** Module loader. */
-  private ModuleLoader modules;
-  /** Opened connections to relational databases. */
-  private JDBCConnections jdbc;
-  /** Opened connections to relational databases. */
-  private ClientSessions sessions;
-  /** Root expression of the query. */
-  MainModule root;
+  MainModule ctxItem;
 
-  /** Parent query context. */
-  private QueryContext parentCtx;
-  /** Query info. */
-  public final QueryInfo info;
+  /** Root expression of the query. */
+  public MainModule root;
+
+  /** Serialization parameters. */
+  private SerializerOptions serParams;
+  /** Indicates if the default serialization parameters are used. */
+  public boolean defaultOutput;
+
+  /** Indicates if the query has been compiled. */
+  private boolean compiled;
   /** Indicates if the query context has been closed. */
   private boolean closed;
 
   /**
    * Constructor.
-   * @param parent parent context
+   * @param qcParent parent context
    */
-  public QueryContext(final QueryContext parent) {
-    this(parent.context);
-    parentCtx = parent;
-    listen = parent.listen;
+  public QueryContext(final QueryContext qcParent) {
+    this(qcParent.context, qcParent);
+    listen = qcParent.listen;
+    resources = qcParent.resources;
   }
 
   /**
    * Constructor.
-   * @param ctx database context
+   * @param context database context
    */
-  public QueryContext(final Context ctx) {
-    context = ctx;
+  public QueryContext(final Context context) {
+    this(context, null);
+    resources = new QueryResources(this);
+  }
+
+  /**
+   * Constructor.
+   * @param context database context
+   * @param qcParent parent context (optional)
+   */
+  private QueryContext(final Context context, final QueryContext qcParent) {
+    this.context = context;
+    this.qcParent = qcParent;
     info = new QueryInfo(this);
   }
 
   /**
    * Parses the specified query.
-   * @param qu input query
+   * @param query query string
    * @param path file path (may be {@code null})
    * @param sc static context
    * @return main module
    * @throws QueryException query exception
    */
-  public StaticScope parse(final String qu, final String path, final StaticContext sc)
+  public StaticScope parse(final String query, final String path, final StaticContext sc)
       throws QueryException {
-    return parse(qu, QueryProcessor.isLibrary(qu), path, sc);
+    return parse(query, QueryProcessor.isLibrary(query), path, sc);
   }
 
   /**
    * Parses the specified query.
-   * @param qu input query
+   * @param query query string
    * @param library library/main module
    * @param path file path (may be {@code null})
    * @param sc static context
    * @return main module
    * @throws QueryException query exception
    */
-  public StaticScope parse(final String qu, final boolean library, final String path,
+  public StaticScope parse(final String query, final boolean library, final String path,
       final StaticContext sc) throws QueryException {
-    return library ? parseLibrary(qu, path, sc) : parseMain(qu, path, sc);
+    return library ? parseLibrary(query, path, sc) : parseMain(query, path, sc);
   }
 
   /**
    * Parses the specified query.
-   * @param qu input query
+   * @param query query string
    * @param path file path (may be {@code null})
    * @param sc static context
    * @return main module
    * @throws QueryException query exception
    */
-  public MainModule parseMain(final String qu, final String path, final StaticContext sc)
+  public MainModule parseMain(final String query, final String path, final StaticContext sc)
       throws QueryException {
-    info.query = qu;
-    root = new QueryParser(qu, path, this, sc).parseMain();
+
+    info.query = query;
+    root = new QueryParser(query, path, this, sc).parseMain();
+    updating = updating && root.expr.has(Flag.UPD);
     return root;
   }
 
   /**
    * Parses the specified module.
-   * @param qu input query
+   * @param query query string
    * @param path file path (may be {@code null})
    * @param sc static context
    * @return name of module
    * @throws QueryException query exception
    */
-  public LibraryModule parseLibrary(final String qu, final String path, final StaticContext sc)
+  public LibraryModule parseLibrary(final String query, final String path, final StaticContext sc)
       throws QueryException {
-    info.query = qu;
-    return new QueryParser(qu, path, this, sc).parseLibrary(true);
+
+    info.query = query;
+    return new QueryParser(query, path, this, sc).parseLibrary(true);
   }
 
   /**
@@ -239,20 +247,41 @@ public final class QueryContext extends Proc {
     updating = rt.expr.has(Flag.UPD);
   }
 
+  /**
+   * Checks function calls and variable references.
+   * @param main main module
+   * @param sc static context
+   * @throws QueryException query exception
+   */
+  void check(final MainModule main, final StaticContext sc) throws QueryException {
+    // check function calls and variable references
+    funcs.check(this);
+    vars.check();
+
+    // check placement of updating expressions if any have been found
+    if(!sc.mixUpdates && updating) {
+      funcs.checkUp();
+      vars.checkUp();
+      if(main != null) main.expr.checkUp();
+    }
+  }
+
   /**
    * Compiles and optimizes the expression.
    * @throws QueryException query exception
    */
   public void compile() throws QueryException {
-    if(nodes == null) nodes = context.current();
+    if(compiled) return;
+    compiled = true;
 
     // set database options
-    final StringList o = tempOpts;
-    for(int s = 0; s < o.size(); s += 2) {
+    final StringList opts = tempOpts;
+    final int os = opts.size();
+    for(int o = 0; o < os; o += 2) {
       try {
-        context.options.assign(o.get(s).toUpperCase(Locale.ENGLISH), o.get(s + 1));
+        context.options.assign(opts.get(o).toUpperCase(Locale.ENGLISH), opts.get(o + 1));
       } catch(final BaseXException ex) {
-        throw BASX_VALUE.get(null, o.get(s), o.get(s + 1));
+        throw BASX_VALUE_X_X.get(null, opts.get(o), opts.get(o + 1));
       }
     }
     // set tail call option after assignment database option
@@ -264,25 +293,26 @@ public final class QueryContext extends Proc {
     if(ctxItem != null) {
       // evaluate initial expression
       try {
-
         ctxItem.compile(this);
-        value = ctxItem.value(this);
+        value = ctxItem.cache(this).value();
       } catch(final QueryException ex) {
-        if(ex.err() != NOCTX) throw ex;
-        // only {@link ParseExpr} instances may cause this error
-        throw CIRCCTX.get(ctxItem.info);
+        // only {@link ParseExpr} instances may lead to a missing context
+        throw ex.error() == NOCTX_X ? CIRCCTX.get(ctxItem.info) : ex;
       }
-    } else if(nodes != null) {
-      // add full-text container reference
-      if(nodes.ftpos != null) ftPosData = new FTPosData();
+    } else {
       // cache the initial context nodes
-      resource.compile(nodes);
+      final DBNodes nodes = context.current();
+      if(nodes != null) {
+        if(!context.perm(Perm.READ, nodes.data().meta.name))
+          throw BASX_PERM_X.get(null, Perm.READ);
+        value = resources.compile(nodes);
+      }
     }
 
-    // if specified, convert context item to specified type
+    // if specified, convert context value to specified type
     // [LW] should not be necessary
-    if(value != null && root.sc.initType != null) {
-      value = root.sc.initType.promote(this, root.sc, null, value, true);
+    if(value != null && root.sc.contextType != null) {
+      value = root.sc.contextType.promote(this, root.sc, null, value, true);
     }
 
     // dynamic compilation
@@ -312,9 +342,39 @@ public final class QueryContext extends Proc {
    * @throws QueryException query exception
    */
   public Iter iter() throws QueryException {
+    compile();
+
     try {
-      // evaluate lazily if query will perform no updates
-      return updating ? value().iter() : root.iter(this);
+      // no updates: iterate through results
+      if(!updating) return root.iter(this);
+
+      // cache results
+      ItemList cache = root.cache(this);
+
+      final Updates updates = resources.updates;
+      if(updates != null) {
+        // if parent context exists, updates will be performed by main context
+        if(qcParent == null) {
+          final ItemList output = resources.output;
+
+          // copy nodes that will be affected by an update operation
+          final HashSet<Data> datas = updates.prepare(this);
+          final StringList dbs = updates.databases();
+          copy(cache, datas, dbs);
+          copy(output, datas, dbs);
+
+          if(context.data() != null) context.invalidate();
+          updates.apply(this);
+
+          // append cached outputs
+          if(output.size() != 0) {
+            if(cache.size() == 0) cache = output;
+            else cache.add(output.value());
+          }
+        }
+      }
+      return cache.iter();
+
     } catch(final StackOverflowError ex) {
       Util.debug(ex);
       throw BASX_STACKOVERFLOW.get(null);
@@ -322,59 +382,47 @@ public final class QueryContext extends Proc {
   }
 
   /**
-   * Returns the result value.
-   * @return result value
-   * @throws QueryException query exception
+   * Creates copies of nodes that will be affected by an update operation.
+   * @param cache node cache
+   * @param datas data references
+   * @param dbs database names
    */
-  public Value value() throws QueryException {
-    try {
-      final Value v = root.value(this);
-      final Value u = update();
-      return u != null ? u : v;
-    } catch(final StackOverflowError ex) {
-      Util.debug(ex);
-      throw BASX_STACKOVERFLOW.get(null);
+  private void copy(final ItemList cache, final HashSet<Data> datas, final StringList dbs) {
+    final long cs = cache.size();
+    for(int c = 0; c < cs; c++) {
+      final Item it = cache.get(c);
+      if(!(it instanceof DBNode)) continue;
+      final Data data = it.data();
+      if(datas.contains(data) || !data.inMemory() && dbs.contains(data.meta.name)) {
+        cache.set(c, ((DBNode) it).dbCopy(context.options));
+      }
     }
   }
 
-  /**
-   * Performs updates.
-   * @return resulting value
-   * @throws QueryException query exception
-   */
-  private Value update() throws QueryException {
-    if(updating) {
-      updates.apply();
-      if(updates.size() != 0 && context.data() != null) context.update();
-      if(output.size() != 0) return output.value();
-    }
-    return null;
-  }
-
-  /**
-   * Evaluates the specified expression and returns an iterator.
-   * @param e expression to be evaluated
-   * @return iterator
-   * @throws QueryException query exception
-   */
-  public Iter iter(final Expr e) throws QueryException {
-    checkStop();
-    return e.iter(this);
-  }
-
   /**
    * Evaluates the specified expression and returns an iterator.
    * @param expr expression to be evaluated
    * @return iterator
    * @throws QueryException query exception
    */
+  public Iter iter(final Expr expr) throws QueryException {
+    checkStop();
+    return expr.iter(this);
+  }
+
+  /**
+   * Evaluates the specified expression and returns a value.
+   * @param expr expression to be evaluated
+   * @return value
+   * @throws QueryException query exception
+   */
   public Value value(final Expr expr) throws QueryException {
     checkStop();
     return expr.value(this);
   }
 
   /**
-   * Returns the current data reference of the context value, or {@code null}.
+   * Returns the current data reference of the context value or {@code null}.
    * @return data reference
    */
   public Data data() {
@@ -385,12 +433,15 @@ public final class QueryContext extends Proc {
   public void databases(final LockResult lr) {
     lr.read.add(readLocks);
     lr.write.add(writeLocks);
+    // use global locking if referenced databases cannot be statically determined
     if(root == null || !root.databases(lr, this) ||
        ctxItem != null && !ctxItem.databases(lr, this)) {
-
       if(updating) lr.writeAll = true;
       else lr.readAll = true;
     }
+    // replace collection lock with context lock
+    if(lr.read.delete(Docs.COLL)) lr.read.add(DBLocking.CONTEXT);
+    if(lr.write.delete(Docs.COLL)) lr.write.add(DBLocking.CONTEXT);
   }
 
   /**
@@ -402,35 +453,58 @@ public final class QueryContext extends Proc {
   }
 
   /**
-   * Binds a value to the context item, using the same rules as for
-   * {@link #bind binding variables}.
+   * Binds the context value, using the same rules as for
+   * {@link #bind(String, Object, String, StaticContext) binding variables}.
    * @param val value to be bound
-   * @param type data type (may be {@code null})
+   * @param type type (may be {@code null})
    * @param sc static context
    * @throws QueryException query exception
    */
   public void context(final Object val, final String type, final StaticContext sc)
       throws QueryException {
-    ctxItem = new MainModule(cast(val, type), new VarScope(sc), null, sc);
+    context(cast(val, type), sc);
+  }
+
+  /**
+   * Binds the context value.
+   * @param val value to be bound
+   * @param sc static context
+   */
+  public void context(final Value val, final StaticContext sc) {
+    ctxItem = new MainModule(val, new VarScope(sc), null, sc);
   }
 
   /**
    * Binds a value to a global variable. The specified type is interpreted as follows:
    * <ul>
-   * <li>If {@code "json"} is specified, the value is converted according to the rules
-   *     specified in {@link JsonMapConverter}.</li>
-   * <li>If {@code "xml"} is specified, the value is converted to a document node.</li>
-   * <li>Otherwise, the type is interpreted as atomic XDM data type.</li>
+   *   <li> If {@code "json"} is specified, the value is converted according to the rules
+   *        specified in {@link JsonMapConverter}.</li>
+   *   <li> Otherwise, the type is cast to the specified XDM type.</li>
    * </ul>
-   * If the value is an XQuery value {@link Value}, it is directly assigned.
+   * If the value is an XQuery {@link Value}, it is directly assigned.
    * Otherwise, it is cast to the XQuery data model, using a Java/XQuery mapping.
    * @param name name of variable
    * @param val value to be bound
-   * @param type data type (may be {@code null})
+   * @param type type (may be {@code null})
+   * @param sc static context
    * @throws QueryException query exception
    */
-  public void bind(final String name, final Object val, final String type) throws QueryException {
-    bind(name, cast(val, type));
+  public void bind(final String name, final Object val, final String type, final StaticContext sc)
+      throws QueryException {
+    bind(name, cast(val, type), sc);
+  }
+
+  /**
+   * Binds a value to a global variable.
+   * @param name name of variable
+   * @param val value to be bound
+   * @param sc static context
+   * @throws QueryException query exception
+   */
+  public void bind(final String name, final Value val, final StaticContext sc)
+      throws QueryException {
+    final byte[] n = token(name);
+    bindings.put(QNm.resolve(indexOf(n, '$') == 0 ? substring(n, 1) : n, null, sc, null), val);
   }
 
   /**
@@ -447,7 +521,7 @@ public final class QueryContext extends Proc {
    * @param string evaluation info
    */
   public void evalInfo(final String string) {
-    (parentCtx != null ? parentCtx.info : info).evalInfo(string);
+    (qcParent != null ? qcParent.info : info).evalInfo(string);
   }
 
   /**
@@ -459,38 +533,15 @@ public final class QueryContext extends Proc {
   }
 
   /**
-   * Returns the module loader.
-   * @return module loader
-   */
-  public ModuleLoader modules() {
-    if(modules == null) modules = new ModuleLoader(context);
-    return modules;
-  }
-
-  /**
-   * Returns JDBC connections.
-   * @return jdbc connections
-   */
-  public JDBCConnections jdbc() {
-    if(jdbc == null) jdbc = new JDBCConnections();
-    return jdbc;
-  }
-
-  /**
-   * Returns client sessions.
-   * @return client session
-   */
-  public ClientSessions sessions() {
-    if(sessions == null) sessions = new ClientSessions();
-    return sessions;
-  }
-
-  /**
-   * Returns the query-specific or global serialization parameters.
+   * Returns query-specific or default serialization parameters.
    * @return serialization parameters
    */
   public SerializerOptions serParams() {
-    return serialOpts != null ? serialOpts : context.options.get(MainOptions.SERIALIZER);
+    if(serParams == null) {
+      serParams = new SerializerOptions(context.options.get(MainOptions.SERIALIZER));
+      defaultOutput = root != null;
+    }
+    return serParams;
   }
 
   /**
@@ -503,7 +554,7 @@ public final class QueryContext extends Proc {
   }
 
   /**
-   * Sets full-text options.
+   * Assigns full-text options.
    * @param opt full-text options
    */
   public void ftOpt(final FTOpt opt) {
@@ -511,34 +562,44 @@ public final class QueryContext extends Proc {
   }
 
   /**
-   * Sets the updating flag.
-   * @param up updating flag
+   * Creates and returns an XML query plan (expression tree) for this query.
+   * @return query plan
    */
-  public void updating(final boolean up) {
-    if(updates == null) updates = new Updates();
-    updating = up;
+  public FElem plan() {
+    // only show root node if functions or variables exist
+    final FElem e = new FElem(QueryText.PLAN);
+    e.add(QueryText.COMPILED, token(compiled));
+    if(root != null) {
+      for(final StaticScope scp : QueryCompiler.usedDecls(root)) scp.plan(e);
+      root.plan(e);
+    } else {
+      funcs.plan(e);
+      vars.plan(e);
+    }
+    return e;
   }
 
   /**
-   * Closes the query context.
+   * Indicates that the query contains any updating expressions.
    */
+  public void updating() {
+    updating = true;
+  }
+
+  @Override
   public void close() {
     // close only once
     if(closed) return;
-    closed = true;
+
+    if(qcParent == null) {
+      closed = true;
+      resources.close();
+    }
 
     // reassign original database options
-    for(final Entry<Option<?>, Object> e : staticOpts.entrySet())
+    for(final Entry<Option<?>, Object> e : staticOpts.entrySet()) {
       context.options.put(e.getKey(), e.getValue());
-
-    // close database connections
-    resource.close();
-    // close JDBC connections
-    if(jdbc != null) jdbc.close();
-    // close client sessions
-    if(sessions != null) sessions.close();
-    // close dynamically loaded JAR files
-    if(modules != null) modules.close();
+    }
   }
 
   @Override
@@ -559,138 +620,146 @@ public final class QueryContext extends Proc {
   // CLASS METHODS ======================================================================
 
   /**
-   * Evaluates the expression with the specified context set.
+   * This function is called by the GUI; use {@link #iter()} instead.
+   * Caches and returns the result of the specified query. If all nodes are of the same database
+   * instance, the returned value will be of type {@link DBNodes}.
+   * @param max maximum number of results to cache (negative: return all values)
    * @return resulting value
    * @throws QueryException query exception
    */
-  Result execute() throws QueryException {
-    // limit number of hits to be returned and displayed
-    int max = context.options.get(MainOptions.MAXHITS);
-    if(max < 0) max = Integer.MAX_VALUE;
+  Value cache(final int max) throws QueryException {
+    final int mx = max >= 0 ? max : Integer.MAX_VALUE;
 
     // evaluates the query
     final Iter ir = iter();
-    final ValueBuilder vb = new ValueBuilder();
+    final ItemList cache;
     Item it;
 
     // check if all results belong to the database of the input context
-    if(serialOpts == null && nodes != null) {
-      final IntList pre = new IntList();
-
-      while((it = ir.next()) != null) {
+    final Data data = resources.globalData();
+    if(defaultOutput && data != null) {
+      final IntList pres = new IntList();
+      while((it = ir.next()) != null && it.data() == data && pres.size() < mx) {
         checkStop();
-        if(it.data() != nodes.data) break;
-        if(pre.size() < max) pre.add(((DBNode) it).pre);
+        pres.add(((DBNode) it).pre());
       }
 
-      final int ps = pre.size();
-      if(it == null || ps == max) {
-        // all nodes have been processed: return GUI-friendly nodeset
-        return ps == 0 ? vb : new Nodes(pre.toArray(), nodes.data, ftPosData);
-      }
+      // all results processed: return compact node sequence
+      final int ps = pres.size();
+      if(it == null || ps == mx) return new DBNodes(data, pres.finish()).ftpos(ftPosData);
 
       // otherwise, add nodes to standard iterator
-      for(int p = 0; p < ps; ++p) vb.add(new DBNode(nodes.data, pre.get(p)));
-      vb.add(it);
+      cache = new ItemList();
+      for(int p = 0; p < ps; p++) cache.add(new DBNode(data, pres.get(p)));
+      cache.add(it);
+    } else {
+      cache = new ItemList();
     }
 
     // use standard iterator
-    while((it = ir.next()) != null) {
+    while((it = ir.next()) != null && cache.size() < mx) {
       checkStop();
-      if(vb.size() < max) vb.add(it.materialize(null));
+      cache.add(it.materialize(null));
     }
-    return vb;
-  }
-
-  /**
-   * Recursively builds a query plan.
-   * @param doc root node
-   */
-  void plan(final FDoc doc) {
-    // only show root node if functions or variables exist
-    final FElem e = new FElem(QueryText.PLAN);
-    if(root != null) {
-      for(final StaticScope scp : QueryCompiler.usedDecls(root)) scp.plan(e);
-    } else {
-      funcs.plan(e);
-      vars.plan(e);
-    }
-    root.plan(e);
-    doc.add(e);
+    return cache.value();
   }
 
   // PRIVATE METHODS ====================================================================
 
-  /**
-   * Binds an expression to a global variable.
-   * @param name name of variable
-   * @param e value to be bound
-   */
-  private void bind(final String name, final Expr e) {
-    // remove optional $ prefix
-    String nm = name.indexOf('$') == 0 ? name.substring(1) : name;
-    byte[] uri = EMPTY;
-
-    // check for namespace declaration
-    final Matcher m = BIND.matcher(nm);
-    if(m.find()) {
-      String u = m.group(3);
-      if(u == null) u = m.group(5);
-      uri = token(u);
-      nm = m.group(6);
-    }
-    final byte[] ln = token(nm);
-
-    // [LW] better throw an error
-    if(nm.isEmpty() || !XMLToken.isNCName(ln)) return;
-
-    // bind variable
-    bindings.put(new QNm(ln, uri), e);
-  }
-
   /**
    * Casts a value to the specified type.
-   * See {@link #bind(String, Object, String)} for more infos.
+   * See {@link #bind(String, Object, String, StaticContext)} for more infos.
    * @param val value to be cast
-   * @param type data type (may be {@code null})
+   * @param type type (may be {@code null})
    * @return cast value
    * @throws QueryException query exception
    */
-  private Expr cast(final Object val, final String type) throws QueryException {
-    final StaticContext sc = root != null ? root.sc : new StaticContext(true);
+  private Value cast(final Object val, final String type) throws QueryException {
+    final StaticContext sc = root != null ? root.sc : new StaticContext(this);
 
-    // return original value
-    if(type == null || type.isEmpty())
-      return val instanceof Expr ? (Expr) val : JavaMapping.toValue(val, this, sc);
+    // String input
+    Object vl = val;
+    if(vl instanceof String) {
+      final String string = (String) vl;
+      final StringList strings = new StringList(1);
+      // strings containing multiple items (value \1 ...)
+      if(string.indexOf('\1') == -1) {
+        strings.add(string);
+      } else {
+        strings.add(string.split("\1"));
+        vl = strings.toArray();
+      }
+
+      // sub types overriding the global value (value \2 type)
+      if(string.indexOf('\2') != -1) {
+        final ValueBuilder vb = new ValueBuilder();
+        for(final String str : strings) {
+          final int i = str.indexOf('\2');
+          final String s = i == -1 ? str : str.substring(0, i);
+          final String t = i == -1 ? type : str.substring(i + 1);
+          vb.add(cast(s, t));
+        }
+        return vb.value();
+      }
+    }
+
+    // no type specified: return original value or convert Java object
+    if(type == null || type.isEmpty()) {
+      return vl instanceof Value ? (Value) vl : JavaMapping.toValue(vl, this, sc);
+    }
 
     // convert to json
-    try {
-      if(type.equalsIgnoreCase(MainParser.JSON.toString())) {
+    if(type.equalsIgnoreCase(MainParser.JSON.name())) {
+      try {
         final JsonParserOptions jp = new JsonParserOptions();
-        jp.set(JsonOptions.SPEC, JsonSpec.ECMA_262);
         jp.set(JsonOptions.FORMAT, JsonFormat.MAP);
         final JsonConverter conv = JsonConverter.get(jp);
-        conv.convert(token(val.toString()), null);
-        return conv.finish();
+        return conv.convert(token(vl.toString()), null);
+      } catch(final QueryIOException ex) {
+        throw ex.getCause();
       }
-    } catch(final QueryIOException ex) {
-      throw ex.getCause();
     }
 
+    // test for empty sequence
+    if(type.equals(QueryText.EMPTY_SEQUENCE + "()")) return Empty.SEQ;
+
     // convert to the specified type
     // [LW] type should be parsed properly
     final QNm nm = new QNm(token(type.replaceAll("\\(.*?\\)$", "")), sc);
-    if(!nm.hasURI() && nm.hasPrefix()) throw NOURI.get(null, nm.string());
+    if(!nm.hasURI() && nm.hasPrefix()) throw NOURI_X.get(null, nm.string());
 
-    Type t;
+    Type tp;
     if(type.endsWith(")")) {
-      t = NodeType.find(nm);
+      if(nm.eq(AtomType.ITEM.name)) tp = AtomType.ITEM;
+      else tp = NodeType.find(nm);
+      if(tp == null) tp = FuncType.find(nm);
     } else {
-      t = ListType.find(nm);
-      if(t == null) t = AtomType.find(nm, false);
+      tp = ListType.find(nm);
+      if(tp == null) tp = AtomType.find(nm, false);
     }
-    if(t == null) throw NOTYPE.get(null, type);
-    return t.cast(val, this, sc, null);
+    if(tp == null) throw WHICHTYPE_X.get(null, type);
+
+    // cast XDM values
+    if(vl instanceof Value) {
+      // cast single item
+      if(vl instanceof Item) return tp.cast((Item) vl, this, sc, null);
+      // cast sequence
+      final Value v = (Value) vl;
+      final ValueBuilder seq = new ValueBuilder();
+      for(final Item i : v) seq.add(tp.cast(i, this, sc, null));
+      return seq.value();
+    }
+
+    if(vl instanceof String[]) {
+      // cast string array
+      final String[] strings = (String[]) vl;
+      final ValueBuilder seq = new ValueBuilder();
+      for(final String s : strings) seq.add(tp.cast(s, this, sc, null));
+      return seq.value();
+    }
+
+    // cast any other object to XDM
+    return tp.cast(vl, this, sc, null);
   }
 
   /**
@@ -750,15 +819,16 @@ public final class QueryContext extends Proc {
    */
   public QueryContext initDateTime() throws QueryException {
     if(time == null) {
-      final Date d = Calendar.getInstance().getTime();
-      final String zon = DateTime.format(d, DateTime.ZONE);
-      final String ymd = DateTime.format(d, DateTime.DATE);
-      final String hms = DateTime.format(d, DateTime.TIME);
-      final String zn = zon.substring(0, 3) + ':' + zon.substring(3);
-      time = new Tim(token(hms + zn), null);
-      date = new Dat(token(ymd + zn), null);
-      dtm = new Dtm(token(ymd + 'T' + hms + zn), null);
-      zone = new DTDur(toInt(zon.substring(0, 3)), toInt(zon.substring(3)));
+      final Date dt = Calendar.getInstance().getTime();
+      final String ymd = DateTime.format(dt, DateTime.DATE);
+      final String hms = DateTime.format(dt, DateTime.TIME);
+      final String zon = DateTime.format(dt, DateTime.ZONE);
+      final String znm = zon.substring(0, 3), zns = zon.substring(3);
+      time = new Tim(token(hms + znm + ':' + zns), null);
+      date = new Dat(token(ymd + znm + ':' + zns), null);
+      datm = new Dtm(token(ymd + 'T' + hms + znm + ':' + zns), null);
+      zone = new DTDur(Strings.toInt(znm), Strings.toInt(zns));
+      nano = System.nanoTime();
     }
     return this;
   }
