@@ -8,25 +8,25 @@ import org.basex.util.*;
  * This class indicates exceptions during the I/O operations of a query.
  * The exception contains a {@link QueryException}, which can later be unwrapped.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class QueryIOException extends IOException {
   /** Wrapped query exception. */
-  private final QueryException exception;
+  private final QueryException cause;
 
   /**
    * Default constructor.
-   * @param qe query exception
+   * @param cause query exception
    */
-  public QueryIOException(final QueryException qe) {
-    super(Util.message(qe));
-    exception = qe;
+  public QueryIOException(final QueryException cause) {
+    super(Util.message(cause));
+    this.cause = cause;
   }
 
   @Override
   public synchronized QueryException getCause() {
-    return exception;
+    return cause;
   }
 
   /**
@@ -35,17 +35,17 @@ public final class QueryIOException extends IOException {
    * @return query exception
    */
   public QueryException getCause(final InputInfo info) {
-    if(info != null) exception.info(info);
-    return exception;
+    if(info != null) cause.info(info);
+    return cause;
   }
 
   @Override
   public String getLocalizedMessage() {
-    return exception.getLocalizedMessage();
+    return cause.getLocalizedMessage();
   }
 
   @Override
   public String getMessage() {
-    return exception.getMessage();
+    return cause.getMessage();
   }
 }
