@@ -1,28 +1,30 @@
 package org.basex.query;
 
 import static org.basex.core.Text.*;
-import static org.basex.query.util.Err.*;
 
 import java.io.*;
+import java.util.*;
 import java.util.regex.*;
 
 import org.basex.core.*;
 import org.basex.core.Context;
-import org.basex.data.*;
+import org.basex.core.locks.*;
 import org.basex.io.parse.json.*;
 import org.basex.io.serial.*;
 import org.basex.query.expr.*;
 import org.basex.query.iter.*;
+import org.basex.query.util.*;
 import org.basex.query.value.*;
 import org.basex.query.value.node.*;
+import org.basex.query.value.seq.*;
 
 /**
- * This class is an entry point for evaluating XQuery implementations.
+ * This class is an entry point for evaluating XQuery strings.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
-public final class QueryProcessor extends Proc {
+public final class QueryProcessor extends Proc implements Closeable {
   /** Pattern for detecting library modules. */
   private static final Pattern LIBMOD_PATTERN = Pattern.compile(
   "^(xquery( version ['\"].*?['\"])?( encoding ['\"].*?['\"])? ?; ?)?module namespace.*");
@@ -30,23 +32,21 @@ public final class QueryProcessor extends Proc {
   /** Static context. */
   public final StaticContext sc;
   /** Expression context. */
-  public final QueryContext ctx;
+  public final QueryContext qc;
   /** Query. */
   private final String query;
   /** Parsed flag. */
   private boolean parsed;
-  /** Compilation flag. */
-  private boolean compiled;
 
   /**
    * Default constructor.
-   * @param qu query to process
-   * @param cx database context
+   * @param query query string
+   * @param ctx database context
    */
-  public QueryProcessor(final String qu, final Context cx) {
-    query = qu;
-    ctx = proc(new QueryContext(cx));
-    sc = new StaticContext(cx.options.get(MainOptions.XQUERY3));
+  public QueryProcessor(final String query, final Context ctx) {
+    this.query = query;
+    qc = proc(new QueryContext(ctx));
+    sc = new StaticContext(qc);
   }
 
   /**
@@ -56,8 +56,8 @@ public final class QueryProcessor extends Proc {
   public void parse() throws QueryException {
     if(parsed) return;
     parsed = true;
-    ctx.parseMain(query, null, sc);
-    updating = ctx.updating;
+    qc.parseMain(query, null, sc);
+    updating = qc.updating;
   }
 
   /**
@@ -65,57 +65,59 @@ public final class QueryProcessor extends Proc {
    * @throws QueryException query exception
    */
   public void compile() throws QueryException {
-    if(compiled) return;
-    compiled = true;
     parse();
-    ctx.compile();
+    qc.compile();
   }
 
   /**
-   * Returns a result iterator.
+   * Returns a memory-efficient result iterator. In most cases, the query will only be fully
+   * evaluated if all items of this iterator are requested.
    * @return result iterator
    * @throws QueryException query exception
    */
   public Iter iter() throws QueryException {
-    compile();
-    return ctx.iter();
+    parse();
+    return qc.iter();
   }
 
   /**
-   * Returns a result value.
+   * Evaluates the query and returns the resulting value.
    * @return result value
    * @throws QueryException query exception
    */
   public Value value() throws QueryException {
-    compile();
-    return ctx.value();
+    parse();
+    return qc.iter().value();
   }
 
   /**
-   * Evaluates the specified query and returns the result.
+   * This function is called by the GUI; use {@link #iter()} or {@link #value()} instead.
+   * Caches and returns the result of the specified query. If all nodes are of the same database
+   * instance, the returned value will be of type {@link DBNodes}.
+   * @param max maximum number of results to cache (negative: return all values)
    * @return result of query
    * @throws QueryException query exception
    */
-  public Result execute() throws QueryException {
-    compile();
-    return ctx.execute();
+  public Value cache(final int max) throws QueryException {
+    parse();
+    return qc.cache(max);
   }
 
   /**
-   * Binds a value with the specified data type to a global variable.
+   * Binds a value with the specified type to a global variable.
    * If the value is an {@link Expr} instance, it is directly assigned.
    * Otherwise, it is first cast to the appropriate XQuery type. If {@code "json"}
-   * is specified as data type, the value is interpreted according to the rules
+   * is specified as type, the value is interpreted according to the rules
    * specified in {@link JsonMapConverter}.
    * @param name name of variable
    * @param value value to be bound
-   * @param type data type (may be {@code null})
+   * @param type type (may be {@code null})
    * @return self reference
    * @throws QueryException query exception
    */
   public QueryProcessor bind(final String name, final Object value, final String type)
       throws QueryException {
-    ctx.bind(name, value, type);
+    qc.bind(name, value, type, sc);
     return this;
   }
 
@@ -131,7 +133,19 @@ public final class QueryProcessor extends Proc {
   }
 
   /**
-   * Binds a value to the context item.
+   * Binds an XQuery value to a global variable.
+   * @param name name of variable
+   * @param value value to be bound
+   * @return self reference
+   * @throws QueryException query exception
+   */
+  public QueryProcessor bind(final String name, final Value value) throws QueryException {
+    qc.bind(name, value, sc);
+    return this;
+  }
+
+  /**
+   * Binds the context value.
    * @param value value to be bound
    * @return self reference
    * @throws QueryException query exception
@@ -140,36 +154,36 @@ public final class QueryProcessor extends Proc {
     return context(value, null);
   }
 
+  /**
+   * Binds the context value.
+   * @param value XQuery value to be bound
+   * @return self reference
+   */
+  public QueryProcessor context(final Value value) {
+    qc.context(value, sc);
+    return this;
+  }
+
   /**
    * Binds the HTTP context to the query processor.
    * @param value HTTP context
    * @return self reference
    */
   public QueryProcessor http(final Object value) {
-    ctx.http(value);
+    qc.http(value);
     return this;
   }
 
   /**
-   * Binds a value with the specified data type to the context item,
+   * Binds the context value with a specified type,
    * using the same rules as for {@link #bind binding variables}.
    * @param value value to be bound
-   * @param type data type (may be {@code null})
+   * @param type type (may be {@code null})
    * @return self reference
    * @throws QueryException query exception
    */
   public QueryProcessor context(final Object value, final String type) throws QueryException {
-    ctx.context(value, type, sc);
-    return this;
-  }
-
-  /**
-   * Binds an initial nodeset to the context item.
-   * @param nodes node set
-   * @return self reference
-   */
-  public QueryProcessor context(final Nodes nodes) {
-    ctx.nodes = nodes;
+    qc.context(value, type, sc);
     return this;
   }
 
@@ -187,6 +201,16 @@ public final class QueryProcessor extends Proc {
     return this;
   }
 
+  /**
+   * Assigns a URI resolver.
+   * @param resolver resolver
+   * @return self reference
+   */
+  public QueryProcessor uriResolver(final UriResolver resolver) {
+    sc.resolver = resolver;
+    return this;
+  }
+
   /**
    * Returns a serializer for the given output stream.
    * Optional output declarations within the query will be included in the
@@ -199,33 +223,19 @@ public final class QueryProcessor extends Proc {
   public Serializer getSerializer(final OutputStream os) throws IOException, QueryException {
     compile();
     try {
-      return Serializer.get(os, ctx.serParams());
+      return Serializer.get(os, qc.serParams()).sc(sc);
     } catch(final QueryIOException ex) {
       throw ex.getCause();
     }
   }
 
-  /**
-   * Evaluates the specified query and returns the result nodes.
-   * @return result nodes
-   * @throws QueryException query exception
-   */
-  public Nodes queryNodes() throws QueryException {
-    final Result res = execute();
-    if(res instanceof Nodes) return (Nodes) res;
-    // throw error
-    if(res.size() != 0) throw BXDB_DBRETURN.get(null);
-    // return empty result set
-    return new Nodes(ctx.nodes.data);
-  }
-
   /**
    * Adds a module reference. Only called from the test APIs.
    * @param uri module uri
    * @param file file name
    */
   public void module(final String uri, final String file) {
-    ctx.modDeclared.put(uri, file);
+    qc.modDeclared.put(uri, file);
   }
 
   /**
@@ -236,16 +246,14 @@ public final class QueryProcessor extends Proc {
     return query;
   }
 
-  /**
-   * Closes the processor.
-   */
+  @Override
   public void close() {
-    ctx.close();
+    qc.close();
   }
 
   @Override
   public void databases(final LockResult lr) {
-    ctx.databases(lr);
+    qc.databases(lr);
   }
 
   /**
@@ -253,7 +261,7 @@ public final class QueryProcessor extends Proc {
    * @return number of updates
    */
   public int updates() {
-    return updating ? ctx.updates.size() : 0;
+    return updating ? qc.resources.updates().size() : 0;
   }
 
   /**
@@ -261,7 +269,7 @@ public final class QueryProcessor extends Proc {
    * @return query information
    */
   public String info() {
-    return ctx.info();
+    return qc.info();
   }
 
   /**
@@ -308,14 +316,51 @@ public final class QueryProcessor extends Proc {
     return sb.toString().trim();
   }
 
+  /**
+   * Returns a map with variable bindings.
+   * @param opts main options
+   * @return bindings
+   */
+  public static HashMap<String, String> bindings(final MainOptions opts) {
+    final HashMap<String, String> bindings = new HashMap<>();
+    final String bind = opts.get(MainOptions.BINDINGS).trim();
+    final StringBuilder key = new StringBuilder();
+    final StringBuilder val = new StringBuilder();
+    boolean first = true;
+    final int sl = bind.length();
+    for(int s = 0; s < sl; s++) {
+      final char ch = bind.charAt(s);
+      if(first) {
+        if(ch == '=') {
+          first = false;
+        } else {
+          key.append(ch);
+        }
+      } else {
+        if(ch == ',') {
+          if(s + 1 == sl || bind.charAt(s + 1) != ',') {
+            bindings.put(key.toString().trim(), val.toString());
+            key.setLength(0);
+            val.setLength(0);
+            first = true;
+            continue;
+          }
+          // literal commas are escaped by a second comma
+          s++;
+        }
+        val.append(ch);
+      }
+    }
+    if(!first) bindings.put(key.toString().trim(), val.toString());
+    return bindings;
+  }
+
   /**
    * Returns a tree representation of the query plan.
    * @return root node
    */
   public FDoc plan() {
-    final FDoc doc = new FDoc();
-    ctx.plan(doc);
-    return doc;
+    return new FDoc().add(qc.plan());
   }
 
   @Override
