@@ -4,17 +4,16 @@ package org.basex.query;
  * A runtime exception wrapping a {@link QueryException}, used for throwing those out of
  * methods whose interface doesn't allow it.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Leo Woerteler
  */
 public final class QueryRTException extends RuntimeException {
   /**
    * Constructor.
-   *
-   * @param qe query exception to wrap
+   * @param cause query exception to wrap
    */
-  public QueryRTException(final QueryException qe) {
-    super(qe);
+  public QueryRTException(final QueryException cause) {
+    super(cause);
   }
 
   @Override
