@@ -1,6 +1,6 @@
 package org.basex.query;
 
-import static org.basex.query.util.Err.*;
+import static org.basex.query.QueryError.*;
 
 import java.io.*;
 import java.util.*;
@@ -8,77 +8,111 @@ import java.util.*;
 import org.basex.build.*;
 import org.basex.core.*;
 import org.basex.core.cmd.*;
+import org.basex.core.users.*;
 import org.basex.data.*;
 import org.basex.io.*;
+import org.basex.query.up.*;
+import org.basex.query.util.list.*;
+import org.basex.query.util.pkg.*;
 import org.basex.query.value.*;
 import org.basex.query.value.node.*;
 import org.basex.query.value.seq.*;
 import org.basex.query.value.type.*;
 import org.basex.util.*;
 import org.basex.util.list.*;
-import org.basex.util.options.*;
 
 /**
- * This class provides access to resources used by an XQuery expression.
+ * This class provides access to all kinds of resources (databases, documents, database connections,
+ * sessions) used by an XQuery expression.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class QueryResources {
-  /** Resources. */
-  public final HashMap<String, String[]> resources = new HashMap<String, String[]>();
-  /** Allow opening of new databases. */
-  public boolean openDB = true;
+  /** Textual resources. */
+  public final HashMap<String, String[]> texts = new HashMap<>();
 
   /** Database context. */
-  private final QueryContext ctx;
-  /** Opened databases. */
-  private Data[] data = new Data[1];
-  /** Number of databases. */
-  private int datas;
+  private final QueryContext qc;
 
   /** Collections: single nodes and sequences. */
-  private Value[] coll = new Value[1];
+  private final ArrayList<Value> colls = new ArrayList<>(1);
   /** Names of collections. */
-  private String[] collName = new String[1];
-  /** Number of collections. */
-  private int colls;
+  private final ArrayList<String> collNames = new ArrayList<>(1);
+  /** Opened databases. */
+  private final ArrayList<Data> datas = new ArrayList<>(1);
+  /** Indicates if the first database in the context is globally opened. */
+  private boolean globalData;
+
+  /** Module loader. */
+  private ModuleLoader modules;
+  /** External resources. */
+  private final HashMap<Class<? extends QueryResource>, QueryResource> external = new HashMap<>();
+
+  /** Pending output. */
+  public final ItemList output = new ItemList();
+  /** Pending updates. */
+  Updates updates;
 
   /**
    * Constructor.
    * @param qc query context
    */
   QueryResources(final QueryContext qc) {
-    ctx = qc;
+    this.qc = qc;
   }
 
   /**
    * Compiles the resources.
    * @param nodes input node set
-   * @throws QueryException query exception
+   * @return context value
    */
-  void compile(final Nodes nodes) throws QueryException {
-    final Data d = nodes.data;
-    if(!ctx.context.perm(Perm.READ, d.meta)) throw BASX_PERM.get(null, Perm.READ);
-
+  Value compile(final DBNodes nodes) {
     // assign initial context value
-    final boolean root = nodes.root;
-    ctx.value = DBNodeSeq.get(new IntList(nodes.pres), d, root, root);
+    final Data data = nodes.data();
+    final boolean all = nodes.all();
+    final Value value = DBNodeSeq.get(new IntList(nodes.pres()), data, all, all);
 
     // create default collection: use initial node set if it contains all
     // documents of the database. otherwise, create new node set
-    addCollection(root ? ctx.value : DBNodeSeq.get(d.resources.docs(), d, true, true), d.meta.name);
+    final Value coll = all ? value : DBNodeSeq.get(data.resources.docs(), data, true, true);
+    addCollection(coll, data.meta.name);
+    addData(data);
+    synchronized(qc.context.datas) { qc.context.datas.pin(data); }
 
-    add(d);
-    synchronized(ctx.context.dbs) { ctx.context.dbs.pin(d); }
+    globalData = true;
+    return value;
+  }
+
+  /**
+   * Adds an external resource.
+   * @param ext external resource
+   */
+  public void add(final QueryResource ext) {
+    external.put(ext.getClass(), ext);
+  }
+
+  /**
+   * Returns an external resource of the specified class.
+   * @param <R> resource
+   * @param resource external resource
+   * @return resource
+   */
+  @SuppressWarnings("unchecked")
+  public <R extends QueryResource> R get(final Class<? extends R> resource) {
+    return (R) external.get(resource);
   }
 
   /**
    * Closes all opened data references that have not been added by the global context.
    */
   void close() {
-    for(int d = 0; d < datas; d++) Close.close(data[d], ctx.context);
-    datas = 0;
+    for(final Data data : datas) Close.close(data, qc.context);
+    datas.clear();
+    // close dynamically loaded JAR files
+    if(modules != null) modules.close();
+    // close external resources
+    for(final QueryResource c : external.values()) c.close();
   }
 
   /**
@@ -90,18 +124,17 @@ public final class QueryResources {
    */
   public Data database(final String name, final InputInfo info) throws QueryException {
     // check if a database with the same name has already been opened
-    for(int d = 0; d < datas; ++d) {
-      if(data[d].inMemory()) continue;
-      final String n = data[d].meta.name;
-      if(Prop.CASE ? n.equals(name) : n.equalsIgnoreCase(name)) return data[d];
+    for(final Data data : datas) {
+      if(data.inMemory()) continue;
+      final String n = data.meta.name;
+      if(Prop.CASE ? n.equals(name) : n.equalsIgnoreCase(name)) return data;
     }
-    if(!openDB) throw BXXQ_NEWDB.get(info);
-
     try {
       // open and add new data reference
-      return add(Open.open(name, ctx.context));
+      final Context ctx = qc.context;
+      return addData(Open.open(name, ctx, ctx.options));
     } catch(final IOException ex) {
-      throw BXDB_OPEN.get(info, ex);
+      throw BXDB_OPEN_X.get(info, ex);
     }
   }
 
@@ -118,23 +151,22 @@ public final class QueryResources {
       throws QueryException {
 
     // favor default database
-    if(ctx.context.options.get(MainOptions.DEFAULTDB) && ctx.nodes != null) {
-      final Data dt = data[0];
-      final int pre = dt.resources.doc(qi.original);
-      if(pre != -1) return new DBNode(dt, pre, Data.DOC);
+    final Data gd = globalData();
+    if(gd != null && qc.context.options.get(MainOptions.DEFAULTDB)) {
+      final int pre = gd.resources.doc(qi.original);
+      if(pre != -1) return new DBNode(gd, pre, Data.DOC);
     }
 
     // check currently opened databases
-    for(int d = 0; d < datas; ++d) {
-      final Data dt = data[d];
+    for(final Data data : datas) {
       // check if database has a single document with an identical input path
-      if(dt.resources.docs().size() == 1 && IO.get(dt.meta.original).eq(qi.input))
-        return new DBNode(dt, 0, Data.DOC);
+      if(data.meta.ndocs == 1 && IO.get(data.meta.original).eq(qi.input))
+        return new DBNode(data, 0, Data.DOC);
 
       // check if database and input have identical name
       // database instance has same name as input path
-      final String n = dt.meta.name;
-      if(Prop.CASE ? n.equals(qi.db) : n.equalsIgnoreCase(qi.db)) return doc(dt, qi, info);
+      final String n = data.meta.name;
+      if(Prop.CASE ? n.equals(qi.db) : n.equalsIgnoreCase(qi.db)) return doc(data, qi, info);
     }
 
     // open new database, or create new instance
@@ -150,8 +182,8 @@ public final class QueryResources {
    * @throws QueryException query exception
    */
   public Value collection(final InputInfo info) throws QueryException {
-    if(colls == 0) throw NODEFCOLL.get(info);
-    return coll[0];
+    if(colls.isEmpty()) throw NODEFCOLL.get(info);
+    return colls.get(0);
   }
 
   /**
@@ -167,10 +199,10 @@ public final class QueryResources {
       throws QueryException {
 
     // favor default database
-    if(ctx.context.options.get(MainOptions.DEFAULTDB) && ctx.nodes != null) {
-      final Data dt = data[0];
-      final IntList pres = dt.resources.docs(qi.original);
-      return DBNodeSeq.get(pres, dt, true, qi.original.isEmpty());
+    final Data gd = globalData();
+    if(qc.context.options.get(MainOptions.DEFAULTDB) && gd != null) {
+      final IntList pres = gd.resources.docs(qi.original);
+      return DBNodeSeq.get(pres, gd, true, qi.original.isEmpty());
     }
 
     // merge input with base directory
@@ -179,21 +211,21 @@ public final class QueryResources {
     // check currently opened collections
     if(in != null) {
       final String[] names = { in, qi.original };
-      for(int c = 0; c < colls; c++) {
-        final String n = collName[c];
-        if(Prop.CASE ? Token.eq(n, names) : Token.eqic(n, names)) return coll[c];
+      final int cs = colls.size();
+      for(int c = 0; c < cs; c++) {
+        final String name = collNames.get(c);
+        if(Prop.CASE ? Strings.eq(name, names) : Strings.eqic(name, names)) return colls.get(c);
       }
     }
 
     // check currently opened databases
     Data dt = null;
-    for(int i = 0; i < datas; ++i) {
+    for(final Data data : datas) {
       // return database instance with the same name or file path
-      final Data d = data[i];
-      final String n = d.meta.name;
+      final String n = data.meta.name;
       if(Prop.CASE ? n.equals(qi.db) : n.equalsIgnoreCase(qi.db) ||
-          IO.get(d.meta.original).eq(qi.input)) {
-        dt = d;
+          IO.get(data.meta.original).eq(qi.input)) {
+        dt = data;
         break;
       }
     }
@@ -204,115 +236,46 @@ public final class QueryResources {
     return DBNodeSeq.get(dt.resources.docs(qi.path), dt, true, qi.path.isEmpty());
   }
 
-  // TEST APIS ====================================================================================
-
   /**
-   * Adds a document with the specified path. Only called from the test APIs.
-   * @param name document identifier (may be {@code null})
-   * @param path documents path
-   * @param baseIO base URI
-   * @throws QueryException query exception
+   * Returns a reference to the updates.
+   * @return updates
    */
-  public void addDoc(final String name, final String path, final IO baseIO)
-      throws QueryException {
-
-    final QueryInput qi = new QueryInput(path);
-    final Data d = create(qi, true, baseIO, null);
-    if(name != null) d.meta.original = name;
+  public Updates updates() {
+    if(updates == null) updates = new Updates();
+    return updates;
   }
 
   /**
-   * Adds a resource with the specified path. Only called from the test APIs.
-   * @param uri resource uri
-   * @param strings resource strings (path, encoding)
+   * Returns the module loader.
+   * @return module loader
    */
-  public void addResource(final String uri, final String... strings) {
-    resources.put(uri, strings);
+  public ModuleLoader modules() {
+    if(modules == null) modules = new ModuleLoader(qc.context);
+    return modules;
   }
 
   /**
-   * Adds a collection with the specified paths. Only called from the test APIs.
-   * @param name name of collection
-   * @param paths documents paths
-   * @param baseIO base URI
-   * @throws QueryException query exception
+   * Removes and closes a database if it has not been added by the global context.
+   * @param name name of database to be removed
    */
-  public void addCollection(final String name, final String[] paths, final IO baseIO)
-      throws QueryException {
-
-    final int ns = paths.length;
-    final DBNode[] nodes = new DBNode[ns];
-    for(int n = 0; n < ns; n++) {
-      final QueryInput qi = new QueryInput(paths[n]);
-      nodes[n] = new DBNode(create(qi, true, baseIO, null), 0, Data.DOC);
-    }
-    addCollection(Seq.get(nodes, ns, NodeType.DOC), name);
-  }
-
-  // PRIVATE METHODS ====================================================================
-
-  /**
-   * Tries to open the addressed database, or returns {@code null}.
-   * @param input query input
-   * @return data reference
-   */
-  private Data open(final QueryInput input) {
-    if(openDB && input.db != null) {
-      try {
-        // try to open database
-        return add(Open.open(input.db, ctx.context));
-      } catch(final IOException ex) {
-        /* ignored */
+  public void remove(final String name) {
+    final int ds = datas.size();
+    for(int d = globalData ? 1 : 0; d < ds; d++) {
+      final Data data = datas.get(d);
+      if(data.meta.name.equals(name)) {
+        Close.close(data, qc.context);
+        datas.remove(d);
+        break;
       }
     }
-    return null;
   }
 
   /**
-   * Creates a new database instance.
-   * @param input query input
-   * @param single expect single document
-   * @param baseIO base URI
-   * @param info input info
-   * @return data reference
-   * @throws QueryException query exception
+   * Returns the globally opened database.
+   * @return database or {@code null} if no database is globally opened
    */
-  private Data create(final QueryInput input, final boolean single, final IO baseIO,
-      final InputInfo info) throws QueryException {
-
-    // check if new databases can be created
-    final Context context = ctx.context;
-    final boolean force = context.options.get(MainOptions.FORCECREATE);
-    if(force && !openDB) throw BXXQ_NEWDB.get(info);
-
-    // do not check input if no read permissions are given
-    if(!context.user.has(Perm.READ))
-      throw BXXQ_PERM.get(info, Util.info(Text.PERM_REQUIRED_X, Perm.READ));
-
-    // check if input is an existing file
-    final IO source = checkPath(input, baseIO, info);
-    if(single && source.isDir()) WHICHRES.get(info, baseIO);
-
-    // overwrite parsing options with default values
-    final MainOptions opts = context.options;
-    final Option<?>[] options = { MainOptions.SKIPCORRUPT, MainOptions.ADDARCHIVES,
-        MainOptions.ADDRAW, MainOptions.PARSER, MainOptions.CREATEFILTER };
-    final Object[] values = new Object[options.length];
-    final int ol = options.length;
-    for(int o = 0; o < ol; o++) {
-      final Option<?> option = options[o];
-      values[o] = opts.get(option);
-      opts.put(option, option.value());
-    }
-    try {
-      return add(CreateDB.create(source.dbname(), new DirParser(source, opts), context, !force));
-    } catch(final IOException ex) {
-      throw IOERR.get(info, ex);
-    } finally {
-      // reset original values
-      for(int o = 0; o < ol; o++) opts.put(options[o], values[o]);
-      input.path = "";
-    }
+  Data globalData() {
+    return globalData ? datas.get(0) : null;
   }
 
   /**
@@ -333,7 +296,104 @@ public final class QueryResources {
       in = baseIO.merge(input.original);
       if(!in.path().equals(input.original) && in.exists()) return in;
     }
-    throw WHICHRES.get(info, in);
+    throw WHICHRES_X.get(info, in);
+  }
+
+  // TEST APIS ====================================================================================
+
+  /**
+   * Adds a document with the specified path. Only called from the test APIs.
+   * @param name document identifier (may be {@code null})
+   * @param path documents path
+   * @param baseIO base URI
+   * @throws QueryException query exception
+   */
+  public void addDoc(final String name, final String path, final IO baseIO) throws QueryException {
+    final QueryInput qi = new QueryInput(path);
+    final Data d = create(qi, true, baseIO, null);
+    if(name != null) d.meta.original = name;
+  }
+
+  /**
+   * Adds a resource with the specified path. Only called from the test APIs.
+   * @param uri resource uri
+   * @param strings resource strings (path, encoding)
+   */
+  public void addResource(final String uri, final String... strings) {
+    texts.put(uri, strings);
+  }
+
+  /**
+   * Adds a collection with the specified paths. Only called from the test APIs.
+   * @param name name of collection
+   * @param paths documents paths
+   * @param baseIO base URI
+   * @throws QueryException query exception
+   */
+  public void addCollection(final String name, final String[] paths, final IO baseIO)
+      throws QueryException {
+
+    final int ns = paths.length;
+    final DBNode[] nodes = new DBNode[ns];
+    for(int n = 0; n < ns; n++) {
+      final QueryInput qi = new QueryInput(paths[n]);
+      nodes[n] = new DBNode(create(qi, true, baseIO, null), 0, Data.DOC);
+    }
+    addCollection(ValueBuilder.value(nodes, ns, NodeType.DOC), name);
+  }
+
+  // PRIVATE METHODS ==============================================================================
+
+  /**
+   * Tries to open the addressed database, or returns {@code null}.
+   * @param input query input
+   * @return data reference
+   */
+  private Data open(final QueryInput input) {
+    if(input.db != null) {
+      try {
+        // try to open database
+        final Context ctx = qc.context;
+        return addData(Open.open(input.db, ctx, ctx.options));
+      } catch(final IOException ex) { Util.debug(ex); }
+    }
+    return null;
+  }
+
+  /**
+   * Creates a new database instance.
+   * @param input query input
+   * @param single expect single document
+   * @param baseIO base URI
+   * @param info input info
+   * @return data reference
+   * @throws QueryException query exception
+   */
+  private Data create(final QueryInput input, final boolean single, final IO baseIO,
+      final InputInfo info) throws QueryException {
+
+    // check if new databases can be created
+    final Context context = qc.context;
+
+    // do not check input if no read permissions are given
+    if(!context.user().has(Perm.READ))
+      throw BXXQ_PERM_X.get(info, Util.info(Text.PERM_REQUIRED_X, Perm.READ));
+
+    // check if input is an existing file
+    final IO source = checkPath(input, baseIO, info);
+    if(single && source.isDir()) WHICHRES_X.get(info, baseIO);
+
+    // overwrite parsing options with default values
+    try {
+      final boolean mem = !context.options.get(MainOptions.FORCECREATE);
+      final MainOptions opts = new MainOptions(context.options);
+      return addData(CreateDB.create(source.dbname(),
+          new DirParser(source, opts), context, opts, mem));
+    } catch(final IOException ex) {
+      throw IOERR_X.get(info, ex);
+    } finally {
+      input.path = "";
+    }
   }
 
   /**
@@ -351,47 +411,26 @@ public final class QueryResources {
     final IntList docs = dt.resources.docs(qi.path);
     // ensure that a single document was filtered
     if(docs.size() == 1) return new DBNode(dt, docs.get(0), Data.DOC);
-    throw (docs.isEmpty() ? BXDB_NODOC : BXDB_SINGLE).get(info, qi.original);
+    throw (docs.isEmpty() ? BXDB_NODOC_X : BXDB_SINGLE_X).get(info, qi.original);
   }
 
   /**
    * Adds a data reference.
-   * @param d data reference to be added
+   * @param data data reference to be added
    * @return argument
    */
-  private Data add(final Data d) {
-    if(datas == data.length) data = Array.copy(data, new Data[Array.newSize(datas)]);
-    data[datas++] = d;
-    return d;
-  }
-
-  /**
-   * Removes and closes a database if it has not been added by the global context.
-   * @param name name of database to be removed
-   */
-  public void remove(final String name) {
-    for(int d = ctx.nodes != null ? 1 : 0; d < datas; d++) {
-      if(data[d].meta.name.equals(name)) {
-        Close.close(data[d], ctx.context);
-        Array.move(data, d + 1, -1, --datas - d);
-        data[datas] = null;
-        break;
-      }
-    }
+  private Data addData(final Data data) {
+    datas.add(data);
+    return data;
   }
 
   /**
    * Adds a collection to the global collection list.
-   * @param nodes collection nodes
+   * @param coll documents of collection
    * @param name collection name
    */
-  private void addCollection(final Value nodes, final String name) {
-    if(colls == coll.length) {
-      final int s = Array.newSize(colls);
-      coll = Array.copy(coll, new Value[s]);
-      collName = Array.copyOf(collName, s);
-    }
-    coll[colls] = nodes;
-    collName[colls++] = name;
+  private void addCollection(final Value coll, final String name) {
+    colls.add(coll);
+    collNames.add(name);
   }
 }
