@@ -5,7 +5,7 @@ import org.basex.query.util.*;
 /**
  * Interface for all expressions defining a new variable scope.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Leo Woerteler
  */
 public interface Scope {
@@ -18,10 +18,10 @@ public interface Scope {
 
   /**
    * Compiles the expression contained in this scope.
-   * @param ctx query context
+   * @param qc query context
    * @throws QueryException compilation errors
    */
-  void compile(QueryContext ctx) throws QueryException;
+  void compile(QueryContext qc) throws QueryException;
 
   /**
    * Checks if this scope has already been compiled.
