@@ -3,8 +3,10 @@ package org.basex.query;
 import static org.basex.query.QueryText.*;
 import static org.basex.util.Token.*;
 
+import org.basex.core.*;
 import org.basex.io.*;
 import org.basex.query.util.*;
+import org.basex.query.util.collation.*;
 import org.basex.query.util.format.*;
 import org.basex.query.value.item.*;
 import org.basex.query.value.type.*;
@@ -14,48 +16,50 @@ import org.basex.util.hash.*;
 /**
  * This class contains the static context of an expression.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class StaticContext {
   /** Decimal formats. */
-  public final TokenObjMap<DecFormatter> decFormats = new TokenObjMap<DecFormatter>();
+  public final TokenObjMap<DecFormatter> decFormats = new TokenObjMap<>();
   /** Static and dynamic namespaces. */
   public final NSContext ns = new NSContext();
+  /** Mix updates flag. */
+  public final boolean mixUpdates;
 
-  /** Default collation (default collection ({@link QueryText#COLLATIONURI}): {@code null}). */
+  /** Default collation (default collection ({@link QueryText#COLLATION_URI}): {@code null}). */
   public Collation collation;
   /** Default element/type namespace. */
   public byte[] elemNS;
   /** Default function namespace. */
-  public byte[] funcNS = FNURI;
-  /** Context item static type. */
-  public SeqType initType;
+  public byte[] funcNS = FN_URI;
+  /** Static type of context value. */
+  SeqType contextType;
 
   /** Construction mode. */
-  public boolean strip;
+  boolean strip;
   /** Ordering mode. */
-  public boolean ordered;
+  boolean ordered;
   /** Default order for empty sequences. */
-  public boolean orderGreatest;
+  boolean orderGreatest;
   /** Boundary-space policy. */
-  public boolean spaces;
+  boolean spaces;
   /** Copy-namespaces mode: (no-)preserve. */
-  public boolean preserveNS = true;
+  boolean preserveNS = true;
   /** Copy-namespaces mode: (no-)inherit. */
-  public boolean inheritNS = true;
-  /** XQuery version flag. */
-  boolean xquery3;
+  boolean inheritNS = true;
 
   /** Static Base URI. */
   private Uri baseURI = Uri.EMPTY;
+  /** Sets a module URI resolver. */
+  UriResolver resolver;
 
   /**
    * Constructor setting the XQuery version.
-   * @param xq30 XQuery 3.0 flag
+   * @param qc query context
    */
-  public StaticContext(final boolean xq30) {
-    xquery3 = xq30;
+  public StaticContext(final QueryContext qc) {
+    mixUpdates = qc.context.options.get(MainOptions.MIXUPDATES);
   }
 
   /**
@@ -66,7 +70,7 @@ public final class StaticContext {
    * @param uri namespace URI
    * @throws QueryException query exception
    */
-  public void namespace(final String prefix, final String uri) throws QueryException {
+  void namespace(final String prefix, final String uri) throws QueryException {
     if(prefix.isEmpty()) {
       elemNS = uri.isEmpty() ? null : token(uri);
     } else if(uri.isEmpty()) {
@@ -77,21 +81,22 @@ public final class StaticContext {
   }
 
   /**
-   * Returns an IO representation of the static base URI, or {@code null}.
+   * Returns an IO representation of the static base URI or {@code null}.
    * @return IO reference
    */
   public IO baseIO() {
-    return baseURI == Uri.EMPTY ? null : IO.get(baseURI.toJava());
+    return baseURI == Uri.EMPTY ? null : IO.get(string(baseURI.string()));
   }
 
   /**
-   * Returns an IO reference for the specified filename.
-   * If a base URI exists, it is merged with the specified filename.
-   * Otherwise, a plain reference is returned.
+   * Returns an IO reference for the specified path.
+   * If a base URI exists, it is merged with the path.
    * @param path file path
+   * @param uri module namespace (can be {@code null})
    * @return io reference
    */
-  public IO io(final String path) {
+  IO resolve(final String path, final String uri) {
+    if(resolver != null) return resolver.resolve(path, uri, baseURI);
     final IO base = baseIO();
     return base != null ? base.merge(path) : IO.get(path);
   }
@@ -110,23 +115,19 @@ public final class StaticContext {
    */
   public void baseURI(final String uri) {
     final IO base = IO.get(uri);
+    String url;
     if(uri.isEmpty()) {
-      baseURI = Uri.EMPTY;
+      url = "";
     } else if(base instanceof IOContent) {
-      baseURI = Uri.uri(uri);
+      url = uri;
     } else if(baseURI == Uri.EMPTY) {
-      baseURI = Uri.uri(base.url());
+      url = base.url();
     } else {
-      baseURI = Uri.uri(baseIO().merge(uri).url());
+      url = baseIO().merge(uri).url();
     }
-  }
-
-  /**
-   * Checks if XQuery 3.0 features are allowed.
-   * @return {@code true} if XQuery 3.0 is allowed, {@code false} otherwise
-   */
-  public boolean xquery3() {
-    return xquery3;
+    // #1062: check if specified URI points to a directory. if yes, add trailing slash
+    if(!url.endsWith("/") && (uri.endsWith(".") || uri.endsWith("/"))) url += '/';
+    baseURI = Uri.uri(url);
   }
 
   @Override
