@@ -1,6 +1,6 @@
 package org.basex.query;
 
-import org.basex.query.util.*;
+import org.basex.query.util.list.*;
 import org.basex.query.value.item.*;
 import org.basex.query.value.type.*;
 import org.basex.query.var.*;
@@ -9,12 +9,12 @@ import org.basex.util.*;
 /**
  * Common superclass for static functions and variables.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Leo Woerteler
  */
 public abstract class StaticDecl extends StaticScope {
   /** Annotations. */
-  public final Ann ann;
+  public final AnnList anns;
   /** This declaration's name. */
   public final QNm name;
   /** Declared type, {@code null} if not specified. */
@@ -25,21 +25,21 @@ public abstract class StaticDecl extends StaticScope {
 
   /**
    * Constructor.
-   * @param sctx static context
-   * @param a annotations
-   * @param nm name
-   * @param t declared return type
-   * @param scp variable scope
-   * @param xqdoc documentation
-   * @param ii input info
+   * @param sc static context
+   * @param anns annotations
+   * @param name name
+   * @param type declared return type
+   * @param scope variable scope
+   * @param doc xqdoc documentation
+   * @param info input info
    */
-  protected StaticDecl(final StaticContext sctx, final Ann a, final QNm nm, final SeqType t,
-      final VarScope scp, final String xqdoc, final InputInfo ii) {
+  protected StaticDecl(final StaticContext sc, final AnnList anns, final QNm name,
+      final SeqType type, final VarScope scope, final String doc, final InputInfo info) {
 
-    super(scp, xqdoc, sctx, ii);
-    ann = a == null ? new Ann() : a;
-    name = nm;
-    declType = t;
+    super(scope, doc, sc, info);
+    this.anns = anns;
+    this.name = name;
+    declType = type;
   }
 
   /**
@@ -49,11 +49,11 @@ public abstract class StaticDecl extends StaticScope {
   public abstract byte[] id();
 
   /**
-   * Returns the type of this expression. If no type has been declare in the expression,
+   * Returns the type of this expression. If no type has been declared in the expression,
    * it is derived from the expression type.
    * @return return type
    */
-  public SeqType type() {
-    return declType != null ? declType : expr.type();
+  public SeqType seqType() {
+    return declType != null ? declType : expr.seqType();
   }
 }
