@@ -2,8 +2,8 @@ package org.basex.query.expr;
 
 import static org.basex.query.QueryText.*;
 
-import org.basex.data.*;
 import org.basex.query.*;
+import org.basex.query.expr.Expr.*;
 import org.basex.query.value.item.*;
 import org.basex.query.value.node.*;
 import org.basex.util.*;
@@ -11,7 +11,7 @@ import org.basex.util.*;
 /**
  * Abstract pragma expression.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Leo Woerteler
  */
 public abstract class Pragma extends ExprInfo {
@@ -22,12 +22,12 @@ public abstract class Pragma extends ExprInfo {
 
   /**
    * Constructor.
-   * @param n name of pragma
-   * @param v optional value
+   * @param name name of pragma
+   * @param value optional value
    */
-  Pragma(final QNm n, final byte[] v) {
-    name = n;
-    value = v;
+  Pragma(final QNm name, final byte[] value) {
+    this.name = name;
+    this.value = value;
   }
 
   @Override
@@ -37,17 +37,25 @@ public abstract class Pragma extends ExprInfo {
 
   /**
    * Initializes the pragma expression.
-   * @param ctx query context
+   * @param qc query context
    * @param info input info
    * @throws QueryException query exception
    */
-  abstract void init(final QueryContext ctx, final InputInfo info) throws QueryException;
+  abstract void init(final QueryContext qc, final InputInfo info) throws QueryException;
 
   /**
    * Finalizes the pragma expression.
-   * @param ctx query context
+   * @param qc query context
    */
-  abstract void finish(final QueryContext ctx);
+  abstract void finish(final QueryContext qc);
+
+  /**
+   * Indicates if an expression has the specified compiler property.
+   * @param flag flag to be checked
+   * @return result of check
+   * @see Expr#has
+   */
+  public abstract boolean has(final Flag flag);
 
   @Override
   public final String toString() {
