@@ -6,7 +6,7 @@ import java.util.*;
 
 import org.basex.query.*;
 import org.basex.query.iter.*;
-import org.basex.query.value.item.*;
+import org.basex.query.util.list.*;
 import org.basex.query.value.node.*;
 import org.basex.query.value.type.*;
 import org.basex.query.var.*;
@@ -15,48 +15,57 @@ import org.basex.util.*;
 /**
  * Set expression.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 abstract class Set extends Arr {
   /** Iterable flag. */
-  boolean iterable = true;
+  boolean iterable;
 
   /**
    * Constructor.
-   * @param ii input info
-   * @param l expression list
+   * @param info input info
+   * @param exprs expressions
    */
-  Set(final InputInfo ii, final Expr[] l) {
-    super(ii, l);
-    type = SeqType.NOD_ZM;
+  Set(final InputInfo info, final Expr[] exprs) {
+    super(info, exprs);
+    seqType = SeqType.NOD_ZM;
   }
 
   @Override
-  public Expr compile(final QueryContext ctx, final VarScope scp) throws QueryException {
-    super.compile(ctx, scp);
-    for(final Expr e : expr) {
-      if(e.iterable()) continue;
-      iterable = false;
-      break;
+  public final Expr compile(final QueryContext qc, final VarScope scp) throws QueryException {
+    super.compile(qc, scp);
+    return optimize(qc, scp);
+  }
+
+  @Override
+  public Expr optimize(final QueryContext qc, final VarScope scp) throws QueryException {
+    boolean i = true;
+    for(final Expr e : exprs) {
+      if(!e.iterable()) {
+        i = false;
+        break;
+      }
     }
+    iterable = i;
     return this;
   }
 
   @Override
-  public final NodeIter iter(final QueryContext ctx) throws QueryException {
-    final Iter[] iter = new Iter[expr.length];
-    for(int e = 0; e != expr.length; ++e) iter[e] = ctx.iter(expr[e]);
-    return iterable ? iter(iter) : eval(iter).sort();
+  public final NodeIter iter(final QueryContext qc) throws QueryException {
+    final int el = exprs.length;
+    final Iter[] iter = new Iter[el];
+    for(int e = 0; e < el; e++) iter[e] = qc.iter(exprs[e]);
+    return iterable ? iter(iter) : eval(iter).iter();
   }
 
   /**
    * Evaluates the specified iterators.
    * @param iter iterators
-   * @return resulting iterator
+   * @return resulting node list
    * @throws QueryException query exception
    */
-  protected abstract NodeSeqBuilder eval(final Iter[] iter) throws QueryException;
+  protected abstract ANodeList eval(final Iter[] iter) throws QueryException;
 
   /**
    * Evaluates the specified iterators in an iterative manner.
@@ -70,6 +79,11 @@ abstract class Set extends Arr {
     return iterable;
   }
 
+  @Override
+  public final String toString() {
+    return PAREN1 + toString(' ' + Util.className(this).toLowerCase(Locale.ENGLISH) + ' ') + PAREN2;
+  }
+
   /**
    * Abstract set iterator.
    */
@@ -81,10 +95,10 @@ abstract class Set extends Arr {
 
     /**
      * Constructor.
-     * @param ir iterator
+     * @param iter iterator
      */
-    SetIter(final Iter[] ir) {
-      iter = ir;
+    SetIter(final Iter[] iter) {
+      this.iter = iter;
     }
 
     @Override
@@ -97,15 +111,9 @@ abstract class Set extends Arr {
      * @throws QueryException query exception
      */
     boolean next(final int i) throws QueryException {
-      final Item it = iter[i].next();
-      item[i] = it == null ? null : checkNode(it);
-      return it != null;
+      final ANode n = toEmptyNode(iter[i].next());
+      item[i] = n;
+      return n != null;
     }
   }
-
-  @Override
-  public final String toString() {
-    return PAR1 + toString(' ' +
-        Util.className(this).toLowerCase(Locale.ENGLISH) + ' ') + PAR2;
-  }
 }
