@@ -1,24 +1,23 @@
 package org.basex.query.expr;
 
 import static org.basex.query.QueryText.*;
+
 import org.basex.query.*;
-import org.basex.query.func.*;
-import org.basex.query.iter.Iter;
+import org.basex.query.func.fn.*;
+import org.basex.query.iter.*;
 import org.basex.query.util.*;
 import org.basex.query.value.*;
 import org.basex.query.value.node.*;
 import org.basex.query.value.type.*;
 import org.basex.query.var.*;
-import org.basex.util.InputInfo;
-import org.basex.util.Token;
-import org.basex.util.TokenBuilder;
+import org.basex.util.*;
 import org.basex.util.hash.*;
 import org.basex.util.list.*;
 
 /**
  * Case expression for typeswitch.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class TypeCase extends Single {
@@ -29,63 +28,68 @@ public final class TypeCase extends Single {
 
   /**
    * Constructor.
-   * @param ii input info
-   * @param v variable
-   * @param ts sequence types this case matches, the empty array means {@code default}
-   * @param r return expression
+   * @param info input info
+   * @param var variable
+   * @param types sequence types this case matches, the empty array means {@code default}
+   * @param expr return expression
    */
-  public TypeCase(final InputInfo ii, final Var v, final SeqType[] ts, final Expr r) {
-    super(ii, r);
-    var = v;
-    types = ts;
+  public TypeCase(final InputInfo info, final Var var, final SeqType[] types, final Expr expr) {
+    super(info, expr);
+    this.var = var;
+    this.types = types;
   }
 
   @Override
-  public TypeCase compile(final QueryContext ctx, final VarScope scp) throws QueryException {
-    return compile(ctx, scp, null);
+  public TypeCase compile(final QueryContext qc, final VarScope scp) throws QueryException {
+    return compile(qc, scp, null);
   }
 
   /**
    * Compiles the expression.
-   * @param ctx query context
+   * @param qc query context
    * @param scp variable scope
    * @param v value to be bound
    * @return resulting item
    * @throws QueryException query exception
    */
-  TypeCase compile(final QueryContext ctx, final VarScope scp, final Value v)
+  TypeCase compile(final QueryContext qc, final VarScope scp, final Value v)
       throws QueryException {
-    final Value val = var != null && v != null ? var.checkType(v, ctx, info, true) : null;
+    final Value val = var != null && v != null ? var.checkType(v, qc, info, true) : null;
     try {
-      super.compile(ctx, scp);
+      super.compile(qc, scp);
       if(val != null) {
-        final Expr inlined = expr.inline(ctx, scp, var, val);
+        final Expr inlined = expr.inline(qc, scp, var, val);
         if(inlined != null) expr = inlined;
       }
     } catch(final QueryException ex) {
       // replace original expression with error
-      expr = FNInfo.error(ex, expr.type());
+      expr = FnError.get(ex, expr.seqType());
     }
-    type = expr.type();
+    return optimize(qc, scp);
+  }
+
+  @Override
+  public TypeCase optimize(final QueryContext qc, final VarScope scp) {
+    seqType = expr.seqType();
     return this;
   }
 
   @Override
-  public Expr inline(final QueryContext ctx, final VarScope scp, final Var v, final Expr e) {
+  public Expr inline(final QueryContext qc, final VarScope scp, final Var v, final Expr ex) {
     try {
-      return super.inline(ctx, scp, v, e);
+      return super.inline(qc, scp, v, ex);
     } catch(final QueryException qe) {
-      expr = FNInfo.error(qe, expr.type());
+      expr = FnError.get(qe, expr.seqType());
       return this;
     }
   }
 
   @Override
-  public TypeCase copy(final QueryContext ctx, final VarScope scp,
+  public TypeCase copy(final QueryContext qc, final VarScope scp,
       final IntObjMap<Var> vs) {
-    final Var v = var == null ? null : scp.newCopyOf(ctx, var);
+    final Var v = var == null ? null : scp.newCopyOf(qc, var);
     if(var != null) vs.put(var.id, v);
-    return new TypeCase(info, v, types.clone(), expr.copy(ctx, scp, vs));
+    return new TypeCase(info, v, types.clone(), expr.copy(qc, scp, vs));
   }
 
   /**
@@ -93,7 +97,7 @@ public final class TypeCase extends Single {
    * @param val value to be matched
    * @return {@code true} if it matches, {@code false} otherwise
    */
-  public boolean matches(final Value val) {
+  boolean matches(final Value val) {
     if(types.length == 0) return true;
     for(final SeqType t : types) if(t.instance(val)) return true;
     return false;
@@ -101,17 +105,17 @@ public final class TypeCase extends Single {
 
   /**
    * Evaluates the expression.
-   * @param ctx query context
+   * @param qc query context
    * @param seq sequence to be checked
    * @return resulting item
    * @throws QueryException query exception
    */
-  Iter iter(final QueryContext ctx, final Value seq) throws QueryException {
+  Iter iter(final QueryContext qc, final Value seq) throws QueryException {
     if(!matches(seq)) return null;
 
-    if(var == null) return ctx.iter(expr);
-    ctx.set(var, seq, info);
-    return ctx.value(expr).iter();
+    if(var == null) return qc.iter(expr);
+    qc.set(var, seq, info);
+    return qc.value(expr).iter();
   }
 
   @Override
@@ -126,7 +130,7 @@ public final class TypeCase extends Single {
         if(!bl.isEmpty()) bl.add(or);
         bl.add(Token.token(t.toString()));
       }
-      e.add(planAttr(Token.token(TYPE), bl.toArray()));
+      e.add(planAttr(Token.token(TYPE), bl.finish()));
     }
     if(var != null) e.add(planAttr(VAR, Token.token(var.toString())));
     expr.plan(e);
@@ -135,23 +139,24 @@ public final class TypeCase extends Single {
 
   @Override
   public String toString() {
-    final TokenBuilder tb = new TokenBuilder(types.length == 0 ? DEFAULT : CASE);
+    final int tl = types.length;
+    final TokenBuilder tb = new TokenBuilder(tl == 0 ? DEFAULT : CASE);
     if(var != null) {
       tb.add(' ').add(var.toString());
-      if(types.length != 0) tb.add(' ').add(AS);
+      if(tl != 0) tb.add(' ').add(AS);
     }
-    if(types.length != 0) {
-      for(int i = 0; i < types.length; i++) {
-        if(i > 0) tb.add(" |");
-        tb.add(' ').add(types[i].toString());
+    if(tl != 0) {
+      for(int t = 0; t < tl; t++) {
+        if(t > 0) tb.add(" |");
+        tb.add(' ').add(types[t].toString());
       }
     }
     return tb.add(' ' + RETURN + ' ' + expr).toString();
   }
 
   @Override
-  public void markTailCalls(final QueryContext ctx) {
-    expr.markTailCalls(ctx);
+  public void markTailCalls(final QueryContext qc) {
+    expr.markTailCalls(qc);
   }
 
   @Override
