@@ -4,7 +4,7 @@ import static org.basex.query.QueryText.*;
 
 import org.basex.query.*;
 import org.basex.query.iter.*;
-import org.basex.query.util.*;
+import org.basex.query.util.list.*;
 import org.basex.query.value.item.*;
 import org.basex.query.value.node.*;
 import org.basex.query.value.seq.*;
@@ -15,29 +15,28 @@ import org.basex.util.hash.*;
 /**
  * Union expression.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class Union extends Set {
   /**
    * Constructor.
-   * @param ii input info
-   * @param e expression list
+   * @param info input info
+   * @param exprs expressions
    */
-  public Union(final InputInfo ii, final Expr... e) {
-    super(ii, e);
+  public Union(final InputInfo info, final Expr... exprs) {
+    super(info, exprs);
   }
 
   @Override
-  public Expr compile(final QueryContext ctx, final VarScope scp) throws QueryException {
-    super.compile(ctx, scp);
+  public Expr optimize(final QueryContext qc, final VarScope scp) throws QueryException {
+    super.optimize(qc, scp);
 
-    final int es = expr.length;
-    final ExprList el = new ExprList(es);
-    for(final Expr ex : expr) {
+    final ExprList el = new ExprList(exprs.length);
+    for(final Expr ex : exprs) {
       if(ex.isEmpty()) {
         // remove empty operands
-        ctx.compInfo(OPTREMOVE, this, ex);
+        qc.compInfo(OPTREMOVE, this, ex);
       } else {
         el.add(ex);
       }
@@ -47,24 +46,24 @@ public final class Union extends Set {
     // ensure that results are always sorted
     if(el.size() == 1 && iterable) return el.get(0);
     // replace expressions with optimized list
-    if(el.size() != es) expr = el.finish();
+    exprs = el.finish();
     return this;
   }
 
   @Override
-  public Expr copy(final QueryContext ctx, final VarScope scp, final IntObjMap<Var> vs) {
-    final Union un = new Union(info, copyAll(ctx, scp, vs, expr));
+  public Expr copy(final QueryContext qc, final VarScope scp, final IntObjMap<Var> vs) {
+    final Union un = new Union(info, copyAll(qc, scp, vs, exprs));
     un.iterable = iterable;
     return copyType(un);
   }
 
   @Override
-  protected NodeSeqBuilder eval(final Iter[] iter) throws QueryException {
-    final NodeSeqBuilder nc = new NodeSeqBuilder().check();
+  protected ANodeList eval(final Iter[] iter) throws QueryException {
+    final ANodeList list = new ANodeList().check();
     for(final Iter ir : iter) {
-      for(Item it; (it = ir.next()) != null;) nc.add(checkNode(it));
+      for(Item it; (it = ir.next()) != null;) list.add(toNode(it));
     }
-    return nc;
+    return list;
   }
 
   @Override
@@ -73,12 +72,14 @@ public final class Union extends Set {
       @Override
       public ANode next() throws QueryException {
         if(item == null) {
-          item = new ANode[iter.length];
-          for(int i = 0; i != iter.length; ++i) next(i);
+          final int il = iter.length;
+          item = new ANode[il];
+          for(int i = 0; i < il; i++) next(i);
         }
 
         int m = -1;
-        for(int i = 0; i != item.length; ++i) {
+        final int il = item.length;
+        for(int i = 0; i < il; i++) {
           if(item[i] == null) continue;
           final int d = m == -1 ? 1 : item[m].diff(item[i]);
           if(d == 0) {
