@@ -11,7 +11,7 @@ import org.basex.util.*;
 /**
  * An XQuery function call, either static or dynamic.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Leo Woerteler
  */
 public abstract class FuncCall extends Arr {
@@ -20,81 +20,80 @@ public abstract class FuncCall extends Arr {
 
   /**
    * Constructor.
-   * @param ii input info
-   * @param e sub-expressions
+   * @param info input info
+   * @param exprs sub-expressions
    */
-  FuncCall(final InputInfo ii, final Expr[] e) {
-    super(ii, e);
+  FuncCall(final InputInfo info, final Expr[] exprs) {
+    super(info, exprs);
   }
 
   /**
    * Evaluates and returns the function to be called.
-   * @param ctx query context
+   * @param qc query context
    * @return the function
    * @throws QueryException query exception
    */
-  abstract XQFunction evalFunc(final QueryContext ctx) throws QueryException;
+  abstract XQFunction evalFunc(final QueryContext qc) throws QueryException;
 
   /**
    * Evaluates and returns the arguments for this call.
-   * @param ctx query context
+   * @param qc query context
    * @return the function
    * @throws QueryException query exception
    */
-  abstract Value[] evalArgs(final QueryContext ctx) throws QueryException;
+  abstract Value[] evalArgs(final QueryContext qc) throws QueryException;
 
   @Override
-  public final void markTailCalls(final QueryContext ctx) {
-    if (ctx != null) ctx.compInfo(QueryText.OPTTCE, this);
+  public final void markTailCalls(final QueryContext qc) {
+    if(qc != null) qc.compInfo(QueryText.OPTTCE, this);
     tailCall = true;
   }
 
   @Override
-  public final Item item(final QueryContext ctx, final InputInfo ii) throws QueryException {
-    return tailCall ? (Item) invokeTail(evalFunc(ctx), evalArgs(ctx), true, ctx, info)
-                    : (Item) invoke(evalFunc(ctx), evalArgs(ctx), true, ctx, info);
+  public final Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
+    return (Item) (tailCall ? invokeTail(evalFunc(qc), evalArgs(qc), true, qc, info)
+                            : invoke(evalFunc(qc), evalArgs(qc), true, qc, info));
   }
 
   @Override
-  public final Value value(final QueryContext ctx) throws QueryException {
-    return tailCall ? invokeTail(evalFunc(ctx), evalArgs(ctx), false, ctx, info)
-                    : invoke(evalFunc(ctx), evalArgs(ctx), false, ctx, info);
+  public final Value value(final QueryContext qc) throws QueryException {
+    return tailCall ? invokeTail(evalFunc(qc), evalArgs(qc), false, qc, info)
+                    : invoke(evalFunc(qc), evalArgs(qc), false, qc, info);
   }
 
   @Override
-  public final Iter iter(final QueryContext ctx) throws QueryException {
-    return value(ctx).iter();
+  public final Iter iter(final QueryContext qc) throws QueryException {
+    return value(qc).iter();
   }
 
   /**
    * Calls the given function with the given arguments and takes care of tail-calls.
    * @param fun function to call
    * @param arg arguments for the call
-   * @param ctx query context
+   * @param qc query context
    * @param itm flag for requesting a single item
    * @param ii input info
    * @return result of the function call
    * @throws QueryException query exception
    */
   private static Value invoke(final XQFunction fun, final Value[] arg, final boolean itm,
-      final QueryContext ctx, final InputInfo ii) throws QueryException {
+      final QueryContext qc, final InputInfo ii) throws QueryException {
 
     XQFunction func = fun;
     Value[] args = arg;
-    final int fp = ctx.stack.enterFrame(func.stackFrameSize());
+    final int fp = qc.stack.enterFrame(func.stackFrameSize());
     try {
       while(true) {
-        final Value ret = itm ? func.invItem(ctx, ii, args) : func.invValue(ctx, ii, args);
-        func = ctx.pollTailCall();
+        final Value ret = itm ? func.invItem(qc, ii, args) : func.invValue(qc, ii, args);
+        func = qc.pollTailCall();
         if(func == null) return ret;
-        ctx.stack.reuseFrame(func.stackFrameSize());
-        args = ctx.pollTailArgs();
+        qc.stack.reuseFrame(func.stackFrameSize());
+        args = qc.pollTailArgs();
       }
     } catch(final QueryException ex) {
-      ex.add(ii);
-      throw ex;
+      throw ex.add(ii);
    } finally {
-      ctx.stack.exitFrame(fp);
+      qc.stack.exitFrame(fp);
     }
   }
 
@@ -102,32 +101,31 @@ public abstract class FuncCall extends Arr {
    * Tail-calls the given function with the given arguments.
    * @param fun function to call
    * @param arg arguments for the call
-   * @param ctx query context
+   * @param qc query context
    * @param itm flag for requesting a single item
    * @param ii input info
    * @return result of the function call
    * @throws QueryException query exception
    */
   private static Value invokeTail(final XQFunction fun, final Value[] arg, final boolean itm,
-      final QueryContext ctx, final InputInfo ii) throws QueryException {
+      final QueryContext qc, final InputInfo ii) throws QueryException {
 
-    final int calls = ctx.tailCalls, max = ctx.maxCalls;
+    final int calls = qc.tailCalls, max = qc.maxCalls;
     if(max >= 0 && calls >= max) {
       // there are at least `ctx.maxCalls` tail-calls on the stack, eliminate them
-      ctx.registerTailCall(fun, arg);
+      qc.registerTailCall(fun, arg);
       return itm ? null : Empty.SEQ;
     }
 
-    ctx.tailCalls++;
-    final int fp = ctx.stack.enterFrame(fun.stackFrameSize());
+    qc.tailCalls++;
+    final int fp = qc.stack.enterFrame(fun.stackFrameSize());
     try {
-      return itm ? fun.invItem(ctx, ii, arg) : fun.invValue(ctx, ii, arg);
+      return itm ? fun.invItem(qc, ii, arg) : fun.invValue(qc, ii, arg);
     } catch(final QueryException ex) {
-      ex.add(ii);
-      throw ex;
+      throw ex.add(ii);
     } finally {
-      ctx.tailCalls = calls;
-      ctx.stack.exitFrame(fp);
+      qc.tailCalls = calls;
+      qc.stack.exitFrame(fp);
     }
   }
 
@@ -136,14 +134,14 @@ public abstract class FuncCall extends Arr {
    * This method takes care of tail calls.
    * @param fun function to call
    * @param arg arguments to the function
-   * @param ctx query context
+   * @param qc query context
    * @param ii input info
    * @return the resulting item
    * @throws QueryException query exception
    */
-  public static Item item(final XQFunction fun, final Value[] arg,
-      final QueryContext ctx, final InputInfo ii) throws QueryException {
-    return (Item) invoke(fun, arg, true, ctx, ii);
+  public static Item item(final XQFunction fun, final Value[] arg, final QueryContext qc,
+      final InputInfo ii) throws QueryException {
+    return (Item) invoke(fun, arg, true, qc, ii);
   }
 
   /**
@@ -151,13 +149,13 @@ public abstract class FuncCall extends Arr {
    * This method takes care of tail calls.
    * @param fun function to call
    * @param arg arguments to the function
-   * @param ctx query context
+   * @param qc query context
    * @param ii input info
    * @return the resulting value
    * @throws QueryException query exception
    */
-  public static Value value(final XQFunction fun, final Value[] arg,
-      final QueryContext ctx, final InputInfo ii) throws QueryException {
-    return invoke(fun, arg, false, ctx, ii);
+  public static Value value(final XQFunction fun, final Value[] arg, final QueryContext qc,
+      final InputInfo ii) throws QueryException {
+    return invoke(fun, arg, false, qc, ii);
   }
 }
