@@ -1,7 +1,7 @@
 package org.basex.query.func;
 
+import static org.basex.query.QueryError.*;
 import static org.basex.query.QueryText.*;
-import static org.basex.query.util.Err.*;
 
 import java.lang.reflect.*;
 
@@ -18,14 +18,14 @@ import org.basex.util.hash.*;
 /**
  * Java function binding.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
-public final class JavaModuleFunc extends JavaMapping {
+final class JavaModuleFunc extends JavaMapping {
   /** Java module. */
   private final Object module;
   /** Method to be called. */
-  private final Method mth;
+  private final Method method;
   /** Method parameters. */
   private final Class<?>[] params;
   /** Indicates if function parameters are of (sub)class {@link Value}. */
@@ -33,62 +33,70 @@ public final class JavaModuleFunc extends JavaMapping {
 
   /**
    * Constructor.
-   * @param sctx static context
-   * @param ii input info
-   * @param jm Java module
-   * @param m Java method/field
-   * @param a arguments
+   * @param sc static context
+   * @param info input info
+   * @param module Java module
+   * @param method Java method/field
+   * @param args arguments
    */
-  JavaModuleFunc(final StaticContext sctx, final InputInfo ii, final Object jm, final Method m,
-      final Expr[] a) {
-    super(sctx, ii, a);
-    module = jm;
-    mth = m;
-    params = m.getParameterTypes();
+  JavaModuleFunc(final StaticContext sc, final InputInfo info, final Object module,
+      final Method method, final Expr[] args) {
+
+    super(sc, info, args);
+    this.module = module;
+    this.method = method;
+    params = method.getParameterTypes();
     vTypes = JavaFunc.values(params);
   }
 
   @Override
-  protected Object eval(final Value[] vals, final QueryContext ctx) throws QueryException {
+  public boolean isVacuous() {
+    return method.getReturnType() == Void.TYPE;
+  }
+
+  @Override
+  protected Object eval(final Value[] vals, final QueryContext qc) throws QueryException {
     // assign context if module is inheriting {@link QueryModule}
     if(module instanceof QueryModule) {
       final QueryModule mod = (QueryModule) module;
       mod.staticContext = sc;
-      mod.queryContext = ctx;
+      mod.queryContext = qc;
     }
 
     final Object[] args = JavaFunc.args(params, vTypes, vals, true);
     if(args != null) {
       try {
-        return mth.invoke(module, args);
+        return method.invoke(module, args);
       } catch(final Exception ex) {
         Throwable e = ex;
         if(e.getCause() != null) {
           Util.debug(e);
           e = e.getCause();
         }
-        throw e instanceof QueryException ? ((QueryException) e).info(info) : JAVAERR.get(info, e);
+        if(e instanceof QueryException) throw ((QueryException) e).info(info);
+        Util.stack(e);
+        throw JAVAERROR_X.get(info, Util.className(e) + ": " + e.getMessage());
       }
     }
 
     // compose error message: expected arguments
     final TokenBuilder expect = new TokenBuilder();
-    for(final Class<?> c : mth.getParameterTypes()) {
+    for(final Class<?> c : method.getParameterTypes()) {
       if(!expect.isEmpty()) expect.add(", ");
       expect.add(Util.className(c));
     }
-    throw JAVAMOD.get(info, mth.getName() + '(' + expect + ')',
-        mth.getName() + '(' + foundArgs(vals) + ')');
+    throw JAVAARGS_X_X.get(info, method.getName() + '(' + expect + ')',
+        method.getName() + '(' + foundArgs(vals) + ')');
   }
 
   @Override
-  public Expr copy(final QueryContext ctx, final VarScope scp, final IntObjMap<Var> vs) {
-    return new JavaModuleFunc(sc, info, module, mth, copyAll(ctx, scp, vs, expr));
+  public Expr copy(final QueryContext qc, final VarScope scp, final IntObjMap<Var> vs) {
+    return new JavaModuleFunc(sc, info, module, method, copyAll(qc, scp, vs, exprs));
   }
 
   @Override
   public void plan(final FElem plan) {
-    addPlan(plan, planElem(NAM, name()), expr);
+    addPlan(plan, planElem(NAM, name()), exprs);
   }
 
   @Override
@@ -101,19 +109,19 @@ public final class JavaModuleFunc extends JavaMapping {
    * @return string
    */
   private String name() {
-    return Util.className(module) + ':' + mth.getName();
+    return Util.className(module) + ':' + method.getName();
   }
 
   @Override
   public String toString() {
-    return name() + PAR1 + toString(SEP) + PAR2;
+    return name() + PAREN1 + toString(SEP) + PAREN2;
   }
 
   @Override
   public boolean has(final Flag f) {
-    return f == Flag.NDT && mth.getAnnotation(Deterministic.class) == null ||
-      (f == Flag.CTX || f == Flag.FCS) &&
-      mth.getAnnotation(FocusDependent.class) == null ||
+    return f == Flag.NDT && method.getAnnotation(Deterministic.class) == null ||
+      (f == Flag.CTX || f == Flag.POS) &&
+      method.getAnnotation(FocusDependent.class) == null ||
       super.has(f);
   }
 }
