@@ -4,12 +4,11 @@ import org.basex.query.*;
 import org.basex.query.value.*;
 import org.basex.query.value.item.*;
 import org.basex.query.value.seq.*;
-import org.basex.util.*;
 
 /**
  * Iterator interface.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public abstract class Iter {
@@ -23,8 +22,7 @@ public abstract class Iter {
   /**
    * Returns the specified item, or an arbitrary item if the index is invalid.
    * This method needs to be implemented - and should only be called - if
-   * {@link Iter#size()} returns the correct number of results. A calling method
-   * should call {@link #reset} after the last items has been retrieved.
+   * {@link Iter#size()} returns the correct number of results.
    * @param i value offset
    * @return specified item
    * @throws QueryException query exception
@@ -45,43 +43,21 @@ public abstract class Iter {
   }
 
   /**
-   * Resets the iterator and returns {@code true} if operation was successful.
-   * {@code false} is returned if the iterator cannot be reset.
-   * @return true if operator could be reset
-   */
-  public boolean reset() {
-    return false;
-  }
-
-  /**
-   * Returns a sequence with all iterator values.
+   * Returns a value with all iterated items.
    * Must only be called if {@link #next} has not been called before.
    * @return sequence
    * @throws QueryException query exception
    */
   public Value value() throws QueryException {
     // check if sequence is empty
-    Item i = next();
-    if(i == null) return Empty.SEQ;
+    final Item i1 = next();
+    if(i1 == null) return Empty.SEQ;
 
-    // if possible, allocate array with final size, and add all single items
-    Item[] item = new Item[Math.max(1, (int) size())];
-    int s = 0;
-    do {
-      if(s == item.length) item = extend(item);
-      item[s++] = i;
-    } while((i = next()) != null);
+    final Item i2 = next();
+    if(i2 == null) return i1;
 
-    // create final value
-    return Seq.get(item, s);
-  }
-
-  /**
-   * Doubles the size of an item array.
-   * @param it item array
-   * @return resulting array
-   */
-  static Item[] extend(final Item[] it) {
-    return Array.copy(it, new Item[Array.newSize(it.length)]);
+    final ValueBuilder vb = new ValueBuilder().add(i1).add(i2);
+    for(Item i; (i = next()) != null;) vb.add(i);
+    return vb.value();
   }
 }
