@@ -1,6 +1,6 @@
 package org.basex.query.up.primitives;
 
-import static org.basex.query.util.Err.*;
+import static org.basex.query.QueryError.*;
 import static org.basex.util.Token.*;
 
 import java.io.*;
@@ -9,7 +9,6 @@ import java.util.*;
 import org.basex.build.*;
 import org.basex.core.*;
 import org.basex.data.*;
-import org.basex.data.atomic.*;
 import org.basex.io.*;
 import org.basex.query.*;
 import org.basex.util.*;
@@ -17,19 +16,19 @@ import org.basex.util.*;
 /**
  * Contains helper methods for adding documents.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
-final class DBNew {
+public final class DBNew {
   /** Query context. */
   private final QueryContext qc;
   /** Input info. */
   private final InputInfo info;
 
   /** Inputs to add. */
-  List<NewInput> inputs;
+  public List<NewInput> inputs;
   /** Insertion sequence. */
-  Data md;
+  public Data data;
 
   /**
    * Constructor.
@@ -37,7 +36,7 @@ final class DBNew {
    * @param inputs input
    * @param info input info
    */
-  DBNew(final QueryContext qc, final List<NewInput> inputs, final InputInfo info) {
+  public DBNew(final QueryContext qc, final List<NewInput> inputs, final InputInfo info) {
     this.qc = qc;
     this.inputs = inputs;
     this.info = info;
@@ -45,15 +44,33 @@ final class DBNew {
 
   /**
    * Inserts all documents to be added to a temporary database.
-   * @param dt target database
+   * @param md temporary database
    * @param name name of database
+   * @param options database options
    * @throws QueryException query exception
    */
-  void addDocs(final MemData dt, final String name) throws QueryException {
-    md = dt;
+  public void addDocs(final MemData md, final String name, final DBOptions options)
+      throws QueryException {
+
+    final MainOptions opts = new MainOptions(qc.context.options);
+    options.assignTo(opts);
+    addDocs(new MemData(md, opts), name, opts);
+  }
+
+  /**
+   * Inserts all documents to be added to a temporary database.
+   * @param dt target database
+   * @param name name of database
+   * @param options main options
+   * @throws QueryException query exception
+   */
+  public void addDocs(final MemData dt, final String name, final MainOptions options)
+      throws QueryException {
+
+    data = dt;
     final long ds = inputs.size();
     for(int i = 0; i < ds; i++) {
-      md.insert(md.meta.size, -1, data(inputs.get(i), name));
+      data.insert(data.meta.size, -1, data(inputs.get(i), name, options));
       // clear list to recover memory
       inputs.set(i, null);
     }
@@ -64,26 +81,28 @@ final class DBNew {
    * Creates a {@link DataClip} instance for the specified document.
    * @param ni new database input
    * @param dbname name of database
+   * @param options main options
    * @return database clip
    * @throws QueryException query exception
    */
-  private DataClip data(final NewInput ni, final String dbname) throws QueryException {
+  private DataClip data(final NewInput ni, final String dbname, final MainOptions options)
+      throws QueryException {
+
     // add document node
     final Context ctx = qc.context;
     if(ni.node != null) {
-      final MemData mdata = (MemData) ni.node.dbCopy(ctx.options).data;
+      final MemData mdata = (MemData) ni.node.dbCopy(options).data();
       mdata.update(0, Data.DOC, ni.path);
       return new DataClip(mdata);
     }
 
     // add input
-    final IOFile dbpath = ctx.globalopts.dbpath(string(ni.dbname));
+    final IOFile dbpath = ctx.soptions.dbpath(string(ni.dbname));
     try {
-      final Parser p = new DirParser(ni.io, ctx, dbpath).target(string(ni.path));
-      final MemBuilder b = new MemBuilder(dbname, p);
-      return new DataClip(b.build());
+      final Parser parser = new DirParser(ni.io, options, dbpath).target(string(ni.path));
+      return new MemBuilder(dbname, parser).dataClip();
     } catch(final IOException ex) {
-      throw IOERR.get(info, ex);
+      throw IOERR_X.get(info, ex);
     }
   }
 }
