@@ -6,31 +6,31 @@ import org.basex.util.*;
 /**
  * Abstract class for an update operations.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Lukas Kircher
  */
 public abstract class Update {
   /** Type of update primitive. */
   public final UpdateType type;
   /** Input info. */
-  final InputInfo info;
+  protected final InputInfo info;
 
   /**
    * Constructor.
    * @param type update primitive
    * @param info input info
    */
-  Update(final UpdateType type, final InputInfo info) {
+  protected Update(final UpdateType type, final InputInfo info) {
     this.type = type;
     this.info = info;
   }
 
   /**
    * Merges two update operations pointing to the same target.
-   * @param p operation to merge with
+   * @param update operation to merge with
    * @throws QueryException exception
    */
-  public abstract void merge(final Update p) throws QueryException;
+  public abstract void merge(final Update update) throws QueryException;
 
   /**
    * Returns the number of update operations.
