@@ -5,12 +5,12 @@ import org.basex.util.list.*;
 /**
  * Jar descriptor.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Rositsa Shadura
  */
-public final class JarDesc {
+final class JarDesc {
   /** List of jar files. */
-  public final TokenList jars = new TokenList();
+  final TokenList jars = new TokenList();
   /** List of public classes. */
   final TokenList classes = new TokenList();
 }
