@@ -6,29 +6,28 @@ import org.basex.io.*;
 import org.basex.io.in.*;
 import org.basex.query.*;
 import org.basex.query.func.*;
-import org.basex.query.util.*;
 import org.basex.util.*;
 
 /**
  * Streamable base64 item ({@code xs:base64Binary}).
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class B64Stream extends B64 {
   /** File reference. */
   private final IO input;
   /** Error message. */
-  private final Err error;
+  private final QueryError error;
 
   /**
    * Constructor.
-   * @param in input
-   * @param err error message to be thrown
+   * @param input input
+   * @param error error message to be thrown
    */
-  public B64Stream(final IO in, final Err err) {
-    input = in;
-    error = err;
+  public B64Stream(final IO input, final QueryError error) {
+    this.input = input;
+    this.error = error;
   }
 
   @Override
@@ -50,7 +49,7 @@ public final class B64Stream extends B64 {
   }
 
   @Override
-  public Item materialize(final InputInfo ii) throws QueryException {
+  public B64 materialize(final InputInfo ii) throws QueryException {
     return new B64(binary(ii));
   }
 
