@@ -1,19 +1,19 @@
 package org.basex.query.value.item;
 
-import static org.basex.query.util.Err.*;
+import static org.basex.query.QueryError.*;
 
 import java.math.*;
 
 import org.basex.query.*;
 import org.basex.query.expr.*;
-import org.basex.query.util.*;
+import org.basex.query.util.collation.*;
 import org.basex.query.value.type.*;
 import org.basex.util.*;
 
 /**
  * Boolean item ({@code xs:boolean}).
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class Bln extends Item {
@@ -22,48 +22,49 @@ public final class Bln extends Item {
   /** Static boolean item without scoring. */
   public static final Bln FALSE = new Bln(false);
   /** Data. */
-  private final boolean val;
+  private final boolean value;
 
   /**
    * Constructor, adding a full-text score.
-   * @param b boolean value
+   * @param value boolean value
    */
-  private Bln(final boolean b) {
+  private Bln(final boolean value) {
     super(AtomType.BLN);
-    val = b;
+    this.value = value;
   }
 
   /**
    * Constructor, adding a full-text score.
-   * @param b boolean value
-   * @param s score value
+   * @param value boolean value
+   * @param score score value
    */
-  private Bln(final boolean b, final double s) {
-    this(b);
-    score = s;
+  private Bln(final boolean value, final double score) {
+    this(value);
+    this.score = score;
   }
 
   /**
    * Constructor, adding a full-text score.
-   * @param s score value
+   * @param value boolean value
+   * @param score score value
    * @return item
    */
-  public static Bln get(final double s) {
-    return s == 0 ? FALSE : new Bln(true, s);
+  public static Bln get(final boolean value, final double score) {
+    return value && score != 0 ? new Bln(true, score) : get(value);
   }
 
   /**
    * Returns a static item instance.
-   * @param b boolean value
+   * @param value boolean value
    * @return item
    */
-  public static Bln get(final boolean b) {
-    return b ? TRUE : FALSE;
+  public static Bln get(final boolean value) {
+    return value ? TRUE : FALSE;
   }
 
   @Override
   public byte[] string(final InputInfo ii) {
-    return Token.token(val);
+    return Token.token(value);
   }
 
   /**
@@ -71,73 +72,72 @@ public final class Bln extends Item {
    * @return string value
    */
   public byte[] string() {
-    return Token.token(val);
+    return Token.token(value);
   }
 
   @Override
   public boolean bool(final InputInfo ii) {
-    return val;
+    return value;
   }
 
   @Override
   public long itr(final InputInfo ii) {
-    return val ? 1 : 0;
+    return value ? 1 : 0;
   }
 
   @Override
   public float flt(final InputInfo ii) {
-    return val ? 1 : 0;
+    return value ? 1 : 0;
   }
 
   @Override
   public double dbl(final InputInfo ii) {
-    return val ? 1 : 0;
+    return value ? 1 : 0;
   }
 
   @Override
   public BigDecimal dec(final InputInfo ii) {
-    return val ? BigDecimal.ONE : BigDecimal.ZERO;
+    return value ? BigDecimal.ONE : BigDecimal.ZERO;
   }
 
   @Override
-  public boolean eq(final Item it, final Collation coll, final InputInfo ii)
+  public boolean eq(final Item it, final Collation coll, final StaticContext sc, final InputInfo ii)
       throws QueryException {
-    return val == (it.type == type ? it.bool(ii) : parse(it.string(ii), ii));
+    return value == (it.type == type ? it.bool(ii) : parse(it.string(ii), ii));
   }
 
   @Override
-  public int diff(final Item it, final Collation coll, final InputInfo ii)
-      throws QueryException {
+  public int diff(final Item it, final Collation coll, final InputInfo ii) throws QueryException {
     final boolean n = it.type == type ? it.bool(ii) : parse(it.string(ii), ii);
-    return val ? n ? 0 : 1 : n ? -1 : 0;
+    return value ? n ? 0 : 1 : n ? -1 : 0;
   }
 
   @Override
   public Boolean toJava() {
-    return val;
+    return value;
   }
 
   @Override
   public boolean sameAs(final Expr cmp) {
-    return cmp instanceof Bln && val == ((Bln) cmp).val;
-  }
-
-  /**
-   * Converts the specified string to a boolean.
-   * @param str string to be checked
-   * @param ii input info
-   * @return result of check
-   * @throws QueryException query exception
-   */
-  public static boolean parse(final byte[] str, final InputInfo ii) throws QueryException {
-    final byte[] s = Token.trim(str);
-    if(Token.eq(s, Token.TRUE) || Token.eq(s, Token.ONE)) return true;
-    if(Token.eq(s, Token.FALSE) || Token.eq(s, Token.ZERO)) return false;
-    throw FUNCAST.get(ii, AtomType.BLN, chop(str));
+    return cmp instanceof Bln && value == ((Bln) cmp).value;
   }
 
   @Override
   public String toString() {
-    return new TokenBuilder(val ? Token.TRUE : Token.FALSE).add("()").toString();
+    return new TokenBuilder(value ? Token.TRUE : Token.FALSE).add("()").toString();
+  }
+
+  /**
+   * Converts the specified string to a boolean.
+   * @param value string to be checked
+   * @param ii input info
+   * @return result of check
+   * @throws QueryException query exception
+   */
+  public static boolean parse(final byte[] value, final InputInfo ii) throws QueryException {
+    final byte[] v = Token.trim(value);
+    if(Token.eq(v, Token.TRUE) || Token.eq(v, Token.ONE)) return true;
+    if(Token.eq(v, Token.FALSE) || Token.eq(v, Token.ZERO)) return false;
+    throw funCastError(ii, AtomType.BLN, v);
   }
 }
