@@ -1,20 +1,20 @@
 package org.basex.query.value.item;
 
+import static org.basex.query.QueryError.*;
 import static org.basex.query.QueryText.*;
-import static org.basex.query.util.Err.*;
 
 import java.math.*;
 import java.util.regex.*;
 
 import org.basex.query.*;
-import org.basex.query.util.*;
+import org.basex.query.util.collation.*;
 import org.basex.query.value.type.*;
 import org.basex.util.*;
 
 /**
  * DayTime Duration item ({@code xs:dayTimeDuration}).
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class DTDur extends Dur {
@@ -24,21 +24,21 @@ public final class DTDur extends Dur {
 
   /**
    * Constructor.
-   * @param d duration item
+   * @param dur duration item
    */
-  public DTDur(final Dur d) {
+  public DTDur(final Dur dur) {
     super(AtomType.DTD);
-    sec = d.sec == null ? BigDecimal.ZERO : d.sec;
+    sec = dur.sec == null ? BigDecimal.ZERO : dur.sec;
   }
 
   /**
    * Timezone constructor.
-   * @param h hours
-   * @param m minutes
+   * @param hours hours
+   * @param minutes minutes
    */
-  public DTDur(final long h, final long m) {
+  public DTDur(final long hours, final long minutes) {
     super(AtomType.DTD);
-    sec = BigDecimal.valueOf(h).multiply(BD60).add(BigDecimal.valueOf(m)).multiply(BD60);
+    sec = BigDecimal.valueOf(hours).multiply(BD60).add(BigDecimal.valueOf(minutes)).multiply(BD60);
   }
 
   /**
@@ -52,46 +52,46 @@ public final class DTDur extends Dur {
 
   /**
    * Constructor.
-   * @param it duration item
-   * @param a duration to be added/subtracted
-   * @param p plus/minus flag
+   * @param dur duration item
+   * @param add duration to be added/subtracted
+   * @param plus plus/minus flag
    * @param ii input info
    * @throws QueryException query exception
    */
-  public DTDur(final DTDur it, final DTDur a, final boolean p, final InputInfo ii)
+  public DTDur(final DTDur dur, final DTDur add, final boolean plus, final InputInfo ii)
       throws QueryException {
 
-    this(it);
-    sec = p ? sec.add(a.sec) : sec.subtract(a.sec);
+    this(dur);
+    sec = plus ? sec.add(add.sec) : sec.subtract(add.sec);
     final double d = sec.doubleValue();
-    if(d <= Long.MIN_VALUE || d >= Long.MAX_VALUE) throw SECDURRANGE.get(ii, d);
+    if(d <= Long.MIN_VALUE || d >= Long.MAX_VALUE) throw SECDURRANGE_X.get(ii, d);
   }
 
   /**
    * Constructor.
-   * @param it duration item
-   * @param f factor
-   * @param m multiplication flag
+   * @param dur duration item
+   * @param factor factor
+   * @param mult multiplication flag
    * @param ii input info
    * @throws QueryException query exception
    */
-  public DTDur(final Dur it, final double f, final boolean m, final InputInfo ii)
+  public DTDur(final Dur dur, final double factor, final boolean mult, final InputInfo ii)
       throws QueryException {
 
-    this(it);
-    if(Double.isNaN(f)) throw DATECALC.get(ii, description(), f);
-    if(m ? Double.isInfinite(f) : f == 0) throw DATEZERO.get(ii, type);
-    if(m ? f == 0 : Double.isInfinite(f)) {
+    this(dur);
+    if(Double.isNaN(factor)) throw DATECALC_X_X.get(ii, description(), factor);
+    if(mult ? Double.isInfinite(factor) : factor == 0) throw DATEZERO_X_X.get(ii, type, factor);
+    if(mult ? factor == 0 : Double.isInfinite(factor)) {
       sec = BigDecimal.ZERO;
     } else {
-      BigDecimal d = BigDecimal.valueOf(f);
+      BigDecimal d = BigDecimal.valueOf(factor);
       try {
-        sec = m ? sec.multiply(d) : sec.divide(d);
+        sec = mult ? sec.multiply(d) : sec.divide(d);
       } catch(final ArithmeticException ex) {
         // catching cases in which a computation yields no exact result; eg:
         // xs:dayTimeDuration("P1D") div xs:double("-1.7976931348623157E308")
-        d = BigDecimal.valueOf(1 / f);
-        sec = m ? sec.divide(d) : sec.multiply(d);
+        d = BigDecimal.valueOf(1 / factor);
+        sec = mult ? sec.divide(d) : sec.multiply(d);
       }
     }
     if(Math.abs(sec.doubleValue()) < 1E-13) sec = BigDecimal.ZERO;
@@ -109,22 +109,22 @@ public final class DTDur extends Dur {
     sec = dat.days().subtract(sub.days()).multiply(DAYSECONDS).add(
         dat.seconds().subtract(sub.seconds()));
     final double d = sec.doubleValue();
-    if(d <= Long.MIN_VALUE || d >= Long.MAX_VALUE) throw SECRANGE.get(ii, d);
+    if(d <= Long.MIN_VALUE || d >= Long.MAX_VALUE) throw SECRANGE_X.get(ii, d);
   }
 
   /**
    * Constructor.
-   * @param vl value
+   * @param value value
    * @param ii input info
    * @throws QueryException query exception
    */
-  public DTDur(final byte[] vl, final InputInfo ii) throws QueryException {
+  public DTDur(final byte[] value, final InputInfo ii) throws QueryException {
     super(AtomType.DTD);
 
-    final String val = Token.string(vl).trim();
+    final String val = Token.string(value).trim();
     final Matcher mt = DUR.matcher(val);
-    if(!mt.matches() || val.endsWith("P") || val.endsWith("T")) throw dateError(vl, XDTD, ii);
-    dayTime(vl, mt, 2, ii);
+    if(!mt.matches() || val.endsWith("P") || val.endsWith("T")) throw dateError(value, XDTD, ii);
+    dayTime(value, mt, 2, ii);
   }
 
   /**
@@ -148,9 +148,8 @@ public final class DTDur extends Dur {
   }
 
   @Override
-  public int diff(final Item it, final Collation coll, final InputInfo ii)
-      throws QueryException {
-    if(it.type != type) throw diffError(ii, it, this);
-    return sec.subtract(((ADateDur) it).sec).signum();
+  public int diff(final Item it, final Collation coll, final InputInfo ii) throws QueryException {
+    if(it.type == type) return sec.subtract(((ADateDur) it).sec).signum();
+    throw diffError(ii, it, this);
   }
 }
