@@ -1,45 +1,45 @@
 package org.basex.query.value.item;
 
-import static org.basex.query.util.Err.*;
+import static org.basex.query.QueryError.*;
 
 import org.basex.query.*;
-import org.basex.query.util.*;
+import org.basex.query.util.collation.*;
 import org.basex.query.value.type.*;
 import org.basex.util.*;
 
 /**
  * HexBinary item ({@code xs:hexBinary}).
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class Hex extends Bin {
   /**
    * Constructor.
-   * @param b bytes
+   * @param value bytes
    */
-  public Hex(final byte[] b) {
-    super(b, AtomType.HEX);
+  public Hex(final byte[] value) {
+    super(value, AtomType.HEX);
   }
 
   /**
    * Constructor.
-   * @param v textual representation
+   * @param value textual representation
    * @param ii input info
    * @throws QueryException query exception
    */
-  public Hex(final byte[] v, final InputInfo ii) throws QueryException {
-    super(decode(Token.trim(v), ii), AtomType.HEX);
+  public Hex(final byte[] value, final InputInfo ii) throws QueryException {
+    super(decode(Token.trim(value), ii), AtomType.HEX);
   }
 
   /**
    * Constructor.
-   * @param b binary data
+   * @param bin binary data
    * @param ii input info
    * @throws QueryException query exception
    */
-  public Hex(final Bin b, final InputInfo ii) throws QueryException {
-    this(b.binary(ii));
+  public Hex(final Bin bin, final InputInfo ii) throws QueryException {
+    this(bin.binary(ii));
   }
 
   @Override
@@ -48,11 +48,19 @@ public final class Hex extends Bin {
   }
 
   @Override
-  public boolean eq(final Item it, final Collation coll, final InputInfo ii) throws QueryException {
+  public boolean eq(final Item it, final Collation coll, final StaticContext sc,
+      final InputInfo ii) throws QueryException {
     return Token.eq(binary(ii), it instanceof Bin ? ((Bin) it).binary(ii) :
       decode(it.string(ii), ii));
   }
 
+  @Override
+  public int diff(final Item it, final Collation coll, final InputInfo ii)
+      throws QueryException {
+    return Token.diff(binary(ii), it instanceof Bin ? ((Bin) it).binary(ii) :
+      decode(it.string(ii), ii));
+  }
+
   /**
    * Converts the input into a byte array.
    * @param d textual data
@@ -61,7 +69,7 @@ public final class Hex extends Bin {
    * @throws QueryException query exception
    */
   public static byte[] decode(final byte[] d, final InputInfo ii) throws QueryException {
-    if((d.length & 1) != 0) throw FUNCAST.get(ii, AtomType.HEX, (char) d[0]);
+    if((d.length & 1) != 0) throw funCastError(ii, AtomType.HEX, (char) d[0]);
     final int l = d.length >>> 1;
     final byte[] v = new byte[l];
     for(int i = 0; i < l; ++i) {
@@ -80,7 +88,7 @@ public final class Hex extends Bin {
   private static int dec(final byte b, final InputInfo ii) throws QueryException {
     if(b >= '0' && b <= '9') return b - '0';
     if(b >= 'a' && b <= 'f' || b >= 'A' && b <= 'F') return (b & 0x0F) + 9;
-    throw FUNCAST.get(ii, AtomType.HEX, (char) b);
+    throw funCastError(ii, AtomType.HEX, (char) b);
   }
 
   @Override
