@@ -1,12 +1,16 @@
 package org.basex.query.value.item;
 
-import static org.basex.query.util.Err.*;
+import static org.basex.query.QueryError.*;
 import static org.basex.util.Token.*;
 
+import java.util.regex.*;
+
 import javax.xml.namespace.*;
 
 import org.basex.query.*;
 import org.basex.query.util.*;
+import org.basex.query.util.collation.*;
+import org.basex.query.util.hash.*;
 import org.basex.query.value.type.*;
 import org.basex.util.*;
 import org.basex.util.list.*;
@@ -14,12 +18,16 @@ import org.basex.util.list.*;
 /**
  * QName item ({@code xs:QName}).
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class QNm extends Item {
+  /** URL pattern (matching Clark and EQName notation). */
+  private static final Pattern BIND = Pattern.compile("^((\"|')(.*?)\\2:|Q?(\\{(.*?)\\}))(.+)$");
+  /** Expanded QName pattern. */
+  private static final Pattern EQNAME = Pattern.compile("(Q\\{([^}]*)\\})?([^}]+)");
   /** Singleton instance. */
-  private static final QNmCache CACHE = new QNmCache();
+  private static final QNmMap CACHE = new QNmMap();
 
   /** Namespace URI. */
   private byte[] uri;
@@ -38,68 +46,112 @@ public final class QNm extends Item {
 
   /**
    * Constructor.
-   * @param n name
+   * @param name name
    */
-  public QNm(final byte[] n) {
+  public QNm(final byte[] name) {
     super(AtomType.QNM);
-    name = n;
-    pref = indexOf(n, ':');
+    this.name = name;
+    pref = indexOf(name, ':');
   }
 
   /**
    * Constructor.
-   * @param n name
+   * @param name name
    */
-  public QNm(final String n) {
-    this(token(n));
+  public QNm(final String name) {
+    this(token(name));
   }
 
   /**
    * Constructor.
-   * @param n name
-   * @param u namespace URI
+   * @param name name
+   * @param uri namespace URI
    */
-  public QNm(final byte[] n, final byte[] u) {
-    this(n);
-    uri(u);
+  public QNm(final byte[] name, final byte[] uri) {
+    this(name);
+    uri(uri);
   }
 
   /**
    * Constructor.
-   * @param n name
-   * @param u namespace URI
+   * @param name name
+   * @param uri namespace URI
    */
-  public QNm(final String n, final byte[] u) {
-    this(token(n), u);
+  public QNm(final String name, final byte[] uri) {
+    this(token(name), uri);
   }
 
   /**
    * Constructor.
-   * @param n name
-   * @param u namespace URI
+   * @param name name
+   * @param uri namespace URI
    */
-  public QNm(final String n, final String u) {
-    this(token(n), u == null ? null : token(u));
+  public QNm(final String name, final String uri) {
+    this(token(name), uri == null ? null : token(uri));
   }
 
   /**
    * Constructor, binding a statically known namespace.
    * If no namespace is found, the namespace uri is set to {@code null}.
-   * @param n name
+   * @param name name
    * @param sc static context
    */
-  public QNm(final byte[] n, final StaticContext sc) {
-    this(n);
+  public QNm(final byte[] name, final StaticContext sc) {
+    this(name);
     uri(sc.ns.uri(prefix()));
   }
 
   /**
    * Constructor for converting a Java QName.
-   * @param qn qname
+   * @param name qname
    */
-  public QNm(final QName qn) {
-    this(token(qn.getPrefix().isEmpty() ? qn.getLocalPart() :
-      qn.getPrefix() + ':' + qn.getLocalPart()), token(qn.getNamespaceURI()));
+  public QNm(final QName name) {
+    this(token(name.getPrefix().isEmpty() ? name.getLocalPart() :
+      name.getPrefix() + ':' + name.getLocalPart()), token(name.getNamespaceURI()));
+  }
+
+  /**
+   * Resolves a QName string.
+   * @param name name to resolve
+   * @param def default namespace (can be {@code null})
+   * @param sc static context (can be {@code null})
+   * @param info input info
+   * @return string
+   * @throws QueryException query exception
+   */
+  public static QNm resolve(final byte[] name, final byte[] def, final StaticContext sc,
+      final InputInfo info) throws QueryException {
+
+    // check for namespace declaration
+    final Matcher m = BIND.matcher(Token.string(name));
+    byte[] uri = null;
+    byte[] nm = name;
+    if(m.find()) {
+      final String u = m.group(3);
+      uri = token(u == null ? m.group(5) : u);
+      nm = token(m.group(6));
+    } else {
+      final int i = indexOf(nm, ':');
+      if(i == -1) {
+        uri = def;
+      } else {
+        if(sc != null) uri = sc.ns.uri(substring(nm, 0, i));
+        if(uri == null) throw NOURI_X.get(info, name);
+      }
+    }
+    if(!XMLToken.isQName(nm)) throw BINDNAME_X.get(info, name);
+    return new QNm(nm, uri);
+  }
+
+  /**
+   * Resolves an expanded QName string.
+   * @param name string
+   * @return resulting QName, or {@code null}
+   */
+  public static QNm resolve(final byte[] name) {
+    final Matcher m = EQNAME.matcher(Token.string(name));
+    return m.matches() ? new QNm(m.group(3), m.group(1) == null ||
+        m.group(2).isEmpty() ? null : m.group(2)) : null;
   }
 
   /**
@@ -107,7 +159,7 @@ public final class QNm extends Item {
    * @param u the uri to be set
    */
   public void uri(final byte[] u) {
-    uri = u == null ? null : norm(u);
+    uri = u == null ? null : normalize(u);
   }
 
   /**
@@ -140,10 +192,19 @@ public final class QNm extends Item {
   }
 
   @Override
-  public boolean eq(final Item it, final Collation coll, final InputInfo ii)
-      throws QueryException {
-    if(it instanceof QNm) return eq((QNm) it);
-    throw INVTYPECMP.get(ii, it.type, type);
+  public boolean eq(final Item item, final Collation coll, final StaticContext sc,
+      final InputInfo ii) throws QueryException {
+
+    final QNm nm;
+    if(item instanceof QNm) {
+      nm = (QNm) item;
+    } else if(item.type.isUntyped() && sc != null) {
+      nm = new QNm(item.string(ii), sc);
+      if(!nm.hasURI() && nm.hasPrefix()) throw NSDECL_X.get(ii, nm.string());
+    } else {
+      throw diffError(ii, this, item);
+    }
+    return eq(nm);
   }
 
   /**
@@ -209,6 +270,14 @@ public final class QNm extends Item {
     return uri == null ? name : internal(null, local(), uri);
   }
 
+  /**
+   * Returns a unique representation of the QName.
+   * @return unique representation
+   */
+  public byte[] prefixId() {
+    return prefixId(null);
+  }
+
   /**
    * Returns a unique representation of the QName.
    * <ul>
@@ -216,13 +285,13 @@ public final class QNm extends Item {
    *   <li> Uses a prefix if its namespace URI is statically known.</li>
    *   <li> Otherwise, {@link #id()} is called.</li>
    * </ul>
-   * @param ns default uri (optional)
+   * @param ns default uri (can be {@code null})
    * @return unique representation
    */
   public byte[] prefixId(final byte[] ns) {
-    if(Token.eq(uri(), ns)) return local();
+    if(ns != null && Token.eq(uri(), ns)) return local();
     final byte[] p = NSGlobal.prefix(uri());
-    return p.length == 0 ? id() : concat(p, token(":"), local());
+    return p.length == 0 ? id() : Token.concat(p, token(":"), local());
   }
 
   @Override
@@ -237,7 +306,7 @@ public final class QNm extends Item {
 
   @Override
   public byte[] xdmInfo() {
-    return new ByteList().add(typeId().bytes()).add(uri()).add(0).toArray();
+    return new ByteList().add(typeId().bytes()).add(uri()).add(0).finish();
   }
 
   @Override
@@ -247,7 +316,7 @@ public final class QNm extends Item {
 
   @Override
   public boolean equals(final Object obj) {
-    return obj.getClass() == QNm.class && eq((QNm) obj);
+    return obj instanceof QNm && eq((QNm) obj);
   }
 
   @Override
@@ -300,8 +369,8 @@ public final class QNm extends Item {
    * @param uri namespace uri
    * @return instance
    */
-  public static QNm get(final String prefix, final String local, final byte[] uri) {
-    return CACHE.index(token(prefix), token(local), uri);
+  public static QNm get(final byte[] prefix, final String local, final byte[] uri) {
+    return CACHE.index(prefix, token(local), uri);
   }
 
   /**
