@@ -1,7 +1,7 @@
 package org.basex.query.value.map;
 
 import org.basex.query.*;
-import org.basex.query.iter.*;
+import org.basex.query.util.collation.*;
 import org.basex.query.value.*;
 import org.basex.query.value.item.*;
 import org.basex.query.value.type.*;
@@ -10,7 +10,7 @@ import org.basex.util.*;
 /**
  * Inner node of a {@link Map}.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Leo Woerteler
  */
 final class Branch extends TrieNode {
@@ -21,14 +21,14 @@ final class Branch extends TrieNode {
 
   /**
    * Constructor taking children array and the size of this map.
-   * @param ch children
-   * @param u bit array
-   * @param s size of this node
+   * @param kids children
+   * @param used bit array
+   * @param size size of this node
    */
-  Branch(final TrieNode[] ch, final int u, final int s) {
-    super(s);
-    kids = ch;
-    used = u;
+  Branch(final TrieNode[] kids, final int used, final int size) {
+    super(size);
+    this.kids = kids;
+    this.used = used;
     assert verify();
   }
 
@@ -45,13 +45,13 @@ final class Branch extends TrieNode {
   }
 
   @Override
-  TrieNode insert(final int h, final Item k, final Value v, final int l,
-      final InputInfo ii) throws QueryException {
+  TrieNode put(final int h, final Item k, final Value v, final int l, final InputInfo ii)
+      throws QueryException {
     final int key = key(h, l);
     final TrieNode sub = kids[key], nsub;
     final int bs, rem;
     if(sub != null) {
-      nsub = sub.insert(h, k, v, l + 1, ii);
+      nsub = sub.put(h, k, v, l + 1, ii);
       if(nsub == sub) return this;
       bs = used;
       rem = sub.size;
@@ -165,15 +165,16 @@ final class Branch extends TrieNode {
   TrieNode add(final Branch o, final int l, final InputInfo ii) throws QueryException {
     TrieNode[] ch = null;
     int nu = used, ns = size;
-    for(int i = 0; i < kids.length; i++) {
-      final TrieNode k = kids[i], ok = o.kids[i];
+    final int kl = kids.length;
+    for(int k = 0; k < kl; k++) {
+      final TrieNode n = kids[k], ok = o.kids[k];
       if(ok != null) {
-        final TrieNode nw = k == null ? ok : ok.addAll(k, l + 1, ii);
-        if(nw != k) {
+        final TrieNode nw = n == null ? ok : ok.addAll(n, l + 1, ii);
+        if(nw != n) {
           if(ch == null) ch = copyKids();
-          ch[i] = nw;
-          nu |= 1 << i;
-          ns += nw.size - (k == null ? 0 : k.size);
+          ch[k] = nw;
+          nu |= 1 << k;
+          ns += nw.size - (n == null ? 0 : n.size);
         }
       }
     }
@@ -196,6 +197,17 @@ final class Branch extends TrieNode {
     for(final TrieNode nd : kids) if(nd != null) nd.keys(ks);
   }
 
+  @Override
+  void values(final ValueBuilder vs) {
+    for(final TrieNode nd : kids) if(nd != null) nd.values(vs);
+  }
+
+  @Override
+  void apply(final ValueBuilder vb, final FItem func, final QueryContext qc, final InputInfo ii)
+      throws QueryException {
+    for(final TrieNode nd : kids) if(nd != null) nd.apply(vb, func, qc, ii);
+  }
+
   @Override
   boolean hasType(final AtomType kt, final SeqType vt) {
     for(final TrieNode k : kids)
@@ -211,7 +223,7 @@ final class Branch extends TrieNode {
   }
 
   @Override
-  boolean deep(final InputInfo ii, final TrieNode o) throws QueryException {
+  boolean deep(final InputInfo ii, final TrieNode o, final Collation coll) throws QueryException {
     if(!(o instanceof Branch)) return false;
     final Branch ob = (Branch) o;
 
@@ -220,7 +232,7 @@ final class Branch extends TrieNode {
 
     // recursively compare children
     for(int i = 0; i < KIDS; i++)
-      if(kids[i] != null && !kids[i].deep(ii, ob.kids[i])) return false;
+      if(kids[i] != null && !kids[i].deep(ii, ob.kids[i], coll)) return false;
 
     // everything OK
     return true;
