@@ -1,7 +1,7 @@
 package org.basex.query.value.map;
 
 import org.basex.query.*;
-import org.basex.query.iter.*;
+import org.basex.query.util.collation.*;
 import org.basex.query.value.*;
 import org.basex.query.value.item.*;
 import org.basex.query.value.type.*;
@@ -10,7 +10,7 @@ import org.basex.util.*;
 /**
  * A single binding of a {@link Map}.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Leo Woerteler
  */
 final class Leaf extends TrieNode {
@@ -23,31 +23,30 @@ final class Leaf extends TrieNode {
 
   /**
    * Constructor.
-   * @param h hash code of the key
-   * @param k key
-   * @param v value
+   * @param hash hash code of the key
+   * @param key key
+   * @param value value
    */
-  Leaf(final int h, final Item k, final Value v) {
+  Leaf(final int hash, final Item key, final Value value) {
     super(1);
-    hash = h;
-    key = k;
-    value = v;
+    this.hash = hash;
+    this.key = key;
+    this.value = value;
     assert verify();
   }
 
   @Override
-  TrieNode insert(final int h, final Item k, final Value v, final int l,
-      final InputInfo ii) throws QueryException {
+  TrieNode put(final int h, final Item k, final Value v, final int l, final InputInfo ii)
+      throws QueryException {
     // same hash, replace or merge
-    if(h == hash) return eq(k, key, ii) ?
-        new Leaf(h, k, v) : new List(hash, key, value, k, v);
+    if(h == hash) return eq(k, key, ii) ? new Leaf(h, k, v) : new List(hash, key, value, k, v);
 
     // different hash, branch
     final TrieNode[] ch = new TrieNode[KIDS];
     final int a = key(h, l), b = key(hash, l);
     final int used;
     if(a == b) {
-      ch[a] = insert(h, k, v, l + 1, ii);
+      ch[a] = put(h, k, v, l + 1, ii);
       used = 1 << a;
     } else {
       ch[a] = new Leaf(h, k, v);
@@ -76,8 +75,7 @@ final class Leaf extends TrieNode {
 
   @Override
   StringBuilder toString(final StringBuilder sb, final String ind) {
-    return sb.append(ind).append("`-- ").append(key).append(
-        " => ").append(value).append('\n');
+    return sb.append(ind).append("`-- ").append(key).append(" => ").append(value).append('\n');
   }
 
   @Override
@@ -91,8 +89,7 @@ final class Leaf extends TrieNode {
         this : new List(hash, key, value, o.key, o.value);
 
     final TrieNode[] ch = new TrieNode[KIDS];
-    final int k = key(hash, l), ok = key(o.hash, l);
-    final int nu;
+    final int k = key(hash, l), ok = key(o.hash, l), nu;
 
     // same key? add recursively
     if(k == ok) {
@@ -103,7 +100,6 @@ final class Leaf extends TrieNode {
       ch[ok] = o;
       nu = 1 << k | 1 << ok;
     }
-
     return new Branch(ch, nu, 2);
   }
 
@@ -136,7 +132,6 @@ final class Leaf extends TrieNode {
       ch[ok] = o;
       nu = 1 << k | 1 << ok;
     }
-
     return new Branch(ch, nu, o.size + 1);
   }
 
@@ -146,8 +141,7 @@ final class Leaf extends TrieNode {
     final TrieNode[] ch = o.copyKids();
     final TrieNode old = ch[k];
     ch[k] = old == null ? this : old.addAll(this, l + 1, ii);
-    return new Branch(ch, o.used | 1 << k,
-        o.size + ch[k].size - (old != null ? old.size : 0));
+    return new Branch(ch, o.used | 1 << k, o.size + ch[k].size - (old != null ? old.size : 0));
   }
 
   @Override
@@ -165,15 +159,25 @@ final class Leaf extends TrieNode {
   }
 
   @Override
-  boolean hasType(final AtomType kt, final SeqType vt) {
-    return (kt == null || key.type.instanceOf(kt))
-        && (vt == null || vt.instance(value));
+  void values(final ValueBuilder vs) {
+    vs.add(value);
   }
 
   @Override
-  boolean deep(final InputInfo ii, final TrieNode o) throws QueryException {
-    return o instanceof Leaf && eq(key, ((Leaf) o).key, ii)
-        && deep(value, ((Leaf) o).value, ii);
+  void apply(final ValueBuilder vb, final FItem func, final QueryContext qc, final InputInfo ii)
+      throws QueryException {
+    vb.add(func.invokeValue(qc, ii, key, value));
+  }
+
+  @Override
+  boolean hasType(final AtomType kt, final SeqType vt) {
+    return (kt == null || key.type.instanceOf(kt)) && (vt == null || vt.instance(value));
+  }
+
+  @Override
+  boolean deep(final InputInfo ii, final TrieNode o, final Collation coll) throws QueryException {
+    return o instanceof Leaf && eq(key, ((Leaf) o).key, ii) &&
+        deep(value, ((Leaf) o).value, coll, ii);
   }
 
   @Override
