@@ -3,8 +3,9 @@ package org.basex.query.value.node;
 import static org.basex.query.QueryText.*;
 
 import org.basex.query.iter.*;
-import org.basex.query.util.*;
+import org.basex.query.util.list.*;
 import org.basex.query.value.type.*;
+import org.basex.query.value.type.Type.ID;
 import org.basex.util.*;
 import org.basex.util.hash.*;
 import org.basex.util.list.*;
@@ -13,14 +14,14 @@ import org.w3c.dom.*;
 /**
  * Document node fragment.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class FDoc extends FNode {
   /** Child nodes. */
   private final ANodeList children;
   /** Base URI. */
-  private final byte[] base;
+  private final byte[] uri;
 
   /**
    * Constructor.
@@ -31,31 +32,31 @@ public final class FDoc extends FNode {
 
   /**
    * Constructor.
-   * @param b base uri
+   * @param uri base uri
    */
-  public FDoc(final String b) {
-    this(Token.token(b));
+  public FDoc(final String uri) {
+    this(Token.token(uri));
   }
 
   /**
    * Constructor.
-   * @param b base uri
+   * @param uri base uri
    */
-  public FDoc(final byte[] b) {
-    this(new ANodeList(), b);
+  public FDoc(final byte[] uri) {
+    this(new ANodeList(), uri);
   }
 
   /**
    * Constructor.
-   * @param ch children
-   * @param b base uri
+   * @param children children
+   * @param uri base uri
    */
-  public FDoc(final ANodeList ch, final byte[] b) {
+  public FDoc(final ANodeList children, final byte[] uri) {
     super(NodeType.DOC);
-    children = ch;
-    base = b;
+    this.children = children;
+    this.uri = uri;
     // update parent references
-    for(final ANode n : ch) n.parent(this);
+    for(final ANode n : children) n.parent(this);
   }
 
   @Override
@@ -95,7 +96,7 @@ public final class FDoc extends FNode {
   }
 
   @Override
-  public AxisMoreIter children() {
+  public BasicNodeIter children() {
     return iter(children);
   }
 
@@ -106,26 +107,26 @@ public final class FDoc extends FNode {
 
   @Override
   public byte[] baseURI() {
-    return base;
+    return uri;
   }
 
   @Override
   public FDoc copy() {
-    return new FDoc(children, base).optimize();
+    return new FDoc(children, uri).optimize();
   }
 
   @Override
   public void plan(final FElem plan) {
-    addPlan(plan, planElem(BASE, base));
+    addPlan(plan, planElem(BASE, uri));
   }
 
   @Override
   public byte[] xdmInfo() {
-    return new ByteList().add(typeId().bytes()).add(base).add(0).toArray();
+    return new ByteList().add(typeId().bytes()).add(uri).add(0).finish();
   }
 
   @Override
-  public Type.ID typeId() {
+  public ID typeId() {
     // check if a document has a single element as child
     return children.size() == 1 && children.get(0).type == NodeType.ELM ?
       NodeType.DEL.id() : type.id();
@@ -133,6 +134,6 @@ public final class FDoc extends FNode {
 
   @Override
   public String toString() {
-    return Util.info("%(%)", type, base);
+    return Util.info("%(%)", type, uri);
   }
 }
