@@ -1,25 +1,26 @@
 package org.basex.query.value.node;
 
 import org.basex.data.*;
+import org.basex.query.util.ft.*;
 
 /**
  * Database node with full-text positions.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class FTPosNode extends DBNode {
   /** Full-text positions. */
-  public final FTPosData ft;
+  public final FTPosData ftpos;
 
   /**
    * Constructor, called by the sequential variant.
-   * @param d data reference
-   * @param p pre value
+   * @param data data reference
+   * @param pre pre value
    * @param ftpos full-text positions
    */
-  public FTPosNode(final Data d, final int p, final FTPosData ftpos) {
-    super(d, p);
-    ft = ftpos;
+  public FTPosNode(final Data data, final int pre, final FTPosData ftpos) {
+    super(data, pre);
+    this.ftpos = ftpos;
   }
 }
