@@ -12,7 +12,7 @@ import org.basex.query.value.type.*;
 /**
  * Sequence of items of type {@link Int xs:decimal}, containing at least two of them.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class DecSeq extends NativeSeq {
@@ -21,11 +21,11 @@ public final class DecSeq extends NativeSeq {
 
   /**
    * Constructor.
-   * @param vals bytes
+   * @param values bytes
    */
-  private DecSeq(final BigDecimal[] vals) {
-    super(vals.length, AtomType.DEC);
-    values = vals;
+  private DecSeq(final BigDecimal[] values) {
+    super(values.length, AtomType.DEC);
+    this.values = values;
   }
 
   @Override
@@ -43,14 +43,6 @@ public final class DecSeq extends NativeSeq {
     return values;
   }
 
-  @Override
-  public Value reverse() {
-    final int s = values.length;
-    final BigDecimal[] tmp = new BigDecimal[s];
-    for(int l = 0, r = s - 1; l < s; l++, r--) tmp[l] = values[r];
-    return get(tmp);
-  }
-
   // STATIC METHODS =====================================================================
 
   /**
@@ -59,26 +51,24 @@ public final class DecSeq extends NativeSeq {
    * @return value
    */
   private static Value get(final BigDecimal[] items) {
-    return items.length == 0 ? Empty.SEQ : items.length == 1 ?
-        Dec.get(items[0]) : new DecSeq(items);
+    return items.length == 0 ? Empty.SEQ : items.length == 1 ? Dec.get(items[0]) :
+      new DecSeq(items);
   }
 
   /**
    * Creates a sequence with the items in the specified expressions.
-   * @param vals values
+   * @param values values
    * @param size size of resulting sequence
    * @return value
    * @throws QueryException query exception
    */
-  public static Value get(final Value[] vals, final int size) throws QueryException {
+  public static Value get(final Value[] values, final int size) throws QueryException {
     final BigDecimal[] tmp = new BigDecimal[size];
     int t = 0;
-    for(final Value val : vals) {
+    for(final Value val : values) {
       // speed up construction, depending on input
       final int vs = (int) val.size();
-      if(val instanceof Item) {
-        tmp[t++] = ((Item) val).dec(null);
-      } else if(val instanceof DecSeq) {
+      if(val instanceof DecSeq) {
         final DecSeq sq = (DecSeq) val;
         System.arraycopy(sq.values, 0, tmp, t, vs);
         t += vs;
