@@ -13,7 +13,7 @@ import org.basex.util.*;
 /**
  * Empty sequence.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class Empty extends Value {
@@ -25,7 +25,6 @@ public final class Empty extends Value {
     @Override public Item get(final long i) { return null; }
     @Override public Value value() { return SEQ; }
     @Override public long size() { return 0; }
-    @Override public boolean reset() { return true; }
   };
 
   /**
@@ -61,22 +60,22 @@ public final class Empty extends Value {
   }
 
   @Override
-  public Item item(final QueryContext ctx, final InputInfo ii) {
+  public Item item(final QueryContext qc, final InputInfo ii) {
     return null;
   }
 
   @Override
-  public Item ebv(final QueryContext ctx, final InputInfo ii) {
+  public Item ebv(final QueryContext qc, final InputInfo ii) {
     return Bln.FALSE;
   }
 
   @Override
-  public Item test(final QueryContext ctx, final InputInfo ii) {
+  public Item test(final QueryContext qc, final InputInfo ii) {
     return null;
   }
 
   @Override
-  public SeqType type() {
+  public SeqType seqType() {
     return SeqType.EMP;
   }
 
@@ -85,27 +84,13 @@ public final class Empty extends Value {
     return true;
   }
 
-  @Override
-  public void plan(final FElem plan) {
-    addPlan(plan, planElem(SIZE, 0));
-  }
-
   @Override
   public int hash(final InputInfo ii) {
     return 0;
   }
-  @Override
-  public String description() {
-    return EMPTY_SEQUENCE + "()";
-  }
 
   @Override
-  public String toString() {
-    return "()";
-  }
-
-  @Override
-  public int writeTo(final Item[] arr, final int start) {
+  public int writeTo(final Item[] arr, final int index) {
     return 0;
   }
 
@@ -114,8 +99,53 @@ public final class Empty extends Value {
     throw Util.notExpected();
   }
 
+  @Override
+  public Value reverse() {
+    return this;
+  }
+
   @Override
   public boolean homogeneous() {
     return true;
   }
+
+  @Override
+  public Value subSeq(final long start, final long len) {
+    return this;
+  }
+
+  @Override
+  public Value materialize(final InputInfo ii) {
+    return this;
+  }
+
+  @Override
+  public Value atomValue(final InputInfo ii) {
+    return this;
+  }
+
+  @Override
+  public Item atomItem(final QueryContext qc, final InputInfo ii) {
+    return null;
+  }
+
+  @Override
+  public long atomSize() {
+    return 0;
+  }
+
+  @Override
+  public void plan(final FElem plan) {
+    addPlan(plan, planElem(SIZE, 0));
+  }
+
+  @Override
+  public String description() {
+    return EMPTY_SEQUENCE + "()";
+  }
+
+  @Override
+  public String toString() {
+    return "()";
+  }
 }
