@@ -1,7 +1,7 @@
 package org.basex.query.value.seq;
 
+import static org.basex.query.QueryError.*;
 import static org.basex.query.QueryText.*;
-import static org.basex.query.util.Err.*;
 
 import org.basex.query.*;
 import org.basex.query.expr.*;
@@ -15,7 +15,7 @@ import org.basex.util.*;
 /**
  * Range sequence, containing at least two integers.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class RangeSeq extends Seq {
@@ -26,25 +26,41 @@ public final class RangeSeq extends Seq {
 
   /**
    * Constructor.
-   * @param s start value
-   * @param sz size
-   * @param a ascending
+   * @param start start value
+   * @param size size
+   * @param asc ascending
    */
-  private RangeSeq(final long s, final long sz, final boolean a) {
-    super(sz, AtomType.ITR);
-    start = s;
-    asc = a;
+  private RangeSeq(final long start, final long size, final boolean asc) {
+    super(size, AtomType.ITR);
+    this.start = start;
+    this.asc = asc;
   }
 
   /**
    * Returns a value representation of the specified items.
    * @param min minimum value
-   * @param sz size
+   * @param size size
    * @param asc ascending
    * @return resulting item or sequence
    */
-  public static Value get(final long min, final long sz, final boolean asc) {
-    return sz < 1 ? Empty.SEQ : sz == 1 ? Int.get(min) : new RangeSeq(min, sz, asc);
+  public static Value get(final long min, final long size, final boolean asc) {
+    return size < 1 ? Empty.SEQ : size == 1 ? Int.get(min) : new RangeSeq(min, size, asc);
+  }
+
+  /**
+   * Returns the first value.
+   * @return start value
+   */
+  public long start() {
+    return start;
+  }
+
+  /**
+   * Returns the last value.
+   * @return end value
+   */
+  public long end() {
+    return asc ? start + size - 1 : start - size + 1;
   }
 
   @Override
@@ -55,25 +71,25 @@ public final class RangeSeq extends Seq {
   }
 
   @Override
-  public Item ebv(final QueryContext ctx, final InputInfo ii) throws QueryException {
-    throw CONDTYPE.get(ii, this);
+  public Item ebv(final QueryContext qc, final InputInfo ii) throws QueryException {
+    throw EBV_X.get(ii, this);
   }
 
   @Override
-  public SeqType type() {
+  public SeqType seqType() {
     return SeqType.ITR_OM;
   }
 
   @Override
   public boolean sameAs(final Expr cmp) {
     if(!(cmp instanceof RangeSeq)) return false;
-    final RangeSeq is = (RangeSeq) cmp;
-    return start == is.start && size == is.size && asc == is.asc;
+    final RangeSeq rs = (RangeSeq) cmp;
+    return start == rs.start && size == rs.size && asc == rs.asc;
   }
 
   @Override
-  public int writeTo(final Item[] arr, final int pos) {
-    for(int i = 0; i < size; i++) arr[pos + i] = itemAt(i);
+  public int writeTo(final Item[] arr, final int index) {
+    for(int i = 0; i < size; i++) arr[index + i] = itemAt(i);
     return (int) size;
   }
 
@@ -82,12 +98,37 @@ public final class RangeSeq extends Seq {
     return Int.get(start + (asc ? pos : -pos));
   }
 
+  @Override
+  public Value insert(final long pos, final Item item) {
+    return copyInsert(pos, item);
+  }
+
+  @Override
+  public Value remove(final long pos) {
+    return pos == 0 || pos == size - 1 ? subSeq(pos == 0 ? 0 : 1, size - 1) : copyRemove(pos);
+  }
+
   @Override
   public Value reverse() {
     final long s = size();
     return asc ? get(start + s - 1, s, false) : get(start - s + 1, s, true);
   }
 
+  @Override
+  public Value materialize(final InputInfo ii) {
+    return this;
+  }
+
+  @Override
+  public Value atomValue(final InputInfo ii) {
+    return this;
+  }
+
+  @Override
+  public long atomSize() {
+    return size;
+  }
+
   @Override
   public boolean homogeneous() {
     return true;
@@ -95,16 +136,14 @@ public final class RangeSeq extends Seq {
 
   @Override
   public void plan(final FElem plan) {
-    final long s = start;
-    final long e = asc ? start + size - 1 : start - size + 1;
-    addPlan(plan, planElem(FROM, s, TO, e));
+    addPlan(plan, planElem(FROM, start(), TO, end()));
   }
 
   @Override
   public String toString() {
     final long s = asc ? start : start - size + 1;
     final long e = asc ? start + size - 1 : start;
-    final String str = PAR1 + s + ' ' + TO + ' ' + e + PAR2;
+    final String str = PAREN1 + s + ' ' + TO + ' ' + e + PAREN2;
     return asc ? str : Function.REVERSE.args(str);
   }
 }
