@@ -1,6 +1,6 @@
 package org.basex.query.value.type;
 
-import static org.basex.query.util.Err.*;
+import static org.basex.query.QueryError.*;
 
 import java.io.*;
 import java.util.regex.*;
@@ -11,7 +11,6 @@ import org.basex.build.xml.*;
 import org.basex.core.*;
 import org.basex.io.*;
 import org.basex.query.*;
-import org.basex.query.util.*;
 import org.basex.query.value.item.*;
 import org.basex.query.value.node.*;
 import org.basex.util.*;
@@ -22,7 +21,7 @@ import org.w3c.dom.Text;
 /**
  * XQuery node types.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Leo Woerteler
  */
 public enum NodeType implements Type {
@@ -32,38 +31,38 @@ public enum NodeType implements Type {
   /** Text type. */
   TXT("text", NOD, ID.TXT) {
     @Override
-    public ANode cast(final Object o, final QueryContext ctx, final StaticContext sc,
+    public ANode cast(final Object value, final QueryContext qc, final StaticContext sc,
         final InputInfo ii) {
-      if(o instanceof BXText) return ((BXNode) o).getNode();
-      if(o instanceof Text) return new FTxt((Text) o);
-      return new FTxt(o.toString());
+      if(value instanceof BXText) return ((BXNode) value).getNode();
+      if(value instanceof Text) return new FTxt((Text) value);
+      return new FTxt(value.toString());
     }
   },
 
   /** PI type. */
   PI("processing-instruction", NOD, ID.PI) {
     @Override
-    public ANode cast(final Object o, final QueryContext ctx, final StaticContext sc,
+    public ANode cast(final Object value, final QueryContext qc, final StaticContext sc,
         final InputInfo ii) throws QueryException {
-      if(o instanceof BXPI) return ((BXNode) o).getNode();
-      if(o instanceof ProcessingInstruction) return new FPI((ProcessingInstruction) o);
-      final Matcher m = Pattern.compile("<\\?(.*?) (.*)\\?>").matcher(o.toString());
+      if(value instanceof BXPI) return ((BXNode) value).getNode();
+      if(value instanceof ProcessingInstruction) return new FPI((ProcessingInstruction) value);
+      final Matcher m = Pattern.compile("<\\?(.*?) (.*)\\?>").matcher(value.toString());
       if(m.find()) return new FPI(m.group(1), m.group(2));
-      throw NODEERR.get(ii, this, chop(o));
+      throw NODEERR_X_X.get(ii, this, chop(value, ii));
     }
   },
 
   /** Element type. */
   ELM("element", NOD, ID.ELM) {
     @Override
-    public ANode cast(final Object o, final QueryContext ctx, final StaticContext sc,
+    public ANode cast(final Object value, final QueryContext qc, final StaticContext sc,
         final InputInfo ii) throws QueryException {
-      if(o instanceof BXElem)  return ((BXNode) o).getNode();
-      if(o instanceof Element) return new FElem((Element) o, null, new TokenMap());
+      if(value instanceof BXElem)  return ((BXNode) value).getNode();
+      if(value instanceof Element) return new FElem((Element) value, null, new TokenMap());
       try {
-        return new DBNode(new IOContent(o.toString()), new MainOptions()).children().next();
+        return new DBNode(new IOContent(value.toString())).children().next();
       } catch(final IOException ex) {
-        throw NODEERR.get(ii, this, ex);
+        throw NODEERR_X_X.get(ii, this, ex);
       }
     }
   },
@@ -71,25 +70,25 @@ public enum NodeType implements Type {
   /** Document type. */
   DOC("document-node", NOD, ID.DOC) {
     @Override
-    public ANode cast(final Object o, final QueryContext ctx, final StaticContext sc,
+    public ANode cast(final Object value, final QueryContext qc, final StaticContext sc,
         final InputInfo ii) throws QueryException {
-      if(o instanceof BXDoc) return ((BXNode) o).getNode();
+      if(value instanceof BXDoc) return ((BXNode) value).getNode();
       try {
-        if(o instanceof Document) {
-          final DOMWrapper p = new DOMWrapper((Document) o, "", new MainOptions());
-          return new DBNode(MemBuilder.build(p));
+        if(value instanceof Document) {
+          final DOMWrapper dom = new DOMWrapper((Document) value, "", MainOptions.get());
+          return new DBNode(MemBuilder.build(dom));
         }
-        if(o instanceof DocumentFragment) {
+        if(value instanceof DocumentFragment) {
           // document fragment
-          final DocumentFragment df = (DocumentFragment) o;
+          final DocumentFragment df = (DocumentFragment) value;
           final String bu = df.getBaseURI();
           return new FDoc(df, bu != null ? Token.token(bu) : Token.EMPTY);
         }
-        final String c = o.toString();
-        if(c.startsWith("<")) return new DBNode(new IOContent(c), new MainOptions());
-        return new FDoc().add(new FTxt(c));
+        final String string = value.toString();
+        if(string.startsWith("<")) return new DBNode(new IOContent(string));
+        return new FDoc().add(new FTxt(string));
       } catch(final IOException ex) {
-        throw NODEERR.get(ii, this, ex);
+        throw NODEERR_X_X.get(ii, this, ex);
       }
     }
   },
@@ -97,35 +96,35 @@ public enum NodeType implements Type {
   /** Document element type. */
   DEL("document-node(element())", NOD, ID.DEL) {
     @Override
-    public Item cast(final Object o, final QueryContext ctx, final StaticContext sc,
+    public Item cast(final Object value, final QueryContext qc, final StaticContext sc,
         final InputInfo ii) throws QueryException {
-      return DOC.cast(o, ctx, sc, ii);
+      return DOC.cast(value, qc, sc, ii);
     }
   },
 
   /** Attribute type. */
   ATT("attribute", NOD, ID.ATT) {
     @Override
-    public ANode cast(final Object o, final QueryContext ctx, final StaticContext sc,
+    public ANode cast(final Object value, final QueryContext qc, final StaticContext sc,
         final InputInfo ii) throws QueryException {
-      if(o instanceof BXAttr) return ((BXNode) o).getNode();
-      if(o instanceof Attr) return new FAttr((Attr) o);
-      final Matcher m = Pattern.compile(" (.*?)=\"(.*)\"").matcher(o.toString());
+      if(value instanceof BXAttr) return ((BXNode) value).getNode();
+      if(value instanceof Attr) return new FAttr((Attr) value);
+      final Matcher m = Pattern.compile(" (.*?)=\"(.*)\"").matcher(value.toString());
       if(m.find()) return new FAttr(m.group(1), m.group(2));
-      throw NODEERR.get(ii, this, chop(o));
+      throw NODEERR_X_X.get(ii, this, chop(value, ii));
     }
   },
 
   /** Comment type. */
   COM("comment", NOD, ID.COM) {
     @Override
-    public ANode cast(final Object o, final QueryContext ctx, final StaticContext sc,
+    public ANode cast(final Object value, final QueryContext qc, final StaticContext sc,
         final InputInfo ii) throws QueryException {
-      if(o instanceof BXComm) return ((BXNode) o).getNode();
-      if(o instanceof Comment) return new FComm((Comment) o);
-      final Matcher m = Pattern.compile("<!--(.*?)-->").matcher(o.toString());
+      if(value instanceof BXComm) return ((BXNode) value).getNode();
+      if(value instanceof Comment) return new FComm((Comment) value);
+      final Matcher m = Pattern.compile("<!--(.*?)-->").matcher(value.toString());
       if(m.find()) return new FComm(m.group(1));
-      throw NODEERR.get(ii, this, chop(o));
+      throw NODEERR_X_X.get(ii, this, chop(value, ii));
     }
   },
 
@@ -140,44 +139,40 @@ public enum NodeType implements Type {
 
   /** Cached enums (faster). */
   private static final NodeType[] VALUES = values();
-  /** String representation. */
-  private final byte[] string;
+  /** Name. */
+  private final byte[] name;
   /** Parent type. */
-  private final Type par;
+  private final Type parent;
   /** Type id . */
   private final ID id;
-  /** Sequence type. */
+
+  /** Sequence type (lazy instantiation). */
   private SeqType seq;
 
   /**
    * Constructor.
-   * @param nm string representation
-   * @param pr parent type
-   * @param i type id
+   * @param name name
+   * @param parent parent type
+   * @param id type id
    */
-  NodeType(final String nm, final Type pr, final ID i) {
-    string = Token.token(nm);
-    par = pr;
-    id = i;
+  NodeType(final String name, final Type parent, final ID id) {
+    this.name = Token.token(name);
+    this.parent = parent;
+    this.id = id;
   }
 
   @Override
-  public final boolean isNode() {
-    return true;
-  }
-
-  @Override
-  public boolean isNumber() {
+  public final boolean isNumber() {
     return false;
   }
 
   @Override
-  public boolean isUntyped() {
+  public final boolean isUntyped() {
     return true;
   }
 
   @Override
-  public boolean isNumberOrUntyped() {
+  public final boolean isNumberOrUntyped() {
     return true;
   }
 
@@ -187,64 +182,64 @@ public enum NodeType implements Type {
   }
 
   @Override
-  public Item cast(final Item it, final QueryContext ctx, final StaticContext sc,
+  public final Item cast(final Item item, final QueryContext qc, final StaticContext sc,
       final InputInfo ii) throws QueryException {
-    return it.type == this ? it : error(it, ii);
+    return item.type == this ? item : error(item, ii);
   }
 
   @Override
-  public Item cast(final Object o, final QueryContext ctx, final StaticContext sc,
+  public Item cast(final Object value, final QueryContext qc, final StaticContext sc,
       final InputInfo ii) throws QueryException {
-    throw Util.notExpected(o);
+    throw Util.notExpected(value);
   }
 
   @Override
-  public Item castString(final String o, final QueryContext ctx, final StaticContext sc,
+  public final Item castString(final String value, final QueryContext qc, final StaticContext sc,
       final InputInfo ii) throws QueryException {
-    return cast(o, ctx, sc, ii);
+    return cast(value, qc, sc, ii);
   }
 
   @Override
-  public SeqType seqType() {
+  public final SeqType seqType() {
     // cannot be statically instantiated due to circular dependency
     if(seq == null) seq = new SeqType(this);
     return seq;
   }
 
   @Override
-  public boolean eq(final Type t) {
+  public final boolean eq(final Type t) {
     return this == t;
   }
 
   @Override
   public final boolean instanceOf(final Type t) {
-    return this == t || par.instanceOf(t);
+    return this == t || parent.instanceOf(t);
   }
 
   @Override
-  public Type union(final Type t) {
-    return t.isNode() ? this == t ? this : NOD : AtomType.ITEM;
+  public final Type union(final Type t) {
+    return t instanceof NodeType ? this == t ? this : NOD : AtomType.ITEM;
   }
 
   @Override
-  public NodeType intersect(final Type t) {
+  public final NodeType intersect(final Type t) {
     if(!(t instanceof NodeType)) return instanceOf(t) ? this : null;
     return this == t ? this : this == NOD ? (NodeType) t : t == NOD ? this : null;
   }
 
   @Override
-  public ID id() {
+  public final ID id() {
     return id;
   }
 
   @Override
-  public byte[] string() {
-    return string;
+  public final byte[] string() {
+    return name;
   }
 
   @Override
-  public String toString() {
-    return new TokenBuilder(string).add("()").toString();
+  public final String toString() {
+    return new TokenBuilder(name).add("()").toString();
   }
 
   /**
@@ -254,30 +249,30 @@ public enum NodeType implements Type {
    * @return dummy item
    * @throws QueryException query exception
    */
-  Item error(final Item it, final InputInfo ii) throws QueryException {
-    throw Err.castError(ii, this, it);
+  final Item error(final Item it, final InputInfo ii) throws QueryException {
+    throw castError(ii, it, this);
+  }
+
+  @Override
+  public boolean nsSensitive() {
+    return false;
   }
 
   /**
    * Finds and returns the specified node type.
-   * @param type type as string
+   * @param type type
    * @return type or {@code null}
    */
   public static NodeType find(final QNm type) {
     if(type.uri().length == 0) {
       final byte[] ln = type.local();
       for(final NodeType t : VALUES) {
-        if(Token.eq(ln, t.string)) return t;
+        if(Token.eq(ln, t.name)) return t;
       }
     }
     return null;
   }
 
-  @Override
-  public boolean nsSensitive() {
-    return false;
-  }
-
   /**
    * Gets the type instance for the given ID.
    * @param id type ID
