@@ -1,6 +1,6 @@
 package org.basex.query.var;
 
-import static org.basex.query.util.Err.*;
+import static org.basex.query.QueryError.*;
 
 import org.basex.data.*;
 import org.basex.query.*;
@@ -14,7 +14,7 @@ import org.basex.util.*;
 /**
  * Variable expression.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  * @author Leo Woerteler
  */
@@ -26,66 +26,68 @@ public final class Var extends ExprInfo {
   public final QNm name;
   /** Variable ID. */
   public final int id;
-  /** Declared type, {@code null} if not specified. */
+  /** Declared sequence type, {@code null} if not specified. */
   public SeqType declType;
 
   /** Stack slot number. */
   int slot = -1;
   /** Expected result size. */
-  long size = -1;
+  public long size = -1;
+  /** Data reference. */
+  public Data data;
 
   /** Flag for function parameters. */
   private final boolean param;
   /** Actual return type (by type inference). */
-  private SeqType inType;
+  private SeqType seqType;
   /** Flag for function conversion. */
   private boolean promote;
 
   /**
    * Constructor.
-   * @param ctx query context, used for generating a variable ID
-   * @param sctx static context
-   * @param n variable name, {@code null} for unnamed variable
-   * @param typ expected type, {@code null} for no check
-   * @param fun function parameter flag
+   * @param qc query context, used for generating a variable ID
+   * @param sc static context
+   * @param name variable name, {@code null} for unnamed variable
+   * @param declType declared sequence type, {@code null} for no check
+   * @param param function parameter flag
    */
-  Var(final QueryContext ctx, final StaticContext sctx, final QNm n, final SeqType typ,
-      final boolean fun) {
-    sc = sctx;
-    name = n;
-    declType = typ == null || typ.eq(SeqType.ITEM_ZM) ? null : typ;
-    inType = SeqType.ITEM_ZM;
-    id = ctx.varIDs++;
-    param = fun;
-    promote = fun;
-    size = inType.occ();
+  Var(final QueryContext qc, final StaticContext sc, final QNm name, final SeqType declType,
+      final boolean param) {
+    this.sc = sc;
+    this.name = name;
+    this.param = param;
+    promote = param;
+    this.declType = declType == null || declType.eq(SeqType.ITEM_ZM) ? null : declType;
+    seqType = SeqType.ITEM_ZM;
+    id = qc.varIDs++;
+    size = seqType.occ();
   }
 
   /**
    * Copy constructor.
-   * @param ctx query context
-   * @param sctx static context
+   * @param qc query context
+   * @param sc static context
    * @param var variable to copy
    */
-  Var(final QueryContext ctx, final StaticContext sctx, final Var var) {
-    this(ctx, sctx, var.name, var.declType, var.param);
+  Var(final QueryContext qc, final StaticContext sc, final Var var) {
+    this(qc, sc, var.name, var.declType, var.param);
     promote = var.promote;
-    inType = var.inType;
+    seqType = var.seqType;
     size = var.size;
   }
 
   /**
-   * Type of values bound to this variable.
-   * @return type (not {@code null})
+   * Sequence type of values bound to this variable.
+   * @return sequence type (not {@code null})
    */
-  public SeqType type() {
-    final SeqType intersect = declType != null ? declType.intersect(inType) : null;
-    return intersect != null ? intersect : declType != null ? declType : inType;
+  public SeqType seqType() {
+    final SeqType intersect = declType != null ? declType.intersect(seqType) : null;
+    return intersect != null ? intersect : declType != null ? declType : seqType;
   }
 
   /**
    * Declared type of this variable.
-   * @return declared type, possibly {@code null}
+   * @return declared type (not {@code null})
    */
   public SeqType declaredType() {
     return declType == null ? SeqType.ITEM_ZM : declType;
@@ -94,30 +96,30 @@ public final class Var extends ExprInfo {
   /**
    * Tries to refine the compile-time type of this variable through the type of the bound
    * expression.
-   * @param t type of the bound expression
-   * @param ctx query context
+   * @param st sequence type of the bound expression
+   * @param qc query context
    * @param ii input info
    * @throws QueryException query exception
    */
-  public void refineType(final SeqType t, final QueryContext ctx, final InputInfo ii)
+  public void refineType(final SeqType st, final QueryContext qc, final InputInfo ii)
       throws QueryException {
 
-    if(t == null) return;
+    if(st == null) return;
 
     if(declType != null) {
-      if(declType.occ.intersect(t.occ) == null) throw INVCAST.get(ii, t, declType);
-      if(t.instanceOf(declType)) {
-        ctx.compInfo(QueryText.OPTCAST, this);
+      if(declType.occ.intersect(st.occ) == null) throw INVCAST_X_X.get(ii, st, declType);
+      if(st.instanceOf(declType)) {
+        qc.compInfo(QueryText.OPTCAST, this);
         declType = null;
-      } else if(!t.promotable(declType)) {
+      } else if(!st.promotable(declType)) {
         return;
       }
     }
 
-    if(!inType.eq(t) && !inType.instanceOf(t)) {
+    if(!seqType.eq(st) && !seqType.instanceOf(st)) {
       // the new type provides new information
-      final SeqType is = inType.intersect(t);
-      if(is != null) inType = is;
+      final SeqType is = seqType.intersect(st);
+      if(is != null) seqType = is;
     }
   }
 
@@ -131,33 +133,33 @@ public final class Var extends ExprInfo {
 
   /**
    * Returns an equivalent to the given expression that checks this variable's type.
-   * @param e expression
+   * @param ex expression
    * @param scp variable scope
-   * @param ctx query context
+   * @param qc query context
    * @param ii input info
    * @return checked expression
    * @throws QueryException query exception
    */
-  public Expr checked(final Expr e, final QueryContext ctx, final VarScope scp, final InputInfo ii)
+  public Expr checked(final Expr ex, final QueryContext qc, final VarScope scp, final InputInfo ii)
       throws QueryException {
-    return checksType() ? new TypeCheck(sc, ii, e, declType, promote).optimize(ctx, scp) : e;
+    return checksType() ? new TypeCheck(sc, ii, ex, declType, promote).optimize(qc, scp) : ex;
   }
 
   /**
    * Checks the type of this value and casts/promotes it when necessary.
    * @param val value to be checked
-   * @param ctx query context
+   * @param qc query context
    * @param ii input info
    * @param opt if the result should be optimized
    * @return checked and possibly cast value
    * @throws QueryException if the check failed
    */
-  public Value checkType(final Value val, final QueryContext ctx, final InputInfo ii,
+  public Value checkType(final Value val, final QueryContext qc, final InputInfo ii,
       final boolean opt) throws QueryException {
 
     if(!checksType() || declType.instance(val)) return val;
-    if(promote) return declType.promote(ctx, sc, ii, val, opt);
-    throw INVCAST.get(ii, val.type(), declType);
+    if(promote) return declType.promote(qc, sc, ii, val, opt);
+    throw INVCAST_X_X.get(ii, val.seqType(), declType);
   }
 
   /**
@@ -165,32 +167,34 @@ public final class Var extends ExprInfo {
    * of this variable.
    *
    * Due to insufficient typing, the check will only be performed if:
-   * - the variable type is an instance of the specified type.
-   *   This way, expressions with super types like item() will not be rejected
-   * - the expression is to be promoted, and it is not of type node (eg: function-declaration-016)
+   * <ul>
+   *   <li> The variable type is an instance of the specified type.
+   *        This way, expressions with super types like item() will not be rejected.</li>
+   *   <li> The expression is to be promoted, and it is not of type node
+   *        (eg: function-declaration-016)</li>
+   * </ul>
    *
    * @param expr expression
    * @param info input info
    * @throws QueryException query exception
    */
   public void checkType(final Expr expr, final InputInfo info) throws QueryException {
-    final SeqType et = expr.type(), vt = type();
+    final SeqType et = expr.seqType(), vt = seqType();
     if(!checksType() || vt.type.instanceOf(et.type) ||
         et.type.instanceOf(vt.type) && et.occ.instanceOf(vt.occ)) return;
 
-    if(!promote || !et.type.isNode() && !et.promotable(vt)) {
-      if(vt.type.nsSensitive() && sc.xquery3()) throw NSSENS.get(info, et, vt);
-      throw INVCAST.get(info, et, vt);
+    if(!promote || !(et.type instanceof NodeType) && !et.promotable(vt)) {
+      throw (vt.type.nsSensitive() ? NSSENS_X_X : INVCAST_X_X).get(info, et, vt);
     }
   }
 
   /**
    * Checks whether the given variable is identical to this one, i.e. has the same ID.
-   * @param v variable to check
-   * @return {@code true}, if the IDs are equal, {@code false} otherwise
+   * @param var variable to check
+   * @return {@code true} if the IDs are equal, {@code false} otherwise
    */
-  public boolean is(final Var v) {
-    return id == v.id;
+  public boolean is(final Var var) {
+    return id == var.id;
   }
 
   /**
@@ -201,6 +205,32 @@ public final class Var extends ExprInfo {
     return promote;
   }
 
+  @Override
+  public boolean equals(final Object obj) {
+    return obj instanceof Var && is((Var) obj);
+  }
+
+  @Override
+  public int hashCode() {
+    return id;
+  }
+
+  /**
+   * Tries to adopt the given type check.
+   * @param st type to check
+   * @param prom if function conversion should be applied
+   * @return {@code true} if the check could be adopted, {@code false} otherwise
+   */
+  public boolean adoptCheck(final SeqType st, final boolean prom) {
+    if(declType == null || st.instanceOf(declType)) {
+      declType = st;
+    } else if(!declType.instanceOf(st)) {
+      return false;
+    }
+    promote |= prom;
+    return true;
+  }
+
   @Override
   public void plan(final FElem plan) {
     final FElem e = planElem(QueryText.NAM, '$' + Token.string(name.string()),
@@ -224,31 +254,4 @@ public final class Var extends ExprInfo {
     if(declType != null) tb.add(" " + declType);
     return tb.toString();
   }
-
-  @Override
-  public boolean equals(final Object obj) {
-    return obj instanceof Var && is((Var) obj);
-  }
-
-  @Override
-  public int hashCode() {
-    return id;
-  }
-
-  /**
-   * Tries to adopt the given type check.
-   * @param t type to check
-   * @param prom if function conversion should be applied
-   * @return {@code true} if the check could be adopted, {@code false} otherwise
-   */
-  public boolean adoptCheck(final SeqType t, final boolean prom) {
-    if(declType == null || t.instanceOf(declType)) {
-      declType = t;
-    } else if(!declType.instanceOf(t)) {
-      return false;
-    }
-
-    promote |= prom;
-    return true;
-  }
-}
\ No newline at end of file
+}
