@@ -2,6 +2,7 @@ package org.basex.query.var;
 
 import static org.basex.query.QueryText.*;
 
+import org.basex.data.*;
 import org.basex.query.*;
 import org.basex.query.expr.*;
 import org.basex.query.iter.*;
@@ -15,7 +16,7 @@ import org.basex.util.hash.*;
 /**
  * Local Variable Reference expression.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  * @author Leo Woerteler
  */
@@ -25,39 +26,44 @@ public final class VarRef extends ParseExpr {
 
   /**
    * Constructor.
-   * @param ii input info
-   * @param v variable
+   * @param info input info
+   * @param var variable
    */
-  public VarRef(final InputInfo ii, final Var v) {
-    super(ii);
-    var = v;
+  public VarRef(final InputInfo info, final Var var) {
+    super(info);
+    this.var = var;
   }
 
   @Override
-  public Expr compile(final QueryContext ctx, final VarScope scp) {
-    return optimize(ctx, scp);
+  public Expr compile(final QueryContext qc, final VarScope scp) {
+    return optimize(qc, scp);
   }
 
   @Override
-  public VarRef optimize(final QueryContext ctx, final VarScope scp) {
-    type = var.type();
+  public VarRef optimize(final QueryContext qc, final VarScope scp) {
+    seqType = var.seqType();
     size = var.size;
     return this;
   }
 
   @Override
-  public Item item(final QueryContext ctx, final InputInfo ii) throws QueryException {
-    return ctx.get(var).item(ctx, ii);
+  public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
+    return qc.get(var).item(qc, ii);
   }
 
   @Override
-  public Iter iter(final QueryContext ctx) {
-    return ctx.get(var).iter();
+  public Iter iter(final QueryContext qc) {
+    return qc.get(var).iter();
   }
 
   @Override
-  public Value value(final QueryContext ctx) {
-    return ctx.get(var);
+  public Value value(final QueryContext qc) {
+    return qc.get(var);
+  }
+
+  @Override
+  public Data data() {
+    return var.data;
   }
 
   @Override
@@ -71,15 +77,15 @@ public final class VarRef extends ParseExpr {
   }
 
   @Override
-  public Expr inline(final QueryContext ctx, final VarScope scp, final Var v, final Expr e) {
+  public Expr inline(final QueryContext qc, final VarScope scp, final Var v, final Expr ex) {
     // [LW] Is copying always necessary?
-    return v.is(var) ? e.isValue() ? e : e.copy(ctx, scp) : null;
+    return var.is(v) ? ex.isValue() ? ex : ex.copy(qc, scp, new IntObjMap<Var>()) : null;
   }
 
   @Override
-  public VarRef copy(final QueryContext ctx, final VarScope scp, final IntObjMap<Var> vs) {
+  public VarRef copy(final QueryContext qc, final VarScope scp, final IntObjMap<Var> vs) {
     final Var nw = vs.get(var.id);
-    return new VarRef(info, nw != null ? nw : var).optimize(ctx, scp);
+    return new VarRef(info, nw != null ? nw : var).optimize(qc, scp);
   }
 
   @Override
@@ -110,8 +116,7 @@ public final class VarRef extends ParseExpr {
 
   @Override
   public String toString() {
-    return new TokenBuilder(DOLLAR).add(
-        var.name.toString()).add('_').addInt(var.id).toString();
+    return new TokenBuilder(DOLLAR).add(var.name.toString()).add('_').addInt(var.id).toString();
   }
 
   @Override
