@@ -9,7 +9,7 @@ import org.basex.util.*;
 /**
  * This exception is thrown if a wrong user/password combination was specified.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class LoginException extends IOException {
@@ -19,12 +19,13 @@ public final class LoginException extends IOException {
   public LoginException() {
     super(ACCESS_DENIED);
   }
+
   /**
    * Constructs an exception with the specified message and extension.
-   * @param s message
-   * @param e message extension
+   * @param message message
+   * @param ext message extension
    */
-  public LoginException(final String s, final Object... e) {
-    super(Util.info(s, e));
+  public LoginException(final String message, final Object... ext) {
+    super(Util.info(message, ext));
   }
 }
