@@ -5,9 +5,9 @@ import java.util.*;
 import org.basex.util.list.*;
 
 /**
- * Convenience methods for handling arrays; serves as an extension to Java's {@link Arrays} class.
+ * Convenience functions for handling arrays; serves as an extension to Java's {@link Arrays} class.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class Array {
@@ -132,7 +132,7 @@ public final class Array {
   }
 
   /**
-   * Sorts the specified tokens and returns an integer array with offsets to the sorted tokens.
+   * Sorts the specified tokens and returns an array with offsets to the sorted array.
    * @param values values to sort by
    * @param numeric numeric sort
    * @param ascending ascending
@@ -142,11 +142,11 @@ public final class Array {
       final boolean ascending) {
     final IntList il = number(values.length);
     il.sort(values, numeric, ascending);
-    return il.toArray();
+    return il.finish();
   }
 
   /**
-   * Sorts the specified doubles and returns an integer array with offsets to the sorted doubles.
+   * Sorts the specified double values and returns an array with offsets to the sorted array.
    * @param values values to sort by
    * @param ascending ascending
    * @return array containing the order
@@ -154,11 +154,11 @@ public final class Array {
   public static int[] createOrder(final double[] values, final boolean ascending) {
     final IntList il = number(values.length);
     il.sort(values, ascending);
-    return il.toArray();
+    return il.finish();
   }
 
   /**
-   * Sorts the specified integers and returns an integer array with offsets to the sorted integers.
+   * Sorts the specified int values and returns an array with offsets to the sorted array.
    * @param values values to sort by
    * @param ascending ascending
    * @return array containing the order
@@ -166,7 +166,19 @@ public final class Array {
   public static int[] createOrder(final int[] values, final boolean ascending) {
     final IntList il = number(values.length);
     il.sort(values, ascending);
-    return il.toArray();
+    return il.finish();
+  }
+
+  /**
+   * Sorts the specified long values and returns an array with offsets to the sorted array.
+   * @param values values to sort by
+   * @param ascending ascending
+   * @return array containing the order
+   */
+  public static int[] createOrder(final long[] values, final boolean ascending) {
+    final IntList il = number(values.length);
+    il.sort(values, ascending);
+    return il.finish();
   }
 
   /**
