@@ -8,7 +8,7 @@ import java.util.*;
  * This class serves as an efficient constructor for {@link Token Tokens}.
  * It bears some resemblance to Java's {@link StringBuilder}.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class TokenBuilder {
@@ -50,7 +50,7 @@ public final class TokenBuilder {
    * @param string initial string
    */
   public TokenBuilder(final String string) {
-    this(token(string));
+    this(Token.token(string));
   }
 
   /**
@@ -63,6 +63,15 @@ public final class TokenBuilder {
     System.arraycopy(token, 0, chars, 0, size);
   }
 
+  /**
+   * Constructor, specifying initial codepoints.
+   * @param cps initial codepoints
+   */
+  public TokenBuilder(final int[] cps) {
+    this(cps.length);
+    add(cps);
+  }
+
   /**
    * Returns the number of bytes.
    * @return number of bytes
@@ -73,10 +82,10 @@ public final class TokenBuilder {
 
   /**
    * Sets the number of bytes. Note that no bound check is performed by this method.
-   * @param s number of bytes
+   * @param sz number of bytes
    */
-  public void size(final int s) {
-    size = s;
+  public void size(final int sz) {
+    size = sz;
   }
 
   /**
@@ -141,6 +150,16 @@ public final class TokenBuilder {
     return addByte(HLINE);
   }
 
+  /**
+   * Adds the specified UTF8 codepoints.
+   * @param cps the codepoints to be added
+   * @return self reference
+   */
+  public TokenBuilder add(final int[] cps) {
+    for(final int cp : cps) add(cp);
+    return this;
+  }
+
   /**
    * Adds the specified UTF8 codepoint.
    * @param cp the codepoint to be added
@@ -175,11 +194,7 @@ public final class TokenBuilder {
     final int s = size;
     final int cl = chars.length;
     final int l = cp <= 0x7F ? 1 : cp <= 0x7FF ? 2 : cp <= 0xFFF ? 3 : 4;
-
-    if(s + l > cl) {
-      final int ns = Math.max(s + l, (int) (cl * Array.RESIZE));
-      chars = Arrays.copyOf(chars, ns);
-    }
+    if(s + l > cl) chars = Arrays.copyOf(chars, Math.max(s + l, (int) (cl * Array.RESIZE)));
     Array.move(chars, pos, l, size - pos);
     size = pos;
     add(cp);
@@ -239,8 +254,12 @@ public final class TokenBuilder {
    * @return self reference
    */
   public TokenBuilder addByte(final byte value) {
-    if(size == chars.length) chars = Arrays.copyOf(chars, Array.newSize(size));
-    chars[size++] = value;
+    byte[] chrs = chars;
+    final int s = size;
+    if(s == chrs.length) chrs = Arrays.copyOf(chrs, Array.newSize(s));
+    chrs[s] = value;
+    chars = chrs;
+    size = s + 1;
     return this;
   }
 
@@ -250,7 +269,7 @@ public final class TokenBuilder {
    * @return self reference
    */
   public TokenBuilder addInt(final int value) {
-    return add(token(value));
+    return add(Token.token(value));
   }
 
   /**
@@ -259,7 +278,7 @@ public final class TokenBuilder {
    * @return self reference
    */
   public TokenBuilder addLong(final long value) {
-    return add(token(value));
+    return add(Token.token(value));
   }
 
   /**
@@ -279,14 +298,12 @@ public final class TokenBuilder {
    * @return self reference
    */
   public TokenBuilder add(final byte[] value, final int start, final int end) {
-    final int l = end - start;
-    final int cl = chars.length;
-    if(size + l > cl) {
-      final int ns = Math.max(size + l, (int) (cl * Array.RESIZE));
-      chars = Arrays.copyOf(chars, ns);
-    }
-    System.arraycopy(value, start, chars, size, l);
-    size += l;
+    byte[] chrs = chars;
+    final int cl = chrs.length, l = end - start, s = size, ns = s + l;
+    if(ns > cl) chrs = Arrays.copyOf(chrs, Array.newSize(ns));
+    System.arraycopy(value, start, chrs, s, l);
+    chars = chrs;
+    size = ns;
     return this;
   }
 
@@ -296,7 +313,7 @@ public final class TokenBuilder {
    * @return self reference
    */
   public TokenBuilder add(final String string) {
-    return add(token(string));
+    return add(Token.token(string));
   }
 
   /**
@@ -306,93 +323,119 @@ public final class TokenBuilder {
    * @return self reference
    */
   public TokenBuilder addSep(final Object[] objects, final String sep) {
-    for(int e = 0; e != objects.length; ++e) {
-      if(e != 0) add(sep);
-      addExt(objects[e]);
+    final int ol = objects.length;
+    for(int o = 0; o < ol; o++) {
+      if(o != 0) add(sep);
+      addExt(objects[o]);
     }
     return this;
   }
 
   /**
-   * Adds the string representation of an object:
-   * <ul>
-   * <li> objects of type {@link Throwable} are converted to a string representation
-   *      via {@link Util#message}.</li>
-   * <li> objects of type {@link Class} are converted via {@link Util#className(Class)}.</li>
-   * <li> {@code null} references are replaced by the string {@code "null"}.</li>
-   * <li> byte arrays are directly inserted as tokens.</li>
-   * <li> for all other typed, {@link Object#toString} is called.</li>
-   * </ul>
+   * Adds the string representation of an object.
    * The specified string may contain {@code "%"} characters as place holders.
    * All place holders will be replaced by the specified extensions. If a digit is
    * specified after the place holder character, it will be interpreted as insertion
    * position.
    *
-   * @param object string to be extended
+   * @param object object to be extended
    * @param ext optional extensions
    * @return self reference
    */
   public TokenBuilder addExt(final Object object, final Object... ext) {
-    final byte[] t;
-    if(object instanceof byte[]) {
-      t = (byte[]) object;
-    } else {
-      final String s;
-      if(object == null) {
-        s = "null";
-      } else if(object instanceof Throwable) {
-        s = Util.message((Throwable) object);
-      } else if(object instanceof Class<?>) {
-        s = Util.className((Class<?>) object);
-      } else {
-        s = object.toString();
-      }
-      t = token(s);
-    }
-
-    for(int i = 0, e = 0; i < t.length; ++i) {
-      if(t[i] != '%' || e == ext.length) {
+    final byte[] t = token(object);
+    final int tl = t.length, el = ext.length;
+    for(int i = 0, e = 0; i < tl; ++i) {
+      if(t[i] != '%' || e == el) {
         addByte(t[i]);
       } else {
-        final byte c = i + 1 < t.length ? t[i + 1] : 0;
+        final byte c = i + 1 < tl ? t[i + 1] : 0;
         final boolean d = c >= '1' && c <= '9';
         if(d) ++i;
         final int n = d ? c - '1' : e++;
-        final Object o = n < ext.length ? ext[n] : null;
+        final Object o = n < el ? ext[n] : null;
         addExt(o);
       }
     }
     return this;
   }
 
+  /**
+   * Returns a token representation of the specified object.
+   * <ul>
+   *   <li> byte arrays are returns as is.</li>
+   *   <li> {@code null} references are replaced by the string "{@code null}".</li>
+   *   <li> objects of type {@link Throwable} are converted to a string representation via
+   *        {@link Util#message}.</li>
+   *   <li> objects of type {@link Class} are converted via {@link Util#className(Class)}.</li>
+   *   <li> for all other typer, {@link Object#toString} is called.</li>
+   * </ul>
+   * @param object object
+   * @return token
+   */
+  public static byte[] token(final Object object) {
+    if(object instanceof byte[]) return (byte[]) object;
+
+    final String s;
+    if(object == null) {
+      s = "null";
+    } else if(object instanceof Throwable) {
+      s = Util.message((Throwable) object);
+    } else if(object instanceof Class<?>) {
+      s = Util.className((Class<?>) object);
+    } else {
+      s = object.toString();
+    }
+    return Token.token(s);
+  }
+
+
   /**
    * Trims leading and trailing whitespaces.
    * @return self reference
    */
   public TokenBuilder trim() {
-    while(size > 0 && ws(chars[size - 1])) --size;
-    int s = -1;
-    while(++s < size && ws(chars[s]));
-    if(s != 0 && s != size) Array.move(chars, s, -s, size - s);
-    size -= s;
+    final byte[] chrs = chars;
+    int s = size;
+    while(s > 0 && ws(chrs[s - 1])) --s;
+    int c = -1;
+    while(++c < s && ws(chrs[c]));
+    if(c != 0 && c != s) Array.move(chrs, c, -c, s - c);
+    size = s - c;
     return this;
   }
 
   /**
    * Returns the token as byte array.
-   * @return character array
+   * @return token
    */
-  public byte[] finish() {
-    return Arrays.copyOf(chars, size);
+  public byte[] toArray() {
+    final int s = size;
+    return s == 0 ? EMPTY : Arrays.copyOf(chars, s);
   }
 
   /**
-   * Returns the original byte array if its size matches the token size, or returns a copy
-   * as {@link #finish()} does.
-   * @return character array
+   * Returns the token as byte array and resets the token buffer.
+   * The call of this function is identical to calling {@link #toArray} and {@link #reset}.
+   * @return token
    */
-  public byte[] array() {
-    return size == chars.length ? chars : finish();
+  public byte[] next() {
+    final int s = size;
+    if(s == 0) return EMPTY;
+    size = 0;
+    return Arrays.copyOf(chars, s);
+  }
+
+  /**
+   * Returns the token as byte array, and invalidates the internal array.
+   * Warning: the function must only be called if the builder is discarded afterwards.
+   * @return token
+   */
+  public byte[] finish() {
+    final byte[] chrs = chars;
+    chars = null;
+    final int s = size;
+    return s == 0 ? EMPTY : s == chrs.length ? chrs : Arrays.copyOf(chrs, s);
   }
 
   @Override
