@@ -5,8 +5,8 @@ import static org.basex.core.Text.*;
 import java.io.*;
 import java.net.*;
 import java.util.*;
+import java.util.Map.Entry;
 
-import org.basex.server.*;
 import org.basex.util.list.*;
 
 /**
@@ -14,7 +14,7 @@ import org.basex.util.list.*;
  * The methods are used for dumping error output, debugging information,
  * getting the application path, etc.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class Util {
@@ -44,24 +44,20 @@ public final class Util {
 
   /**
    * Throws a runtime exception for an unexpected exception.
-   * @param ext optional extension
    * @return runtime exception (indicates that an error is raised)
    */
-  public static RuntimeException notExpected(final Object... ext) {
-    final TokenBuilder tb = new TokenBuilder();
-    tb.addExt("%", ext.length == 0 ? "Not Expected." : ext[0]);
-    return new RuntimeException(tb.toString());
+  public static RuntimeException notExpected() {
+    return notExpected("Not Expected.");
   }
 
   /**
-   * Throws a runtime exception for an unimplemented method.
+   * Throws a runtime exception for an unexpected exception.
+   * @param message message
    * @param ext optional extension
    * @return runtime exception (indicates that an error is raised)
    */
-  public static UnsupportedOperationException notImplemented(final Object... ext) {
-    final TokenBuilder tb = new TokenBuilder("Not Implemented");
-    if(ext.length != 0) tb.addExt(" (%)", ext);
-    return new UnsupportedOperationException(tb.add('.').toString());
+  public static RuntimeException notExpected(final Object message, final Object... ext) {
+    return new RuntimeException(info(message, ext));
   }
 
   /**
@@ -154,7 +150,6 @@ public final class Util {
   public static String message(final Throwable throwable) {
     debug(throwable);
     if(throwable instanceof BindException) return SRV_RUNNING;
-    if(throwable instanceof LoginException) return ACCESS_DENIED;
     if(throwable instanceof ConnectException) return CONNECTION_ERROR;
     if(throwable instanceof SocketTimeoutException) return TIMEOUT_EXCEEDED;
     if(throwable instanceof SocketException) return CONNECTION_ERROR;
@@ -247,9 +242,10 @@ public final class Util {
    */
   private static String[] toArray(final Throwable throwable) {
     final StackTraceElement[] st = throwable.getStackTrace();
-    final String[] obj = new String[st.length + 1];
+    final int sl = st.length;
+    final String[] obj = new String[sl + 1];
     obj[0] = throwable.toString();
-    for(int i = 0; i < st.length; i++) obj[i + 1] = "\tat " + st[i];
+    for(int s = 0; s < sl; s++) obj[s + 1] = "\tat " + st[s];
     return obj;
   }
 
@@ -264,34 +260,16 @@ public final class Util {
         "-cp", System.getProperty("java.class.path") };
     final StringList sl = new StringList().add(largs);
 
-    for(final Map.Entry<Object, Object> o : System.getProperties().entrySet()) {
+    for(final Entry<Object, Object> o : System.getProperties().entrySet()) {
       final String k = o.getKey().toString();
-      if(k.startsWith(Prop.DBPREFIX)) sl.add("-D" + o.getValue());
+      if(k.startsWith(Prop.DBPREFIX)) sl.add("-D" + k + "=" + o.getValue());
     }
     sl.add(clazz.getName()).add("-D").add(args);
 
     try {
-      return new ProcessBuilder(sl.toArray()).start();
+      return new ProcessBuilder(sl.finish()).start();
     } catch(final IOException ex) {
       throw notExpected(ex);
     }
   }
-
-  /**
-   * Checks if the specified string is "yes", "true" or "on".
-   * @param string string to be checked
-   * @return result of check
-   */
-  public static boolean yes(final String string) {
-    return Token.eqic(string, YES, TRUE, ON);
-  }
-
-  /**
-   * Checks if the specified string is "no", "false" or "off".
-   * @param string string to be checked
-   * @return result of check
-   */
-  public static boolean no(final String string) {
-    return Token.eqic(string, NO, FALSE, OFF);
-  }
 }
