@@ -5,8 +5,7 @@ import java.util.*;
 
 import org.basex.index.*;
 import org.basex.index.query.*;
-import org.basex.io.serial.*;
-import org.basex.query.ft.*;
+import org.basex.query.expr.ft.*;
 import org.basex.util.*;
 import org.basex.util.list.*;
 
@@ -14,7 +13,7 @@ import org.basex.util.list.*;
  * Performs full-text lexing on token. Calls tokenizers, stemmers matching to
  * full-text options to achieve this.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Jens Erat
  */
 public final class FTLexer extends FTIterator implements IndexToken {
@@ -24,6 +23,8 @@ public final class FTLexer extends FTIterator implements IndexToken {
   private final FTOpt ftopt;
   /** Text to be tokenized. */
   private byte[] text = Token.EMPTY;
+  /** Levenshtein error. */
+  private int lserror;
 
   /** Iterator over result tokens. */
   private FTIterator iter;
@@ -33,8 +34,8 @@ public final class FTLexer extends FTIterator implements IndexToken {
   private byte[] ctxt;
 
   /**
-   * Constructor, using the default full-text options. Called by the
-   * {@link XMLSerializer}, {@link FTFilter}, and the map visualizations.
+   * Constructor, using the default full-text options. Called by the serializer,
+   * {@link FTFilter}, and the map visualizations.
    */
   public FTLexer() {
     this(null);
@@ -42,31 +43,31 @@ public final class FTLexer extends FTIterator implements IndexToken {
 
   /**
    * Default constructor.
-   * @param opt full-text options
+   * @param ftopt full-text options
    */
-  public FTLexer(final FTOpt opt) {
-    ftopt = opt;
+  public FTLexer(final FTOpt ftopt) {
+    this.ftopt = ftopt;
 
     // check if language option is provided:
-    Language lang = opt != null ? opt.ln : null;
+    Language lang = ftopt != null ? ftopt.ln : null;
     if(lang == null) lang = Language.def();
 
     // use default tokenizer if specific tokenizer is not available.
-    Tokenizer tk = Tokenizer.IMPL.getFirst();
+    Tokenizer tk = Tokenizer.IMPL.get(0);
     for(final Tokenizer t : Tokenizer.IMPL) {
       if(t.supports(lang)) {
         tk = t;
         break;
       }
     }
-    tok = tk.get(opt);
+    tok = tk.get(ftopt);
     iter = tok;
 
     // wrap original iterator
-    if(opt != null && opt.is(FTFlag.ST)) {
-      if(opt.sd == null) {
+    if(ftopt != null && ftopt.is(FTFlag.ST)) {
+      if(ftopt.sd == null) {
         // use default stemmer if specific stemmer is not available.
-        Stemmer st = Stemmer.IMPL.getFirst();
+        Stemmer st = Stemmer.IMPL.get(0);
         for(final Stemmer stem : Stemmer.IMPL) {
           if(stem.supports(lang)) {
             st = stem;
@@ -75,18 +76,26 @@ public final class FTLexer extends FTIterator implements IndexToken {
         }
         iter = st.get(lang, iter);
       } else {
-        iter = new DictionaryStemmer(opt.sd, iter);
+        iter = new DictionaryStemmer(ftopt.sd, iter);
       }
     }
   }
 
   /**
-   * Sets the special character flag.
-   * Returns not only tokens, but also delimiters.
+   * If called, the original tokens will be returned (including non-fulltext tokens).
    * @return self reference
    */
-  public FTLexer sc() {
-    tok.special = true;
+  public FTLexer original() {
+    tok.original = true;
+    return all();
+  }
+
+  /**
+   * If called, all tokens will be returned (including non-fulltext tokens).
+   * @return self reference
+   */
+  public FTLexer all() {
+    tok.all = true;
     return this;
   }
 
@@ -97,6 +106,23 @@ public final class FTLexer extends FTIterator implements IndexToken {
     init(text);
   }
 
+  /**
+   * Sets the Levenshtein error.
+   * @param ls error
+   */
+  public void lserror(final int ls) {
+    lserror = ls;
+  }
+
+  /**
+   * Returns the Levenshtein error for the specified token.
+   * @param token token
+   * @return error
+   */
+  public int lserror(final byte[] token) {
+    return lserror == 0 ? token.length >> 2 : lserror;
+  }
+
   @Override
   public FTLexer init(final byte[] txt) {
     text = txt;
@@ -151,8 +177,8 @@ public final class FTLexer extends FTIterator implements IndexToken {
   }
 
   /**
-   * Returns the full-text options. Can be {@code null}.
-   * @return full-text options
+   * Returns the full-text options.
+   * @return full-text options (may be {@code null})
    */
   public FTOpt ftOpt() {
     return ftopt;
@@ -167,7 +193,8 @@ public final class FTLexer extends FTIterator implements IndexToken {
   }
 
   /**
-   * Is paragraph? Does not have to be implemented by all tokenizers.
+   * Returns if the current token starts a new paragraph. Needed for visualizations.
+   * Does not have to be implemented by all tokenizers.
    * Returns false if not implemented.
    * @return boolean
    */
@@ -178,17 +205,17 @@ public final class FTLexer extends FTIterator implements IndexToken {
   /**
    * Calculates a position value, dependent on the specified unit. Does not have
    * to be implemented by all tokenizers. Returns 0 if not implemented.
-   * @param w word position
-   * @param u unit
+   * @param word word position
+   * @param unit unit
    * @return new position
    */
-  public int pos(final int w, final FTUnit u) {
-    return tok.pos(w, u);
+  public int pos(final int word, final FTUnit unit) {
+    return tok.pos(word, unit);
   }
 
   /**
-   * Gets full-text info for the specified token; needed for visualizations.
-   * See {@link Tokenizer#info()} for more info.
+   * Gets full-text info for the specified token.
+   * Needed for visualizations; see {@link Tokenizer#info()} for more info.
    * @return int arrays or empty array if not implemented
    */
   public int[][] info() {
@@ -200,7 +227,7 @@ public final class FTLexer extends FTIterator implements IndexToken {
    * @return supported languages
    */
   public static StringList languages() {
-    final TreeMap<Language, Stemmer> langs = new TreeMap<Language, Stemmer>();
+    final TreeMap<Language, Stemmer> langs = new TreeMap<>();
     for(final Stemmer stem : Stemmer.IMPL) {
       for(final Language l : stem.languages()) {
         if(langs.containsKey(l)) continue;
@@ -213,6 +240,6 @@ public final class FTLexer extends FTIterator implements IndexToken {
     for(final Entry<Language, Stemmer> l : langs.entrySet()) {
       sl.add(l.getKey() + " (" + l.getValue() + ')');
     }
-    return sl.sort(true);
+    return sl.sort();
   }
 }
