@@ -4,10 +4,10 @@ package org.basex.util.ft;
  * Internal stemmer implementation.
  * The names of the implementations
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
-public abstract class InternalStemmer extends Stemmer {
+abstract class InternalStemmer extends Stemmer {
   /**
    * Constructor.
    * @param fti full-text iterator
