@@ -12,15 +12,14 @@ import org.basex.util.*;
  * The Lucene stemmers are based on the Apache License:
  * {@code http://lucene.apache.org/}.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 final class LuceneStemmer extends Stemmer {
   /** Name of the package with all Lucene stemmers. */
   private static final String PATTERN = "org.apache.lucene.analysis.%Stemmer";
   /** Stemmer classes which the Lucene library provides. */
-  private static final HashMap<Language, StemmerClass> CLASSES =
-      new HashMap<Language, StemmerClass>();
+  private static final HashMap<Language, StemmerClass> CLASSES = new HashMap<>();
 
   /** Stemmer class corresponding to the required properties. */
   private StemmerClass clazz;
@@ -102,8 +101,8 @@ final class LuceneStemmer extends Stemmer {
   }
 
   @Override
-  Stemmer get(final Language l, final FTIterator fti) {
-    return new LuceneStemmer(l, fti);
+  Stemmer get(final Language lang, final FTIterator fti) {
+    return new LuceneStemmer(lang, fti);
   }
 
   @Override
@@ -141,14 +140,14 @@ final class LuceneStemmer extends Stemmer {
 
     /**
      * Constructor.
-     * @param sc class implementing the stemmer
-     * @param stm method {@code stem}
-     * @param ch indicator for stemming via character array
+     * @param clz class implementing the stemmer
+     * @param stem method {@code stem}
+     * @param chars indicator for stemming via character array
      */
-    StemmerClass(final Class<?> sc, final Method stm, final boolean ch) {
-      clz = sc;
-      stem = stm;
-      chars = ch;
+    StemmerClass(final Class<?> clz, final Method stem, final boolean chars) {
+      this.clz = clz;
+      this.stem = stem;
+      this.chars = chars;
       stem.setAccessible(true);
     }
   }
