@@ -10,7 +10,7 @@ import org.basex.util.*;
 /**
  * This is an efficient and memory-saving hash map for storing tokens and integers.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class TokenIntMap extends TokenSet {
@@ -68,8 +68,8 @@ public final class TokenIntMap extends TokenSet {
   }
 
   @Override
-  protected void rehash(final int s) {
-    super.rehash(s);
-    values = Arrays.copyOf(values, s);
+  protected void rehash(final int sz) {
+    super.rehash(sz);
+    values = Arrays.copyOf(values, sz);
   }
 }
