@@ -3,16 +3,16 @@ package org.basex.util.options;
 /**
  * Comment.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class Comment extends Option<Object> {
   /**
    * Constructor without default value.
-   * @param n name
+   * @param name name
    */
-  public Comment(final String n) {
-    super(n);
+  public Comment(final String name) {
+    super(name);
   }
 
   @Override
