@@ -3,7 +3,7 @@ package org.basex.util.options;
 /**
  * Option containing an enumeration value.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  * @param <V> enumeration value
  */
@@ -15,24 +15,24 @@ public final class EnumOption<V extends Enum<V>> extends Option<V> {
 
   /**
    * Constructor.
-   * @param n name
-   * @param v value
+   * @param name name
+   * @param value value
    */
   @SuppressWarnings("unchecked")
-  public EnumOption(final String n, final V v) {
-    super(n);
-    value = v;
-    clazz = (Class<V>) v.getClass();
+  public EnumOption(final String name, final V value) {
+    super(name);
+    this.value = value;
+    clazz = (Class<V>) value.getClass();
   }
 
   /**
    * Constructor.
-   * @param n name
-   * @param v value
+   * @param name name
+   * @param clazz class
    */
-  public EnumOption(final String n, final Class<V> v) {
-    super(n);
-    clazz = v;
+  public EnumOption(final String name, final Class<V> clazz) {
+    super(name);
+    this.clazz = clazz;
     value = null;
   }
 
@@ -42,7 +42,7 @@ public final class EnumOption<V extends Enum<V>> extends Option<V> {
   }
 
   /**
-   * Returns an enumeration value for the specified string, or {@code null}.
+   * Returns an enumeration value for the specified string or {@code null}.
    * @param string value
    * @return enumeration
    */
