@@ -1,10 +1,9 @@
 package org.basex.util.options;
 
-
 /**
  * Single option, stored in {@link Options} instances.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  * @param <O> option type
  */
@@ -14,10 +13,10 @@ public abstract class Option<O> {
 
   /**
    * Constructor without default value.
-   * @param n name
+   * @param name name
    */
-  Option(final String n) {
-    name = n;
+  Option(final String name) {
+    this.name = name;
   }
 
   /**
@@ -32,13 +31,13 @@ public abstract class Option<O> {
    * Returns the default value.
    * @return default value
    */
-  public abstract Object value();
+  public abstract O value();
 
   /**
    * Copies mutable default values. Otherwise, returns the existing instance.
    * @return default value
    */
-  public Object copy() {
+  public O copy() {
     return value();
   }
 
