@@ -12,7 +12,13 @@ import java.util.Map.Entry;
 import org.basex.core.*;
 import org.basex.io.*;
 import org.basex.io.in.*;
+import org.basex.query.*;
+import org.basex.query.value.*;
+import org.basex.query.value.item.*;
+import org.basex.query.value.map.Map;
+import org.basex.query.value.type.*;
 import org.basex.util.*;
+import org.basex.util.http.*;
 import org.basex.util.list.*;
 
 /**
@@ -21,22 +27,45 @@ import org.basex.util.list.*;
  * If an instance of this class contains no pre-defined options, assigned options will
  * be added as free options.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public class Options implements Iterable<Option<?>> {
+  /** Yes/No enumeration. */
+  public enum YesNo {
+    /** Yes. */ YES,
+    /** No.  */ NO;
+
+    @Override
+    public String toString() {
+      return super.toString().toLowerCase(Locale.ENGLISH);
+    }
+  }
+
+  /** Yes/No/Omit enumeration. */
+  public enum YesNoOmit {
+    /** Yes.  */ YES,
+    /** No.   */ NO,
+    /** Omit. */ OMIT;
+
+    @Override
+    public String toString() {
+      return super.toString().toLowerCase(Locale.ENGLISH);
+    }
+  }
+
   /** Comment in configuration file. */
   private static final String PROPUSER = "# Local Options";
 
   /** Map with option names and definition. */
-  protected final TreeMap<String, Option<?>> options = new TreeMap<String, Option<?>>();
+  protected final TreeMap<String, Option<?>> options = new TreeMap<>();
   /** Map with option names and values. */
-  private final TreeMap<String, Object> values = new TreeMap<String, Object>();
+  private final TreeMap<String, Object> values = new TreeMap<>();
   /** Free option definitions. */
-  private final HashMap<String, String> free = new HashMap<String, String>();
-  /** Options, cached from an input file. */
-  private final StringBuilder user = new StringBuilder();
+  private final HashMap<String, String> free = new HashMap<>();
 
+  /** Options, cached from an input file. */
+  private final StringList user = new StringList();
   /** Options file. */
   private IOFile file;
 
@@ -44,7 +73,7 @@ public class Options implements Iterable<Option<?>> {
    * Default constructor.
    */
   public Options() {
-    this(null);
+    this((IOFile) null);
   }
 
   /**
@@ -52,14 +81,6 @@ public class Options implements Iterable<Option<?>> {
    * @param opts options file
    */
   protected Options(final IOFile opts) {
-    init();
-    if(opts != null) read(opts);
-  }
-
-  /**
-   * Initializes all options.
-   */
-  private void init() {
     try {
       for(final Option<?> opt : options(getClass())) {
         if(opt instanceof Comment) continue;
@@ -70,40 +91,56 @@ public class Options implements Iterable<Option<?>> {
     } catch(final Exception ex) {
       throw Util.notExpected(ex);
     }
+    if(opts != null) read(opts);
+  }
+
+  /**
+   * Constructor with options to be copied.
+   * @param opts options
+   */
+  protected Options(final Options opts) {
+    for(final Entry<String, Option<?>> e : opts.options.entrySet())
+      options.put(e.getKey(), e.getValue());
+    for(final Entry<String, Object> e : opts.values.entrySet())
+      values.put(e.getKey(), e.getValue());
+    for(final Entry<String, String> e : opts.free.entrySet())
+      free.put(e.getKey(), e.getValue());
+    user.add(opts.user);
+    file = opts.file;
   }
 
   /**
    * Writes the options to disk.
    */
   public final synchronized void write() {
-    final TokenBuilder tmp = new TokenBuilder();
+    final StringList lines = new StringList();
     try {
-      boolean first = true;
       for(final Option<?> opt : options(getClass())) {
         final String name = opt.name();
         if(opt instanceof Comment) {
-          if(!first) tmp.add(NL);
-          tmp.add("# " + name).add(NL);
+          if(!lines.isEmpty()) lines.add("");
+          lines.add("# " + name);
         } else if(opt instanceof NumbersOption) {
           final int[] ints = get((NumbersOption) opt);
           final int is = ints == null ? 0 : ints.length;
-          for(int i = 0; i < is; ++i) tmp.add(name + i + " = " + ints[i]).add(NL);
+          for(int i = 0; i < is; ++i) lines.add(name + i + " = " + ints[i]);
         } else if(opt instanceof StringsOption) {
           final String[] strings = get((StringsOption) opt);
           final int ss = strings == null ? 0 : strings.length;
-          tmp.add(name + " = " + ss).add(NL);
-          for(int i = 0; i < ss; ++i) tmp.add(name + (i + 1) + " = " + strings[i]).add(NL);
+          lines.add(name + " = " + ss);
+          for(int i = 0; i < ss; ++i) lines.add(name + (i + 1) + " = " + strings[i]);
         } else {
-          tmp.add(name + " = " + get(opt)).add(NL);
+          lines.add(name + " = " + get(opt));
         }
-        first = false;
       }
-      tmp.add(NL).add(PROPUSER).add(NL);
-      tmp.add(user.toString());
-      final byte[] content = tmp.array();
+      lines.add("").add(PROPUSER).add(user);
 
       // only write file if contents have changed
-      if(!file.exists() || !eq(content, file.read())) file.write(content);
+      if(update(lines)) {
+        final TokenBuilder tb = new TokenBuilder();
+        for(final String line : lines) tb.add(line).add(NL);
+        file.write(tb.finish());
+      }
 
     } catch(final Exception ex) {
       Util.errln("% could not be written.", file);
@@ -175,42 +212,50 @@ public class Options implements Iterable<Option<?>> {
   }
 
   /**
-   * Returns the requested string array.
+   * Returns the requested map.
+   * @param option option to be found
+   * @return value
+   */
+  public final synchronized Map get(final MapOption option) {
+    return (Map) get((Option<?>) option);
+  }
+
+  /**
+   * Returns the requested function.
+   * @param option option to be found
+   * @return value
+   */
+  public final synchronized FuncItem get(final FuncOption option) {
+    return (FuncItem) get((Option<?>) option);
+  }
+
+  /**
+   * Returns the original instance of the requested string array.
    * @param option option to be found
    * @return value
    */
   public final synchronized String[] get(final StringsOption option) {
-    final String[] v = (String[]) get((Option<?>) option);
-    return v == null ? null : v.clone();
+    return (String[]) get((Option<?>) option);
   }
 
   /**
-   * Returns the requested integer array.
+   * Returns the original instance of the requested integer array.
    * @param option option to be found
    * @return value
    */
   public final synchronized int[] get(final NumbersOption option) {
-    final int[] v = (int[]) get((Option<?>) option);
-    return v == null ? null : v.clone();
+    return (int[]) get((Option<?>) option);
   }
 
   /**
-   * Returns the requested options.
+   * Returns the original instance of the requested options.
    * @param option option to be found
    * @param <O> options
    * @return value
    */
   @SuppressWarnings("unchecked")
   public final synchronized <O extends Options> O get(final OptionsOption<O> option) {
-    final O o = (O) get((Option<?>) option);
-    if(o == null) return null;
-    try {
-      final O n = ((Class<O>) o.getClass()).newInstance();
-      n.parse(o.toString());
-      return n;
-    } catch(final Exception ex) {
-      throw Util.notExpected(ex);
-    }
+    return (O) get((Option<?>) option);
   }
 
   /**
@@ -317,6 +362,26 @@ public class Options implements Iterable<Option<?>> {
     }
   }
 
+  /**
+   * Assigns a value after casting it to the correct type. If the option is unknown,
+   * it will be added as free option.
+   * @param name name of option
+   * @param val value
+   * @param error error
+   * @throws BaseXException database exception
+   * @throws QueryException query exception
+   */
+  public synchronized void assign(final Item name, final Item val, final boolean error)
+      throws BaseXException, QueryException {
+
+    final String key = string(name.string(null));
+    if(options.isEmpty()) {
+      free.put(key, string(val.string(null)));
+    } else {
+      assign(key, val, error);
+    }
+  }
+
   /**
    * Returns all name/value pairs without pre-defined option.
    * @return options
@@ -351,19 +416,75 @@ public class Options implements Iterable<Option<?>> {
    * All properties starting with {@code org.basex.} will be assigned as options.
    */
   public final void setSystem() {
-    // collect parameters that start with "org.basex."
-    final StringList sl = new StringList();
-    for(final Object key : System.getProperties().keySet()) {
-      final String k = key.toString();
-      if(k.startsWith(DBPREFIX)) sl.add(k);
-    }
-    // assign properties
-    for(final String key : sl) {
-      final String v = System.getProperty(key);
+    // assign global options
+    for(final Entry<String, String> entry : Prop.entries()) {
+      final String n = entry.getKey(), v = entry.getValue().toString();
       try {
-        final String k = key.substring(DBPREFIX.length()).toUpperCase(Locale.ENGLISH);
-        if(assign(k, v, -1, false)) Util.debug(k + Text.COLS + v);
-      } catch(final BaseXException ignore) { /* may belong to another Options instance */ }
+        if(assign(n, v, -1, false)) Util.debug(n + Text.COLS + v);
+      } catch(final BaseXException ex) {
+        Util.errln(ex);
+      }
+    }
+  }
+
+  /**
+   * Parses the specified options.
+   * @param type media type
+   * @throws BaseXException database exception
+   */
+  public synchronized void parse(final MediaType type) throws BaseXException {
+    for(final Entry<String, String> entry : type.parameters().entrySet()) {
+      if(options.isEmpty()) {
+        free.put(entry.getKey(), entry.getValue());
+      } else {
+        // ignore unknown options
+        assign(entry.getKey(), entry.getValue(), -1, false);
+      }
+    }
+  }
+
+  /**
+   * Parses an option string and sets the options accordingly.
+   * @param string options string
+   * @throws BaseXException database exception
+   */
+  public synchronized void parse(final String string) throws BaseXException {
+    final int sl = string.length();
+    int i = 0;
+    while(i < sl) {
+      int k = string.indexOf('=', i);
+      if(k == -1) k = sl;
+      final String key = string.substring(i, k).trim();
+      final StringBuilder val = new StringBuilder();
+      i = k;
+      while(++i < sl) {
+        final char ch = string.charAt(i);
+        if(ch == ',' && (++i == sl || string.charAt(i) != ',')) break;
+        val.append(ch);
+      }
+      assign(key, val.toString());
+    }
+  }
+
+  /**
+   * Parses options in the specified map.
+   * @param map map
+   * @param error raise error if option is unknown
+   * @throws BaseXException database exception
+   * @throws QueryException query exception
+   */
+  public synchronized void parse(final Map map, final boolean error)
+      throws BaseXException, QueryException {
+
+    for(final Item name : map.keys()) {
+      if(!name.type.isStringOrUntyped())
+        throw new BaseXException(Text.OPT_EXPECT, AtomType.STR, name.type, name);
+
+      final Value value = map.get(name, null);
+      if(!(value instanceof Item))
+        throw new BaseXException(Text.OPT_EXPECT, AtomType.ITEM, value.seqType(), value);
+
+      assign(name, (Item) value, error);
     }
   }
 
@@ -374,7 +495,7 @@ public class Options implements Iterable<Option<?>> {
 
   @Override
   public final synchronized String toString() {
-    // only those options are listed the value of which differs from default value
+    // only those options are listed whose value differs from default value
     final StringBuilder sb = new StringBuilder();
     for(final Entry<String, Object> e : values.entrySet()) {
       final String name = e.getKey();
@@ -403,57 +524,6 @@ public class Options implements Iterable<Option<?>> {
 
   // STATIC METHODS =====================================================================
 
-  /**
-   * Returns a system property. If necessary, the key will be converted to lower-case
-   * and prefixed with the {@link Prop#DBPREFIX} string.
-   * @param option option
-   * @return value, or empty string
-   */
-  public static String getSystem(final Option<?> option) {
-    String name = option.name().toLowerCase(Locale.ENGLISH);
-    if(!name.startsWith(DBPREFIX)) name = DBPREFIX + name;
-    final String v = System.getProperty(name);
-    return v == null ? "" : v;
-  }
-
-  /**
-   * Sets a system property if it has not been set before.
-   * @param option option
-   * @param val value
-   */
-  public static void setSystem(final Option<?> option, final Object val) {
-    setSystem(option.name(), val);
-  }
-
-  /**
-   * Sets a system property if it has not been set before. If necessary, the key will
-   * be converted to lower-case and prefixed with the {@link Prop#DBPREFIX} string.
-   * @param key key
-   * @param val value
-   */
-  public static void setSystem(final String key, final Object val) {
-    final String name = key.indexOf('.') == -1 ? DBPREFIX + key.toLowerCase(Locale.ENGLISH) : key;
-    if(System.getProperty(name) == null) System.setProperty(name, val.toString());
-  }
-
-  /**
-   * Returns all options from the specified class.
-   * @param clz options class
-   * @return option instances
-   * @throws IllegalAccessException exception
-   */
-  public static Option<?>[] options(final Class<? extends Options> clz)
-      throws IllegalAccessException {
-
-    final ArrayList<Option<?>> opts = new ArrayList<Option<?>>();
-    for(final Field f : clz.getFields()) {
-      if(!Modifier.isStatic(f.getModifiers())) continue;
-      final Object obj = f.get(null);
-      if(obj instanceof Option) opts.add((Option<?>) obj);
-    }
-    return opts.toArray(new Option[opts.size()]);
-  }
-
   /**
    * Returns a list of allowed keys.
    * @param option option
@@ -469,26 +539,21 @@ public class Options implements Iterable<Option<?>> {
   // PRIVATE METHODS ====================================================================
 
   /**
-   * Parses an option string and sets the options accordingly.
-   * @param string options string
-   * @throws BaseXException database exception
+   * Returns all options from the specified class.
+   * @param clz options class
+   * @return option instances
+   * @throws IllegalAccessException exception
    */
-  public synchronized void parse(final String string) throws BaseXException {
-    final int sl = string.length();
-    int i = 0;
-    while(i < sl) {
-      int k = string.indexOf('=', i);
-      if(k == -1) k = sl;
-      final String key = string.substring(i, k).trim();
-      final StringBuilder val = new StringBuilder();
-      i = k;
-      while(++i < sl) {
-        final char ch = string.charAt(i);
-        if(ch == ',' && (++i == sl || string.charAt(i) != ',')) break;
-        val.append(ch);
-      }
-      assign(key, val.toString());
+  private static Option<?>[] options(final Class<? extends Options> clz)
+      throws IllegalAccessException {
+
+    final ArrayList<Option<?>> opts = new ArrayList<>();
+    for(final Field f : clz.getFields()) {
+      if(!Modifier.isStatic(f.getModifiers())) continue;
+      final Object obj = f.get(null);
+      if(obj instanceof Option) opts.add((Option<?>) obj);
     }
+    return opts.toArray(new Option[opts.size()]);
   }
 
   /**
@@ -502,9 +567,7 @@ public class Options implements Iterable<Option<?>> {
     final StringList errs = new StringList();
     final boolean exists = file.exists();
     if(exists) {
-      NewlineInput nli = null;
-      try {
-        nli = new NewlineInput(opts);
+      try(final NewlineInput nli = new NewlineInput(opts)) {
         boolean local = false;
         for(String line; (line = nli.readLine()) != null;) {
           line = line.trim();
@@ -514,7 +577,7 @@ public class Options implements Iterable<Option<?>> {
             local = true;
             continue;
           }
-          if(local) user.append(line).append(NL);
+          if(local) user.add(line);
 
           if(line.isEmpty() || line.charAt(0) == '#') continue;
           final int d = line.indexOf('=');
@@ -531,7 +594,7 @@ public class Options implements Iterable<Option<?>> {
           final int ss = name.length();
           for(int s = 0; s < ss; ++s) {
             if(Character.isDigit(name.charAt(s))) {
-              num = toInt(name.substring(s));
+              num = Strings.toInt(name.substring(s));
               name = name.substring(0, s);
               break;
             }
@@ -539,7 +602,7 @@ public class Options implements Iterable<Option<?>> {
 
           if(local) {
             // cache local options as system properties
-            setSystem(name, val);
+            Prop.put(name, val);
           } else {
             try {
               assign(name, val, num, true);
@@ -552,8 +615,6 @@ public class Options implements Iterable<Option<?>> {
       } catch(final IOException ex) {
         errs.add("file could not be parsed.");
         Util.errln(ex);
-      } finally {
-        if(nli != null) try { nli.close(); } catch(final IOException ignored) { }
       }
     }
 
@@ -576,16 +637,106 @@ public class Options implements Iterable<Option<?>> {
     }
   }
 
+  /**
+   * Checks if the options file needs to be updated.
+   * @param lines lines of new file
+   * @return result of check
+   * @throws IOException I/O exception
+   */
+  private boolean update(final StringList lines) throws IOException {
+    if(!file.exists()) return true;
+
+    int l = 0;
+    final int ls = lines.size();
+    try(final NewlineInput nli = new NewlineInput(file)) {
+      for(String line; (line = nli.readLine()) != null;) {
+        if(l == ls || !lines.get(l++).equals(line)) return true;
+      }
+    }
+    return l != ls;
+  }
+
+  /**
+   * Assigns the specified name and value.
+   * @param name name of option
+   * @param item value of option
+   * @param error raise error if option is unknown
+   * @return success flag
+   * @throws BaseXException database exception
+   * @throws QueryException query exception
+   */
+  private synchronized boolean assign(final String name, final Item item, final boolean error)
+      throws BaseXException, QueryException {
+
+    final Option<?> option = options.get(name);
+    if(option == null) {
+      if(error) throw new BaseXException(error(name));
+      return false;
+    }
+
+    if(option instanceof BooleanOption) {
+      final boolean v;
+      if(item.type.isStringOrUntyped()) {
+        v = Strings.yes(string(item.string(null)));
+        if(!v && !Strings.no(string(item.string(null))))
+          throw new BaseXException(Text.OPT_BOOLEAN, option.name());
+      } else if(item instanceof Bln) {
+        v = ((Bln) item).bool(null);
+      } else {
+        throw new BaseXException(Text.OPT_BOOLEAN, option.name());
+      }
+      put(option, v);
+    } else if(option instanceof NumberOption) {
+      if(item instanceof ANum) {
+        put(option, (int) ((ANum) item).itr(null));
+      } else {
+        throw new BaseXException(Text.OPT_NUMBER, option.name());
+      }
+    } else if(option instanceof StringOption) {
+      if(item.type.isStringOrUntyped()) {
+        put(option, string(item.string(null)));
+      } else {
+        throw new BaseXException(Text.OPT_STRING, option.name());
+      }
+    } else if(option instanceof EnumOption) {
+      if(item.type.isStringOrUntyped()) {
+        final EnumOption<?> eo = (EnumOption<?>) option;
+        final Object v = eo.get(string(item.string(null)));
+        if(v == null) throw new BaseXException(allowed(option, (Object[]) eo.values()));
+        put(option, v);
+      } else {
+        throw new BaseXException(Text.OPT_STRING, option.name());
+      }
+    } else if(option instanceof OptionsOption) {
+      final Options o = ((OptionsOption<?>) option).newInstance();
+      if(item instanceof Map) {
+        o.parse((Map) item, error);
+      } else {
+        throw new BaseXException(Text.OPT_MAP, option.name());
+      }
+      put(option, o);
+    } else if(option instanceof MapOption) {
+      if(!(item instanceof Map)) throw new BaseXException(Text.OPT_FUNC, option.name());
+      put(option, item);
+    } else if(option instanceof FuncOption) {
+      if(!(item instanceof FuncItem)) throw new BaseXException(Text.OPT_FUNC, option.name());
+      put(option, item);
+    } else {
+      throw Util.notExpected("Unsupported option: " + option);
+    }
+    return true;
+  }
+
   /**
    * Assigns the specified name and value.
    * @param name name of option
    * @param val value of option
-   * @param num number (optional)
+   * @param index index (optional, can be {@code -1})
    * @param error raise error if option is unknown
-   * @throws BaseXException database exception
    * @return success flag
+   * @throws BaseXException database exception
    */
-  private synchronized boolean assign(final String name, final String val, final int num,
+  private synchronized boolean assign(final String name, final String val, final int index,
       final boolean error) throws BaseXException {
 
     final Option<?> option = options.get(name);
@@ -601,12 +752,12 @@ public class Options implements Iterable<Option<?>> {
         if(b == null) throw new BaseXException(Text.OPT_BOOLEAN, option.name());
         v = !b;
       } else {
-        v = Util.yes(val);
-        if(!v && !Util.no(val)) throw new BaseXException(Text.OPT_BOOLEAN, option.name());
+        v = Strings.yes(val);
+        if(!v && !Strings.no(val)) throw new BaseXException(Text.OPT_BOOLEAN, option.name());
       }
       put(option, v);
     } else if(option instanceof NumberOption) {
-      final int v = toInt(val);
+      final int v = Strings.toInt(val);
       if(v == MIN_VALUE) throw new BaseXException(Text.OPT_NUMBER, option.name());
       put(option, v);
     } else if(option instanceof StringOption) {
@@ -621,41 +772,43 @@ public class Options implements Iterable<Option<?>> {
       o.parse(val);
       put(option, o);
     } else if(option instanceof NumbersOption) {
-      final int v = toInt(val);
+      final int v = Strings.toInt(val);
       if(v == MIN_VALUE) throw new BaseXException(Text.OPT_NUMBER, option.name());
       int[] ii = (int[]) get(option);
-      if(num == -1) {
+      if(index == -1) {
         if(ii == null) ii = new int[0];
         final IntList il = new IntList(ii.length + 1);
         for(final int i : ii) il.add(i);
-        il.add(v);
-        put(option, il.toArray());
+        put(option, il.add(v).finish());
       } else {
-        if(num < 0 || num >= ii.length) throw new BaseXException(Text.OPT_OFFSET, option.name());
-        ii[num] = v;
+        if(index < 0 || index >= ii.length)
+          throw new BaseXException(Text.OPT_OFFSET, option.name());
+        ii[index] = v;
       }
     } else if(option instanceof StringsOption) {
       String[] ss = (String[]) get(option);
-      if(num == -1) {
+      if(index == -1) {
         if(ss == null) ss = new String[0];
         final StringList sl = new StringList(ss.length + 1);
         for(final String s : ss) sl.add(s);
-        sl.add(val);
-        put(option, sl.toArray());
-      } else if(num == 0) {
-        final int v = toInt(val);
+        put(option, sl.add(val).finish());
+      } else if(index == 0) {
+        final int v = Strings.toInt(val);
         if(v == MIN_VALUE) throw new BaseXException(Text.OPT_NUMBER, option.name());
         values.put(name, new String[v]);
       } else {
-        if(num <= 0 || num > ss.length) throw new BaseXException(Text.OPT_OFFSET, option.name());
-        ss[num - 1] = val;
+        if(index <= 0 || index > ss.length)
+          throw new BaseXException(Text.OPT_OFFSET, option.name());
+        ss[index - 1] = val;
       }
+    } else {
+      throw Util.notExpected("Unsupported option: " + option);
     }
     return true;
   }
 
   /**
-   * Returns an option name similar to the specified string, or {@code null}.
+   * Returns an option name similar to the specified string or {@code null}.
    * @param name name to be found
    * @return similar name
    */
