@@ -1,10 +1,12 @@
 package org.basex.core;
 
+import static org.basex.query.func.Function.*;
 import static org.junit.Assert.*;
 
-import org.basex.core.cmd.*;
-import org.basex.index.*;
 import org.basex.*;
+import org.basex.core.cmd.*;
+import org.basex.core.locks.*;
+import org.basex.index.*;
 import org.basex.query.func.*;
 import org.basex.util.list.*;
 import org.junit.Test;
@@ -13,10 +15,10 @@ import org.junit.Test;
  * This class tests commands and XQueries for correct identification of databases
  * to lock.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Jens Erat
  */
-public class CommandLockingTest extends SandboxTest {
+public final class CommandLockingTest extends SandboxTest {
   /** Static dummy context so we do not have to create a new one every time. */
   private static final Context DUMMY_CONTEXT = new Context();
   /** Test file name. */
@@ -34,23 +36,17 @@ public class CommandLockingTest extends SandboxTest {
   /** StringList containing name. */
   private static final StringList NAME_LIST = new StringList(NAME);
   /** StringList containing context. */
-  private static final StringList CTX_LIST = new StringList(DBLocking.CTX);
-  /** StringList containing collection. */
-  private static final StringList COLL_LIST = new StringList(DBLocking.COLL);
+  private static final StringList CTX_LIST = new StringList(DBLocking.CONTEXT);
   /** StringList containing name and context. */
-  private static final StringList NAME_CTX = new StringList(NAME, DBLocking.CTX);
+  private static final StringList NAME_CTX = new StringList(NAME, DBLocking.CONTEXT);
   /** StringList containing ADMIN lock string. */
   private static final StringList ADMIN_LIST = new StringList(DBLocking.ADMIN);
-  /** StringList containing ADMIN lock string and name. */
-  private static final StringList ADMIN_NAME = new StringList(DBLocking.ADMIN, NAME);
   /** StringList containing REPO lock string. */
   private static final StringList REPO_LIST = new StringList(DBLocking.REPO);
   /** StringList containing BACKUP lock string. */
   private static final StringList BACKUP_LIST = new StringList(DBLocking.BACKUP);
   /** StringList containing BACKUP lock string and name. */
   private static final StringList BACKUP_NAME = new StringList(DBLocking.BACKUP, NAME);
-  /** StringList containing EVENT lock string. */
-  private static final StringList EVENT_LIST = new StringList(DBLocking.EVENT);
   /** StringList containing java module test lock strings. */
   private static final StringList MODULE_LIST = new StringList(DBLocking.MODULE_PREFIX
       + QueryModuleTest.LOCK1, DBLocking.MODULE_PREFIX + QueryModuleTest.LOCK2);
@@ -58,23 +54,22 @@ public class CommandLockingTest extends SandboxTest {
    * Test commands affecting databases.
    */
   @Test
-  public final void databaseCommands() {
+  public void databaseCommands() {
     ckDBs(new Add(FILE, FILE), true, CTX_LIST);
     ckDBs(new AlterDB(NAME, NAME2), true, new StringList(NAME, NAME2));
+    ckDBs(new AlterPassword(NAME, NAME), true, ADMIN_LIST);
     ckDBs(new AlterUser(NAME, NAME), true, ADMIN_LIST);
     ckDBs(new Check(NAME), false, NAME_CTX);
     ckDBs(new Close(), false, CTX_LIST);
     ckDBs(new Copy(NAME2, NAME), new StringList(NAME2), NAME_LIST);
     ckDBs(new CreateBackup(NAME), NAME_LIST, BACKUP_LIST);
     ckDBs(new CreateDB(NAME), CTX_LIST, NAME_LIST);
-    ckDBs(new CreateEvent(NAME), true, EVENT_LIST);
     ckDBs(new CreateIndex(IndexType.TEXT), true, CTX_LIST);
     ckDBs(new CreateUser(NAME, NAME), true, ADMIN_LIST);
     ckDBs(new Delete(FILE), true, CTX_LIST);
     ckDBs(new DropBackup(NAME), true, BACKUP_LIST);
     ckDBs(new DropDB(NAME + '*'), true, null); // Drop using globbing
     ckDBs(new DropDB(NAME), true, NAME_LIST);
-    ckDBs(new DropEvent(NAME), true, EVENT_LIST);
     ckDBs(new DropIndex(IndexType.TEXT), true, CTX_LIST);
     ckDBs(new DropUser(NAME), true, ADMIN_LIST);
     ckDBs(new Execute("RUN " + FILE), true, null);
@@ -83,8 +78,8 @@ public class CommandLockingTest extends SandboxTest {
     ckDBs(new Flush(), true, CTX_LIST);
     ckDBs(new Get("DBPATH"), false, NONE);
     ckDBs(new Grant("all", NAME), true, ADMIN_LIST);
-    ckDBs(new Grant("all", NAME, NAME), true, ADMIN_NAME);
-    ckDBs(new Grant("all", NAME, NAME + '*'), true, null);
+    ckDBs(new Grant("all", NAME, NAME), true, ADMIN_LIST);
+    ckDBs(new Grant("all", NAME, NAME + '*'), true, ADMIN_LIST);
     ckDBs(new Help("HELP"), false, NONE);
     ckDBs(new Info(), false, NONE);
     ckDBs(new InfoDB(), false, CTX_LIST);
@@ -108,10 +103,9 @@ public class CommandLockingTest extends SandboxTest {
     ckDBs(new Run(FILE), true, null);
     ckDBs(new Set(NAME, NAME), false, NONE);
     ckDBs(new ShowBackups(), false, BACKUP_LIST);
-    ckDBs(new ShowEvents(), false, EVENT_LIST);
     ckDBs(new ShowSessions(), false, NONE);
     ckDBs(new ShowUsers(), false, ADMIN_LIST);
-    ckDBs(new ShowUsers(NAME), false, ADMIN_NAME);
+    ckDBs(new ShowUsers(NAME), false, ADMIN_LIST);
     ckDBs(new Store(FILE), true, CTX_LIST);
   }
 
@@ -120,56 +114,64 @@ public class CommandLockingTest extends SandboxTest {
   @Test
   public void xquery() throws BaseXException {
     // Basic document access
-    ckDBs(new XQuery("collection('" + NAME + "')"), false, NAME_LIST);
-    ckDBs(new XQuery("collection()"), false, COLL_LIST);
+    ckDBs(new XQuery(COLLECTION.args(NAME)), false, NAME_LIST);
+    ckDBs(new XQuery(COLLECTION.args()), false, CTX_LIST);
     // fn:collection() always accesses the global context, no matter what local context is
-    ckDBs(new XQuery("<a/>/count(collection())"), false, COLL_LIST);
-    ckDBs(new XQuery("doc('" + NAME + "')"), false, NAME_LIST);
-    ckDBs(new XQuery("doc-available('" + NAME + "/foo.xml')"), false, NAME_LIST, null);
-    ckDBs(new XQuery("parse-xml('<foo/>')"), true, NONE);
-    ckDBs(new XQuery("parse-xml-fragment('<foo/>')"), true, NONE);
-    ckDBs(new XQuery("put(<foo/>, '" + NAME + "')"), true, NONE);
-    ckDBs(new XQuery("put(., '" + NAME + "')"), true, CTX_LIST);
-    ckDBs(new XQuery("root()"), false, CTX_LIST);
-    ckDBs(new XQuery("root(.)"), false, CTX_LIST);
-    ckDBs(new XQuery("root(./test)"), false, CTX_LIST);
-    ckDBs(new XQuery("serialize('<foo/>')"), true, NONE);
-    ckDBs(new XQuery("unparsed-text('" + FILE + "')"), false, NONE);
-    ckDBs(new XQuery("unparsed-text-available('" + FILE + "')"), false, NONE);
-    ckDBs(new XQuery("unparsed-text-lines('" + FILE + "')"), false, NONE);
-    ckDBs(new XQuery("uri-collection('" + NAME + "')"), false, NAME_LIST);
-    ckDBs(new XQuery("uri-collection()"), false, COLL_LIST);
+    ckDBs(new XQuery("<a/>/" + COUNT.args(COLLECTION.args())), false, CTX_LIST);
+    ckDBs(new XQuery(DOC.args(NAME)), false, NAME_LIST);
+    ckDBs(new XQuery(ID.args(NAME)), false, CTX_LIST);
+    ckDBs(new XQuery(IDREF.args(NAME)), false, CTX_LIST);
+    ckDBs(new XQuery(ELEMENT_WITH_ID.args(NAME)), false, CTX_LIST);
+    ckDBs(new XQuery(LANG.args(NAME)), false, CTX_LIST);
+    ckDBs(new XQuery(ID.args(NAME, DOC.args(NAME))), false, NAME_LIST);
+    ckDBs(new XQuery(IDREF.args(NAME, DOC.args(NAME))), false, NAME_LIST);
+    ckDBs(new XQuery(ELEMENT_WITH_ID.args(NAME, DOC.args(NAME))), false, NAME_LIST);
+    ckDBs(new XQuery(LANG.args(NAME, DOC.args(NAME))), false, NAME_LIST);
+    ckDBs(new XQuery(DOC_AVAILABLE.args(NAME + "/foo.xml")), false, NAME_LIST, null);
+    ckDBs(new XQuery(PARSE_XML.args("<foo/>")), true, NONE);
+    ckDBs(new XQuery(PARSE_XML_FRAGMENT.args("<foo/>")), true, NONE);
+    ckDBs(new XQuery(PUT.args("<foo/>", NAME)), true, NONE);
+    ckDBs(new XQuery(PUT.args(" .", NAME)), true, CTX_LIST);
+    ckDBs(new XQuery(ROOT.args()), false, CTX_LIST);
+    ckDBs(new XQuery(ROOT.args(" .")), false, CTX_LIST);
+    ckDBs(new XQuery(ROOT.args(" ./test")), false, CTX_LIST);
+    ckDBs(new XQuery(ROOT.args("<foo/>")), true, NONE);
+    ckDBs(new XQuery(UNPARSED_TEXT.args(FILE)), false, NONE);
+    ckDBs(new XQuery(UNPARSED_TEXT_AVAILABLE.args(FILE)), false, NONE);
+    ckDBs(new XQuery(UNPARSED_TEXT_LINES.args(FILE)), false, NONE);
+    ckDBs(new XQuery(URI_COLLECTION.args(NAME)), false, NAME_LIST);
+    ckDBs(new XQuery(URI_COLLECTION.args()), false, CTX_LIST);
 
     // Accessor and node functions
-    for(final String fn : new String[] { "data", "string", "number", "string-length",
-        "normalize-space", "document-uri", "nilled", "node-name", "local-name", "name",
-        "namespace-uri", "root", "base-uri", "generate-id", "has-children", "path"}) {
-      ckDBs(new XQuery(fn + "()"), false, CTX_LIST);
-      ckDBs(new XQuery("doc('" + NAME + "')/" + fn + "()"), false, NAME_LIST, NAME_CTX);
+    for(final Function fn : new Function[] { DATA, STRING, NUMBER, STRING_LENGTH, NORMALIZE_SPACE,
+        DOCUMENT_URI, NILLED, NODE_NAME, LOCAL_NAME, Function.NAME, NAMESPACE_URI, ROOT, BASE_URI,
+        GENERATE_ID, HAS_CHILDREN, PATH }) {
+      ckDBs(new XQuery(fn.args()), false, CTX_LIST);
+      ckDBs(new XQuery(DOC.args(NAME) + '/' + fn.args()), false, NAME_LIST, NAME_CTX);
     }
-    for(final String fn : new String[] { "data", "string", "number", "string-length",
-        "normalize-space", "document-uri", "nilled", "node-name", "local-name", "name",
-        "namespace-uri", "root", "base-uri", "generate-id", "has-children", "path"}) {
-      ckDBs(new XQuery(fn + "(doc('" + NAME + "'))"), false, NAME_LIST);
+    for(final Function fn : new Function[] { DATA, STRING, NUMBER, STRING_LENGTH, NORMALIZE_SPACE,
+        DOCUMENT_URI, NILLED, NODE_NAME, LOCAL_NAME, Function.NAME, NAMESPACE_URI, ROOT, BASE_URI,
+        GENERATE_ID, HAS_CHILDREN, PATH }) {
+      ckDBs(new XQuery(fn.args(DOC.args(NAME))), false, NAME_LIST);
     }
 
     // Others
     ckDBs(new XQuery("."), false, CTX_LIST);
-    ckDBs(new XQuery("error()"), false, NONE);
-    ckDBs(new XQuery("error(xs:QName('foo'))"), false, NONE);
-    ckDBs(new XQuery("error(xs:QName('foo'), 'bar')"), false, NONE);
-    ckDBs(new XQuery("error(xs:QName('foo'), 'bar', <batz/>)"), false, NONE);
-    ckDBs(new XQuery("random:integer()"), false, NONE);
+    ckDBs(new XQuery(ERROR.args()), false, NONE);
+    ckDBs(new XQuery(ERROR.args("xs:QName('foo')")), false, NONE);
+    ckDBs(new XQuery(ERROR.args("xs:QName('foo')", "bar")), false, NONE);
+    ckDBs(new XQuery(ERROR.args("xs:QName('foo')", "bar", "<batz/>")), false, NONE);
+    ckDBs(new XQuery(_RANDOM_INTEGER.args()), false, NONE);
 
     // User defined functions
     ckDBs(new XQuery("declare function local:a($a) {" +
         "if($a = 0) then $a else local:a($a idiv 2) };" +
         "local:a(5)"), false, NONE);
     ckDBs(new XQuery("declare function local:a($a) {" +
-        "if($a = 0) then collection() else local:a($a idiv 2) };" +
-        "local:a(5)"), false, COLL_LIST);
+        "if($a = 0) then " + COLLECTION.args() + " else local:a($a idiv 2) };" +
+        "local:a(5)"), false, CTX_LIST);
     ckDBs(new XQuery("declare function local:a($a) {" +
-        "if($a = 0) then doc('" + NAME + "') else local:a($a idiv 2) };" +
+        "if($a = 0) then " + DOC.args(NAME) + " else local:a($a idiv 2) };" +
         "local:a(5)"), false, NAME_LIST);
 
     // Java module function test. Locks are added at compilation, so execute each query
@@ -189,107 +191,99 @@ public class CommandLockingTest extends SandboxTest {
   /** Test admin module. */
   @Test
   public void admin() {
-    ckDBs(new XQuery("admin:users()"), false, ADMIN_LIST);
-    ckDBs(new XQuery("admin:users('" + NAME + "')"), false, ADMIN_NAME);
-    ckDBs(new XQuery("admin:sessions()"), false, ADMIN_LIST);
-    ckDBs(new XQuery("admin:logs()"), false, NONE);
+    ckDBs(new XQuery(_ADMIN_SESSIONS.args()), false, ADMIN_LIST);
+    ckDBs(new XQuery(_ADMIN_LOGS.args()), false, ADMIN_LIST);
+  }
+
+  /** Test user module. */
+  @Test
+  public void user() {
+    ckDBs(new XQuery(_USER_LIST.args()), false, ADMIN_LIST);
+    ckDBs(new XQuery(_USER_LIST_DETAILS.args()), false, ADMIN_LIST);
   }
 
   /** Test database module. */
   @Test
   public void db() {
     // General Functions
-    ckDBs(new XQuery("db:info('" + NAME + "')"), false, NAME_LIST);
-    ckDBs(new XQuery("db:list('" + NAME + "')"), false, NAME_LIST);
-    ckDBs(new XQuery("db:list()"), false, null);
-    ckDBs(new XQuery("db:list-details('" + NAME + "')"), false, NAME_LIST);
-    ckDBs(new XQuery("db:list-details()"), false, null);
-    ckDBs(new XQuery("db:open('" + NAME + "')"), false, NAME_LIST);
-    ckDBs(new XQuery("db:open-id('" + NAME + "', 0)"), false, NAME_LIST);
-    ckDBs(new XQuery("db:open-pre('" + NAME + "', 0)"), false, NAME_LIST);
-    ckDBs(new XQuery("db:system()"), false, NONE);
+    ckDBs(new XQuery(_DB_INFO.args(NAME)), false, NAME_LIST);
+    ckDBs(new XQuery(_DB_LIST.args(NAME)), false, NAME_LIST);
+    ckDBs(new XQuery(_DB_LIST_DETAILS.args(NAME)), false, NAME_LIST);
+    ckDBs(new XQuery(_DB_LIST_DETAILS.args()), false, null);
+    ckDBs(new XQuery(_DB_OPEN.args(NAME)), false, NAME_LIST);
+    ckDBs(new XQuery(_DB_OPEN_ID.args(NAME, 0)), false, NAME_LIST);
+    ckDBs(new XQuery(_DB_OPEN_PRE.args(NAME, 0)), false, NAME_LIST);
+    ckDBs(new XQuery(_DB_SYSTEM.args()), false, NONE);
 
     // Read Operations
-    ckDBs(new XQuery("db:attribute('" + NAME + "', 'foo')"), false, NAME_LIST);
-    ckDBs(new XQuery("db:attribute-range('" + NAME + "', '23', '42')"), false, NAME_LIST);
-    ckDBs(new XQuery("db:node-id(.)"), false, CTX_LIST);
-    ckDBs(new XQuery("db:node-pre(.)"), false, CTX_LIST);
-    ckDBs(new XQuery("db:retrieve('" + NAME + "', 'foo')"), false, NAME_LIST);
-    ckDBs(new XQuery("db:text('" + NAME + "', 'foo')"), false, NAME_LIST);
-    ckDBs(new XQuery("db:text-range('" + NAME + "', '23', '42')"), false, NAME_LIST);
+    ckDBs(new XQuery(_DB_ATTRIBUTE.args(NAME, "foo")), false, NAME_LIST);
+    ckDBs(new XQuery(_DB_ATTRIBUTE.args(NAME, 23, 42)), false, NAME_LIST);
+    ckDBs(new XQuery(_DB_NODE_ID.args(" .")), false, CTX_LIST);
+    ckDBs(new XQuery(_DB_NODE_PRE.args(" .")), false, CTX_LIST);
+    ckDBs(new XQuery(_DB_RETRIEVE.args(NAME, "foo")), false, NAME_LIST);
+    ckDBs(new XQuery(_DB_TEXT.args(NAME, "foo")), false, NAME_LIST);
+    ckDBs(new XQuery(_DB_TEXT_RANGE.args(NAME, 23, 42)), false, NAME_LIST);
 
     // Updates
-    ckDBs(new XQuery("db:create('" + NAME + "')"), true, NAME_LIST);
-    ckDBs(new XQuery("db:create('" + NAME + "', '" + FILE + "')"), true, NAME_LIST);
-    ckDBs(new XQuery("db:create('" + NAME + "', '<foo/>', '" + FILE + "')"), true,
-        NAME_LIST);
-    ckDBs(new XQuery("db:create('" + NAME + "', '" + FILE + "', '" + FILE + "')"), true,
-        NAME_LIST);
-    ckDBs(new XQuery("db:drop('" + NAME + "')"), true, NAME_LIST);
-    ckDBs(new XQuery("db:add('" + NAME + "', '" + FILE + "')"), true, NAME_LIST);
-    ckDBs(new XQuery("db:add('" + NAME + "', '<foo/>', '" + FILE + "')"), true,
-        NAME_LIST);
-    ckDBs(new XQuery("db:add('" + NAME + "', '" + FILE + "', '" + FILE + "')"), true,
-        NAME_LIST);
-    ckDBs(new XQuery("db:delete('" + NAME + "', '" + FILE + "')"), true, NAME_LIST);
-    ckDBs(new XQuery("db:optimize('" + NAME + "')"), true, NAME_LIST);
-    ckDBs(new XQuery("db:optimize('" + NAME + "', true())"), true, NAME_LIST);
-    ckDBs(new XQuery("db:rename('" + NAME + "', '" + FILE + "', '" + FILE + "2')"), true,
-        NAME_LIST);
-    ckDBs(new XQuery("db:replace('" + NAME + "', '" + FILE + "', '" + FILE + "2')"), true,
-        NAME_LIST);
-    ckDBs(new XQuery("db:store('" + NAME + "', '" + FILE + "', 'foo')"), true, NAME_LIST);
-    ckDBs(new XQuery("db:output('foo')"), true, NONE);
-    ckDBs(new XQuery("db:flush('" + NAME + "')"), true, NAME_LIST);
+    ckDBs(new XQuery(_DB_CREATE.args(NAME)), true, NAME_LIST);
+    ckDBs(new XQuery(_DB_CREATE.args(NAME, FILE)), true, NAME_LIST);
+    ckDBs(new XQuery(_DB_CREATE.args(NAME, "<foo/>", FILE)), true, NAME_LIST);
+    ckDBs(new XQuery(_DB_CREATE.args(NAME, FILE, FILE)), true, NAME_LIST);
+    ckDBs(new XQuery(_DB_DROP.args(NAME)), true, NAME_LIST);
+    ckDBs(new XQuery(_DB_ADD.args(NAME, FILE)), true, NAME_LIST);
+    ckDBs(new XQuery(_DB_ADD.args(NAME, "<foo/>", FILE)), true, NAME_LIST);
+    ckDBs(new XQuery(_DB_ADD.args(NAME, FILE, FILE)), true, NAME_LIST);
+    ckDBs(new XQuery(_DB_DELETE.args(NAME, FILE)), true, NAME_LIST);
+    ckDBs(new XQuery(_DB_OPTIMIZE.args(NAME)), true, NAME_LIST);
+    ckDBs(new XQuery(_DB_OPTIMIZE.args(NAME, "true()")), true, NAME_LIST);
+    ckDBs(new XQuery(_DB_RENAME.args(NAME, FILE, FILE + '2')), true, NAME_LIST);
+    ckDBs(new XQuery(_DB_REPLACE.args(NAME, FILE, FILE + '2')), true, NAME_LIST);
+    ckDBs(new XQuery(_DB_STORE.args(NAME, FILE, "foo")), true, NAME_LIST);
+    ckDBs(new XQuery(_DB_OUTPUT.args("foo")), true, NONE);
+    ckDBs(new XQuery(_DB_FLUSH.args(NAME)), true, NAME_LIST);
 
     // Helper Functions
-    ckDBs(new XQuery("db:exists('" + NAME + "')"), false, NAME_LIST);
-    ckDBs(new XQuery("db:is-raw('" + NAME + "', '" + FILE + "')"), false, NAME_LIST);
-    ckDBs(new XQuery("db:is-xml('" + NAME + "', '" + FILE + "')"), false, NAME_LIST);
-    ckDBs(new XQuery("db:content-type('" + NAME + "', '" + FILE + "')"), false,
-        NAME_LIST);
-    ckDBs(new XQuery("db:event('foo', 'bar')"), false, NONE);
-    ckDBs(new XQuery("db:event('foo', doc('" + NAME + "'))"), false, NAME_LIST);
+    ckDBs(new XQuery(_DB_EXISTS.args(NAME)), false, NAME_LIST);
+    ckDBs(new XQuery(_DB_IS_RAW.args(NAME, FILE)), false, NAME_LIST);
+    ckDBs(new XQuery(_DB_IS_XML.args(NAME, FILE)), false, NAME_LIST);
+    ckDBs(new XQuery(_DB_CONTENT_TYPE.args(NAME, FILE)), false, NAME_LIST);
   }
 
   /** Test ft module. */
   @Test
   public void ft() {
-    ckDBs(new XQuery("ft:search('" + NAME + "', 'foo')"), false, NAME_LIST);
-    ckDBs(new XQuery("ft:tokens('" + NAME + "')"), false, NAME_LIST);
-    ckDBs(new XQuery("ft:tokens('" + NAME + "', 'foo')"), false, NAME_LIST);
-    ckDBs(new XQuery("ft:tokenize('foo')"), false, NONE);
+    ckDBs(new XQuery(_FT_SEARCH.args(NAME, "foo")), false, NAME_LIST);
+    ckDBs(new XQuery(_FT_TOKENS.args(NAME)), false, NAME_LIST);
+    ckDBs(new XQuery(_FT_TOKENS.args(NAME, "foo")), false, NAME_LIST);
+    ckDBs(new XQuery(_FT_TOKENIZE.args("foo")), false, NONE);
   }
 
   /** Test index module. */
   @Test
   public void index() {
-    ckDBs(new XQuery("index:facets('" + NAME + "')"), false, NAME_LIST);
-    ckDBs(new XQuery("index:texts('" + NAME + "')"), false, NAME_LIST);
-    ckDBs(new XQuery("index:texts('" + NAME + "', 'foo')"), false, NAME_LIST);
-    ckDBs(new XQuery("index:texts('" + NAME + "', 'foo', true())"), false, NAME_LIST);
-    ckDBs(new XQuery("index:attributes('" + NAME + "')"), false, NAME_LIST);
-    ckDBs(new XQuery("index:attributes('" + NAME + "', 'foo')"), false, NAME_LIST);
-    ckDBs(new XQuery("index:attributes('" + NAME + "', 'foo', true())"), false,
-        NAME_LIST);
-    ckDBs(new XQuery("index:element-names('" + NAME + "')"), false, NAME_LIST);
-    ckDBs(new XQuery("index:attribute-names('" + NAME + "')"), false, NAME_LIST);
+    ckDBs(new XQuery(_INDEX_FACETS.args(NAME)), false, NAME_LIST);
+    ckDBs(new XQuery(_INDEX_TEXTS.args(NAME)), false, NAME_LIST);
+    ckDBs(new XQuery(_INDEX_TEXTS.args(NAME, "foo")), false, NAME_LIST);
+    ckDBs(new XQuery(_INDEX_TEXTS.args(NAME, "foo", "true()")), false, NAME_LIST);
+    ckDBs(new XQuery(_INDEX_ATTRIBUTES.args(NAME)), false, NAME_LIST);
+    ckDBs(new XQuery(_INDEX_ATTRIBUTES.args(NAME, "foo")), false, NAME_LIST);
+    ckDBs(new XQuery(_INDEX_ATTRIBUTES.args(NAME, "foo", "true()")), false, NAME_LIST);
+    ckDBs(new XQuery(_INDEX_ELEMENT_NAMES.args(NAME)), false, NAME_LIST);
+    ckDBs(new XQuery(_INDEX_ATTRIBUTE_NAMES.args(NAME)), false, NAME_LIST);
   }
 
   /** Test repository module. */
   @Test
   public void repository() {
-//    ckDBs(new XQuery("repo:install('" + FILE + "')"), true, REPO_LIST);
-//    ckDBs(new XQuery("repo:install('foo')"), true, REPO_LIST);
-    ckDBs(new XQuery("repo:list()"), false, REPO_LIST);
+    ckDBs(new XQuery(_REPO_LIST.args()), false, REPO_LIST);
   }
 
   /** Test XQuery module. */
   @Test
   public void xqueryModule() {
-    ckDBs(new XQuery("xquery:eval('1')"), false, null);
-    ckDBs(new XQuery("xquery:eval('" + FILE + "')"), false, null);
-    ckDBs(new XQuery("xquery:type(doc('" + NAME + "'))"), false, NAME_LIST);
+    ckDBs(new XQuery(_XQUERY_EVAL.args(1)), false, null);
+    ckDBs(new XQuery(_XQUERY_EVAL.args(FILE)), false, null);
+    ckDBs(new XQuery(_XQUERY_TYPE.args(DOC.args(NAME))), false, NAME_LIST);
   }
 
   /**
@@ -350,7 +344,6 @@ public class CommandLockingTest extends SandboxTest {
                             final StringList reqWt, final StringList allowWt) {
     // Fetch databases BaseX thinks it needs to lock
     final LockResult lr = new LockResult();
-    // [CG] cmd.updating needed because of some side-effects (instantiate QueryProcessor?)
     cmd.updating(DUMMY_CONTEXT);
     cmd.databases(lr);
     // Need sorted lists for compareAll
