@@ -1,22 +1,21 @@
 package org.basex.core;
 
-import static org.basex.core.Text.*;
 import static org.junit.Assert.*;
 
 import java.io.*;
 
 import org.basex.*;
+import org.basex.api.client.*;
 import org.basex.core.cmd.*;
-import org.basex.server.*;
+import org.basex.core.users.*;
 import org.basex.util.*;
 import org.junit.*;
 import org.junit.Test;
 
 /**
- * This class tests the database commands with the client/server
- * architecture.
+ * This class tests the database commands with the client/server architecture.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class ServerCommandTest extends CommandTest {
@@ -54,13 +53,13 @@ public final class ServerCommandTest extends CommandTest {
    */
   @Test
   public void kill() throws IOException {
-    ok(new Kill(S_ADMIN));
-    ok(new Kill(S_ADMIN + '2'));
+    ok(new Kill(UserText.ADMIN));
+    ok(new Kill(UserText.ADMIN + '2'));
     ok(new Kill(Prop.NAME + '*'));
-    ok(new CreateUser(NAME2, Token.md5(NAME2)));
-    final ClientSession cs = createClient(NAME2, NAME2);
-    ok(new Kill(NAME2));
-    ok(new Kill(NAME2 + '?'));
-    cs.close();
+    ok(new CreateUser(NAME2, NAME2));
+    try(final ClientSession cs = createClient(NAME2, NAME2)) {
+      ok(new Kill(NAME2));
+      ok(new Kill(NAME2 + '?'));
+    }
   }
 }
