@@ -8,10 +8,10 @@ import org.junit.*;
 /**
  * Test index updates when using disk storage ({@link DiskData}).
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Dimitar Popov
  */
-public class DiskDataTest extends MemDataTest {
+public final class DiskDataTest extends MemDataTest {
   /** Test database name. */
   private final String dbname = Util.className(DiskDataTest.class);
 
