@@ -8,7 +8,7 @@ import org.junit.*;
 /**
  * Test class for IO methods.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class IOTest {
@@ -16,12 +16,12 @@ public final class IOTest {
   @Test
   public void urlToFile() {
     if(Prop.WIN) {
-      assertEquals("C:/x y", IOFile.get("file:/c:/x%20y").path());
-      assertEquals("C:/x y", IOFile.get("file://c:/x y").path());
-      assertEquals("D:/x+y", IOFile.get("file:///D:/x%2By").path());
-      assertEquals("G:/X", IOFile.get("file:///G:/X").path());
+      assertEquals("C:/x y", IO.get("file:/c:/x%20y").path());
+      assertEquals("C:/x y", IO.get("file://C:/x y").path());
+      assertEquals("D:/x+y", IO.get("file:///D:/x%2By").path());
+      assertEquals("G:/X", IO.get("file:///G:/X").path());
     } else {
-      assertEquals("/x y", IOFile.get("file:///x%20y").path());
+      assertEquals("/x y", IOUrl.toFile("file:///x%20y"));
     }
   }
 
