@@ -1,15 +1,16 @@
 package org.basex.query;
 
 import static org.basex.core.Text.*;
+import static org.basex.query.QueryError.*;
 import static org.basex.util.Token.*;
 import static org.junit.Assert.*;
 
 import org.basex.core.*;
 import org.basex.core.cmd.*;
+import org.basex.data.*;
 import org.basex.io.*;
 import org.basex.io.serial.*;
-import org.basex.io.serial.SerializerOptions.YesNo;
-import org.basex.query.up.primitives.*;
+import org.basex.query.up.primitives.node.*;
 import org.basex.query.util.*;
 import org.basex.query.value.node.*;
 import org.basex.util.*;
@@ -19,7 +20,7 @@ import org.junit.Test;
 /**
  * This class tests namespaces.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Lukas Kircher
  */
 public final class NamespaceTest extends AdvancedQueryTest {
@@ -47,6 +48,7 @@ public final class NamespaceTest extends AdvancedQueryTest {
     { "d18", "<n xmlns:ns='ns'><a/></n>"},
     { "d19", "<x:n xmlns:x='X'/>"},
     { "d20", "<x:a xmlns:x='A'><x:b xmlns:x='B'/><x:c/></x:a>"},
+    { "d21", "<n><a xmlns:p1='u1'><b xmlns:p2='u2'/></a><c/></n>"}
   };
 
   /**
@@ -59,8 +61,8 @@ public final class NamespaceTest extends AdvancedQueryTest {
     create(12);
     query("insert node <b xmlns:ns='A'/> into doc('d12')/*:a/*:b");
     assertEquals(NL +
-        "  Pre[3] xmlns:ns=\"A\" " + NL +
-        "  Pre[4] xmlns=\"B\" ",
+        "  Pre[3] xmlns:ns=\"A\"" + NL +
+        "  Pre[4] xmlns=\"B\"",
         context.data().nspaces.toString());
   }
 
@@ -74,7 +76,7 @@ public final class NamespaceTest extends AdvancedQueryTest {
     create(13);
     query("insert node <c/> as first into doc('d13')/a");
     assertEquals(NL +
-        "  Pre[3] xmlns=\"A\" ",
+        "  Pre[3] xmlns=\"A\"",
         context.data().nspaces.toString());
   }
 
@@ -88,10 +90,10 @@ public final class NamespaceTest extends AdvancedQueryTest {
     create(14);
     query("insert node <n xmlns='D'/> into doc('d14')/*:a/*:b");
     assertEquals(NL +
-        "  Pre[1] xmlns=\"A\" " + NL +
-        "    Pre[2] xmlns=\"B\" " + NL +
-        "      Pre[3] xmlns=\"D\" " + NL +
-        "    Pre[4] xmlns=\"C\" ",
+        "  Pre[1] xmlns=\"A\"" + NL +
+        "    Pre[2] xmlns=\"B\"" + NL +
+        "      Pre[3] xmlns=\"D\"" + NL +
+        "    Pre[4] xmlns=\"C\"",
         context.data().nspaces.toString());
   }
 
@@ -105,7 +107,7 @@ public final class NamespaceTest extends AdvancedQueryTest {
     create(12);
     query("delete node doc('d12')/a/b");
     assertEquals(NL +
-        "  Pre[2] xmlns=\"B\" ",
+        "  Pre[2] xmlns=\"B\"",
         context.data().nspaces.toString());
   }
 
@@ -119,8 +121,8 @@ public final class NamespaceTest extends AdvancedQueryTest {
     create(14);
     query("delete node doc('d14')/*:a/*:b");
     assertEquals(NL +
-        "  Pre[1] xmlns=\"A\" " + NL +
-        "    Pre[2] xmlns=\"C\" ",
+        "  Pre[1] xmlns=\"A\"" + NL +
+        "    Pre[2] xmlns=\"C\"",
         context.data().nspaces.toString());
   }
 
@@ -134,9 +136,9 @@ public final class NamespaceTest extends AdvancedQueryTest {
     create(15);
     query("delete node doc('d15')/*:a/*:c");
     assertEquals(NL +
-        "  Pre[1] xmlns=\"A\" " + NL +
-        "    Pre[2] xmlns=\"B\" " + NL +
-        "    Pre[3] xmlns=\"E\" ",
+        "  Pre[1] xmlns=\"A\"" + NL +
+        "    Pre[2] xmlns=\"B\"" + NL +
+        "    Pre[3] xmlns=\"E\"",
         context.data().nspaces.toString());
   }
 
@@ -152,6 +154,23 @@ public final class NamespaceTest extends AdvancedQueryTest {
     assertTrue(context.data().nspaces.toString().isEmpty());
   }
 
+  /**
+   * Inserts an attribute with namespace.
+   * @throws Exception exception
+   */
+  @Test
+  public void insertAttributeWithNs() throws Exception {
+    create(1);
+    query("insert node attribute { QName('ns', 'pref:local') } { } into /*");
+    final Data data = context.data();
+    assertEquals(false, data.nsFlag(0));
+    assertEquals(true, data.nsFlag(1));
+    assertEquals(false, data.nsFlag(2));
+    assertEquals(0, data.uriId(1, data.kind(1)));
+    assertEquals(1, data.uriId(2, data.kind(2)));
+    assertEquals("ns", string(data.nspaces.uri(1)));
+  }
+
   /**
    * Tests for correct namespace hierarchy, esp. if namespace nodes
    * on the following axis of an insert/delete operation are
@@ -166,6 +185,19 @@ public final class NamespaceTest extends AdvancedQueryTest {
         "<a xmlns='A'><c xmlns:ns1='AA'><d/></c></a>");
   }
 
+  /**
+   * Tests if a namespace node is deleted.
+   * @throws Exception exception
+   */
+  @Test
+  public void delete2() throws Exception {
+    create(21);
+    query("delete node //b");
+    assertEquals(NL +
+        "  Pre[2] xmlns:p1=\"u1\"",
+        context.data().nspaces.toString());
+  }
+
   /** Test query. */
   @Test
   public void copy1() {
@@ -250,9 +282,9 @@ public final class NamespaceTest extends AdvancedQueryTest {
     create(9);
     query("insert node <f xmlns='F'/> into doc('d9')//*:e");
     assertEquals(NL +
-        "  Pre[1] xmlns=\"A\" " + NL +
-        "    Pre[4] xmlns=\"D\" " + NL +
-        "    Pre[6] xmlns=\"F\" ",
+        "  Pre[1] xmlns=\"A\"" + NL +
+        "    Pre[4] xmlns=\"D\"" + NL +
+        "    Pre[6] xmlns=\"F\"",
         context.data().nspaces.toString());
   }
 
@@ -265,10 +297,10 @@ public final class NamespaceTest extends AdvancedQueryTest {
     create(10);
     query("insert node <f xmlns='F'/> into doc('d10')//*:e");
     assertEquals(NL +
-        "  Pre[1] xmlns=\"A\" " + NL +
-        "    Pre[4] xmlns=\"D\" " + NL +
-        "      Pre[5] xmlns=\"G\" " + NL +
-        "    Pre[7] xmlns=\"F\" ",
+        "  Pre[1] xmlns=\"A\"" + NL +
+        "    Pre[4] xmlns=\"D\"" + NL +
+        "      Pre[5] xmlns=\"G\"" + NL +
+        "    Pre[7] xmlns=\"F\"",
         context.data().nspaces.toString());
   }
 
@@ -287,8 +319,8 @@ public final class NamespaceTest extends AdvancedQueryTest {
     create(2);
     query("insert node <a xmlns='y'/> into doc('d2')//*:x");
     assertEquals(NL +
-        "  Pre[1] xmlns=\"xx\" " + NL +
-        "    Pre[2] xmlns=\"y\" ",
+        "  Pre[1] xmlns=\"xx\"" + NL +
+        "    Pre[2] xmlns=\"y\"",
         context.data().nspaces.toString());
   }
 
@@ -465,10 +497,10 @@ public final class NamespaceTest extends AdvancedQueryTest {
   @Test
   public void deleteDocumentNode() throws Exception {
     create(2);
-    context.data().startUpdate();
+    context.data().startUpdate(context.options);
     context.data().delete(0);
-    context.data().finishUpdate();
-    final byte[] ns = context.data().nspaces.globalNS();
+    context.data().finishUpdate(context.options);
+    final byte[] ns = context.data().nspaces.globalUri();
     assertTrue(ns != null && ns.length == 0);
   }
 
@@ -563,7 +595,7 @@ public final class NamespaceTest extends AdvancedQueryTest {
       "copy $a := <a xmlns:p='A' a='v'/> " +
       "modify rename node $a/@a as QName('uri', 'p:a') " +
       "return $a",
-      Err.UPNSCONFL);
+      UPNSCONFL);
   }
 
   /**
@@ -590,7 +622,7 @@ public final class NamespaceTest extends AdvancedQueryTest {
       "modify for $el in $a/descendant-or-self::element() return " +
       "rename node $el as QName('',local-name($el)) " +
       "return $a",
-      Err.UPNSCONFL);
+      UPNSCONFL);
   }
 
   /**
@@ -616,7 +648,7 @@ public final class NamespaceTest extends AdvancedQueryTest {
     query(
       "let $b := <a xmlns:x='X' x:id='0'/> " +
       "return insert node $b//@*:id into /*:n");
-    assertEquals(1, context.data().ns(1).size());
+    assertEquals(1, context.data().namespaces(1).size());
   }
 
   /** Handles duplicate prefixes. */
@@ -712,10 +744,10 @@ public final class NamespaceTest extends AdvancedQueryTest {
   @Test
   public void stripNS() throws Exception {
     final IO io = IO.get("<a xmlns:a='a'><b><c/><c/><c/></b></a>");
-    final ANode root = new DBNode(io, context.options);
-    final QueryProcessor qp = new QueryProcessor("/*:a/*:b", context).context(root);
-    final ANode sub = (ANode) qp.iter().next();
-    DataBuilder.stripNS(sub, token("a"), context);
+    try(final QueryProcessor qp = new QueryProcessor("/*:a/*:b", context).context(new DBNode(io))) {
+      final ANode sub = (ANode) qp.iter().next();
+      DataBuilder.stripNS(sub, token("a"), context);
+    }
   }
 
   /**
@@ -725,14 +757,15 @@ public final class NamespaceTest extends AdvancedQueryTest {
   @Test
   @Ignore
   public void xuty0004() {
-    try {
-      new QueryProcessor("declare variable $input-context external;" +
-          "let $source as node()* := (" +
-          "    <status>on leave</status>," +
-          "    <!-- for 6 months -->" +
-          "  )," +
-          "  $target := $input-context/works[1]/employee[1]" +
-          "return insert nodes $source into $target", context).execute();
+    final String query = "declare variable $input-context external;" +
+        "let $source as node()* := (" +
+        "    <status>on leave</status>," +
+        "    <!-- for 6 months -->" +
+        "  )," +
+        "  $target := $input-context/works[1]/employee[1]" +
+        "return insert nodes $source into $target";
+    try(final QueryProcessor qp = new QueryProcessor(query, context)) {
+      qp.value();
     } catch(final QueryException ex) {
       assertEquals("XUTY0004", string(ex.qname().local()));
     }
@@ -768,7 +801,6 @@ public final class NamespaceTest extends AdvancedQueryTest {
    * @throws Exception exception
    */
   @Test
-  @Ignore
   public void defaultNS() throws Exception {
     create(1);
     query("<h xmlns='U'>{ doc('d1')/x }</h>/*", "");
@@ -798,7 +830,7 @@ public final class NamespaceTest extends AdvancedQueryTest {
     create(1);
     query("insert node attribute xml:space { 'preserve' } into /x", "");
     query(".", "<x xml:space='preserve'/>");
-    error("insert node attribute xml:space { 'preserve' } into /x", Err.UPATTDUPL);
+    error("insert node attribute xml:space { 'preserve' } into /x", UPATTDUPL_X);
   }
 
   /**
@@ -813,7 +845,7 @@ public final class NamespaceTest extends AdvancedQueryTest {
     error("copy $c := <a xmlns='X'/> modify (" +
         "  rename node $c as QName('Y','b')," +
         "  insert node attribute c{'a'} into $c" +
-        ") return $c", Err.UPNSCONFL);
+        ") return $c", UPNSCONFL);
     query("copy $c := <a/> modify (" +
         "  rename node $c as QName('X','b')," +
         "  insert node attribute c{'a'} into $c" +
@@ -838,9 +870,7 @@ public final class NamespaceTest extends AdvancedQueryTest {
   @BeforeClass
   public static void start() throws BaseXException {
     // turn off pretty printing
-    final SerializerOptions sopts = new SerializerOptions();
-    sopts.set(SerializerOptions.INDENT, YesNo.NO);
-    new Set(MainOptions.SERIALIZER, sopts).execute(context);
+    new Set(MainOptions.SERIALIZER, SerializerOptions.get(false)).execute(context);
   }
 
   /**
