@@ -4,21 +4,18 @@ import static org.junit.Assert.*;
 
 import java.util.*;
 
-import org.basex.core.*;
+import org.basex.*;
 import org.junit.*;
 
 /**
  * Runs parallel queries.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
-public final class ParallelQueryTest {
+public final class ParallelQueryTest extends SandboxTest {
   /** Query. */
   private static final String QUERY = "count((for $i in 1 to 50000 return <a><b/></a>)/b)";
-
-  /** Context. */
-  private final Context context = new Context();
   /** Error. */
   private Throwable error;
   /** Reference result. */
@@ -33,7 +30,7 @@ public final class ParallelQueryTest {
     // generate reference result
     result = query();
     // generate results to be compared
-    final ArrayList<Query> queries = new ArrayList<Query>();
+    final ArrayList<Query> queries = new ArrayList<>();
     for(int i = 0; i < 10; i++) queries.add(new Query());
     for(final Query q : queries) q.start();
     for(final Query q : queries) q.join();
@@ -43,10 +40,12 @@ public final class ParallelQueryTest {
   /**
    * Runs a single query.
    * @return result
-   * @throws QueryException exception
+   * @throws Exception exception
    */
-  private String query() throws QueryException {
-    return new QueryProcessor(QUERY, context).value().toString();
+  private static String query() throws Exception {
+    try(final QueryProcessor qp = new QueryProcessor(QUERY, context)) {
+      return qp.value().serialize().toString();
+    }
   }
 
   /**
