@@ -1,21 +1,22 @@
 package org.basex.query.up;
 
+import static org.basex.query.QueryError.*;
+import static org.basex.query.func.Function.*;
 import static org.junit.Assert.*;
 
 import org.basex.core.*;
 import org.basex.core.cmd.*;
-import org.basex.data.atomic.*;
 import org.basex.io.*;
 import org.basex.query.*;
-import org.basex.query.up.primitives.*;
-import org.basex.query.util.*;
+import org.basex.query.up.atomic.*;
+import org.basex.query.up.primitives.node.*;
 import org.junit.*;
 import org.junit.Test;
 
 /**
  * General test of the XQuery Update Facility implementation.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Lukas Kircher
  */
 public final class UpdateTest extends AdvancedQueryTest {
@@ -24,7 +25,7 @@ public final class UpdateTest extends AdvancedQueryTest {
 
   /**
    * Creates a database.
-   * @param input input database string, if null, then use default.
+   * @param input input database string; use default if {@code null}
    * @throws BaseXException database exception
    */
   private static void createDB(final String input) throws BaseXException {
@@ -48,7 +49,7 @@ public final class UpdateTest extends AdvancedQueryTest {
   public void delete() {
     query(transform("<n><a><b/></a><c/><d><e><f/></e><g/></d></n>",
         "delete node $input//b, delete node $input//f, delete node $input//e"),
-        "<n><a/><c/><d><g/></d></n>");
+        "<n>\n<a/>\n<c/>\n<d>\n<g/>\n</d>\n</n>");
   }
 
   /**
@@ -57,7 +58,8 @@ public final class UpdateTest extends AdvancedQueryTest {
   @Test
   public void delete2() {
     query(transform("<a><b/><c/><d/></a>",
-        "delete node $input//b, delete node $input//c"), "<a><d/></a>");
+        "delete node $input//b, delete node $input//c"),
+        "<a>\n<d/>\n</a>");
   }
 
   /**
@@ -70,7 +72,7 @@ public final class UpdateTest extends AdvancedQueryTest {
             "<n2/><n3/><n4/><n5/><n6/><n7/><n8/><n9/><n10/><n11/>" +
         "</n1>";
     query(transform(doc, "delete node ($input//n3, $input//n5, $input//n7)"),
-        "<n1><n2/><n4/><n6/><n8/><n9/><n10/><n11/></n1>");
+        "<n1>\n<n2/>\n<n4/>\n<n6/>\n<n8/>\n<n9/>\n<n10/>\n<n11/>\n</n1>");
   }
 
   /** Transform expression shadowing another variable. */
@@ -80,6 +82,13 @@ public final class UpdateTest extends AdvancedQueryTest {
     query("declare variable $d := document{ <x/> } update (); $d/x", "<x/>");
   }
 
+  /** Transform expression containing a simple expression. */
+  @Test
+  public void transSimple() {
+    error("<a/> update ('')", UPMODIFY);
+    error("copy $a := <a/> modify ('') return $a", UPMODIFY);
+  }
+
   /**
    * Checks whether existing indexes etc. are NOT recycled for the copy of a transform expression.
    * @throws BaseXException BaseX exception.
@@ -96,9 +105,13 @@ public final class UpdateTest extends AdvancedQueryTest {
         "$xml update (" +
         "for $i in 1 to 2 return " +
         "insert node $xml/instance/data/vocable[@hits = '1'] into ./instance))",
-        "<instance><data><vocable hits=\"1\"/></data><vocable hits=\"1\"/>" +
-        "<vocable hits=\"1\"/></instance><instance><data>" +
-        "<vocable hits=\"1\"/></data><vocable hits=\"1\"/><vocable hits=\"1\"/></instance>");
+        "<instance>\n<data>\n" +
+        "<vocable hits=\"1\"/>\n</data>\n" +
+        "<vocable hits=\"1\"/>\n" +
+        "<vocable hits=\"1\"/>\n</instance>\n<instance>\n<data>\n" +
+        "<vocable hits=\"1\"/>\n</data>\n" +
+        "<vocable hits=\"1\"/>\n" +
+        "<vocable hits=\"1\"/>\n</instance>");
     new Set("mainmem", "off").execute(context);
   }
 
@@ -109,7 +122,7 @@ public final class UpdateTest extends AdvancedQueryTest {
   public void insertinto() {
     query(transform("<n><a/></n>",
         "insert node <x2/> into $input, insert node <x1/> into $input//a"),
-        "<n><a><x1/></a><x2/></n>");
+        "<n>\n<a>\n<x1/>\n</a>\n<x2/>\n</n>");
   }
 
   /**
@@ -119,7 +132,7 @@ public final class UpdateTest extends AdvancedQueryTest {
   public void insertinto2() {
     query(transform("<n><a/><b/></n>",
         "insert node <x1/> into $input//a, insert node <x2/> into $input//b"),
-        "<n><a><x1/></a><b><x2/></b></n>");
+        "<n>\n<a>\n<x1/>\n</a>\n<b>\n<x2/>\n</b>\n</n>");
   }
 
   /**
@@ -129,7 +142,7 @@ public final class UpdateTest extends AdvancedQueryTest {
   public void insertIntoAsFirst() {
     query(transform("<a att='0'/>",
         "insert node <b/> as first into $input, delete node $input/@att"),
-        "<a><b/></a>");
+        "<a>\n<b/>\n</a>");
   }
 
   /**
@@ -140,7 +153,7 @@ public final class UpdateTest extends AdvancedQueryTest {
     query(transform("<a att='0'/>",
         "insert node <b/> as first into $input, replace node $input/@att with " +
         "(attribute {'att1'}{0}, attribute {'att2'}{0})"),
-        "<a att1=\"0\" att2=\"0\"><b/></a>");
+        "<a att1=\"0\" att2=\"0\">\n<b/>\n</a>");
   }
 
   /**
@@ -150,19 +163,16 @@ public final class UpdateTest extends AdvancedQueryTest {
   public void insertSequenceMerging() {
     query(transform("<n/>",
         "insert node <e1/> into $input, insert node <e2/> into $input"),
-        "<n><e1/><e2/></n>");
-
+        "<n>\n<e1/>\n<e2/>\n</n>");
     query(transform("<n/>",
         "insert node <e1/> as last into $input, insert node <e2/> as last into $input"),
-        "<n><e1/><e2/></n>");
-
+        "<n>\n<e1/>\n<e2/>\n</n>");
     query(transform("<n/>",
         "insert node <e1/> into $input, insert node <e2/> as last into $input"),
-        "<n><e1/><e2/></n>");
-
+        "<n>\n<e1/>\n<e2/>\n</n>");
     query(transform("<n/>",
         "insert node <e1/> as last into $input, insert node <e2/> into $input"),
-        "<n><e2/><e1/></n>");
+        "<n>\n<e2/>\n<e1/>\n</n>");
   }
 
   /**
@@ -170,8 +180,7 @@ public final class UpdateTest extends AdvancedQueryTest {
    */
   @Test
   public void deleteLastNode() {
-    query(transform("<a><b/><c/></a>", "delete node $input//c"),
-        "<a><b/></a>");
+    query(transform("<a><b/><c/></a>", "delete node $input//c"), "<a>\n<b/>\n</a>");
   }
 
   /**
@@ -180,11 +189,11 @@ public final class UpdateTest extends AdvancedQueryTest {
   @Test
   public void lazyReplace() {
     query(transform("<n><r>a</r></n>", "replace node $input/r with <r>b</r>"),
-        "<n><r>b</r></n>");
-
+        "<n>\n<r>b</r>\n</n>");
     query(transform("<n><r>a</r></n>", "replace node $input/r with <r>b</r>"),
-        "<n><r>b</r></n>");
+        "<n>\n<r>b</r>\n</n>");
   }
+
   /**
    * ReplaceValue on attribute.
    */
@@ -233,19 +242,19 @@ public final class UpdateTest extends AdvancedQueryTest {
     // check 'global' duplicate detection
     String q = transform("<x/>",
         "for $i in 1 to 2 return insert node attribute a { 'b' } into $input");
-    error(q, Err.UPATTDUPL);
+    error(q, UPATTDUPL_X);
 
     // check if insertion sequence itself is duplicate free (which it is not)
     q = transform("<x a='a'/>",
         "delete node $input/@a," +
         "for $i in 1 to 2 return insert node attribute a { 'b' } into $input");
-    error(q, Err.UPATTDUPL);
+    error(q, UPATTDUPL_X);
 
     // replace with a + delete a + insert a
     q = transform("<x a='a'/>",
         "delete node $input/@a, replace node $input/@a with attribute a {'b'}," +
         "insert node attribute a { 'b' } into $input");
-    error(q, Err.UPATTDUPL);
+    error(q, UPATTDUPL_X);
   }
 
   /**
@@ -254,7 +263,7 @@ public final class UpdateTest extends AdvancedQueryTest {
   @Test
   public void replaceLastNode() {
     query(transform("<a><b/><c><d/><d/><d/></c></a>", "replace node $input//c with <c/>"),
-        "<a><b/><c/></a>");
+        "<a>\n<b/>\n<c/>\n</a>");
   }
 
   /**
@@ -275,7 +284,7 @@ public final class UpdateTest extends AdvancedQueryTest {
   public void replaceAttribute2() {
     query(transform("<a><b att0='0'/><c/></a>",
         "replace node $input/b/@att0 with attribute att1 {'1'}"),
-        "<a><b att1=\"1\"/><c/></a>");
+        "<a>\n<b att1=\"1\"/>\n<c/>\n</a>");
   }
 
   /**
@@ -290,8 +299,7 @@ public final class UpdateTest extends AdvancedQueryTest {
   }
 
   /**
-   *  **** TC tries to provoke multiple delete atomics on the same PRE within the same
-   * snapshot. *****
+   * TC tries to provoke multiple delete atomics on the same PRE within the same snapshot.
    *
    * Only delete primitives {@link DeleteNode} are allowed to create atomic delete
    * updates {@link AtomicUpdateCache}. This ensures that
@@ -309,7 +317,7 @@ public final class UpdateTest extends AdvancedQueryTest {
     query(transform("<n>text<doNotDelete/></n>",
         "replace value of node $input//text() with \"\", " +
         "delete node $input//text()"),
-        "<n><doNotDelete/></n>");
+        "<n>\n<doNotDelete/>\n</n>");
   }
 
   /**
@@ -350,8 +358,7 @@ public final class UpdateTest extends AdvancedQueryTest {
   }
 
   /**
-   * ReplaceElementContent on a target T with a text node and insertBefore
-   * on a child of T.
+   * ReplaceElementContent on a target T with a text node and insertBefore on a child of T.
    */
   @Test
   public void replaceelementcontent3() {
@@ -377,7 +384,8 @@ public final class UpdateTest extends AdvancedQueryTest {
   @Test
   public void replaceelementcontent5() {
     testBothSequences("<n><A/></n>", "<n>newText</n>",
-        "replace value of node $input with 'newText'", "insert node <newA/> into $input");
+        "replace value of node $input with 'newText'",
+        "insert node <newA/> into $input");
   }
 
   /**
@@ -405,12 +413,11 @@ public final class UpdateTest extends AdvancedQueryTest {
   }
 
   /**
-   * ReplaceNode on a target T and replaceElementContent on the only child of
-   * T.
+   * ReplaceNode on a target T and replaceElementContent on the only child of T.
    */
   @Test
   public void replaceelementcontent8() {
-    testBothSequences("<n><A><B/></A></n>", "<n><newA/></n>",
+    testBothSequences("<n><A><B/></A></n>", "<n>\n<newA/>\n</n>",
         "replace node $input/A with <newA/>",
         "replace value of node $input/A/B with 'newContentForA'");
   }
@@ -420,7 +427,7 @@ public final class UpdateTest extends AdvancedQueryTest {
    */
   @Test
   public void replaceelementcontent9() {
-    testBothSequences("<n><A/></n>", "<n><newA/></n>",
+    testBothSequences("<n><A/></n>", "<n>\n<newA/>\n</n>",
         "replace node $input/A with <newA/>",
         "replace value of node $input/A with 'newContentForA'");
   }
@@ -430,7 +437,7 @@ public final class UpdateTest extends AdvancedQueryTest {
    */
   @Test
   public void deleteAndReplaceOnSameTarget() {
-    testBothSequences("<a><b/></a>", "<a><newB/></a>",
+    testBothSequences("<a><b/></a>", "<a>\n<newB/>\n</a>",
         "replace node $input/b with <newB/>", "delete node $input/b");
   }
 
@@ -467,7 +474,7 @@ public final class UpdateTest extends AdvancedQueryTest {
   public void emptyInsert1() {
     query(
       "copy $x := <X/> modify insert nodes <A/> into $x return $x",
-      "<X><A/></X>");
+      "<X>\n<A/>\n</X>");
   }
 
   /**
@@ -508,7 +515,7 @@ public final class UpdateTest extends AdvancedQueryTest {
   @Test
   public void outOfScope() {
     error("let $d := copy $e := <a/> modify () return $e return $e",
-        Err.VARUNDEF);
+        VARUNDEF_X);
   }
 
   /**
@@ -553,7 +560,7 @@ public final class UpdateTest extends AdvancedQueryTest {
   public void textMerging00() {
     query(transform("<a>AA<b/>CC</a>", "delete node $input//b",
         "($input,count($input//text()))"),
-        "<a>AACC</a>1");
+        "<a>AACC</a>\n1");
   }
 
   /**
@@ -594,7 +601,7 @@ public final class UpdateTest extends AdvancedQueryTest {
       "insert node 'foo' into $i/quantity)");
     query("let $i := //item[@id='item0'] return " +
       "(($i/location/text())[1], ($i/quantity/text())[1])",
-      "fooUnited States1foo");
+      "fooUnited States\n1foo");
   }
 
   /**
@@ -605,10 +612,8 @@ public final class UpdateTest extends AdvancedQueryTest {
   @Test
   public void textMerging04() throws Exception {
     createDB(null);
-    query("let $i := //item[@id='item0'] return insert node 'foo' " +
-      "before $i/location/text()");
-    query("let $i := //item[@id='item0'] return " +
-      "($i/location/text())[1]", "fooUnited States");
+    query("let $i := //item[@id='item0'] return insert node 'foo' before $i/location/text()");
+    query("let $i := //item[@id='item0'] return ($i/location/text())[1]", "fooUnited States");
   }
 
   /**
@@ -633,8 +638,7 @@ public final class UpdateTest extends AdvancedQueryTest {
     createDB(null);
     query("let $i := //item[@id='item0']/location return " +
       "(insert node <n/> into $i, insert node 'foo' as last into $i)");
-    query("let $i := //item[@id='item0']/location return " +
-      "delete node $i/n");
+    query("let $i := //item[@id='item0']/location return delete node $i/n");
     query("(//item[@id='item0']/location/text())[1]", "United Statesfoo");
   }
 
@@ -645,8 +649,7 @@ public final class UpdateTest extends AdvancedQueryTest {
   @Test
   public void textMerging07() throws Exception {
     createDB(null);
-    query("let $i := //item[@id='item0']/location return " +
-      "insert node 'foo' after $i/text()");
+    query("let $i := //item[@id='item0']/location return insert node 'foo' after $i/text()");
     query("(//item[@id='item0']/location/text())[1]", "United Statesfoo");
   }
 
@@ -657,13 +660,12 @@ public final class UpdateTest extends AdvancedQueryTest {
   @Test
   public void textMerging08() throws Exception {
     createDB(null);
-    query("let $i := //item[@id='item0'] return " +
-      "(insert node 'foo' after $i/location)");
+    query("let $i := //item[@id='item0'] return (insert node 'foo' after $i/location)");
     query("let $i := //item[@id='item0']/location return " +
       "(insert node 'foo' after $i, insert node 'faa' before $i, insert " +
       "node 'faa' into $i, delete node $i/text())");
-    query("let $i := //item[@id='item0']/location " +
-      "return ($i/text(), ($i/../text())[2])", "faafoofoo");
+    query("let $i := //item[@id='item0']/location return ($i/text(), ($i/../text())[2])",
+        "faa\nfoofoo");
   }
 
   /**
@@ -673,7 +675,7 @@ public final class UpdateTest extends AdvancedQueryTest {
   public void textMerging09() {
     query(transform("<n>aa<d/><d/>cc</n>",
         "delete node $input//d, insert node 'bb' after ($input//d)[1]",
-        "count($input//text()), $input//text()"), "1aabbcc");
+        "count($input//text()), $input//text()"), "1\naabbcc");
   }
 
   /**
@@ -683,7 +685,7 @@ public final class UpdateTest extends AdvancedQueryTest {
   public void textMerging10() {
     query("copy $c := <n>aa<d/><d/>cc</n> " +
       "modify (delete node $c//d, insert node 'bb' before ($c//d)[2]) " +
-      "return (count($c//text()), $c//text())", "1aabbcc");
+      "return (count($c//text()), $c//text())", "1\naabbcc");
   }
 
   /**
@@ -694,7 +696,7 @@ public final class UpdateTest extends AdvancedQueryTest {
     query(
       "copy $c := <n>aa<d/><d/>cc</n> " +
       "modify (delete node $c//d, insert node 'bb' before ($c//d)[2]) " +
-      "return (count($c//text()), $c//text())", "1aabbcc");
+      "return (count($c//text()), $c//text())", "1\naabbcc");
   }
 
   /**
@@ -742,7 +744,7 @@ public final class UpdateTest extends AdvancedQueryTest {
    */
   @Test
   public void delayedDistanceAdjustment000() {
-    query(transform("<a><b/><c/></a>", "delete node $input/b"), "<a><c/></a>");
+    query(transform("<a><b/><c/></a>", "delete node $input/b"), "<a>\n<c/>\n</a>");
   }
 
   /**
@@ -751,7 +753,7 @@ public final class UpdateTest extends AdvancedQueryTest {
   @Test
   public void delayedDistanceAdjustment00() {
     query(transform("<a><b/><c/><d/></a>", "delete node ($input/b, $input/c)"),
-        "<a><d/></a>");
+        "<a>\n<d/>\n</a>");
   }
 
   /**
@@ -763,7 +765,7 @@ public final class UpdateTest extends AdvancedQueryTest {
     query("copy $c := <n><a/><n><a/><n/><a/></n><a/><n/><a/></n> " +
           "modify for $a in $c//a return replace node $a with <b/> " +
           "return $c",
-          "<n><b/><n><b/><n/><b/></n><b/><n/><b/></n>");
+          "<n>\n<b/>\n<n>\n<b/>\n<n/>\n<b/>\n</n>\n<b/>\n<n/>\n<b/>\n</n>");
   }
 
   /**
@@ -775,148 +777,148 @@ public final class UpdateTest extends AdvancedQueryTest {
     query("copy $c := <n><a/><a/></n> " +
         "modify for $a in $c//a return replace node $a with <b/> " +
         "return $c",
-        "<n><b/><b/></n>");
+        "<n>\n<b/>\n<b/>\n</n>");
   }
 
   /**
    * Distance caching tested for inserts at different levels.
-   * @throws BaseXException excp
+   * @throws BaseXException exception
    */
   @Test
   public void delayedDistanceAdjustment1() throws BaseXException {
     createDB("<A><B><C/></B><D/></A>");
     query("insert node <XB/> before //B, insert node <XC/> before //C, " +
         "insert node <XD/> before //D");
-    query("/", "<A><XB/><B><XC/><C/></B><XD/><D/></A>");
+    query("/", "<A>\n<XB/>\n<B>\n<XC/>\n<C/>\n</B>\n<XD/>\n<D/>\n</A>");
   }
 
   /**
    * Distance caching tested for inserts at different levels.
-   * @throws BaseXException excp
+   * @throws BaseXException exception
    */
   @Test
   public void delayedDistanceAdjustment2() throws BaseXException {
     createDB("<A><B><C/></B><D><E/></D></A>");
     query("insert node <XB/> before //B, insert node <XC/> before //C, " +
         "insert node <XD/> before //D, insert node <XE/> before //E");
-    query("/", "<A><XB/><B><XC/><C/></B><XD/><D><XE/><E/></D></A>");
+    query("/", "<A>\n<XB/>\n<B>\n<XC/>\n<C/>\n</B>\n<XD/>\n<D>\n<XE/>\n<E/>\n</D>\n</A>");
   }
 
   /**
    * Distance caching tested for inserts at different levels.
-   * @throws BaseXException excp
+   * @throws BaseXException exception
    */
   @Test
   public void delayedDistanceAdjustment3() throws BaseXException {
     createDB("<A><B><C/><D/></B></A>");
     query("insert node <XB/> before //B, insert node <XC/> before //C, " +
         "insert node <XXC/> into //C");
-    query("/", "<A><XB/><B><XC/><C><XXC/></C><D/></B></A>");
+    query("/", "<A>\n<XB/>\n<B>\n<XC/>\n<C>\n<XXC/>\n</C>\n<D/>\n</B>\n</A>");
   }
 
   /**
    * Distance caching tested for inserts at different levels.
-   * @throws BaseXException excp
+   * @throws BaseXException exception
    */
   @Test
   public void delayedDistanceAdjustment4() throws BaseXException {
     createDB("<A><B><C/><D/></B><E/></A>");
     query("insert node <XB/> before //B, insert node <XC/> before //C, " +
         "insert node <XXC/> into //C");
-    query("/", "<A><XB/><B><XC/><C><XXC/></C><D/></B><E/></A>");
+    query("/", "<A>\n<XB/>\n<B>\n<XC/>\n<C>\n<XXC/>\n</C>\n<D/>\n</B>\n<E/>\n</A>");
   }
 
   /**
    * Distance caching tested for inserts at different levels.
-   * @throws BaseXException excp
+   * @throws BaseXException exception
    */
   @Test
   public void delayedDistanceAdjustment5() throws BaseXException {
     createDB("<A><B><C/></B></A>");
     query("insert node <XB/> before //B, insert node <XC/> before //C");
-    query("/", "<A><XB/><B><XC/><C/></B></A>");
+    query("/", "<A>\n<XB/>\n<B>\n<XC/>\n<C/>\n</B>\n</A>");
   }
 
   /**
    * Distance caching tested for simple deletes.
-   * @throws BaseXException excp
+   * @throws BaseXException exception
    */
   @Test
   public void delayedDistanceAdjustment6() throws BaseXException {
     createDB("<A><B/><C/></A>");
     query("delete node //B");
-    query("/", "<A><C/></A>");
+    query("/", "<A>\n<C/>\n</A>");
   }
 
   /**
    * Distance caching tested for simple deletes.
-   * @throws BaseXException excp
+   * @throws BaseXException exception
    */
   @Test
   public void delayedDistanceAdjustment7() throws BaseXException {
     createDB("<A><B/><C/><D/><E/></A>");
     query("delete node (//B,//D)");
-    query("/", "<A><C/><E/></A>");
+    query("/", "<A>\n<C/>\n<E/>\n</A>");
   }
 
   /**
    * Distance caching tested for deletes at different levels.
-   * @throws BaseXException excp
+   * @throws BaseXException exception
    */
   @Test
   public void delayedDistanceAdjustment8() throws BaseXException {
     createDB("<A><B/><C><D/><E/></C></A>");
     query("delete node (//B,//D)");
-    query("/", "<A><C><E/></C></A>");
+    query("/", "<A>\n<C>\n<E/>\n</C>\n</A>");
   }
 
   /**
    * Distance caching tested for deletes at different levels.
-   * @throws BaseXException excp
+   * @throws BaseXException exception
    */
   @Test
   public void delayedDistanceAdjustment9() throws BaseXException {
     createDB("<A><B/><C><D/><E/><F/></C></A>");
     query("delete node (//B,//D)");
-    query("/", "<A><C><E/><F/></C></A>");
+    query("/", "<A>\n<C>\n<E/>\n<F/>\n</C>\n</A>");
   }
 
   /**
    * Distance caching tested for deletes at different levels.
-   * @throws BaseXException excp
+   * @throws BaseXException exception
    */
   @Test
   public void delayedDistanceAdjustment10() throws BaseXException {
     createDB("<A><B/><C><D/><E/></C><F/></A>");
     query("delete node (//B,//D)");
-    query("/", "<A><C><E/></C><F/></A>");
+    query("/", "<A>\n<C>\n<E/>\n</C>\n<F/>\n</A>");
   }
 
   /**
    * Distance caching tested for deletes at different levels.
-   * @throws BaseXException excp
+   * @throws BaseXException exception
    */
   @Test
   public void delayedDistanceAdjustment11() throws BaseXException {
     createDB("<A><B/><C/><D/><E/></A>");
     query("delete node (//C,//D)");
-    query("/", "<A><B/><E/></A>");
+    query("/", "<A>\n<B/>\n<E/>\n</A>");
   }
 
   /**
    * Distance caching tested for deletes at different levels.
-   * @throws BaseXException excp
+   * @throws BaseXException exception
    */
   @Test
   public void delayedDistanceAdjustment12() throws BaseXException {
     createDB("<A><B/><C/><D/><E/></A>");
     query("delete node (//B, //C), insert node <CNEW><X/></CNEW> before //D");
-    query("/", "<A><CNEW><X/></CNEW><D/><E/></A>");
+    query("/", "<A>\n<CNEW>\n<X/>\n</CNEW>\n<D/>\n<E/>\n</A>");
   }
 
   /**
    * Distance caching tested for deletes at different levels.
-   * @throws BaseXException excp
+   * @throws BaseXException exception
    */
   @Test
   public void delayedDistanceAdjustment13() throws BaseXException {
@@ -924,12 +926,12 @@ public final class UpdateTest extends AdvancedQueryTest {
     query("insert node <X/> into //C," +
         "insert node <X><Y/></X> before //C," +
         "insert node <X/> after //D");
-    query("/", "<A><B><X><Y/></X><C><X/></C><D/><X/></B></A>");
+    query("/", "<A>\n<B>\n<X>\n<Y/>\n</X>\n<C>\n<X/>\n</C>\n<D/>\n<X/>\n</B>\n</A>");
   }
 
   /**
    * Distance caching tested for neighboring inserts.
-   * @throws BaseXException excp
+   * @throws BaseXException exception
    */
   @Test
   public void delayedDistanceAdjustment14() throws BaseXException {
@@ -937,64 +939,65 @@ public final class UpdateTest extends AdvancedQueryTest {
     query("insert node <X><Y/></X> into //C," +
         "insert node <X><Y/></X> before //C," +
         "insert node <X><Y/></X> after //D");
-    query("/", "<A><B><X><Y/></X><C><X><Y/></X></C><D/><X><Y/></X></B></A>");
+    query("/", "<A>\n<B>\n<X>\n<Y/>\n</X>\n<C>\n<X>\n<Y/>\n</X>\n" +
+        "</C>\n<D/>\n<X>\n<Y/>\n</X>\n</B>\n</A>");
   }
 
   /**
    * Distance caching tested for neighboring inserts.
-   * @throws BaseXException excp
+   * @throws BaseXException exception
    */
   @Test
   public void delayedDistanceAdjustment15() throws BaseXException {
     createDB("<A><B/><C/></A>");
     query("insert node <X2/> before //C," +
         "insert node <X1/> after //B");
-    query("/", "<A><B/><X1/><X2/><C/></A>");
+    query("/", "<A>\n<B/>\n<X1/>\n<X2/>\n<C/>\n</A>");
   }
 
   /**
    * Distance caching tested for neighboring inserts.
-   * @throws BaseXException excp
+   * @throws BaseXException exception
    */
   @Test
   public void delayedDistanceAdjustment16() throws BaseXException {
     createDB("<A><B/><C><D/></C><E/></A>");
     query("insert node <X1/> into //C," +
         "insert node <X2/> as last into //C");
-    query("/", "<A><B/><C><D/><X1/><X2/></C><E/></A>");
+    query("/", "<A>\n<B/>\n<C>\n<D/>\n<X1/>\n<X2/>\n</C>\n<E/>\n</A>");
   }
 
   /**
    * Tests if pre cache is clear / free of ambiguous entries.
-   * @throws BaseXException excp
+   * @throws BaseXException exception
    */
   @Test
   public void delayedDistanceAdjustment17() throws BaseXException {
     createDB("<A><B/><C/><D/></A>");
     query("insert node <X/> after //B, delete node //C");
-    query("/", "<A><B/><X/><D/></A>");
+    query("/", "<A>\n<B/>\n<X/>\n<D/>\n</A>");
   }
 
   /**
    * Tests if pre cache is clear / free of ambiguous entries.
-   * @throws BaseXException excp
+   * @throws BaseXException exception
    */
   @Test
   public void delayedDistanceAdjustment18() throws BaseXException {
     createDB("<A><B/><C/><D/></A>");
     query("insert node <X/> before //D, delete node //C");
-    query("/", "<A><B/><X/><D/></A>");
+    query("/", "<A>\n<B/>\n<X/>\n<D/>\n</A>");
   }
 
   /**
    * Tests if pre cache is clear / free of ambiguous entries.
-   * @throws BaseXException excp
+   * @throws BaseXException exception
    */
   @Test
   public void delayedDistanceAdjustment19() throws BaseXException {
     createDB("<A><B/><C/><D/></A>");
     query("replace node //C with <X/>");
-    query("/", "<A><B/><X/><D/></A>");
+    query("/", "<A>\n<B/>\n<X/>\n<D/>\n</A>");
   }
 
   /**
@@ -1029,47 +1032,47 @@ public final class UpdateTest extends AdvancedQueryTest {
   /**
    * Testing distance caching when a node is deleted and there have been updates on the
    * descendant axis. Tests effect on following nodes.
-   * @throws BaseXException excp
+   * @throws BaseXException exception
    */
   @Test
   public void delayedDistanceAdjustment22() throws BaseXException {
     createDB("<A><B><C/><D/></B><E/></A>");
     query("insert node <X/> into //D, delete node //B");
-    query("/", "<A><E/></A>");
+    query("/", "<A>\n<E/>\n</A>");
   }
 
   /**
    * Tests if updates are executed in the correct order and if the sorting of updates
    * is stable.
-   * @throws BaseXException excp
+   * @throws BaseXException exception
    */
   @Test
   public void delayedDistanceAdjustment23() throws BaseXException {
     createDB("<A><B/></A>");
     query("insert node <P2/> into //B, insert node <P3/> into //A");
-    query("/", "<A><B><P2/></B><P3/></A>");
+    query("/", "<A>\n<B>\n<P2/>\n</B>\n<P3/>\n</A>");
   }
 
   /**
    * Tests if reordering of updates works correctly.
-   * @throws BaseXException excp
+   * @throws BaseXException exception
    */
   @Test
   public void delayedDistanceAdjustment24() throws BaseXException {
     createDB("<A><B/><C/><D/><E/></A>");
     query("insert node <X/> into //B, delete node //C");
-    query("/", "<A><B><X/></B><D/><E/></A>");
+    query("/", "<A>\n<B>\n<X/>\n</B>\n<D/>\n<E/>\n</A>");
   }
 
   /**
    * Tests if reordering of updates works correctly.
-   * @throws BaseXException excp
+   * @throws BaseXException exception
    */
   @Test
   public void delayedDistanceAdjustment25() throws BaseXException {
     createDB("<A><B><C/></B><D/><E/></A>");
     query("insert node <X/> into //B, delete node //C");
-    query("/", "<A><B><X/></B><D/><E/></A>");
+    query("/", "<A>\n<B>\n<X/>\n</B>\n<D/>\n<E/>\n</A>");
   }
 
   /**
@@ -1083,7 +1086,7 @@ public final class UpdateTest extends AdvancedQueryTest {
         "delete node .//@at1," +
         "delete node .//@at3," +
         "rename node (.//@at2)[1] as 'at2x')",
-        "<n><x at2x=\"0\"/><y/><b/></n>");
+        "<n>\n<x at2x=\"0\"/>\n<y/>\n<b/>\n</n>");
   }
 
   /**
@@ -1092,10 +1095,10 @@ public final class UpdateTest extends AdvancedQueryTest {
    */
   @Test
   public void dbUpdateTransform() {
-    error("copy $c := <a/> modify db:output('x') return $c", Err.BASX_DBTRANSFORM);
+    error("copy $c := <a/> modify db:output('x') return $c", BASX_DBTRANSFORM);
     error("copy $c := <a/> modify db:add('" + NAME + "','<x/>','x.xml') return $c",
-        Err.BASX_DBTRANSFORM);
-    error("copy $c := <a/> modify put(<a/>, 'x.txt') return $c", Err.BASX_DBTRANSFORM);
+        BASX_DBTRANSFORM);
+    error("copy $c := <a/> modify put(<a/>, 'x.txt') return $c", BASX_DBTRANSFORM);
   }
 
   /**
@@ -1128,19 +1131,6 @@ public final class UpdateTest extends AdvancedQueryTest {
       "xquery:eval('declare variable $c external; $c()', map { 'c': local:c#0 })", "<a/>");
   }
 
-  /**
-   * Tests the expressions in modify clauses for updates.
-   */
-  @Test
-  public void modifyCheck() {
-    error("copy $c:= <a>X</a> modify 'a' return $c", Err.UPMODIFY);
-    error("copy $c:= <a>X</a> modify(delete node $c/text(),'a') return $c", Err.UPALL);
-
-    error("text { <a/> update (delete node <a/>,<b/>) }", Err.UPALL);
-    error("1[<a/> update (delete node <a/>,<b/>)]", Err.UPALL);
-    error("for $i in 1 order by (<a/> update (delete node <a/>,<b/>)) return $i", Err.UPALL);
-  }
-
   /** Tests adding an attribute and thus crossing the {@link IO#MAXATTS} line (GH-752). */
   @Test
   public void insertAttrMaxAtt() {
@@ -1160,7 +1150,7 @@ public final class UpdateTest extends AdvancedQueryTest {
   @Test
   public void modify() {
     query("let $c := <x/> return $c update ()", "<x/>");
-    query("let $c := <x/> return $c update insert node <y/> into .", "<x><y/></x>");
+    query("let $c := <x/> return $c update insert node <y/> into .", "<x>\n<y/>\n</x>");
   }
 
   /**
@@ -1173,30 +1163,64 @@ public final class UpdateTest extends AdvancedQueryTest {
     query("(<X/>,<Y/>)/(insert node <Z/> into .)");
   }
 
+  /**
+   * Tests the expressions in modify clauses for updates.
+   */
+  @Test
+  public void modifyCheck() {
+    error("copy $c:= <a>X</a> modify 'a' return $c", UPMODIFY);
+    error("copy $c:= <a>X</a> modify(delete node $c/text(),'a') return $c", UPALL_X);
+
+    error("text { <a/> update (delete node <a/>,<b/>) }", UPALL_X);
+    error("1[<a/> update (delete node <a/>,<b/>)]", UPALL_X);
+    error("for $i in 1 order by (<a/> update (delete node <a/>,<b/>)) return $i", UPALL_X);
+  }
 
   /**
    * Reject updating function items.
    */
   @Test
   public void updatingFuncItems() {
-    error("db:output(?)", Err.SERFUNC);
-    error("db:output#1", Err.SERFUNC);
-    error("declare updating function local:a() { () }; local:a#0", Err.SERFUNC);
-    error("declare function local:a() { local:b#0 };"
-        + "declare updating function local:b() { db:output('1') }; local:a()", Err.SERFUNC);
+    query("db:output(?)", "function (anonymous)#1");
+    query("db:output#1", "function db:output#1");
+    query("declare updating function local:a() { () }; local:a#0", "function local:a#0");
+    query("declare function local:a() { local:a#0 };"
+        + "declare updating function local:b() { db:output('1') }; local:a()",
+        "function local:a#0");
     query("declare function local:not-used() { local:b#0 };"
         + "declare updating function local:b() { db:output('1') }; local:b()", "1");
 
-    error("db:output(?)(<a/>)", Err.UPFUNCUP);
-    error("db:output#1(<a/>)", Err.UPFUNCUP);
-    error("declare updating function local:a() { () }; local:a#0()", Err.UPFUNCUP);
-    error("declare function local:a() { local:b#0 };"
-        + "declare updating function local:b() { db:output('1') }; local:a()()", Err.UPFUNCUP);
+    error("function() { delete node <a/> }()", UPNOT_X);
+    error("updating function() { delete node <a/> }()", UPNOT_X);
+    error("updating %updating function() { 1 }()", UPEXPECTF);
 
-    error("updating count(?)(1)", Err.UPFUNCNOTUP);
-    error("updating count#1(1)", Err.UPFUNCNOTUP);
-    error("declare function local:a() { () }; updating local:a#0()", Err.UPFUNCNOTUP);
+    error("db:output(?)(<a/>)", UPFUNCUP);
+    error("db:output#1(<a/>)", UPFUNCUP);
+    error("%updating function($a) { db:output($a) }(1)", UPFUNCUP);
+    error("%updating function() { 1 }()", UPFUNCUP);
+    error("declare updating function local:a() { () }; local:a#0()", UPFUNCUP);
     error("declare function local:a() { local:b#0 };"
-        + "declare function local:b() { count('1') }; updating local:a()()", Err.UPFUNCNOTUP);
+        + "declare updating function local:b() { db:output('1') }; local:a()()", UPFUNCUP);
+
+    error("updating count(?)(1)", UPFUNCNOTUP);
+    error("updating count#1(1)", UPFUNCNOTUP);
+    error("updating function($a) { count($a) }(1)", UPFUNCNOTUP);
+    error("declare function local:a() { () }; updating local:a#0()", UPFUNCNOTUP);
+    error("declare function local:a() { local:b#0 };"
+        + "declare function local:b() { count('1') }; updating local:a()()", UPFUNCNOTUP);
+  }
+
+  /** Test method. */
+  @Test
+  public void updateCheck() {
+    query("declare function local:a() { fold-left((), (), function($a, $b) { local:a() }) };"
+        + "declare function local:b() { () }; ()", "");
+  }
+
+  /** Test output URI is correctly resolved. */
+  @Test
+  public void resolveUri() {
+    final String output = sandbox().merge("test.xml").url();
+    query(PUT.args("<a/>", output));
   }
 }
