@@ -9,20 +9,21 @@ import org.junit.*;
 /**
  * Tests for the {@link MinHeap} implementation.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Leo Woerteler
  */
 public final class MinHeapTest {
   /** Checks if the heap can be used for sorting. */
   @Test
   public void heapSort() {
-    final MinHeap<Integer, Integer> heap = new MinHeap<Integer, Integer>(2, null);
-    final Integer[] vals = new Integer[1000];
-    for(int i = 0; i < vals.length; i++) vals[i] = i;
+    final MinHeap<Integer, Integer> heap = new MinHeap<>(2, null);
+    final int vl = 1000;
+    final Integer[] vals = new Integer[vl];
+    for(int v = 0; v < vl; v++) vals[v] = v;
     Collections.shuffle(Arrays.asList(vals));
 
-    for(final int i : vals) {
-      heap.insert(i, i);
+    for(final int v : vals) {
+      heap.insert(v, v);
       heap.verify();
     }
 
@@ -37,7 +38,7 @@ public final class MinHeapTest {
   /** Checks if the heap can be used for sorting a pre-sorted sequence. */
   @Test
   public void heapPreSort() {
-    final MinHeap<Integer, Integer> heap = new MinHeap<Integer, Integer>(2, null);
+    final MinHeap<Integer, Integer> heap = new MinHeap<>(2, null);
     for(int i = 0; i < 1000; i++) {
       heap.insert(i, i);
       heap.verify();
