@@ -2,13 +2,13 @@ package org.basex.util;
 
 import static org.junit.Assert.*;
 
-import org.basex.util.list.StringList;
-import org.junit.Test;
+import org.basex.util.list.*;
+import org.junit.*;
 
 /**
  * Tests for the {@link StringList} implementation.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  */
 public class StringListTest {
   /** Tests {@code containsAll(l)} function. */
