@@ -12,48 +12,52 @@ import java.util.*;
  *
  * Documentation: http://docs.basex.org/wiki/Clients
  *
- * (C) BaseX Team 2005-14, BSD License
+ * (C) BaseX Team 2005-15, BSD License
  */
-public class BaseXClient {
+public final class BaseXClient {
   /** UTF-8 charset. */
-  static final Charset UTF8 = Charset.forName("UTF-8");
-  /** Event notifications. */
-  final Map<String, EventNotifier> notifiers = new HashMap<String, EventNotifier>();
+  private static final Charset UTF8 = Charset.forName("UTF-8");
   /** Output stream. */
-  final OutputStream out;
+  private final OutputStream out;
+  /** Input stream (buffered). */
+  private final BufferedInputStream in;
+
   /** Socket. */
-  final Socket socket;
-  /** Cache. */
-  final BufferedInputStream in;
+  private final Socket socket;
   /** Command info. */
-  String info;
-  /** Socket event reference. */
-  Socket esocket;
-  /** Socket host name. */
-  String ehost;
+  private String info;
 
   /**
    * Constructor.
    * @param host server name
    * @param port server port
-   * @param user user name
-   * @param pass password
+   * @param username user name
+   * @param password password
    * @throws IOException Exception
    */
-  public BaseXClient(final String host, final int port, final String user,
-      final String pass) throws IOException {
+  public BaseXClient(final String host, final int port, final String username,
+      final String password) throws IOException {
 
     socket = new Socket();
     socket.connect(new InetSocketAddress(host, port), 5000);
     in = new BufferedInputStream(socket.getInputStream());
     out = socket.getOutputStream();
-    ehost = host;
 
-    // receive timestamp
-    final String ts = receive();
-    // send {Username}0 and hashed {Password/Timestamp}0
-    send(user);
-    send(md5(md5(pass) + ts));
+    // receive server response
+    final String[] response = receive().split(":");
+    final String code, nonce;
+    if(response.length > 1) {
+      // support for digest authentication
+      code = username + ':' + response[0] + ':' + password;
+      nonce = response[1];
+    } else {
+      // support for cram-md5 (Version < 8.0)
+      code = password;
+      nonce = response[0];
+    }
+
+    send(username);
+    send(md5(md5(code) + nonce));
 
     // receive success flag
     if(!ok()) throw new IOException("Access denied.");
@@ -61,27 +65,27 @@ public class BaseXClient {
 
   /**
    * Executes a command and serializes the result to an output stream.
-   * @param cmd command
-   * @param o output stream
+   * @param command command
+   * @param output output stream
    * @throws IOException Exception
    */
-  public void execute(final String cmd, final OutputStream o) throws IOException {
+  public void execute(final String command, final OutputStream output) throws IOException {
     // send {Command}0
-    send(cmd);
-    receive(in, o);
+    send(command);
+    receive(in, output);
     info = receive();
     if(!ok()) throw new IOException(info);
   }
 
   /**
    * Executes a command and returns the result.
-   * @param cmd command
+   * @param command command
    * @return result
    * @throws IOException Exception
    */
-  public String execute(final String cmd) throws IOException {
+  public String execute(final String command) throws IOException {
     final ByteArrayOutputStream os = new ByteArrayOutputStream();
-    execute(cmd, os);
+    execute(command, os);
     return new String(os.toByteArray(), UTF8);
   }
 
@@ -107,7 +111,7 @@ public class BaseXClient {
 
   /**
    * Adds a document to a database.
-   * @param path path to document
+   * @param path path to resource
    * @param input xml input
    * @throws IOException I/O exception
    */
@@ -117,7 +121,7 @@ public class BaseXClient {
 
   /**
    * Replaces a document in a database.
-   * @param path path to document
+   * @param path path to resource
    * @param input xml input
    * @throws IOException I/O exception
    */
@@ -127,7 +131,7 @@ public class BaseXClient {
 
   /**
    * Stores a binary resource in a database.
-   * @param path path to document
+   * @param path path to resource
    * @param input xml input
    * @throws IOException I/O exception
    */
@@ -135,46 +139,6 @@ public class BaseXClient {
     send(13, path, input);
   }
 
-  /**
-   * Watches an event.
-   * @param name event name
-   * @param notifier event notification
-   * @throws IOException I/O exception
-   */
-  public void watch(final String name, final EventNotifier notifier) throws IOException {
-    out.write(10);
-    if(esocket == null) {
-      final int eport = Integer.parseInt(receive());
-      // initialize event socket
-      esocket = new Socket();
-      esocket.connect(new InetSocketAddress(ehost, eport), 5000);
-      final OutputStream os = esocket.getOutputStream();
-      receive(in, os);
-      os.write(0);
-      os.flush();
-      final InputStream is = esocket.getInputStream();
-      is.read();
-      listen(is);
-    }
-    send(name);
-    info = receive();
-    if(!ok()) throw new IOException(info);
-    notifiers.put(name, notifier);
-  }
-
-  /**
-   * Unwatches an event.
-   * @param name event name
-   * @throws IOException I/O exception
-   */
-  public void unwatch(final String name) throws IOException {
-    out.write(11);
-    send(name);
-    info = receive();
-    if(!ok()) throw new IOException(info);
-    notifiers.remove(name);
-  }
-
   /**
    * Returns command information.
    * @return string info
@@ -190,7 +154,6 @@ public class BaseXClient {
   public void close() throws IOException {
     send("exit");
     out.flush();
-    if(esocket != null) esocket.close();
     socket.close();
   }
 
@@ -199,7 +162,7 @@ public class BaseXClient {
    * @return value of check
    * @throws IOException Exception
    */
-  boolean ok() throws IOException {
+  private boolean ok() throws IOException {
     out.flush();
     return in.read() == 0;
   }
@@ -209,7 +172,7 @@ public class BaseXClient {
    * @return String result or info
    * @throws IOException I/O exception
    */
-  String receive() throws IOException {
+  private String receive() throws IOException {
     final ByteArrayOutputStream os = new ByteArrayOutputStream();
     receive(in, os);
     return new String(os.toByteArray(), UTF8);
@@ -217,66 +180,40 @@ public class BaseXClient {
 
   /**
    * Sends a string to the server.
-   * @param s string to be sent
+   * @param string string to be sent
    * @throws IOException I/O exception
    */
-  void send(final String s) throws IOException {
-    out.write((s + '\0').getBytes(UTF8));
+  private void send(final String string) throws IOException {
+    out.write((string + '\0').getBytes(UTF8));
   }
 
   /**
    * Receives a string and writes it to the specified output stream.
-   * @param is input stream
-   * @param os output stream
+   * @param input input stream
+   * @param output output stream
    * @throws IOException I/O exception
    */
-  static void receive(final InputStream is, final OutputStream os) throws IOException {
-    for(int b; (b = is.read()) > 0;) {
+  private static void receive(final InputStream input, final OutputStream output)
+      throws IOException {
+    for(int b; (b = input.read()) > 0;) {
       // read next byte if 0xFF is received
-      os.write(b == 0xFF ? is.read() : b);
+      output.write(b == 0xFF ? input.read() : b);
     }
   }
 
   /**
    * Sends a command, argument, and input.
-   * @param cmd command
-   * @param path path to document
+   * @param code command code
+   * @param path name, or path to resource
    * @param input xml input
    * @throws IOException I/O exception
    */
-  private void send(final int cmd, final String path, final InputStream input)
-      throws IOException {
-    out.write(cmd);
+  private void send(final int code, final String path, final InputStream input) throws IOException {
+    out.write(code);
     send(path);
     send(input);
   }
 
-  /**
-   * Starts the listener thread.
-   * @param is input stream
-   */
-  private void listen(final InputStream is) {
-    final BufferedInputStream bi = new BufferedInputStream(is);
-    new Thread() {
-      @Override
-      public void run() {
-        try {
-          while(true) {
-            ByteArrayOutputStream os = new ByteArrayOutputStream();
-            receive(bi, os);
-            final String name = new String(os.toByteArray(), UTF8);
-            os = new ByteArrayOutputStream();
-            receive(bi, os);
-            final String data = new String(os.toByteArray(), UTF8);
-            notifiers.get(name).notify(data);
-          }
-        } catch(final IOException ex) {
-          // loop will be quit if no data can be received anymore
-        }
-      }
-    }.start();
-  }
-
   /**
    * Sends an input stream to the server.
    * @param input xml input
@@ -334,7 +271,7 @@ public class BaseXClient {
      * @param query query string
      * @throws IOException I/O exception
      */
-    public Query(final String query) throws IOException {
+    Query(final String query) throws IOException {
       id = exec(0, query);
     }
 
@@ -355,8 +292,7 @@ public class BaseXClient {
      * @param type type (can be an empty string)
      * @throws IOException I/O exception
      */
-    public void bind(final String name, final String value, final String type)
-        throws IOException {
+    public void bind(final String name, final String value, final String type) throws IOException {
       cache = null;
       exec(3, id + '\0' + name + '\0' + value + '\0' + type);
     }
@@ -390,7 +326,7 @@ public class BaseXClient {
       if(cache == null) {
         out.write(4);
         send(id);
-        cache = new ArrayList<byte[]>();
+        cache = new ArrayList<>();
         final ByteArrayOutputStream os = new ByteArrayOutputStream();
         while(in.read() > 0) {
           receive(in, os);
@@ -451,28 +387,17 @@ public class BaseXClient {
 
     /**
      * Executes the specified command.
-     * @param cmd command
+     * @param code command code
      * @param arg argument
      * @return resulting string
      * @throws IOException I/O exception
      */
-    private String exec(final int cmd, final String arg) throws IOException {
-      out.write(cmd);
+    private String exec(final int code, final String arg) throws IOException {
+      out.write(code);
       send(arg);
       final String s = receive();
       if(!ok()) throw new IOException(receive());
       return s;
     }
   }
-
-  /**
-   * Interface for event notifications.
-   */
-  public interface EventNotifier {
-    /**
-     * Invoked when a database event was fired.
-     * @param value event string
-     */
-    void notify(final String value);
-  }
 }
\ No newline at end of file
