@@ -1,13 +1,13 @@
 package org.basex.examples.module;
 
 import org.basex.core.*;
-import org.basex.data.*;
 import org.basex.query.*;
+import org.basex.query.value.*;
 
 /**
  * This example demonstrates how Java classes can be imported as XQuery modules.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  */
 public final class FruitsExample {
   /**
@@ -22,7 +22,6 @@ public final class FruitsExample {
 
     System.out.println("=== FruitsExample ===");
 
-    // ------------------------------------------------------------------------
     // Specify query to be executed
     String query =
         "import module namespace fruits = " +
@@ -40,25 +39,17 @@ public final class FruitsExample {
     System.out.println("\n* Query:");
     System.out.println(query);
 
-    // ------------------------------------------------------------------------
     // Create a query processor
-    QueryProcessor processor = new QueryProcessor(query, context);
+    try(QueryProcessor processor = new QueryProcessor(query, context)) {
+      // Execute the query
+      Value result = processor.value();
 
-    // ------------------------------------------------------------------------
-    // Execute the query
-    Result result = processor.execute();
+      System.out.println("\n* Result:");
 
-    System.out.println("\n* Result:");
+      // Print result as string
+      System.out.println(result);
+    }
 
-    // ------------------------------------------------------------------------
-    // Print result as string
-    System.out.println(result);
-
-    // ------------------------------------------------------------------------
-    // Close the query processor
-    processor.close();
-
-    // ------------------------------------------------------------------------
     // Close the database context
     context.close();
   }
