@@ -4,7 +4,7 @@ import java.io.*;
 import java.util.*;
 
 import org.basex.*;
-import org.basex.server.*;
+import org.basex.api.client.*;
 
 /**
  * This class connects multiple clients to one server instance.
@@ -12,7 +12,7 @@ import org.basex.server.*;
  * Database information will be shown before and after the
  * clients have been run.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  */
 public final class ServerConcurrency {
   /**
@@ -31,68 +31,57 @@ public final class ServerConcurrency {
   void run() throws Exception {
     System.out.println("=== ServerConcurrency ===");
 
-    // ------------------------------------------------------------------------
     // Start server
     System.out.println("\n* Start server.");
 
     BaseXServer server = new BaseXServer();
 
-    // ------------------------------------------------------------------------
     // Create a client session with host name, port, user name and password
     System.out.println("\n* Create a client session.");
 
-    ClientSession session =
-      new ClientSession("localhost", 1984, "admin", "admin", System.out);
+    try(ClientSession session =
+      new ClientSession("localhost", 1984, "admin", "admin", System.out)) {
 
-    // ------------------------------------------------------------------------
-    // Create a database
-    System.out.println("\n* Create a database.");
+      // Create a database
+      System.out.println("\n* Create a database.");
 
-    send("CREATE DB input src/main/resources/xml/input.xml", session);
+      send("CREATE DB input src/main/resources/xml/input.xml", session);
 
-    // ------------------------------------------------------------------------
-    // Setup some clients that simultaneously read and write from the database
-    System.out.println("\n* Run one reader and two writers threads.");
+      // Setup some clients that simultaneously read and write from the database
+      System.out.println("\n* Run one reader and two writers threads.");
 
-    ClientExample reader1 = new ClientExample("//li");
-    ClientExample writer1 = new ClientExample("insert node " +
-        "<li>new node</li> as last into /html/body//ul");
-    ClientExample writer2 = new ClientExample("insert node " +
-        "<new>One more</new> as last into /html/body");
+      ClientExample reader1 = new ClientExample("//li");
+      ClientExample writer1 = new ClientExample("insert node " +
+          "<li>new node</li> as last into /html/body//ul");
+      ClientExample writer2 = new ClientExample("insert node " +
+          "<new>One more</new> as last into /html/body");
 
-    // -------------------------------------------------------------------------
-    // Let the clients run their query several times:
-    Thread.sleep(2000);
+      // Let the clients run their query several times:
+      Thread.sleep(2000);
 
-    // ------------------------------------------------------------------------
-    // Stop the clients
-    System.out.println("\n* Stop client threads.");
+      // Stop the clients
+      System.out.println("\n* Stop client threads.");
 
-    reader1.stop();
-    writer1.stop();
-    writer2.stop();
+      reader1.stop();
+      writer1.stop();
+      writer2.stop();
 
-    Thread.sleep(1000);
+      Thread.sleep(1000);
 
-    // -------------------------------------------------------------------------
-    // Show modified database contents
-    System.out.println("\n* Show modified database contents:");
+      // Show modified database contents
+      System.out.println("\n* Show modified database contents:");
 
-    send("XQUERY //li", session);
+      send("XQUERY //li", session);
 
-    // ----------------------------------------------------------------------
-    // Drop the database
-    System.out.println("\n* Drop the database.");
+      // Drop the database
+      System.out.println("\n* Drop the database.");
 
-    send("DROP DB input", session);
+      send("DROP DB input", session);
 
-    // ------------------------------------------------------------------------
-    // Close the client session
-    System.out.println("\n* Close the client session.");
+      // Close the client session
+      System.out.println("\n* Close the client session.");
+    }
 
-    session.close();
-
-    // ------------------------------------------------------------------------
     // Stop the server
     System.out.println("\n* Stop server.");
 
@@ -107,7 +96,6 @@ public final class ServerConcurrency {
    * @throws IOException I/O exception
    */
   static void send(final String cmd, final ClientSession cs) throws IOException {
-    // ------------------------------------------------------------------------
     // Execute the command
     cs.execute(cmd);
   }
@@ -128,20 +116,16 @@ public final class ServerConcurrency {
      * @throws IOException I/O exception
      */
     ClientExample(final String query) throws IOException {
-      // ----------------------------------------------------------------------
       // Create a client session and open database
-      final ClientSession session =
-        new ClientSession("localhost", 1984, "admin", "admin");
+      final ClientSession session = new ClientSession("localhost", 1984, "admin", "admin");
       send("OPEN input", session);
 
-      // ----------------------------------------------------------------------
       // Create and run the query thread
 
       new Thread() {
         @Override
         public void run() {
           try {
-            // ----------------------------------------------------------------
             // Loop until the running flag has been invalidated
             while(running) {
               // Run the specified query
@@ -150,11 +134,15 @@ public final class ServerConcurrency {
               // Wait for a random time
               Thread.sleep(r.nextInt(500));
             }
-            // ----------------------------------------------------------------
-            // Close the client session
-            session.close();
-          } catch(final Exception ex) {
+          } catch(Exception ex) {
             ex.printStackTrace();
+          } finally {
+            // Close the client session
+            try {
+              session.close();
+            } catch(Exception ex) {
+              ex.printStackTrace();
+            }
           }
         }
       }.start();
