@@ -9,14 +9,13 @@ import javax.xml.xquery.*;
 import org.w3c.dom.*;
 
 /**
- * XQJ Example, derived from the XQJ Tutorial
- * <a href="http://www.xquery.com/tutorials/xqj_tutorial">
- * http://www.xquery.com/tutorials/xqj_tutorial</a>
- * from Marc van Cappellen.
+ * XQJ Examples, derived from an
+ * <a href="https://www.progress.com/products/data-integration-suite/data-integration-suite-developer-center/data-integration-suite-tutorials/learning-xquery/introduction-to-the-xquery-api-for-java-xqj-">
+ * XQJ online tutorial</a>.
  *
  * Part 3: Querying Data from XML Files or Java XML APIs.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  */
 public final class Part3 extends Main {
   /**
@@ -72,10 +71,10 @@ public final class Part3 extends Main {
     if(xqs.next()) print("Query: " + query, xqs);
 
     // Execute a query from a file input stream
-    InputStream is = new FileInputStream(path + "/orders.xq");
-    xqs = xqe.executeQuery(is);
-    if(xqs.next()) print("Query from input stream", xqs);
-    is.close();
+    try(InputStream is = new FileInputStream(path + "/orders.xq")) {
+      xqs = xqe.executeQuery(is);
+      if(xqs.next()) print("Query from input stream", xqs);
+    }
 
     // Close the connection
     close(xqc);
