@@ -6,14 +6,13 @@ import java.util.*;
 import javax.xml.xquery.*;
 
 /**
- * XQJ Example, derived from the XQJ Tutorial
- * <a href="http://www.xquery.com/tutorials/xqj_tutorial">
- * http://www.xquery.com/tutorials/xqj_tutorial</a>
- * from Marc van Cappellen.
+ * XQJ Examples, derived from an
+ * <a href="https://www.progress.com/products/data-integration-suite/data-integration-suite-developer-center/data-integration-suite-tutorials/learning-xquery/introduction-to-the-xquery-api-for-java-xqj-">
+ * XQJ online tutorial</a>.
  *
  * Part 5: Serializing Results.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  */
 public final class Part5 extends Main {
   /**
@@ -32,11 +31,10 @@ public final class Part5 extends Main {
     info("Serialize output to disk");
 
     String path = new File("src/main/resources/xml").getAbsolutePath();
-    FileOutputStream fos = new FileOutputStream("result.xml");
-    XQSequence xqs = xqe.executeQuery(
-        "doc('" + path + "/orders.xml')//order[id='174']");
-    xqs.writeSequence(fos, new Properties());
-    fos.close();
+    try(FileOutputStream fos = new FileOutputStream("result.xml")) {
+      XQSequence xqs = xqe.executeQuery("doc('" + path + "/orders.xml')//order[id='174']");
+      xqs.writeSequence(fos, new Properties());
+    }
 
     /* Remaining examples from the tutorial are skipped, as
      * serialization in BaseX uses defaults. */
