@@ -10,14 +10,13 @@ import javax.xml.xquery.*;
 import org.w3c.dom.*;
 
 /**
- * XQJ Example, derived from the XQJ Tutorial
- * <a href="http://www.xquery.com/tutorials/xqj_tutorial">
- * http://www.xquery.com/tutorials/xqj_tutorial</a>
- * from Marc van Cappellen.
+ * XQJ Examples, derived from an
+ * <a href="https://www.progress.com/products/data-integration-suite/data-integration-suite-developer-center/data-integration-suite-tutorials/learning-xquery/introduction-to-the-xquery-api-for-java-xqj-">
+ * XQJ online tutorial</a>.
  *
  * Part 8: Binding External Variables.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  */
 public final class Part8 extends Main {
   /**
@@ -104,19 +103,19 @@ public final class Part8 extends Main {
 
     // Bind via StAX
     XMLInputFactory xif = XMLInputFactory.newInstance();
-    FileInputStream fis = new FileInputStream(path + "/orders.xml");
-    XMLStreamReader reader = xif.createXMLStreamReader(fis);
+    try(FileInputStream fis = new FileInputStream(path + "/orders.xml")) {
+      XMLStreamReader reader = xif.createXMLStreamReader(fis);
 
-    xqp = xqc.prepareExpression("declare variable $e external; $e");
-    xqp.bindDocument(new QName("e"), reader, null);
-    fis.close();
+      xqp = xqc.prepareExpression("declare variable $e external; $e");
+      xqp.bindDocument(new QName("e"), reader, null);
+    }
     print("Bind via StAX", xqp);
 
     // Bind via input stream
     xqp = xqc.prepareExpression("declare variable $e external; $e");
-    fis = new FileInputStream(path + "/orders.xml");
-    xqp.bindDocument(new QName("e"), fis, null, null);
-    fis.close();
+    try(FileInputStream fis = new FileInputStream(path + "/orders.xml")) {
+      xqp.bindDocument(new QName("e"), fis, null, null);
+    }
     print("Bind via input stream", xqp);
 
     // Close the connection
