@@ -1,11 +1,11 @@
 package org.basex.tests.bxapi;
 
+import java.io.*;
 import java.util.*;
 
 import javax.xml.namespace.*;
 
 import org.basex.core.Context;
-import org.basex.io.serial.*;
 import org.basex.query.*;
 import org.basex.query.expr.*;
 import org.basex.query.func.*;
@@ -21,10 +21,10 @@ import org.basex.util.list.*;
 /**
  * Wrapper for evaluating XQuery expressions.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
-public final class XQuery implements Iterable<XdmItem> {
+public final class XQuery implements Iterable<XdmItem>, Closeable {
   /** Query processor. */
   private final QueryProcessor qp;
   /** Query iterator. */
@@ -33,10 +33,10 @@ public final class XQuery implements Iterable<XdmItem> {
   /**
    * Constructor.
    * @param query query
-   * @param ctx database context
+   * @param context database context
    */
-  public XQuery(final String query, final Context ctx) {
-    qp = new QueryProcessor(query, ctx);
+  public XQuery(final String query, final Context context) {
+    qp = new QueryProcessor(query, context);
   }
 
   /**
@@ -45,15 +45,9 @@ public final class XQuery implements Iterable<XdmItem> {
    * @return self reference
    * @throws XQueryException exception
    */
-  public XQuery context(final Object value) {
-    try {
-      if(value != null) qp.context(value instanceof XdmValue ?
-          ((XdmValue) value).internal() : value);
-      return this;
-    } catch(final QueryException ex) {
-      Util.debug(ex);
-      throw new XQueryException(ex);
-    }
+  public XQuery context(final XdmValue value) {
+    qp.context(value.internal());
+    return this;
   }
 
   /**
@@ -63,12 +57,11 @@ public final class XQuery implements Iterable<XdmItem> {
    * @return self reference
    * @throws XQueryException exception
    */
-  public XQuery bind(final String key, final Object value) {
+  public XQuery bind(final String key, final XdmValue value) {
     try {
-      qp.bind(key, value instanceof XdmValue ? ((XdmValue) value).internal() : value);
+      qp.bind(key, value.internal());
       return this;
     } catch(final QueryException ex) {
-      Util.debug(ex);
       throw new XQueryException(ex);
     }
   }
@@ -86,7 +79,6 @@ public final class XQuery implements Iterable<XdmItem> {
       qp.namespace(prefix, uri);
       return this;
     } catch(final QueryException ex) {
-      Util.debug(ex);
       throw new XQueryException(ex);
     }
   }
@@ -106,7 +98,6 @@ public final class XQuery implements Iterable<XdmItem> {
       qp.sc.decFormats.put(new QNm(name).id(), new DecFormatter(null, tm));
       return this;
     } catch(final QueryException ex) {
-      Util.debug(ex);
       throw new XQueryException(ex);
     }
   }
@@ -121,9 +112,36 @@ public final class XQuery implements Iterable<XdmItem> {
     final StringList sl = new StringList();
     for(final String p : paths) sl.add(p);
     try {
-      qp.ctx.resource.addCollection(name, sl.toArray(), qp.sc.baseIO());
+      qp.qc.resources.addCollection(name, sl.toArray(), qp.sc.baseIO());
+    } catch(final QueryException ex) {
+      throw new XQueryException(ex);
+    }
+  }
+
+  /**
+   * Returns a collection reference.
+   * @param name name of the collection
+   * @return reference
+   * @throws XQueryException exception
+   */
+  public XdmValue collection(final String name) {
+    try {
+      return XdmValue.get(qp.qc.resources.collection(new QueryInput(name), qp.sc.baseIO(), null));
+    } catch(final QueryException ex) {
+      throw new XQueryException(ex);
+    }
+  }
+
+  /**
+   * Returns a document reference.
+   * @param name name of the collection
+   * @return reference
+   * @throws XQueryException exception
+   */
+  public XdmValue document(final String name) {
+    try {
+      return XdmItem.get(qp.qc.resources.doc(new QueryInput(name), qp.sc.baseIO(), null));
     } catch(final QueryException ex) {
-      Util.debug(ex);
       throw new XQueryException(ex);
     }
   }
@@ -136,9 +154,8 @@ public final class XQuery implements Iterable<XdmItem> {
    */
   public void addDocument(final String name, final String path) {
     try {
-      qp.ctx.resource.addDoc(name, path, qp.sc.baseIO());
+      qp.qc.resources.addDoc(name, path, qp.sc.baseIO());
     } catch(final QueryException ex) {
-      Util.debug(ex);
       throw new XQueryException(ex);
     }
   }
@@ -150,7 +167,7 @@ public final class XQuery implements Iterable<XdmItem> {
    * @throws XQueryException exception
    */
   public void addResource(final String name, final String... strings) {
-    qp.ctx.resource.addResource(name, strings);
+    qp.qc.resources.addResource(name, strings);
   }
 
   /**
@@ -180,13 +197,12 @@ public final class XQuery implements Iterable<XdmItem> {
    * @param args function arguments
    * @return the function call
    */
-  public Object funcCall(final String fName, final Expr... args) {
+  public StandardFunc funcCall(final String fName, final Expr... args) {
+    final QNm qName = new QNm(fName);
+    qName.uri(qName.hasPrefix() ? NSGlobal.uri(qName.prefix()) : qp.sc.funcNS);
     try {
-      final QNm qName = new QNm(fName);
-      qName.uri(qName.hasPrefix() ? NSGlobal.uri(qName.prefix()) : qp.sc.funcNS);
       return Functions.get().get(qName, args, qp.sc, null);
     } catch(QueryException ex) {
-      Util.debug(ex);
       throw new XQueryException(ex);
     }
   }
@@ -203,7 +219,6 @@ public final class XQuery implements Iterable<XdmItem> {
       it = ir.next();
       return it != null ? XdmItem.get(it) : null;
     } catch(final QueryException ex) {
-      Util.debug(ex);
       throw new XQueryException(ex);
     } finally {
       if(it == null) qp.close();
@@ -217,9 +232,8 @@ public final class XQuery implements Iterable<XdmItem> {
    */
   public XdmValue value() {
     try {
-      return XdmValue.get(qp.value());
+      return XdmValue.get(qp.value().materialize(null));
     } catch(final QueryException ex) {
-      Util.debug(ex);
       throw new XQueryException(ex);
     } finally {
       qp.close();
@@ -227,18 +241,14 @@ public final class XQuery implements Iterable<XdmItem> {
   }
 
   /**
-   * Returns serialization properties.
-   * @return serialization properties
+   * Returns the query processor.
+   * @return query processor
    */
-  public SerializerOptions serializer() {
-    return qp.ctx.serParams();
+  public QueryProcessor qp() {
+    return qp;
   }
 
-  /**
-   * Closes the query; will be called whenever if items have been returned.
-   * Should be manually called if not all items are retrieved.
-   * @throws XQueryException exception
-   */
+  @Override
   public void close() {
     qp.close();
   }
@@ -272,12 +282,12 @@ public final class XQuery implements Iterable<XdmItem> {
   /**
    * Returns the string representation of a query result.
    * @param query query string
-   * @param val optional context
-   * @param ctx database context
+   * @param value optional context
+   * @param context database context
    * @return optional expected test suite result
    */
-  public static String string(final String query, final XdmValue val, final Context ctx) {
-    final XdmValue xv = new XQuery(query, ctx).context(val).value();
+  public static String string(final String query, final XdmValue value, final Context context) {
+    final XdmValue xv = new XQuery(query, context).context(value).value();
     return xv.size() == 0 ? "" : xv.getString();
   }
 
