@@ -9,27 +9,25 @@ import java.util.regex.*;
 
 import org.basex.build.*;
 import org.basex.core.*;
-import org.basex.core.Context;
 import org.basex.core.cmd.*;
 import org.basex.data.*;
 import org.basex.io.*;
 import org.basex.io.out.*;
 import org.basex.io.serial.*;
 import org.basex.query.*;
-import org.basex.query.expr.*;
-import org.basex.query.func.*;
-import org.basex.query.iter.*;
-import org.basex.query.util.*;
+import org.basex.query.func.fn.*;
 import org.basex.query.value.*;
 import org.basex.query.value.item.*;
+import org.basex.query.value.node.*;
 import org.basex.query.value.seq.*;
 import org.basex.util.*;
 import org.basex.util.list.*;
+import org.basex.util.options.Options.*;
 
 /**
  * XQuery Test Suite wrapper.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public abstract class W3CTS extends Main {
@@ -88,11 +86,11 @@ public abstract class W3CTS extends Main {
   private String group;
 
   /** Cached source files. */
-  private final HashMap<String, String> srcs = new HashMap<String, String>();
+  private final HashMap<String, String> srcs = new HashMap<>();
   /** Cached module files. */
-  private final HashMap<String, String> mods = new HashMap<String, String>();
+  private final HashMap<String, String> mods = new HashMap<>();
   /** Cached collections. */
-  private final HashMap<String, String[]> colls = new HashMap<String, String[]>();
+  private final HashMap<String, String[]> colls = new HashMap<>();
 
   /** OK log. */
   private final StringBuilder logOK = new StringBuilder();
@@ -124,7 +122,12 @@ public abstract class W3CTS extends Main {
     input = nm + "Catalog" + IO.XMLSUFFIX;
     testid = nm.substring(0, 4);
     pathlog = testid.toLowerCase(Locale.ENGLISH) + ".log";
-    context.globalopts.set(GlobalOptions.DBPATH, sandbox().path() + "/data");
+    context.soptions.set(StaticOptions.DBPATH, sandbox().path() + "/data");
+
+    final SerializerOptions sopts = new SerializerOptions();
+    sopts.set(SerializerOptions.METHOD, SerialMethod.XML);
+    sopts.set(SerializerOptions.INDENT, YesNo.NO);
+    context.options.set(MainOptions.SERIALIZER, sopts);
   }
 
   /**
@@ -151,35 +154,29 @@ public abstract class W3CTS extends Main {
     final Performance perf = new Performance();
     context.options.set(MainOptions.CHOP, false);
 
-    data = MemBuilder.build(new IOFile(path + input), context);
+    data = MemBuilder.build(new IOFile(path + input));
 
-    final Nodes root = new Nodes(0, data);
-    Util.outln(NL + Util.className(this) + " Test Suite " +
-        text("/*:test-suite/@version", root));
+    final DBNode root = new DBNode(data, 0);
+    Util.outln(NL + Util.className(this) + " Test Suite " + text("/*:test-suite/@version", root));
 
     Util.outln("Caching Sources...");
-    for(final int s : nodes("//*:source", root).pres) {
-      final Nodes srcRoot = new Nodes(s, data);
-      final String val = (path + text("@FileName", srcRoot)).replace('\\', '/');
-      srcs.put(text("@ID", srcRoot), val);
+    for(final Item node : nodes("//*:source", root)) {
+      final String val = (path + text("@FileName", node)).replace('\\', '/');
+      srcs.put(text("@ID", node), val);
     }
 
     Util.outln("Caching Modules...");
-    for(final int s : nodes("//*:module", root).pres) {
-      final Nodes srcRoot = new Nodes(s, data);
-      final String val = (path + text("@FileName", srcRoot)).replace('\\', '/');
-      mods.put(text("@ID", srcRoot), val);
+    for(final Item node : nodes("//*:module", root)) {
+      final String val = (path + text("@FileName", node)).replace('\\', '/');
+      mods.put(text("@ID", node), val);
     }
 
     Util.outln("Caching Collections...");
-    for(final int c : nodes("//*:collection", root).pres) {
-      final Nodes nodes = new Nodes(c, data);
-      final String cname = text("@ID", nodes);
-
+    for(final Item node : nodes("//*:collection", root)) {
+      final String cname = text("@ID", node);
       final StringList dl = new StringList();
-      final Nodes doc = nodes("*:input-document", nodes);
-      for(int d = 0; d < doc.size(); ++d) {
-        dl.add(sources + string(data.atom(doc.pres[d])) + IO.XMLSUFFIX);
+      for(final Item doc : nodes("*:input-document", node)) {
+        dl.add(sources + string(doc.string(null)) + IO.XMLSUFFIX);
       }
       colls.put(cname, dl.toArray());
     }
@@ -191,46 +188,47 @@ public abstract class W3CTS extends Main {
     }
 
     if(verbose) Util.outln();
-    final Nodes nodes = minimum ?
+    final Value nodes = minimum ?
       nodes("//*:test-group[starts-with(@name, 'Minim')]//*:test-case", root) :
       group != null ? nodes("//*:test-group[@name eq '" + group +
           "']//*:test-case", root) : nodes("//*:test-case", root);
 
     long total = nodes.size();
     Util.out("Parsing " + total + " Queries");
-    for(int t = 0; t < total; ++t) {
-      if(!parse(new Nodes(nodes.pres[t], data))) break;
-      if(!verbose && t % 500 == 0) Util.out(".");
+    int t = 0;
+    for(final Item node : nodes) {
+      if(!parse(node)) break;
+      if(!verbose && t++ % 500 == 0) Util.out(".");
     }
     Util.outln();
     total = ok + ok2 + err + err2;
 
     final String time = perf.getTime();
     Util.outln("Writing log file..." + NL);
-    PrintOutput po = new PrintOutput(path + pathlog);
-    po.println("TEST RESULTS ________________________________________________");
-    po.println(NL + "Total #Queries: " + total);
-    po.println("Correct / Empty Results: " + ok + " / " + ok2);
-    po.print("Conformance (w/Empty Results): ");
-    po.println(pc(ok, total) + " / " + pc(ok + ok2, total));
-    po.println("Wrong Results / Errors: " + err + " / " + err2 + NL);
-    po.println("WRONG _______________________________________________________");
-    po.print(NL + logErr);
-    po.println("WRONG (ERRORS) ______________________________________________");
-    po.print(NL + logErr2);
-    po.println("CORRECT? (EMPTY) ____________________________________________");
-    po.print(NL + logOK2);
-    po.println("CORRECT _____________________________________________________");
-    po.print(NL + logOK);
-    po.println("_____________________________________________________________");
-    po.close();
+    try(final PrintOutput po = new PrintOutput(path + pathlog)) {
+      po.println("TEST RESULTS ________________________________________________");
+      po.println(NL + "Total #Queries: " + total);
+      po.println("Correct / Empty Results: " + ok + " / " + ok2);
+      po.print("Conformance (w/Empty Results): ");
+      po.println(pc(ok, total) + " / " + pc(ok + ok2, total));
+      po.println("Wrong Results / Errors: " + err + " / " + err2 + NL);
+      po.println("WRONG _______________________________________________________");
+      po.print(NL + logErr);
+      po.println("WRONG (ERRORS) ______________________________________________");
+      po.print(NL + logErr2);
+      po.println("CORRECT? (EMPTY) ____________________________________________");
+      po.print(NL + logOK2);
+      po.println("CORRECT _____________________________________________________");
+      po.print(NL + logOK);
+      po.println("_____________________________________________________________");
+    }
 
     if(reporting) {
-      po = new PrintOutput(report + Prop.NAME + IO.XMLSUFFIX);
-      print(po, report + Prop.NAME + "Pre" + IO.XMLSUFFIX);
-      po.print(logReport.toString());
-      print(po, report + Prop.NAME + "Pos" + IO.XMLSUFFIX);
-      po.close();
+      try(final PrintOutput po = new PrintOutput(report + Prop.NAME + IO.XMLSUFFIX)) {
+        print(po, report + Prop.NAME + "Pre" + IO.XMLSUFFIX);
+        po.print(logReport.toString());
+        print(po, report + Prop.NAME + "Pos" + IO.XMLSUFFIX);
+      }
     }
 
     Util.outln("Total #Queries: " + total);
@@ -260,7 +258,7 @@ public abstract class W3CTS extends Main {
    * @throws IOException I/O exception
    * @return true if the query, specified by {@link #single}, was evaluated
    */
-  private boolean parse(final Nodes root) throws QueryException, IOException {
+  private boolean parse(final Item root) throws QueryException, IOException {
     final String pth = text("@FilePath", root);
     final String outname = text("@name", root);
     if(single != null && !outname.startsWith(single)) return true;
@@ -271,216 +269,207 @@ public abstract class W3CTS extends Main {
     boolean inspect = false;
     boolean correct = true;
 
-    final Nodes nodes = states(root);
-    for(int n = 0; n < nodes.size(); ++n) {
-      final Nodes state = new Nodes(nodes.pres[n], nodes.data);
-
+    final Value states = states(root);
+    final long ss = states.size();
+    for(int s = 0; s < ss; s++) {
+      final Item state = states.itemAt(s);
       final String inname = text("*:query/@name", state);
       final IOFile query = new IOFile(queries + pth + inname + IO.XQSUFFIX);
       context.options.set(MainOptions.QUERYPATH, query.path());
       final String in = read(query);
       String er = null;
-      ValueBuilder iter = null;
+      Value value = null;
 
-      final Nodes cont = nodes("*:contextItem", state);
-      Nodes curr = null;
-      if(cont.size() != 0) {
-        final String p = srcs.get(string(data.atom(cont.pres[0])));
-        final Data d = MemBuilder.build(IO.get(p), context);
-        curr = new Nodes(d.resources.docs().toArray(), d);
-        curr.root = true;
+      final Value cont = nodes("*:contextItem", state);
+      Value curr = null;
+      if(!cont.isEmpty()) {
+        final String p = srcs.get(string(cont.itemAt(0).string(null)));
+        final Data d = MemBuilder.build(IO.get(p));
+        curr = DBNodeSeq.get(d.resources.docs(), d, true, true);
       }
 
       context.options.set(MainOptions.QUERYINFO, compile);
-      final QueryProcessor xq = new QueryProcessor(in, context).context(curr);
-      context.options.set(MainOptions.QUERYINFO, false);
+      try(final QueryProcessor qp = new QueryProcessor(in, context)) {
+        if(curr != null) qp.context(curr);
+        context.options.set(MainOptions.QUERYINFO, false);
 
-      final ArrayOutput ao = new ArrayOutput();
-      final TokenBuilder files = new TokenBuilder();
+        final ArrayOutput ao = new ArrayOutput();
+        final TokenBuilder files = new TokenBuilder();
 
-      try {
-        files.add(file(nodes("*:input-file", state),
-            nodes("*:input-file/@variable", state), xq, n == 0));
-        files.add(file(nodes("*:defaultCollection", state), null, xq, n == 0));
-        var(nodes("*:input-URI", state), nodes("*:input-URI/@variable", state), xq);
-        eval(nodes("*:input-query/@name", state),
-            nodes("*:input-query/@variable", state), pth, xq);
+        try {
+          files.add(file(nodes("*:input-file", state),
+              nodes("*:input-file/@variable", state), qp, s == 0));
+          files.add(file(nodes("*:defaultCollection", state), null, qp, s == 0));
+          var(nodes("*:input-URI", state), nodes("*:input-URI/@variable", state), qp);
+          eval(nodes("*:input-query/@name", state), nodes("*:input-query/@variable", state), pth, qp);
 
-        parse(xq, state);
+          parse(qp, state);
 
-        for(final int p : nodes("*:module", root).pres) {
-          final String uri = text("@namespace", new Nodes(p, data));
-          final String file = IO.get(mods.get(string(data.atom(p))) + IO.XQSUFFIX).path();
-          xq.module(uri, file);
-        }
-
-        // evaluate query
-        iter = xq.value().cache();
-
-        // serialize query
-        final SerializerOptions sp = new SerializerOptions();
-        sp.set(SerializerOptions.INDENT, NO);
-        final Serializer ser = Serializer.get(ao, sp);
-        for(Item it; (it = iter.next()) != null;) ser.serialize(it);
-        ser.close();
-
-      } catch(final Exception ex) {
-        if(!(ex instanceof QueryException || ex instanceof IOException)) {
-          Util.errln("\n*** " + outname + " ***");
-          Util.errln(in + '\n');
-          Util.stack(ex);
-        }
-        er = ex.getMessage();
-        if(er.startsWith(STOPPED_AT)) er = er.substring(er.indexOf('\n') + 1);
-        if(!er.isEmpty() && er.charAt(0) == '[')
-          er = er.replaceAll("\\[(.*?)\\] (.*)", "$1 $2");
-        // unexpected error - dump stack trace
-      }
-
-      // print compilation steps
-      if(compile) {
-        Util.errln("---------------------------------------------------------");
-        Util.err(xq.info());
-        Util.errln(in);
-      }
-
-      final Nodes expOut = nodes("*:output-file/text()", state);
-      final TokenList result = new TokenList();
-      for(int o = 0; o < expOut.size(); ++o) {
-        final String resFile = string(data.atom(expOut.pres[o]));
-        final IOFile exp = new IOFile(expected + pth + resFile);
-        result.add(read(exp).replaceAll("\r\n|\r|\n", Prop.NL));
-      }
-
-      final Nodes cmpFiles = nodes("*:output-file/@compare", state);
-      boolean xml = false;
-      boolean frag = false;
-      boolean ignore = false;
-      for(int o = 0; o < cmpFiles.size(); ++o) {
-        final byte[] type = data.atom(cmpFiles.pres[o]);
-        xml |= eq(type, XML);
-        frag |= eq(type, FRAGMENT);
-        ignore |= eq(type, IGNORE);
-      }
-
-      String expError = text("*:expected-error/text()", state);
-
-      final StringBuilder log = new StringBuilder(pth + inname + IO.XQSUFFIX);
-      if(!files.isEmpty()) log.append(" [").append(files).append(']');
-      log.append(NL);
-
-      /** Remove comments. */
-      log.append(norm(in)).append(NL);
-      final String logStr = log.toString();
-      // skip queries with variable results
-      final boolean print = currTime || !logStr.contains("current-");
-
-      boolean correctError = false;
-      if(er != null && (expOut.size() == 0 || !expError.isEmpty())) {
-        expError = error(pth + outname, expError);
-        final String code = er.substring(0, Math.min(8, er.length()));
-        for(final String e : SLASH.split(expError)) {
-          if(code.equals(e)) {
-            correctError = true;
-            break;
+          for(final Item node : nodes("*:module", root)) {
+            final String uri = text("@namespace", node);
+            final String file = IO.get(mods.get(string(node.string(null))) + IO.XQSUFFIX).path();
+            qp.module(uri, file);
           }
+
+          // evaluate query
+          value = qp.value();
+
+          // serialize query
+          final SerializerOptions options = context.options.get(MainOptions.SERIALIZER);
+          try(final Serializer ser = Serializer.get(ao, options)) {
+            for(final Item it : value) ser.serialize(it);
+          }
+
+        } catch(final Exception ex) {
+          if(!(ex instanceof QueryException || ex instanceof IOException)) {
+            Util.errln("\n*** " + outname + " ***");
+            Util.errln(in + '\n');
+            Util.stack(ex);
+          }
+          er = ex.getMessage();
+          if(er.startsWith(STOPPED_AT)) er = er.substring(er.indexOf('\n') + 1);
+          if(!er.isEmpty() && er.charAt(0) == '[')
+            er = er.replaceAll("\\[(.*?)\\] (.*)", "$1 $2");
+          // unexpected error - dump stack trace
         }
-      }
 
-      if(correctError) {
-        if(print) {
-          logOK.append(logStr);
-          logOK.append("[Right] ");
-          logOK.append(norm(er));
-          logOK.append(NL);
-          logOK.append(NL);
-          addLog(pth, outname + ".log", er);
+        // print compilation steps
+        if(compile) {
+          Util.errln("---------------------------------------------------------");
+          Util.err(qp.info());
+          Util.errln(in);
         }
-        ++ok;
-      } else if(er == null) {
-        int s = -1;
-        final int rs = result.size();
 
-        while(!ignore && ++s < rs) {
-          inspect |= s < cmpFiles.pres.length && eq(data.atom(cmpFiles.pres[s]), INSPECT);
+        final Value expOut = nodes("*:output-file/text()", state);
+        final TokenList result = new TokenList();
+        for(final Item item : expOut) {
+          final String resFile = string(item.string(null));
+          final IOFile exp = new IOFile(expected + pth + resFile);
+          result.add(read(exp).replaceAll("\r\n|\r|\n", Prop.NL));
+        }
 
-          final String expect = string(result.get(s));
-          final String actual = ao.toString();
-          if(expect.equals(actual)) break;
+        final Value cmpFiles = nodes("*:output-file/@compare", state);
+        boolean xml = false, frag = false, ignore = false;
+        for(final Item item : cmpFiles) {
+          final byte[] type = item.string(null);
+          xml |= eq(type, XML);
+          frag |= eq(type, FRAGMENT);
+          ignore |= eq(type, IGNORE);
+        }
 
-          if(xml || frag) {
-            iter.reset();
-            try {
-              final ValueIter vb = toIter(expect.replaceAll(
-                  "^<\\?xml.*?\\?>", "").trim(), frag);
-              if(Compare.deep(iter, vb, (InputInfo) null)) break;
-              vb.reset();
-              final ValueIter ia = toIter(actual, frag);
-              if(Compare.deep(ia, vb, (InputInfo) null)) break;
-            } catch(final Throwable ex) {
-              Util.errln('\n' + outname + ':');
-              Util.stack(ex);
+        String expError = text("*:expected-error/text()", state);
+
+        final StringBuilder log = new StringBuilder(pth + inname + IO.XQSUFFIX);
+        if(!files.isEmpty()) log.append(" [").append(files).append(']');
+        log.append(NL);
+
+        // Remove comments.
+        log.append(norm(in)).append(NL);
+        final String logStr = log.toString();
+        // skip queries with variable results
+        final boolean print = currTime || !logStr.contains("current-");
+
+        boolean correctError = false;
+        if(er != null && (expOut.size() == 0 || !expError.isEmpty())) {
+          expError = error(pth + outname, expError);
+          final String code = er.substring(0, Math.min(8, er.length()));
+          for(final String e : SLASH.split(expError)) {
+            if(code.equals(e)) {
+              correctError = true;
+              break;
             }
           }
         }
-        if((rs > 0 || !expError.isEmpty()) && s == rs && !inspect) {
-          if(print) {
-            if(expOut.size() == 0) result.add(error(pth + outname, expError));
-            logErr.append(logStr);
-            logErr.append('[' + testid + " ] ");
-            logErr.append(norm(string(result.get(0))));
-            logErr.append(NL);
-            logErr.append("[Wrong] ");
-            logErr.append(norm(ao.toString()));
-            logErr.append(NL);
-            logErr.append(NL);
-            addLog(pth, outname + (xml ? IO.XMLSUFFIX : ".txt"), ao.toString());
-          }
-          correct = false;
-          ++err;
-        } else {
+
+        if(correctError) {
           if(print) {
             logOK.append(logStr);
             logOK.append("[Right] ");
-            logOK.append(norm(ao.toString()));
+            logOK.append(norm(er));
             logOK.append(NL);
             logOK.append(NL);
-            addLog(pth, outname + (xml ? IO.XMLSUFFIX : ".txt"), ao.toString());
+            addLog(pth, outname + ".log", er);
           }
           ++ok;
-        }
-      } else {
-        if(expOut.size() == 0 || !expError.isEmpty()) {
-          if(print) {
-            logOK2.append(logStr);
-            logOK2.append('[' + testid + " ] ");
-            logOK2.append(norm(expError));
-            logOK2.append(NL);
-            logOK2.append("[Rght?] ");
-            logOK2.append(norm(er));
-            logOK2.append(NL);
-            logOK2.append(NL);
-            addLog(pth, outname + ".log", er);
+        } else if(er == null) {
+          int r = -1;
+          final int rs = result.size();
+
+          while(!ignore && ++r < rs) {
+            inspect |= r < cmpFiles.size() && eq(cmpFiles.itemAt(r).string(null), INSPECT);
+
+            final String expect = string(result.get(r));
+            final String actual = ao.toString();
+            if(expect.equals(actual)) break;
+
+            if(xml || frag) {
+              try {
+                final Value v = toValue(expect.replaceAll("^<\\?xml.*?\\?>", "").trim(), frag);
+                if(new Compare().equal(value.iter(), v.iter())) break;
+                if(new Compare().equal(toValue(actual, frag).iter(), v.iter())) break;
+              } catch(final Throwable ex) {
+                Util.errln('\n' + outname + ':');
+                Util.stack(ex);
+              }
+            }
+          }
+          if((rs > 0 || !expError.isEmpty()) && r == rs && !inspect) {
+            if(print) {
+              if(expOut.size() == 0) result.add(error(pth + outname, expError));
+              logErr.append(logStr);
+              logErr.append('[' + testid + " ] ");
+              logErr.append(norm(string(result.get(0))));
+              logErr.append(NL);
+              logErr.append("[Wrong] ");
+              logErr.append(norm(ao.toString()));
+              logErr.append(NL);
+              logErr.append(NL);
+              addLog(pth, outname + (xml ? IO.XMLSUFFIX : ".txt"), ao.toString());
+            }
+            correct = false;
+            ++err;
+          } else {
+            if(print) {
+              logOK.append(logStr);
+              logOK.append("[Right] ");
+              logOK.append(norm(ao.toString()));
+              logOK.append(NL);
+              logOK.append(NL);
+              addLog(pth, outname + (xml ? IO.XMLSUFFIX : ".txt"), ao.toString());
+            }
+            ++ok;
           }
-          ++ok2;
         } else {
-          if(print) {
-            logErr2.append(logStr);
-            logErr2.append('[' + testid + " ] ");
-            logErr2.append(norm(string(result.get(0))));
-            logErr2.append(NL);
-            logErr2.append("[Wrong] ");
-            logErr2.append(norm(er));
-            logErr2.append(NL);
-            logErr2.append(NL);
-            addLog(pth, outname + ".log", er);
+          if(expOut.size() == 0 || !expError.isEmpty()) {
+            if(print) {
+              logOK2.append(logStr);
+              logOK2.append('[' + testid + " ] ");
+              logOK2.append(norm(expError));
+              logOK2.append(NL);
+              logOK2.append("[Rght?] ");
+              logOK2.append(norm(er));
+              logOK2.append(NL);
+              logOK2.append(NL);
+              addLog(pth, outname + ".log", er);
+            }
+            ++ok2;
+          } else {
+            if(print) {
+              logErr2.append(logStr);
+              logErr2.append('[' + testid + " ] ");
+              logErr2.append(norm(string(result.get(0))));
+              logErr2.append(NL);
+              logErr2.append("[Wrong] ");
+              logErr2.append(norm(er));
+              logErr2.append(NL);
+              logErr2.append(NL);
+              addLog(pth, outname + ".log", er);
+            }
+            correct = false;
+            ++err2;
           }
-          correct = false;
-          ++err2;
         }
       }
-      if(curr != null) Close.close(curr.data, context);
-      xq.close();
     }
 
     if(reporting) {
@@ -507,22 +496,20 @@ public abstract class W3CTS extends Main {
   }
 
   /**
-   * Creates an item iterator for the given XML fragment.
+   * Creates the given XML fragments as XQuery value.
    * @param xml fragment
    * @param frag fragment flag
    * @return iterator
    */
-  private ValueIter toIter(final String xml, final boolean frag) {
+  private Value toValue(final String xml, final boolean frag) {
     try {
       final String str = frag ? "<X>" + xml + "</X>" : xml;
-      final Data d = MemBuilder.build(IO.get(str), context);
+      final Data d = MemBuilder.build(IO.get(str));
       final IntList il = new IntList();
-      for(int p = frag ? 2 : 0; p < d.meta.size; p += d.size(p, d.kind(p))) {
-        il.add(p);
-      }
-      return DBNodeSeq.get(il, d, false, false).iter();
+      for(int p = frag ? 2 : 0; p < d.meta.size; p += d.size(p, d.kind(p))) il.add(p);
+      return DBNodeSeq.get(il, d, false, false);
     } catch(final IOException ex) {
-      return Str.get(Long.toString(System.nanoTime())).iter();
+      return Str.get(Long.toString(System.nanoTime()));
     }
   }
 
@@ -537,63 +524,58 @@ public abstract class W3CTS extends Main {
 
   /**
    * Initializes the input files, specified by the context nodes.
-   * @param nod variables
-   * @param var documents
+   * @param nodes nodes
+   * @param vars variables
    * @param qp query processor
    * @param first call
    * @return string with input files
    * @throws QueryException query exception
    * @throws BaseXException database exception
    */
-  private byte[] file(final Nodes nod, final Nodes var, final QueryProcessor qp,
+  private byte[] file(final Value nodes, final Value vars, final QueryProcessor qp,
       final boolean first) throws QueryException, BaseXException {
 
     final TokenBuilder tb = new TokenBuilder();
-    for(int c = 0; c < nod.size(); ++c) {
-      final byte[] nm = data.atom(nod.pres[c]);
+    final long ns = nodes.size();
+    for(int n = 0; n < ns; ++n) {
+      final byte[] nm = nodes.itemAt(n).string(null);
       String src = srcs.get(string(nm));
       if(!tb.isEmpty()) tb.add(", ");
       tb.add(nm);
 
-      Expr expr = null;
-      if(src == null) {
-        // assign collection
-        expr = coll(nm, qp);
-      } else {
-        // assign document
-        final String dbname = new IOFile(src).dbname();
-        Function def = Function.DOC;
-        // updates: drop updated document or open updated database
-        if(updating()) {
-          if(first) {
-            new DropDB(dbname).execute(context);
-          } else {
-            def = Function._DB_OPEN;
-            src = dbname;
-          }
+      // assign document
+      final String dbname = new IOFile(src).dbname();
+      // updates: drop updated document or open updated database
+      if(updating()) {
+        if(first) {
+          new DropDB(dbname).execute(context);
+        } else {
+          src = dbname;
         }
-        expr = def.get(qp.sc, Str.get(src));
       }
-      if(var != null) qp.bind(string(data.atom(var.pres[c])), expr);
+
+      final Value value = qp.qc.resources.doc(new QueryInput(src), qp.sc.baseIO(), null);
+      qp.bind(string(vars.itemAt(n).string(null)), value);
     }
     return tb.finish();
   }
 
   /**
    * Assigns the nodes to the specified variables.
-   * @param nod nodes
-   * @param var variables
+   * @param nodes nodes
+   * @param vars variables
    * @param qp query processor
    * @throws QueryException query exception
    */
-  private void var(final Nodes nod, final Nodes var, final QueryProcessor qp)
+  private void var(final Value nodes, final Value vars, final QueryProcessor qp)
       throws QueryException {
 
-    for(int c = 0; c < nod.size(); ++c) {
-      final byte[] nm = data.atom(nod.pres[c]);
-      final String src = srcs.get(string(nm));
+    final long ns = nodes.size();
+    for(int n = 0; n < ns; ++n) {
+      final String nm = string(nodes.itemAt(n).string(null));
+      final String src = srcs.get(nm);
       final Item it = src == null ? coll(nm, qp) : Str.get(src);
-      qp.bind(string(data.atom(var.pres[c])), it);
+      qp.bind(string(vars.itemAt(n).string(null)), it);
     }
   }
 
@@ -604,48 +586,47 @@ public abstract class W3CTS extends Main {
    * @return expression
    * @throws QueryException query exception
    */
-  private Uri coll(final byte[] name, final QueryProcessor qp) throws QueryException {
-    qp.ctx.resource.addCollection(string(name), colls.get(string(name)), qp.sc.baseIO());
+  private Uri coll(final String name, final QueryProcessor qp) throws QueryException {
+    qp.qc.resources.addCollection(name, colls.get(name), qp.sc.baseIO());
     return Uri.uri(name);
   }
 
   /**
    * Evaluates the the input files and assigns the result to the specified variables.
-   * @param nod variables
-   * @param var documents
+   * @param nodes nodes
+   * @param vars variables
    * @param pth file path
    * @param qp query processor
    * @throws QueryException query exception
    */
-  private void eval(final Nodes nod, final Nodes var, final String pth,
-      final QueryProcessor qp) throws QueryException {
+  private void eval(final Value nodes, final Value vars, final String pth, final QueryProcessor qp)
+      throws QueryException {
 
-    for(int c = 0; c < nod.size(); ++c) {
-      final String file = pth + string(data.atom(nod.pres[c])) + IO.XQSUFFIX;
+    final long ns = nodes.size();
+    for(int n = 0; n < ns; ++n) {
+      final String file = pth + string(nodes.itemAt(n).string(null)) + IO.XQSUFFIX;
       final String in = read(new IOFile(queries + file));
-      final QueryProcessor xq = new QueryProcessor(in, context);
-      final Value val = xq.value();
-      qp.bind(string(data.atom(var.pres[c])), val);
-      xq.close();
+      try(final QueryProcessor xq = new QueryProcessor(in, context)) {
+        qp.bind(string(vars.itemAt(n).string(null)), xq.value());
+      }
     }
   }
 
   /**
    * Adds a log file.
    * @param pth file path
-   * @param nm file name
+   * @param name file name
    * @param msg message
    * @throws IOException I/O exception
    */
-  private void addLog(final String pth, final String nm, final String msg) throws IOException {
-
+  private void addLog(final String pth, final String name, final String msg) throws IOException {
     if(reporting) {
       final File file = new File(results + pth);
       if(!file.exists()) file.mkdirs();
-      final BufferedWriter bw = new BufferedWriter(new OutputStreamWriter(
-          new FileOutputStream(results + pth + nm), UTF8));
-      bw.write(msg);
-      bw.close();
+      try(final BufferedWriter bw = new BufferedWriter(new OutputStreamWriter(
+          new FileOutputStream(results + pth + name), Strings.UTF8))) {
+        bw.write(msg);
+      }
     }
   }
 
@@ -668,12 +649,13 @@ public abstract class W3CTS extends Main {
    * @return attribute value
    * @throws QueryException query exception
    */
-  protected String text(final String qu, final Nodes root) throws QueryException {
-    final Nodes n = nodes(qu, root);
+  protected String text(final String qu, final Value root) throws QueryException {
     final TokenBuilder tb = new TokenBuilder();
-    for(int i = 0; i < n.size(); ++i) {
-      if(i != 0) tb.add('/');
-      tb.add(data.atom(n.pres[i]));
+    final Value nodes = nodes(qu, root);
+    final long rs = nodes.size();
+    for(int r = 0; r < rs; ++r) {
+      if(r != 0) tb.add('/');
+      tb.add(nodes.itemAt(r).string(null));
     }
     return tb.toString();
   }
@@ -685,8 +667,10 @@ public abstract class W3CTS extends Main {
    * @return attribute value
    * @throws QueryException query exception
    */
-  protected Nodes nodes(final String qu, final Nodes root) throws QueryException {
-    return new QueryProcessor(qu, context).context(root).queryNodes();
+  protected Value nodes(final String qu, final Value root) throws QueryException {
+    try(final QueryProcessor qp = new QueryProcessor(qu, context)) {
+      return qp.context(root).value();
+    }
   }
 
   /**
@@ -696,9 +680,9 @@ public abstract class W3CTS extends Main {
    * @throws IOException I/O exception
    */
   private static void print(final PrintOutput po, final String f) throws IOException {
-    final BufferedReader br = new BufferedReader(new FileReader(f));
-    for(String line; (line = br.readLine()) != null;) po.println(line);
-    br.close();
+    try(final BufferedReader br = new BufferedReader(new FileReader(f))) {
+      for(String line; (line = br.readLine()) != null;) po.println(line);
+    }
   }
 
   /**
@@ -717,11 +701,11 @@ public abstract class W3CTS extends Main {
 
   /**
    * Initializes the test.
-   * @param root root nodes reference
+   * @param root root node reference
    * @throws QueryException query exception
    */
   @SuppressWarnings("unused")
-  protected void init(final Nodes root) throws QueryException { }
+  protected void init(final DBNode root) throws QueryException { }
 
   /**
    * Performs test specific parsings.
@@ -730,7 +714,7 @@ public abstract class W3CTS extends Main {
    * @throws QueryException query exception
    */
   @SuppressWarnings("unused")
-  protected void parse(final QueryProcessor qp, final Nodes root) throws QueryException { }
+  protected void parse(final QueryProcessor qp, final Item root) throws QueryException { }
 
   /**
    * Returns all query states.
@@ -739,7 +723,7 @@ public abstract class W3CTS extends Main {
    * @throws QueryException query exception
    */
   @SuppressWarnings("unused")
-  protected Nodes states(final Nodes root) throws QueryException {
+  protected Value states(final Item root) throws QueryException {
     return root;
   }
 
