@@ -2,30 +2,31 @@ package org.basex.tests.w3c;
 
 import java.util.*;
 
-import org.basex.data.*;
 import org.basex.io.*;
 import org.basex.query.*;
-import org.basex.query.ft.*;
+import org.basex.query.expr.ft.*;
+import org.basex.query.value.item.*;
+import org.basex.query.value.node.*;
 import org.basex.util.*;
 import org.basex.util.ft.*;
 
 /**
  * XQuery Full Text Test Suite wrapper.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class XQFTTS extends W3CTS {
   /** Cached stop word files. */
-  private final HashMap<String, IO> stop = new HashMap<String, IO>();
+  private final HashMap<String, IO> stop = new HashMap<>();
   /** Cached stop word files. */
-  private final HashMap<String, IO> stop2 = new HashMap<String, IO>();
+  private final HashMap<String, IO> stop2 = new HashMap<>();
   /** Cached stemming dictionaries. */
-  private final HashMap<String, IO> stem = new HashMap<String, IO>();
+  private final HashMap<String, IO> stem = new HashMap<>();
   /** Cached thesaurus. */
-  private final HashMap<String, IO> thes = new HashMap<String, IO>();
+  private final HashMap<String, IO> thes = new HashMap<>();
   /** Cached thesaurus. */
-  private final HashMap<String, IO> thes2 = new HashMap<String, IO>();
+  private final HashMap<String, IO> thes2 = new HashMap<>();
 
   /**
    * Main method of the test class.
@@ -45,34 +46,31 @@ public final class XQFTTS extends W3CTS {
   }
 
   @Override
-  protected void init(final Nodes root) throws QueryException {
+  protected void init(final DBNode root) throws QueryException {
     Util.outln("Caching Full-text Structures...");
-    for(final int s : nodes("//*:stopwords", root).pres) {
-      final Nodes srcRoot = new Nodes(s, data);
-      final String val = (path + text("@FileName", srcRoot)).replace('\\', '/');
-      stop.put(text("@uri", srcRoot), IO.get(val));
-      stop2.put(text("@ID", srcRoot), IO.get(val));
+    for(final Item node : nodes("//*:stopwords", root)) {
+      final String val = (path + text("@FileName", node)).replace('\\', '/');
+      stop.put(text("@uri", node), IO.get(val));
+      stop2.put(text("@ID", node), IO.get(val));
     }
-    for(final int s : nodes("//*:stemming-dictionary", root).pres) {
-      final Nodes srcRoot = new Nodes(s, data);
-      final String val = (path + text("@FileName", srcRoot)).replace('\\', '/');
-      stem.put(text("@ID", srcRoot), IO.get(val));
+    for(final Item node : nodes("//*:stemming-dictionary", root)) {
+      final String val = (path + text("@FileName", node)).replace('\\', '/');
+      stem.put(text("@ID", node), IO.get(val));
     }
-    for(final int s : nodes("//*:thesaurus", root).pres) {
-      final Nodes srcRoot = new Nodes(s, data);
-      final String val = (path + text("@FileName", srcRoot)).replace('\\', '/');
-      thes.put(text("@uri", srcRoot), IO.get(val));
-      thes2.put(text("@ID", srcRoot), IO.get(val));
+    for(final Item node : nodes("//*:thesaurus", root)) {
+      final String val = (path + text("@FileName", node)).replace('\\', '/');
+      thes.put(text("@uri", node), IO.get(val));
+      thes2.put(text("@ID", node), IO.get(val));
     }
   }
 
   @Override
-  protected void parse(final QueryProcessor qp, final Nodes root) throws QueryException {
-    final QueryContext ctx = qp.ctx;
-    ctx.stop = stop;
-    ctx.thes = thes;
+  protected void parse(final QueryProcessor qp, final Item root) throws QueryException {
+    final QueryContext qc = qp.qc;
+    qc.stop = stop;
+    qc.thes = thes;
 
-    final FTOpt opt = ctx.ftOpt();
+    final FTOpt opt = qc.ftOpt();
     for(final String s : aux("stopwords", root)) {
       final IO fn = stop2.get(s);
       if(fn != null) {
@@ -105,7 +103,7 @@ public final class XQFTTS extends W3CTS {
    * @return attribute value
    * @throws QueryException query exception
    */
-  private String[] aux(final String role, final Nodes root) throws QueryException {
-    return text("*:aux-URI[@role = '" + role + "']", root).split("/");
+  private String[] aux(final String role, final Item root) throws QueryException {
+    return Strings.split(text("*:aux-URI[@role = '" + role + "']", root), '/');
   }
 }
