@@ -1,15 +1,15 @@
 package org.basex.performance;
 
+import org.basex.*;
 import org.basex.core.*;
 import org.basex.core.cmd.*;
 import org.basex.io.*;
-import org.basex.*;
 import org.junit.Test;
 
 /**
  * This class replaces document nodes in a database.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Christian Gruen
  */
 public final class DocReplaceTest extends SandboxTest {
@@ -25,16 +25,18 @@ public final class DocReplaceTest extends SandboxTest {
     context.options.set(MainOptions.TEXTINDEX, false);
     context.options.set(MainOptions.ATTRINDEX, false);
     context.options.set(MainOptions.AUTOFLUSH, false);
+    context.options.set(MainOptions.INTPARSE, true);
 
     // create test database
     new CreateDB(NAME).execute(context);
 
-    // replace nodes
+    // add documents
     for(int i = 0; i < NQUERIES; i++) {
       new Add(i + IO.XMLSUFFIX, "<a/>").execute(context);
     }
+    new Flush().execute(context);
 
-    // replace nodes with same content
+    // replace documents with same content
     for(int i = 0; i < NQUERIES; i++) {
       new Replace(i + IO.XMLSUFFIX, "<a/>").execute(context);
     }
