@@ -1,12 +1,12 @@
 package org.basex.qt3ts.op;
 
-import org.basex.tests.bxapi.XQuery;
+import org.basex.tests.bxapi.*;
 import org.basex.tests.qt3ts.*;
 
 /**
  * Tests for the gYear-equal() function.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Leo Woerteler
  */
 @SuppressWarnings("all")
@@ -538,7 +538,7 @@ public class OpGYearEqual extends QT3TestSet {
   @org.junit.Test
   public void opGYearEqual1() {
     final XQuery query = new XQuery(
-      "(xs:gYear(\"2005-14:00\") eq xs:gYear(\"2005+12:00\"))",
+      "(xs:gYear(\"2005-15:00\") eq xs:gYear(\"2005+12:00\"))",
       ctx);
     try {
       result = new QT3Result(query.value());
