@@ -1,12 +1,12 @@
 package org.basex.qt3ts.prod;
 
-import org.basex.tests.bxapi.XQuery;
+import org.basex.tests.bxapi.*;
 import org.basex.tests.qt3ts.*;
 
 /**
  * Tests for the DefaultNamespaceDecl production.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Leo Woerteler
  */
 @SuppressWarnings("all")
@@ -297,7 +297,6 @@ public class ProdDefaultNamespaceDecl extends QT3TestSet {
    */
   @org.junit.Test
   public void k2DefaultNamespaceProlog12() {
-    xquery10();
     final XQuery query = new XQuery(
       "<a xmlns=\"http://www.w3.org/2001/XMLSchema\"> {1 cast as byte} <b xmlns=\"http://www.w3.org/1999/XSL/Transform\"> {count(1), 2 cast as byte} </b> {2 cast as byte} </a>",
       ctx);
