@@ -1,12 +1,12 @@
 package org.basex.qt3ts.prod;
 
-import org.basex.tests.bxapi.XQuery;
+import org.basex.tests.bxapi.*;
 import org.basex.tests.qt3ts.*;
 
 /**
  * Tests for the DirElemConstructor (Direct Element Constructor) production.
  *
- * @author BaseX Team 2005-14, BSD License
+ * @author BaseX Team 2005-15, BSD License
  * @author Leo Woerteler
  */
 @SuppressWarnings("all")
@@ -1251,7 +1251,6 @@ public class ProdDirElemConstructor extends QT3TestSet {
    */
   @org.junit.Test
   public void k2DirectConElem53() {
-    xquery10();
     final XQuery query = new XQuery(
       "namespace {\"p\"} {\"abc\"}",
       ctx);
